[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula A"}},"key":"1D538"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula B"}},"key":"1D539"},{"key":"2102","mappings":{"default":{"default":"negrita de pizarra mayúscula C"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula D"}},"key":"1D53B"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula E"}},"key":"1D53C"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula F"}},"key":"1D53D"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula G"}},"key":"1D53E"},{"key":"210D","mappings":{"default":{"default":"negrita de pizarra mayúscula H"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula I"}},"key":"1D540"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula J"}},"key":"1D541"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula K"}},"key":"1D542"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula L"}},"key":"1D543"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula M"}},"key":"1D544"},{"key":"2115","mappings":{"default":{"default":"negrita de pizarra mayúscula N"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula O"}},"key":"1D546"},{"key":"2119","mappings":{"default":{"default":"negrita de pizarra mayúscula P"}},"category":"Lu"},{"key":"211A","mappings":{"default":{"default":"negrita de pizarra mayúscula Q"}},"category":"Lu"},{"key":"211D","mappings":{"default":{"default":"negrita de pizarra mayúscula R","defaultMP":"R mayúscula negrita"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula S"}},"key":"1D54A"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula T"}},"key":"1D54B"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula U"}},"key":"1D54C"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula V"}},"key":"1D54D"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula W"}},"key":"1D54E"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula X"}},"key":"1D54F"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula Y"}},"key":"1D550"},{"key":"2124","mappings":{"default":{"default":"negrita de pizarra mayúscula Z"}},"category":"Lu"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra a"}},"key":"1D552"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra b"}},"key":"1D553"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra c"}},"key":"1D554"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra d"}},"key":"1D555"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra e"}},"key":"1D556"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra f"}},"key":"1D557"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra g"}},"key":"1D558"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra h"}},"key":"1D559"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra i"}},"key":"1D55A"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra j"}},"key":"1D55B"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra k"}},"key":"1D55C"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra l"}},"key":"1D55D"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra m"}},"key":"1D55E"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra n"}},"key":"1D55F"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra o"}},"key":"1D560"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra p"}},"key":"1D561"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra q"}},"key":"1D562"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra r"}},"key":"1D563"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra s"}},"key":"1D564"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra t"}},"key":"1D565"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra u"}},"key":"1D566"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra v"}},"key":"1D567"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra w"}},"key":"1D568"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra x"}},"key":"1D569"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra y"}},"key":"1D56A"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra z"}},"key":"1D56B"}]
