sre.BrowserUtil.mapsForIE = {
"en/algebra.js": 
[{"locale":"en"},{"category":"Algebra","mappings":{"default":{"default":"degree"}},"key":"deg","names":["deg"]},{"category":"Algebra","mappings":{"default":{"default":"determinant","short":"det"}},"key":"det","names":["det"]},{"category":"Algebra","mappings":{"default":{"default":"dimension"}},"key":"dim","names":["dim"]},{"category":"Algebra","mappings":{"default":{"default":"homomorphism","short":"hom"}},"key":"hom","names":["hom","Hom"]},{"category":"Algebra","mappings":{"default":{"default":"kernel"}},"key":"ker","names":["ker"]},{"category":"Algebra","mappings":{"default":{"default":"trace"}},"key":"Tr","names":["Tr","tr"]}]
,
"en/elementary.js": 
[{"locale":"en"},{"category":"Elementary","mappings":{"default":{"default":"logarithm","alternative":"logarithm function","short":"log"}},"key":"log","names":["log"]},{"category":"Elementary","mappings":{"default":{"default":"natural logarithm","alternative":"natural logarithm function","short":"natural log"},"mathspeak":{"default":"ln"}},"key":"ln","names":["ln"]},{"category":"Elementary","mappings":{"default":{"default":"logarithm base 10","short":"log base 10"}},"key":"lg","names":["lg"]},{"category":"Elementary","mappings":{"default":{"default":"exponential","alternative":"exponential function","short":"exp"}},"key":"exp","names":["exp","expt"]},{"category":"Elementary","mappings":{"default":{"default":"greatest common divisor","short":"gcd"}},"key":"gcd","names":["gcd"]},{"category":"Elementary","mappings":{"default":{"default":"least common multiple","short":"lcm"}},"key":"lcm","names":["lcm"]},{"category":"Complex","mappings":{"default":{"default":"argument","short":"arg"}},"key":"arg","names":["arg"]},{"category":"Complex","mappings":{"default":{"default":"imaginary part","short":"imaginary"},"mathspeak":{"default":"im"}},"key":"im","names":["im"]},{"category":"Complex","mappings":{"default":{"default":"real part","short":"real"},"mathspeak":{"default":"re"}},"key":"re","names":["re"]},{"category":"Limits","mappings":{"default":{"default":"infimum","short":"inf"}},"key":"inf","names":["inf"]},{"category":"Limits","mappings":{"default":{"default":"limit","short":"lim"},"mathspeak":{"default":"limit"}},"key":"lim","names":["lim"]},{"category":"Limits","mappings":{"default":{"default":"infimum default","alternative":"inferior limit","short":"liminf"}},"key":"liminf","names":["lim inf","liminf"]},{"category":"Limits","mappings":{"default":{"default":"supremum limit","alternative":"superior limit","short":"limsup"}},"key":"limsup","names":["lim sup","limsup"]},{"category":"Limits","mappings":{"default":{"default":"maximum","short":"max"}},"key":"max","names":["max"]},{"category":"Limits","mappings":{"default":{"default":"minimum","short":"min"}},"key":"min","names":["min"]},{"category":"Limits","mappings":{"default":{"default":"supremum","short":"sup"}},"key":"sup","names":["sup"]},{"category":"Limits","mappings":{"default":{"default":"injective limit","alternative":"direct limit","short":"colimit"}},"key":"injlim","names":["injlim","inj lim"]},{"category":"Limits","mappings":{"default":{"default":"projective limit","alternative":"inverse limit","short":"limit"}},"key":"projlim","names":["projlim","proj lim"]},{"category":"Elementary","mappings":{"default":{"default":"modulo","short":"mod"}},"key":"mod","names":["mod"]},{"category":"Probability","mappings":{"default":{"default":"probability"}},"key":"Pr","names":["Pr"]}]
,
"en/hyperbolic.js": 
[{"locale":"en"},{"category":"Hyperbolic","mappings":{"default":{"default":"hyperbolic cosine function","short":"hyperbolic cosine"}},"key":"cosh","names":["cosh"]},{"category":"Hyperbolic","mappings":{"default":{"default":"hyperbolic cotangent function","short":"hyperbolic cotangent"}},"key":"coth","names":["coth"]},{"category":"Hyperbolic","mappings":{"default":{"default":"hyperbolic cosecant function","short":"hyperbolic cosecant"}},"key":"csch","names":["csch"]},{"category":"Hyperbolic","mappings":{"default":{"default":"hyperbolic secant function","short":"hyperbolic secant"}},"key":"sech","names":["sech"]},{"category":"Hyperbolic","mappings":{"default":{"default":"hyperbolic sine function","short":"hyperbolic sine"}},"key":"sinh","names":["sinh"]},{"category":"Hyperbolic","mappings":{"default":{"default":"hyperbolic tangent function","short":"hyperbolic tangent"}},"key":"tanh","names":["tanh"]},{"category":"Area","mappings":{"default":{"default":"inverse hyperbolic cosine function","alternative":"area hyperbolic cosine function","short":"area hyperbolic cosine"}},"key":"arcosh","names":["arcosh","arccosh"]},{"category":"Area","mappings":{"default":{"default":"inverse hyperbolic cotangent function","alternative":"area hyperbolic cotangent function","short":"area hyperbolic cotangent"}},"key":"arcoth","names":["arcoth","arccoth"]},{"category":"Area","mappings":{"default":{"default":"inverse hyperbolic cosecant function","alternative":"area hyperbolic cosecant function","short":"area hyperbolic cosecant"}},"key":"arcsch","names":["arcsch","arccsch"]},{"category":"Area","mappings":{"default":{"default":"inverse hyperbolic secant function","alternative":"area hyperbolic secant function","short":"area hyperbolic secant"}},"key":"arsech","names":["arsech","arcsech"]},{"category":"Area","mappings":{"default":{"default":"inverse hyperbolic sine function","alternative":"area hyperbolic sine function","short":"area hyperbolic sine"}},"key":"arsinh","names":["arsinh","arcsinh"]},{"category":"Area","mappings":{"default":{"default":"inverse hyperbolic tangent function","alternative":"area hyperbolic tangent function","short":"area hyperbolic tangent"}},"key":"artanh","names":["artanh","arctanh"]}]
,
"en/trigonometry.js": 
[{"locale":"en"},{"category":"Trigonometric","mappings":{"default":{"default":"cosine function","short":"cosine"}},"key":"cos","names":["cos","cosine"]},{"category":"Trigonometric","mappings":{"default":{"default":"cotangent function","short":"cotangent"}},"key":"cot","names":["cot"]},{"category":"Trigonometric","mappings":{"default":{"default":"cosecant function","short":"cosecant"}},"key":"csc","names":["csc"]},{"category":"Trigonometric","mappings":{"default":{"default":"secant function","short":"secant"}},"key":"sec","names":["sec"]},{"category":"Trigonometric","mappings":{"default":{"default":"sine function","alternative":"sine function","short":"sine"}},"key":"sin","names":["sin","sine"]},{"category":"Trigonometric","mappings":{"default":{"default":"tangent function","short":"tangent"}},"key":"tan","names":["tan"]},{"category":"Cyclometric","mappings":{"default":{"default":"inverse cosine function","alternative":"arc cosine function","short":"arc cosine"}},"key":"arccos","names":["arccos"]},{"category":"Cyclometric","mappings":{"default":{"default":"inverse cotangent function","alternative":"arc cotangent function","short":"arc cotangent"}},"key":"arccot","names":["arccot"]},{"category":"Cyclometric","mappings":{"default":{"default":"inverse cosecant function","alternative":"arc cosecant function","short":"arc cosecant"}},"key":"arccsc","names":["arccsc"]},{"category":"Cyclometric","mappings":{"default":{"default":"inverse secant function","alternative":"arc secant function","short":"arc secant"}},"key":"arcsec","names":["arcsec"]},{"category":"Cyclometric","mappings":{"default":{"default":"inverse sine function","alternative":"arc sine function","short":"arc sine"}},"key":"arcsin","names":["arcsin"]},{"category":"Cyclometric","mappings":{"default":{"default":"inverse tangent function","alternative":"arc tangent function","short":"arc tangent"}},"key":"arctan","names":["arctan"]}]
,
"en/greek-capital.js": 
[{"locale":"en"},{"category":"Lu","key":"0391","mappings":{"default":{"default":"greek capital letter alpha","short":"cap alpha"},"mathspeak":{"default":"upper Alpha"}}},{"category":"Lu","key":"0392","mappings":{"default":{"default":"greek capital letter beta","short":"cap beta"},"mathspeak":{"default":"upper Beta"}}},{"category":"Lu","key":"0393","mappings":{"default":{"default":"greek capital letter gamma","short":"cap gamma"},"mathspeak":{"default":"upper Gamma"}}},{"category":"Lu","key":"0394","mappings":{"default":{"default":"greek capital letter delta","short":"cap delta"},"mathspeak":{"default":"upper Delta"}}},{"category":"Lu","key":"0395","mappings":{"default":{"default":"greek capital letter epsilon","short":"cap epsilon"},"mathspeak":{"default":"upper Epsilon"}}},{"category":"Lu","key":"0396","mappings":{"default":{"default":"greek capital letter zeta","short":"cap zeta"},"mathspeak":{"default":"upper Zeta"}}},{"category":"Lu","key":"0397","mappings":{"default":{"default":"greek capital letter eta","short":"cap eta"},"mathspeak":{"default":"upper Eta"}}},{"category":"Lu","key":"0398","mappings":{"default":{"default":"greek capital letter theta","short":"cap theta"},"mathspeak":{"default":"upper Theta"}}},{"category":"Lu","key":"0399","mappings":{"default":{"default":"greek capital letter iota","short":"cap iota"},"mathspeak":{"default":"upper Iota"}}},{"category":"Lu","key":"039A","mappings":{"default":{"default":"greek capital letter kappa","short":"cap kappa"},"mathspeak":{"default":"upper Kappa"}}},{"category":"Lu","key":"039B","mappings":{"default":{"default":"greek capital letter lamda","alternative":"greek capital letter lambda","short":"cap lamda"},"mathspeak":{"default":"upper Lamda"}}},{"category":"Lu","key":"039C","mappings":{"default":{"default":"greek capital letter mu","short":"cap mu"},"mathspeak":{"default":"upper Mu"}}},{"category":"Lu","key":"039D","mappings":{"default":{"default":"greek capital letter nu","short":"cap nu"},"mathspeak":{"default":"upper Nu"}}},{"category":"Lu","key":"039E","mappings":{"default":{"default":"greek capital letter xi","short":"cap xi"},"mathspeak":{"default":"upper Xi"}}},{"category":"Lu","key":"039F","mappings":{"default":{"default":"greek capital letter omicron","short":"cap omicron"},"mathspeak":{"default":"upper Omicron"}}},{"category":"Lu","key":"03A0","mappings":{"default":{"default":"greek capital letter pi","short":"cap pi"},"mathspeak":{"default":"upper Pi"}}},{"category":"Lu","key":"03A1","mappings":{"default":{"default":"greek capital letter rho","short":"cap rho"},"mathspeak":{"default":"upper Rho"}}},{"category":"Lu","key":"03A3","mappings":{"default":{"default":"greek capital letter sigma","short":"cap sigma"},"mathspeak":{"default":"upper Sigma"}}},{"category":"Lu","key":"03A4","mappings":{"default":{"default":"greek capital letter tau","short":"cap tau"},"mathspeak":{"default":"upper Tau"}}},{"category":"Lu","key":"03A5","mappings":{"default":{"default":"greek capital letter upsilon","short":"cap upsilon"},"mathspeak":{"default":"upper Upsilon"}}},{"category":"Lu","key":"03A6","mappings":{"default":{"default":"greek capital letter phi","short":"cap phi"},"mathspeak":{"default":"upper Phi"}}},{"category":"Lu","key":"03A7","mappings":{"default":{"default":"greek capital letter chi","short":"cap chi"},"mathspeak":{"default":"upper Chi"}}},{"category":"Lu","key":"03A8","mappings":{"default":{"default":"greek capital letter psi","short":"cap psi"},"mathspeak":{"default":"upper Psi"}}},{"category":"Lu","key":"03A9","mappings":{"default":{"default":"greek capital letter omega","short":"cap omega"},"mathspeak":{"default":"upper Omega"}}}]
,
"en/greek-mathfonts-bold.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital alpha","alternative":"bold capital alpha","short":"bold cap alpha"},"mathspeak":{"default":"bold upper Alpha"}},"key":"1D6A8"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital beta","alternative":"bold capital beta","short":"bold cap beta"},"mathspeak":{"default":"bold upper Beta"}},"key":"1D6A9"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital gamma","alternative":"bold capital gamma","short":"bold cap gamma"},"mathspeak":{"default":"bold upper Gamma"}},"key":"1D6AA"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital delta","alternative":"bold capital delta","short":"bold cap delta"},"mathspeak":{"default":"bold upper Delta"}},"key":"1D6AB"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital epsilon","alternative":"bold capital epsilon","short":"bold cap epsilon"},"mathspeak":{"default":"bold upper Epsilon"}},"key":"1D6AC"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital zeta","alternative":"bold capital zeta","short":"bold cap zeta"},"mathspeak":{"default":"bold upper Zeta"}},"key":"1D6AD"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital eta","alternative":"bold capital eta","short":"bold cap eta"},"mathspeak":{"default":"bold upper Eta"}},"key":"1D6AE"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital theta","alternative":"bold capital theta","short":"bold cap theta"},"mathspeak":{"default":"bold upper Theta"}},"key":"1D6AF"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital iota","alternative":"bold capital iota","short":"bold cap iota"},"mathspeak":{"default":"bold upper Iota"}},"key":"1D6B0"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital kappa","alternative":"bold capital kappa","short":"bold cap kappa"},"mathspeak":{"default":"bold upper Kappa"}},"key":"1D6B1"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital lamda","alternative":"bold capital lamda","short":"bold cap lamda"},"mathspeak":{"default":"bold upper Lamda"}},"key":"1D6B2"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital mu","alternative":"bold capital mu","short":"bold cap mu"},"mathspeak":{"default":"bold upper Mu"}},"key":"1D6B3"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital nu","alternative":"bold capital nu","short":"bold cap nu"},"mathspeak":{"default":"bold upper Nu"}},"key":"1D6B4"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital xi","alternative":"bold capital xi","short":"bold cap xi"},"mathspeak":{"default":"bold upper Xi"}},"key":"1D6B5"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital omicron","alternative":"bold capital omicron","short":"bold cap omicron"},"mathspeak":{"default":"bold upper Omicron"}},"key":"1D6B6"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital pi","alternative":"bold capital pi","short":"bold cap pi"},"mathspeak":{"default":"bold upper Pi"}},"key":"1D6B7"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital rho","alternative":"bold capital rho","short":"bold cap rho"},"mathspeak":{"default":"bold upper Rho"}},"key":"1D6B8"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital sigma","alternative":"bold capital sigma","short":"bold cap sigma"},"mathspeak":{"default":"bold upper Sigma"}},"key":"1D6BA"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital tau","alternative":"bold capital tau","short":"bold cap tau"},"mathspeak":{"default":"bold upper Tau"}},"key":"1D6BB"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital upsilon","alternative":"bold capital upsilon","short":"bold cap upsilon"},"mathspeak":{"default":"bold upper Upsilon"}},"key":"1D6BC"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital phi","alternative":"bold capital phi","short":"bold cap phi"},"mathspeak":{"default":"bold upper Phi"}},"key":"1D6BD"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital chi","alternative":"bold capital chi","short":"bold cap chi"},"mathspeak":{"default":"bold upper Chi"}},"key":"1D6BE"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital psi","alternative":"bold capital psi","short":"bold cap psi"},"mathspeak":{"default":"bold upper Psi"}},"key":"1D6BF"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital omega","alternative":"bold capital omega","short":"bold cap omega"},"mathspeak":{"default":"bold upper Omega"}},"key":"1D6C0"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small alpha","alternative":"bold small alpha","short":"bold alpha"}},"key":"1D6C2"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small beta","alternative":"bold small beta","short":"bold beta"}},"key":"1D6C3"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small gamma","alternative":"bold small gamma","short":"bold gamma"}},"key":"1D6C4"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small delta","alternative":"bold small delta","short":"bold delta"}},"key":"1D6C5"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small epsilon","alternative":"bold small epsilon","short":"bold epsilon"}},"key":"1D6C6"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small zeta","alternative":"bold small zeta","short":"bold zeta"}},"key":"1D6C7"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small eta","alternative":"bold small eta","short":"bold eta"}},"key":"1D6C8"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small theta","alternative":"bold small theta","short":"bold theta"}},"key":"1D6C9"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small iota","alternative":"bold small iota","short":"bold iota"}},"key":"1D6CA"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small kappa","alternative":"bold small kappa","short":"bold kappa"}},"key":"1D6CB"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small lamda","alternative":"bold small lamda","short":"bold lamda"}},"key":"1D6CC"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small mu","alternative":"bold small mu","short":"bold mu"}},"key":"1D6CD"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small nu","alternative":"bold small nu","short":"bold nu"}},"key":"1D6CE"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small xi","alternative":"bold small xi","short":"bold xi"}},"key":"1D6CF"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small omicron","alternative":"bold small omicron","short":"bold omicron"}},"key":"1D6D0"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small pi","alternative":"bold small pi","short":"bold pi"}},"key":"1D6D1"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small rho","alternative":"bold small rho","short":"bold rho"}},"key":"1D6D2"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small final sigma","alternative":"bold small final sigma","short":"bold final sigma"}},"key":"1D6D3"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small sigma","alternative":"bold small sigma","short":"bold sigma"}},"key":"1D6D4"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small tau","alternative":"bold small tau","short":"bold tau"}},"key":"1D6D5"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small upsilon","alternative":"bold small upsilon","short":"bold upsilon"}},"key":"1D6D6"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small phi","alternative":"bold small phi","short":"bold phi"}},"key":"1D6D7"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small chi","alternative":"bold small chi","short":"bold chi"}},"key":"1D6D8"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small psi","alternative":"bold small psi","short":"bold psi"}},"key":"1D6D9"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small omega","alternative":"bold small omega","short":"bold omega"}},"key":"1D6DA"}]
,
"en/greek-mathfonts-italic.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital alpha","alternative":"italic capital alpha","short":"italic cap alpha"},"mathspeak":{"default":"italic upper Alpha"}},"key":"1D6E2"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital beta","alternative":"italic capital beta","short":"italic cap beta"},"mathspeak":{"default":"italic upper Beta"}},"key":"1D6E3"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital gamma","alternative":"italic capital gamma","short":"italic cap gamma"},"mathspeak":{"default":"italic upper Gamma"}},"key":"1D6E4"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital delta","alternative":"italic capital delta","short":"italic cap delta"},"mathspeak":{"default":"italic upper Delta"}},"key":"1D6E5"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital epsilon","alternative":"italic capital epsilon","short":"italic cap epsilon"},"mathspeak":{"default":"italic upper Epsilon"}},"key":"1D6E6"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital zeta","alternative":"italic capital zeta","short":"italic cap zeta"},"mathspeak":{"default":"italic upper Zeta"}},"key":"1D6E7"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital eta","alternative":"italic capital eta","short":"italic cap eta"},"mathspeak":{"default":"italic upper Eta"}},"key":"1D6E8"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital theta","alternative":"italic capital theta","short":"italic cap theta"},"mathspeak":{"default":"italic upper Theta"}},"key":"1D6E9"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital iota","alternative":"italic capital iota","short":"italic cap iota"},"mathspeak":{"default":"italic upper Iota"}},"key":"1D6EA"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital kappa","alternative":"italic capital kappa","short":"italic cap kappa"},"mathspeak":{"default":"italic upper Kappa"}},"key":"1D6EB"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital lamda","alternative":"italic capital lamda","short":"italic cap lamda"},"mathspeak":{"default":"italic upper Lamda"}},"key":"1D6EC"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital mu","alternative":"italic capital mu","short":"italic cap mu"},"mathspeak":{"default":"italic upper Mu"}},"key":"1D6ED"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital nu","alternative":"italic capital nu","short":"italic cap nu"},"mathspeak":{"default":"italic upper Nu"}},"key":"1D6EE"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital xi","alternative":"italic capital xi","short":"italic cap xi"},"mathspeak":{"default":"italic upper Xi"}},"key":"1D6EF"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital omicron","alternative":"italic capital omicron","short":"italic cap omicron"},"mathspeak":{"default":"italic upper Omicron"}},"key":"1D6F0"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital pi","alternative":"italic capital pi","short":"italic cap pi"},"mathspeak":{"default":"italic upper Pi"}},"key":"1D6F1"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital rho","alternative":"italic capital rho","short":"italic cap rho"},"mathspeak":{"default":"italic upper Rho"}},"key":"1D6F2"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital sigma","alternative":"italic capital sigma","short":"italic cap sigma"},"mathspeak":{"default":"italic upper Sigma"}},"key":"1D6F4"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital tau","alternative":"italic capital tau","short":"italic cap tau"},"mathspeak":{"default":"italic upper Tau"}},"key":"1D6F5"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital upsilon","alternative":"italic capital upsilon","short":"italic cap upsilon"},"mathspeak":{"default":"italic upper Upsilon"}},"key":"1D6F6"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital phi","alternative":"italic capital phi","short":"italic cap phi"},"mathspeak":{"default":"italic upper Phi"}},"key":"1D6F7"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital chi","alternative":"italic capital chi","short":"italic cap chi"},"mathspeak":{"default":"italic upper Chi"}},"key":"1D6F8"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital psi","alternative":"italic capital psi","short":"italic cap psi"},"mathspeak":{"default":"italic upper Psi"}},"key":"1D6F9"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital omega","alternative":"italic capital omega","short":"italic cap omega"},"mathspeak":{"default":"italic upper Omega"}},"key":"1D6FA"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small alpha","alternative":"italic small alpha","short":"italic alpha"}},"key":"1D6FC"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small beta","alternative":"italic small beta","short":"italic beta"}},"key":"1D6FD"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small gamma","alternative":"italic small gamma","short":"italic gamma"}},"key":"1D6FE"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small delta","alternative":"italic small delta","short":"italic delta"}},"key":"1D6FF"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small epsilon","alternative":"italic small epsilon","short":"italic epsilon"}},"key":"1D700"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small zeta","alternative":"italic small zeta","short":"italic zeta"}},"key":"1D701"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small eta","alternative":"italic small eta","short":"italic eta"}},"key":"1D702"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small theta","alternative":"italic small theta","short":"italic theta"}},"key":"1D703"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small iota","alternative":"italic small iota","short":"italic iota"}},"key":"1D704"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small kappa","alternative":"italic small kappa","short":"italic kappa"}},"key":"1D705"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small lamda","alternative":"italic small lamda","short":"italic lamda"}},"key":"1D706"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small mu","alternative":"italic small mu","short":"italic mu"}},"key":"1D707"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small nu","alternative":"italic small nu","short":"italic nu"}},"key":"1D708"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small xi","alternative":"italic small xi","short":"italic xi"}},"key":"1D709"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small omicron","alternative":"italic small omicron","short":"italic omicron"}},"key":"1D70A"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small pi","alternative":"italic small pi","short":"italic pi"}},"key":"1D70B"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small rho","alternative":"italic small rho","short":"italic rho"}},"key":"1D70C"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small final sigma","alternative":"italic small final sigma","short":"italic final sigma"}},"key":"1D70D"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small sigma","alternative":"italic small sigma","short":"italic sigma"}},"key":"1D70E"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small tau","alternative":"italic small tau","short":"italic tau"}},"key":"1D70F"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small upsilon","alternative":"italic small upsilon","short":"italic upsilon"}},"key":"1D710"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small phi","alternative":"italic small phi","short":"italic phi"}},"key":"1D711"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small chi","alternative":"italic small chi","short":"italic chi"}},"key":"1D712"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small psi","alternative":"italic small psi","short":"italic psi"}},"key":"1D713"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small omega","alternative":"italic small omega","short":"italic omega"}},"key":"1D714"}]
,
"en/greek-mathfonts-sans-serif-bold.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital alpha","alternative":"sans serif bold capital alpha","short":"sans serif bold cap alpha"},"mathspeak":{"default":"sans serif bold upper Alpha"}},"key":"1D756"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital beta","alternative":"sans serif bold capital beta","short":"sans serif bold cap beta"},"mathspeak":{"default":"sans serif bold upper Beta"}},"key":"1D757"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital gamma","alternative":"sans serif bold capital gamma","short":"sans serif bold cap gamma"},"mathspeak":{"default":"sans serif bold upper Gamma"}},"key":"1D758"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital delta","alternative":"sans serif bold capital delta","short":"sans serif bold cap delta"},"mathspeak":{"default":"sans serif bold upper Delta"}},"key":"1D759"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital epsilon","alternative":"sans serif bold capital epsilon","short":"sans serif bold cap epsilon"},"mathspeak":{"default":"sans serif bold upper Epsilon"}},"key":"1D75A"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital zeta","alternative":"sans serif bold capital zeta","short":"sans serif bold cap zeta"},"mathspeak":{"default":"sans serif bold upper Zeta"}},"key":"1D75B"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital eta","alternative":"sans serif bold capital eta","short":"sans serif bold cap eta"},"mathspeak":{"default":"sans serif bold upper Eta"}},"key":"1D75C"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital theta","alternative":"sans serif bold capital theta","short":"sans serif bold cap theta"},"mathspeak":{"default":"sans serif bold upper Theta"}},"key":"1D75D"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital iota","alternative":"sans serif bold capital iota","short":"sans serif bold cap iota"},"mathspeak":{"default":"sans serif bold upper Iota"}},"key":"1D75E"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital kappa","alternative":"sans serif bold capital kappa","short":"sans serif bold cap kappa"},"mathspeak":{"default":"sans serif bold upper Kappa"}},"key":"1D75F"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital lamda","alternative":"sans serif bold capital lamda","short":"sans serif bold cap lamda"},"mathspeak":{"default":"sans serif bold upper Lamda"}},"key":"1D760"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital mu","alternative":"sans serif bold capital mu","short":"sans serif bold cap mu"},"mathspeak":{"default":"sans serif bold upper Mu"}},"key":"1D761"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital nu","alternative":"sans serif bold capital nu","short":"sans serif bold cap nu"},"mathspeak":{"default":"sans serif bold upper Nu"}},"key":"1D762"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital xi","alternative":"sans serif bold capital xi","short":"sans serif bold cap xi"},"mathspeak":{"default":"sans serif bold upper Xi"}},"key":"1D763"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital omicron","alternative":"sans serif bold capital omicron","short":"sans serif bold cap omicron"},"mathspeak":{"default":"sans serif bold upper Omicron"}},"key":"1D764"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital pi","alternative":"sans serif bold capital pi","short":"sans serif bold cap pi"},"mathspeak":{"default":"sans serif bold upper Pi"}},"key":"1D765"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital rho","alternative":"sans serif bold capital rho","short":"sans serif bold cap rho"},"mathspeak":{"default":"sans serif bold upper Rho"}},"key":"1D766"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital sigma","alternative":"sans serif bold capital sigma","short":"sans serif bold cap sigma"},"mathspeak":{"default":"sans serif bold upper Sigma"}},"key":"1D768"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital tau","alternative":"sans serif bold capital tau","short":"sans serif bold cap tau"},"mathspeak":{"default":"sans serif bold upper Tau"}},"key":"1D769"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital upsilon","alternative":"sans serif bold capital upsilon","short":"sans serif bold cap upsilon"},"mathspeak":{"default":"sans serif bold upper Upsilon"}},"key":"1D76A"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital phi","alternative":"sans serif bold capital phi","short":"sans serif bold cap phi"},"mathspeak":{"default":"sans serif bold upper Phi"}},"key":"1D76B"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital chi","alternative":"sans serif bold capital chi","short":"sans serif bold cap chi"},"mathspeak":{"default":"sans serif bold upper Chi"}},"key":"1D76C"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital psi","alternative":"sans serif bold capital psi","short":"sans serif bold cap psi"},"mathspeak":{"default":"sans serif bold upper Psi"}},"key":"1D76D"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital omega","alternative":"sans serif bold capital omega","short":"sans serif bold cap omega"},"mathspeak":{"default":"sans serif bold upper Omega"}},"key":"1D76E"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small alpha","alternative":"sans serif bold small alpha","short":"sans serif bold alpha"}},"key":"1D770"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small beta","alternative":"sans serif bold small beta","short":"sans serif bold beta"}},"key":"1D771"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small gamma","alternative":"sans serif bold small gamma","short":"sans serif bold gamma"}},"key":"1D772"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small delta","alternative":"sans serif bold small delta","short":"sans serif bold delta"}},"key":"1D773"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small epsilon","alternative":"sans serif bold small epsilon","short":"sans serif bold epsilon"}},"key":"1D774"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small zeta","alternative":"sans serif bold small zeta","short":"sans serif bold zeta"}},"key":"1D775"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small eta","alternative":"sans serif bold small eta","short":"sans serif bold eta"}},"key":"1D776"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small theta","alternative":"sans serif bold small theta","short":"sans serif bold theta"}},"key":"1D777"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small iota","alternative":"sans serif bold small iota","short":"sans serif bold iota"}},"key":"1D778"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small kappa","alternative":"sans serif bold small kappa","short":"sans serif bold kappa"}},"key":"1D779"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small lamda","alternative":"sans serif bold small lamda","short":"sans serif bold lamda"}},"key":"1D77A"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small mu","alternative":"sans serif bold small mu","short":"sans serif bold mu"}},"key":"1D77B"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small nu","alternative":"sans serif bold small nu","short":"sans serif bold nu"}},"key":"1D77C"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small xi","alternative":"sans serif bold small xi","short":"sans serif bold xi"}},"key":"1D77D"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small omicron","alternative":"sans serif bold small omicron","short":"sans serif bold omicron"}},"key":"1D77E"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small pi","alternative":"sans serif bold small pi","short":"sans serif bold pi"}},"key":"1D77F"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small rho","alternative":"sans serif bold small rho","short":"sans serif bold rho"}},"key":"1D780"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small final sigma","alternative":"sans serif bold small final sigma","short":"sans serif bold final sigma"}},"key":"1D781"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small sigma","alternative":"sans serif bold small sigma","short":"sans serif bold sigma"}},"key":"1D782"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small tau","alternative":"sans serif bold small tau","short":"sans serif bold tau"}},"key":"1D783"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small upsilon","alternative":"sans serif bold small upsilon","short":"sans serif bold upsilon"}},"key":"1D784"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small phi","alternative":"sans serif bold small phi","short":"sans serif bold phi"}},"key":"1D785"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small chi","alternative":"sans serif bold small chi","short":"sans serif bold chi"}},"key":"1D786"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small psi","alternative":"sans serif bold small psi","short":"sans serif bold psi"}},"key":"1D787"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold small omega","alternative":"sans serif bold small omega","short":"sans serif bold omega"}},"key":"1D788"}]
,
"en/greek-scripts.js": 
[{"locale":"en"},{"category":"Ll","key":"1D26","mappings":{"default":{"default":"greek letter small capital gamma","alternative":"greek letter gamma","short":"small cap gamma"},"mathspeak":{"default":"small upper Gamma"}}},{"category":"Ll","key":"1D27","mappings":{"default":{"default":"greek letter small capital lamda","alternative":"greek letter lamda","short":"small cap lamda"},"mathspeak":{"default":"small upper Lamda"}}},{"category":"Ll","key":"1D28","mappings":{"default":{"default":"greek letter small capital pi","alternative":"greek letter pi","short":"small cap pi"},"mathspeak":{"default":"small upper Pi"}}},{"category":"Ll","key":"1D29","mappings":{"default":{"default":"greek letter small capital rho","alternative":"greek letter rho","short":"small cap rho"},"mathspeak":{"default":"small upper Rho"}}},{"category":"Ll","key":"1D2A","mappings":{"default":{"default":"greek letter small capital psi","alternative":"greek letter psi","short":"small cap psi"},"mathspeak":{"default":"small upper Psi"}}},{"category":"Lm","key":"1D5E","mappings":{"default":{"default":"modifier letter small greek gamma","alternative":"greek letter superscript gamma","short":"superscript gamma"}}},{"category":"Lm","key":"1D60","mappings":{"default":{"default":"modifier letter small greek phi","alternative":"greek letter superscript phi","short":"superscript phi"}}},{"category":"Lm","key":"1D66","mappings":{"default":{"default":"greek subscript small letter beta","short":"subscript beta"}}},{"category":"Lm","key":"1D67","mappings":{"default":{"default":"greek subscript small letter gamma","alternative":"greek letter gamma","short":"subscript gamma"}}},{"category":"Lm","key":"1D68","mappings":{"default":{"default":"greek subscript small letter rho","alternative":"greek letter rho","short":"subscript rho"}}},{"category":"Lm","key":"1D69","mappings":{"default":{"default":"greek subscript small letter phi","alternative":"greek letter phi","short":"subscript phi"}}},{"category":"Lm","key":"1D6A","mappings":{"default":{"default":"greek subscript small letter chi","alternative":"greek letter chi","short":"subscript chi"}}}]
,
"en/greek-small.js": 
[{"locale":"en"},{"category":"Ll","key":"03B1","mappings":{"default":{"default":"greek small letter alpha","short":"alpha"}}},{"category":"Ll","key":"03B2","mappings":{"default":{"default":"greek small letter beta","short":"beta"}}},{"category":"Ll","key":"03B3","mappings":{"default":{"default":"greek small letter gamma","short":"gamma"}}},{"category":"Ll","key":"03B4","mappings":{"default":{"default":"greek small letter delta","short":"delta"}}},{"category":"Ll","key":"03B5","mappings":{"default":{"default":"greek small letter epsilon","short":"epsilon"}}},{"category":"Ll","key":"03B6","mappings":{"default":{"default":"greek small letter zeta","short":"zeta"}}},{"category":"Ll","key":"03B7","mappings":{"default":{"default":"greek small letter eta","short":"eta"}}},{"category":"Ll","key":"03B8","mappings":{"default":{"default":"greek small letter theta","short":"theta"}}},{"category":"Ll","key":"03B9","mappings":{"default":{"default":"greek small letter iota","short":"iota"}}},{"category":"Ll","key":"03BA","mappings":{"default":{"default":"greek small letter kappa","short":"kappa"}}},{"category":"Ll","key":"03BB","mappings":{"default":{"default":"greek small letter lamda","alternative":"greek small letter lambda","short":"lamda"}}},{"category":"Ll","key":"03BC","mappings":{"default":{"default":"greek small letter mu","short":"mu"}}},{"category":"Ll","key":"03BD","mappings":{"default":{"default":"greek small letter nu","short":"nu"}}},{"category":"Ll","key":"03BE","mappings":{"default":{"default":"greek small letter xi","short":"xi"}}},{"category":"Ll","key":"03BF","mappings":{"default":{"default":"greek small letter omicron","short":"omicron"}}},{"category":"Ll","key":"03C0","mappings":{"default":{"default":"greek small letter pi","short":"pi"}}},{"category":"Ll","key":"03C1","mappings":{"default":{"default":"greek small letter rho","short":"rho"}}},{"category":"Ll","key":"03C2","mappings":{"default":{"default":"greek small letter final sigma","short":"final sigma"}}},{"category":"Ll","key":"03C3","mappings":{"default":{"default":"greek small letter sigma","short":"sigma"}}},{"category":"Ll","key":"03C4","mappings":{"default":{"default":"greek small letter tau","short":"tau"}}},{"category":"Ll","key":"03C5","mappings":{"default":{"default":"greek small letter upsilon","short":"upsilon"}}},{"category":"Ll","key":"03C6","mappings":{"default":{"default":"greek small letter phi","short":"phi"}}},{"category":"Ll","key":"03C7","mappings":{"default":{"default":"greek small letter chi","short":"chi"}}},{"category":"Ll","key":"03C8","mappings":{"default":{"default":"greek small letter psi","short":"psi"}}},{"category":"Ll","key":"03C9","mappings":{"default":{"default":"greek small letter omega","short":"omega"}}}]
,
"en/greek-symbols.js": 
[{"locale":"en"},{"category":"Ll","mappings":{"default":{"default":"greek beta symbol","alternative":"greek small letter curled beta","short":"beta"}},"key":"03D0"},{"category":"Ll","mappings":{"default":{"default":"greek theta symbol","alternative":"greek small letter script theta","short":"theta"}},"key":"03D1"},{"category":"Ll","mappings":{"default":{"default":"greek phi symbol","alternative":"greek small letter script phi","short":"phi"}},"key":"03D5"},{"category":"Ll","mappings":{"default":{"default":"greek pi symbol","alternative":"greek small letter omega pi","short":"pi"}},"key":"03D6"},{"category":"Ll","mappings":{"default":{"default":"greek kai symbol","short":"kai"}},"key":"03D7"},{"category":"Ll","mappings":{"default":{"default":"greek kappa symbol","alternative":"greek small letter script kappa","short":"kappa"}},"key":"03F0"},{"category":"Ll","mappings":{"default":{"default":"greek rho symbol","alternative":"greek small letter tailed rho","short":"rho"}},"key":"03F1"},{"category":"Ll","mappings":{"default":{"default":"greek lunate epsilon symbol","short":"epsilon"}},"key":"03F5"},{"category":"Sm","mappings":{"default":{"default":"greek reversed lunate epsilon symbol","short":"reversed epsilon"}},"key":"03F6"},{"category":"Lu","mappings":{"default":{"default":"greek capital theta symbol","short":"cap theta"},"mathspeak":{"default":"upper Theta"}},"key":"03F4"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital theta symbol","alternative":"bold capital theta","short":"bold cap theta"},"mathspeak":{"default":"bold upper Theta"}},"key":"1D6B9"},{"category":"Lu","mappings":{"default":{"default":"mathematical italic capital theta symbol","alternative":"italic capital theta","short":"italic cap theta"},"mathspeak":{"default":"italic upper Theta"}},"key":"1D6F3"},{"category":"Lu","mappings":{"default":{"default":"mathematical sans serif bold capital theta symbol","alternative":"sans serif bold capital theta","short":"sans serif bold cap theta"},"mathspeak":{"default":"sans serif bold upper Theta"}},"key":"1D767"},{"category":"Sm","mappings":{"default":{"default":"mathematical bold nabla","alternative":"bold nabla"}},"key":"1D6C1"},{"category":"Sm","mappings":{"default":{"default":"mathematical bold partial differential","alternative":"bold partial differential","short":"bold partial differential"}},"key":"1D6DB"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold epsilon symbol","alternative":"bold epsilon","short":"bold epsilon"}},"key":"1D6DC"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold theta symbol","alternative":"bold theta","short":"bold theta"}},"key":"1D6DD"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold kappa symbol","alternative":"bold kappa","short":"bold kappa"}},"key":"1D6DE"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold phi symbol","alternative":"bold phi","short":"bold phi"}},"key":"1D6DF"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold rho symbol","alternative":"bold rho","short":"bold rho"}},"key":"1D6E0"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold pi symbol","alternative":"bold pi","short":"bold pi"}},"key":"1D6E1"},{"category":"Sm","mappings":{"default":{"default":"mathematical italic nabla","alternative":"italic nabla","short":"italic nabla"}},"key":"1D6FB"},{"category":"Sm","mappings":{"default":{"default":"mathematical italic partial differential","alternative":"italic partial differential","short":"italic partial differential"}},"key":"1D715"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic epsilon symbol","alternative":"italic epsilon","short":"italic epsilon"}},"key":"1D716"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic theta symbol","alternative":"italic theta","short":"italic theta"}},"key":"1D717"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic kappa symbol","alternative":"italic kappa","short":"italic kappa"}},"key":"1D718"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic phi symbol","alternative":"italic phi","short":"italic phi"}},"key":"1D719"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic rho symbol","alternative":"italic rho","short":"italic rho"}},"key":"1D71A"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic pi symbol","alternative":"italic pi","short":"italic pi"}},"key":"1D71B"},{"category":"Sm","mappings":{"default":{"default":"mathematical sans serif bold nabla","alternative":"sans serif bold nabla","short":"sans serif bold nabla"}},"key":"1D76F"},{"category":"Sm","mappings":{"default":{"default":"mathematical sans serif bold partial differential","alternative":"sans serif bold partial differential","short":"sans serif bold partial differential"}},"key":"1D789"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold epsilon symbol","alternative":"sans serif bold epsilon","short":"sans serif bold epsilon"}},"key":"1D78A"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold theta symbol","alternative":"sans serif bold theta","short":"sans serif bold theta"}},"key":"1D78B"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold kappa symbol","alternative":"sans serif bold kappa","short":"sans serif bold kappa"}},"key":"1D78C"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold phi symbol","alternative":"sans serif bold phi","short":"sans serif bold phi"}},"key":"1D78D"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold rho symbol","alternative":"sans serif bold rho","short":"sans serif bold rho"}},"key":"1D78E"},{"category":"Ll","mappings":{"default":{"default":"mathematical sans serif bold pi symbol","alternative":"sans serif bold pi","short":"sans serif bold pi"}},"key":"1D78F"},{"category":"Lu","mappings":{"default":{"default":"mathematical bold capital digamma","alternative":"bold capital digamma","short":"bold cap digamma"},"mathspeak":{"default":"bold upper Digamma"}},"key":"1D7CA"},{"category":"Ll","mappings":{"default":{"default":"mathematical bold small digamma","alternative":"bold small digamma","short":"bold digamma"}},"key":"1D7CB"}]
,
"en/hebrew_letters.js": 
[{"locale":"en"},{"category":"Lo","mappings":{"default":{"default":"alef symbol","alternative":"first transfinite cardinal","short":"alef"}},"key":"2135"},{"category":"Lo","mappings":{"default":{"default":"bet symbol","alternative":"second transfinite cardinal","short":"bet"}},"key":"2136"},{"category":"Lo","mappings":{"default":{"default":"gimel symbol","alternative":"third transfinite cardinal","short":"gimel"}},"key":"2137"},{"category":"Lo","mappings":{"default":{"default":"dalet symbol","alternative":"fourth transfinite cardinal","short":"dalet"}},"key":"2138"}]
,
"en/latin-lower-double-accent.js": 
[{"locale":"en"},{"category":"Ll","key":"01D6","mappings":{"default":{"default":"latin small letter u with diaeresis and macron","alternative":"latin small letter u double overdot overbar","short":"u double overdot overbar"}}},{"category":"Ll","key":"01D8","mappings":{"default":{"default":"latin small letter u with diaeresis and acute","alternative":"latin small letter u double overdot acute","short":"u double overdot acute"}}},{"category":"Ll","key":"01DA","mappings":{"default":{"default":"latin small letter u with diaeresis and caron","alternative":"latin small letter u double overdot hacek","short":"u double overdot caron"}}},{"category":"Ll","key":"01DC","mappings":{"default":{"default":"latin small letter u with diaeresis and grave","alternative":"latin small letter u double overdot grave","short":"u double overdot grave"}}},{"category":"Ll","key":"01DF","mappings":{"default":{"default":"latin small letter a with diaeresis and macron","alternative":"latin small letter a double overdot overbar","short":"a double overdot overbar"}}},{"category":"Ll","key":"01E1","mappings":{"default":{"default":"latin small letter a with dot above and macron","alternative":"latin small letter a dot overbar","short":"a overdot overbar"}}},{"category":"Ll","key":"01ED","mappings":{"default":{"default":"latin small letter o with ogonek and macron","alternative":"latin small letter o ogonek overbar","short":"o ogonek overbar"}}},{"category":"Ll","key":"01FB","mappings":{"default":{"default":"latin small letter a with ring above and acute","alternative":"latin small letter a ring above acute","short":"a ring above acute"}}},{"category":"Ll","key":"022B","mappings":{"default":{"default":"latin small letter o with diaeresis and macron","alternative":"latin small letter o double overdot overbar","short":"o double overdot overbar"}}},{"category":"Ll","key":"022D","mappings":{"default":{"default":"latin small letter o with tilde and macron","alternative":"latin small letter o tilde overbar","short":"o tilde overbar"}}},{"category":"Ll","key":"0231","mappings":{"default":{"default":"latin small letter o with dot above and macron","alternative":"latin small letter o overdot overbar","short":"o overdot overbar"}}},{"category":"Ll","key":"1E09","mappings":{"default":{"default":"latin small letter c with cedilla and acute","alternative":"latin small letter c cedilla acute","short":"c cedilla acute"}}},{"category":"Ll","key":"1E15","mappings":{"default":{"default":"latin small letter e with macron and grave","alternative":"latin small letter e overbar grave","short":"e overbar grave"}}},{"category":"Ll","key":"1E17","mappings":{"default":{"default":"latin small letter e with macron and acute","alternative":"latin small letter e overbar acute","short":"e overbar acute"}}},{"category":"Ll","key":"1E1D","mappings":{"default":{"default":"latin small letter e with cedilla and breve","alternative":"latin small letter e cedilla breve","short":"e cedilla breve"}}},{"category":"Ll","key":"1E2F","mappings":{"default":{"default":"latin small letter i with diaeresis and acute","alternative":"latin small letter i double overdot acute","short":"i double overdot acute"}}},{"category":"Ll","key":"1E39","mappings":{"default":{"default":"latin small letter l with dot below and macron","alternative":"latin small letter l underdot overbar","short":"l underdot overbar"}}},{"category":"Ll","key":"1E4D","mappings":{"default":{"default":"latin small letter o with tilde and acute","alternative":"latin small letter o tilde acute","short":"o tilde acute"}}},{"category":"Ll","key":"1E4F","mappings":{"default":{"default":"latin small letter o with tilde and diaeresis","alternative":"latin small letter o tilde double overdot","short":"o tilde double overdot"}}},{"category":"Ll","key":"1E51","mappings":{"default":{"default":"latin small letter o with macron and grave","alternative":"latin small letter o overbar grave","short":"o overbar grave"}}},{"category":"Ll","key":"1E53","mappings":{"default":{"default":"latin small letter o with macron and acute","alternative":"latin small letter o overbar acute","short":"o overbar acute"}}},{"category":"Ll","key":"1E5D","mappings":{"default":{"default":"latin small letter r with dot below and macron","alternative":"latin small letter r underdot overbar","short":"r underdot overbar"}}},{"category":"Ll","key":"1E65","mappings":{"default":{"default":"latin small letter s with acute and dot above","alternative":"latin small letter s acute overdot","short":"s acute overdot"}}},{"category":"Ll","key":"1E67","mappings":{"default":{"default":"latin small letter s with caron and dot above","alternative":"latin small letter s caron overdot","short":"s caron overdot"}}},{"category":"Ll","key":"1E69","mappings":{"default":{"default":"latin small letter s with dot below and dot above","alternative":"latin small letter s underdot overdot","short":"s underdot overdot"}}},{"category":"Ll","key":"1E79","mappings":{"default":{"default":"latin small letter u with tilde and acute","alternative":"latin small letter u tilde acute","short":"u tilde acute"}}},{"category":"Ll","key":"1E7B","mappings":{"default":{"default":"latin small letter u with macron and diaeresis","alternative":"latin small letter u overbar double overdot","short":"u overbar double overdot"}}},{"category":"Ll","key":"1EA5","mappings":{"default":{"default":"latin small letter a with circumflex and acute","alternative":"latin small letter a hat acute","short":"a hat acute"}}},{"category":"Ll","key":"1EA7","mappings":{"default":{"default":"latin small letter a with circumflex and grave","alternative":"latin small letter a hat grave","short":"a hat grave"}}},{"category":"Ll","key":"1EA9","mappings":{"default":{"default":"latin small letter a with circumflex and hook above","alternative":"latin small letter a hat hook above","short":"a hat hook above"}}},{"category":"Ll","key":"1EAB","mappings":{"default":{"default":"latin small letter a with circumflex and tilde","alternative":"latin small letter a hat tilde","short":"a hat tilde"}}},{"category":"Ll","key":"1EAD","mappings":{"default":{"default":"latin small letter a with circumflex and dot below","alternative":"latin small letter a hat underdot","short":"a hat underdot"}}},{"category":"Ll","key":"1EAF","mappings":{"default":{"default":"latin small letter a with breve and acute","alternative":"latin small letter a breve acute","short":"a breve acute"}}},{"category":"Ll","key":"1EB1","mappings":{"default":{"default":"latin small letter a with breve and grave","alternative":"latin small letter a breve grave","short":"a breve grave"}}},{"category":"Ll","key":"1EB3","mappings":{"default":{"default":"latin small letter a with breve and hook above","alternative":"latin small letter a breve hook above","short":"a breve hook above"}}},{"category":"Ll","key":"1EB5","mappings":{"default":{"default":"latin small letter a with breve and tilde","alternative":"latin small letter a breve tilde","short":"a breve tilde"}}},{"category":"Ll","key":"1EB7","mappings":{"default":{"default":"latin small letter a with breve and dot below","alternative":"latin small letter a breve underdot","short":"a breve underdot"}}},{"category":"Ll","key":"1EBF","mappings":{"default":{"default":"latin small letter e with circumflex and acute","alternative":"latin small letter e hat acute","short":"e hat acute"}}},{"category":"Ll","key":"1EC1","mappings":{"default":{"default":"latin small letter e with circumflex and grave","alternative":"latin small letter e hat grave","short":"e hat grave"}}},{"category":"Ll","key":"1EC3","mappings":{"default":{"default":"latin small letter e with circumflex and hook above","alternative":"latin small letter e hat hook above","short":"e hat hook above"}}},{"category":"Ll","key":"1EC5","mappings":{"default":{"default":"latin small letter e with circumflex and tilde","alternative":"latin small letter e hat tilde","short":"e hat tilde"}}},{"category":"Ll","key":"1EC7","mappings":{"default":{"default":"latin small letter e with circumflex and dot below","alternative":"latin small letter e hat underdot","short":"e hat underdot"}}},{"category":"Ll","key":"1ED1","mappings":{"default":{"default":"latin small letter o with circumflex and acute","alternative":"latin small letter o hat acute","short":"o hat acute"}}},{"category":"Ll","key":"1ED3","mappings":{"default":{"default":"latin small letter o with circumflex and grave","alternative":"latin small letter o hat grave","short":"o hat grave"}}},{"category":"Ll","key":"1ED5","mappings":{"default":{"default":"latin small letter o with circumflex and hook above","alternative":"latin small letter o hat hook above","short":"o hat hook above"}}},{"category":"Ll","key":"1ED7","mappings":{"default":{"default":"latin small letter o with circumflex and tilde","alternative":"latin small letter o hat tilde","short":"o hat tilde"}}},{"category":"Ll","key":"1ED9","mappings":{"default":{"default":"latin small letter o with circumflex and dot below","alternative":"latin small letter o hat underdot","short":"o hat underdot"}}},{"category":"Ll","key":"1EDB","mappings":{"default":{"default":"latin small letter o with horn and acute","alternative":"latin small letter o acute prime","short":"o acute prime"}}},{"category":"Ll","key":"1EDD","mappings":{"default":{"default":"latin small letter o with horn and grave","alternative":"latin small letter o grave prime","short":"o grave prime"}}},{"category":"Ll","key":"1EDF","mappings":{"default":{"default":"latin small letter o with horn and hook above","alternative":"latin small letter o hook above prime","short":"o hook above prime"}}},{"category":"Ll","key":"1EE1","mappings":{"default":{"default":"latin small letter o with horn and tilde","alternative":"latin small letter o tilde prime","short":"o tilde prime"}}},{"category":"Ll","key":"1EE3","mappings":{"default":{"default":"latin small letter o with horn and dot below","alternative":"latin small letter o underdot prime","short":"o underdot prime"}}},{"category":"Ll","key":"1EE9","mappings":{"default":{"default":"latin small letter u with horn and acute","alternative":"latin small letter u acute prime","short":"u acute prime"}}},{"category":"Ll","key":"1EEB","mappings":{"default":{"default":"latin small letter u with horn and grave","alternative":"latin small letter u grave prime","short":"u grave prime"}}},{"category":"Ll","key":"1EED","mappings":{"default":{"default":"latin small letter u with horn and hook above","alternative":"latin small letter u hook above prime","short":"u hook above prime"}}},{"category":"Ll","key":"1EEF","mappings":{"default":{"default":"latin small letter u with horn and tilde","alternative":"latin small letter u tilde prime","short":"u tilde prime"}}},{"category":"Ll","key":"1EF1","mappings":{"default":{"default":"latin small letter u with horn and dot below","alternative":"latin small letter u underdot prime","short":"u underdot prime"}}}]
,
"en/latin-lower-normal.js": 
[{"locale":"en"},{"category":"Ll","key":"0061","mappings":{"default":{"default":"latin small letter a","short":"a"}}},{"category":"Ll","key":"0062","mappings":{"default":{"default":"latin small letter b","short":"b"}}},{"category":"Ll","key":"0063","mappings":{"default":{"default":"latin small letter c","short":"c"}}},{"category":"Ll","key":"0064","mappings":{"default":{"default":"latin small letter d","short":"d"}}},{"category":"Ll","key":"0065","mappings":{"default":{"default":"latin small letter e","short":"e"}}},{"category":"Ll","key":"0066","mappings":{"default":{"default":"latin small letter f","short":"f"}}},{"category":"Ll","key":"0067","mappings":{"default":{"default":"latin small letter g","short":"g"}}},{"category":"Ll","key":"0068","mappings":{"default":{"default":"latin small letter h","short":"h"}}},{"category":"Ll","key":"0069","mappings":{"default":{"default":"latin small letter i","short":"i"}}},{"category":"Ll","key":"006A","mappings":{"default":{"default":"latin small letter j","short":"j"}}},{"category":"Ll","key":"006B","mappings":{"default":{"default":"latin small letter k","short":"k"}}},{"category":"Ll","key":"006C","mappings":{"default":{"default":"latin small letter l","short":"l"}}},{"category":"Ll","key":"006D","mappings":{"default":{"default":"latin small letter m","short":"m"}}},{"category":"Ll","key":"006E","mappings":{"default":{"default":"latin small letter n","short":"n"}}},{"category":"Ll","key":"006F","mappings":{"default":{"default":"latin small letter o","short":"o"}}},{"category":"Ll","key":"0070","mappings":{"default":{"default":"latin small letter p","short":"p"}}},{"category":"Ll","key":"0071","mappings":{"default":{"default":"latin small letter q","short":"q"}}},{"category":"Ll","key":"0072","mappings":{"default":{"default":"latin small letter r","short":"r"}}},{"category":"Ll","key":"0073","mappings":{"default":{"default":"latin small letter s","short":"s"}}},{"category":"Ll","key":"0074","mappings":{"default":{"default":"latin small letter t","short":"t"}}},{"category":"Ll","key":"0075","mappings":{"default":{"default":"latin small letter u","short":"u"}}},{"category":"Ll","key":"0076","mappings":{"default":{"default":"latin small letter v","short":"v"}}},{"category":"Ll","key":"0077","mappings":{"default":{"default":"latin small letter w","short":"w"}}},{"category":"Ll","key":"0078","mappings":{"default":{"default":"latin small letter x","short":"x"}}},{"category":"Ll","key":"0079","mappings":{"default":{"default":"latin small letter y","short":"y"}}},{"category":"Ll","key":"007A","mappings":{"default":{"default":"latin small letter z","short":"z"}}},{"category":"Ll","key":"FF41","mappings":{"default":{"default":"fullwidth latin small letter a","short":"a"}}},{"category":"Ll","key":"FF42","mappings":{"default":{"default":"fullwidth latin small letter b","short":"b"}}},{"category":"Ll","key":"FF43","mappings":{"default":{"default":"fullwidth latin small letter c","short":"c"}}},{"category":"Ll","key":"FF44","mappings":{"default":{"default":"fullwidth latin small letter d","short":"d"}}},{"category":"Ll","key":"FF45","mappings":{"default":{"default":"fullwidth latin small letter e","short":"e"}}},{"category":"Ll","key":"FF46","mappings":{"default":{"default":"fullwidth latin small letter f","short":"f"}}},{"category":"Ll","key":"FF47","mappings":{"default":{"default":"fullwidth latin small letter g","short":"g"}}},{"category":"Ll","key":"FF48","mappings":{"default":{"default":"fullwidth latin small letter h","short":"h"}}},{"category":"Ll","key":"FF49","mappings":{"default":{"default":"fullwidth latin small letter i","short":"i"}}},{"category":"Ll","key":"FF4A","mappings":{"default":{"default":"fullwidth latin small letter j","short":"j"}}},{"category":"Ll","key":"FF4B","mappings":{"default":{"default":"fullwidth latin small letter k","short":"k"}}},{"category":"Ll","key":"FF4C","mappings":{"default":{"default":"fullwidth latin small letter l","short":"l"}}},{"category":"Ll","key":"FF4D","mappings":{"default":{"default":"fullwidth latin small letter m","short":"m"}}},{"category":"Ll","key":"FF4E","mappings":{"default":{"default":"fullwidth latin small letter n","short":"n"}}},{"category":"Ll","key":"FF4F","mappings":{"default":{"default":"fullwidth latin small letter o","short":"o"}}},{"category":"Ll","key":"FF50","mappings":{"default":{"default":"fullwidth latin small letter p","short":"p"}}},{"category":"Ll","key":"FF51","mappings":{"default":{"default":"fullwidth latin small letter q","short":"q"}}},{"category":"Ll","key":"FF52","mappings":{"default":{"default":"fullwidth latin small letter r","short":"r"}}},{"category":"Ll","key":"FF53","mappings":{"default":{"default":"fullwidth latin small letter s","short":"s"}}},{"category":"Ll","key":"FF54","mappings":{"default":{"default":"fullwidth latin small letter t","short":"t"}}},{"category":"Ll","key":"FF55","mappings":{"default":{"default":"fullwidth latin small letter u","short":"u"}}},{"category":"Ll","key":"FF56","mappings":{"default":{"default":"fullwidth latin small letter v","short":"v"}}},{"category":"Ll","key":"FF57","mappings":{"default":{"default":"fullwidth latin small letter w","short":"w"}}},{"category":"Ll","key":"FF58","mappings":{"default":{"default":"fullwidth latin small letter x","short":"x"}}},{"category":"Ll","key":"FF59","mappings":{"default":{"default":"fullwidth latin small letter y","short":"y"}}},{"category":"Ll","key":"FF5A","mappings":{"default":{"default":"fullwidth latin small letter z","short":"z"}}}]
,
"en/latin-lower-phonetic.js": 
[{"locale":"en"},{"category":"Ll","key":"00F8","mappings":{"default":{"default":"latin small letter o with stroke","alternative":"latin small letter o slash","short":"o with stroke"}}},{"category":"Ll","key":"0111","mappings":{"default":{"default":"latin small letter d with stroke","alternative":"latin small letter d bar","short":"d with stroke"}}},{"category":"Ll","key":"0127","mappings":{"default":{"default":"latin small letter h with stroke","alternative":"latin small letter h bar","short":"h with stroke"}}},{"category":"Ll","key":"0142","mappings":{"default":{"default":"latin small letter l with stroke","alternative":"latin small letter l slash","short":"l with stroke"}}},{"category":"Ll","key":"0167","mappings":{"default":{"default":"latin small letter t with stroke","alternative":"latin small letter t bar","short":"t with stroke"}}},{"category":"Ll","key":"0180","mappings":{"default":{"default":"latin small letter b with stroke","alternative":"latin small letter b bar","short":"b with stroke"}}},{"category":"Ll","key":"019B","mappings":{"default":{"default":"latin small letter lambda with stroke","alternative":"latin small letter barred lambda","short":"lambda with stroke"}}},{"category":"Ll","key":"01B6","mappings":{"default":{"default":"latin small letter z with stroke","alternative":"latin small letter z bar","short":"z with stroke"}}},{"category":"Ll","key":"01BE","mappings":{"default":{"default":"latin letter inverted glottal stop with stroke","alternative":"latin letter inverted glottal stop bar","short":"latin letter inverted glottal stop with stroke"}}},{"category":"Ll","key":"01E5","mappings":{"default":{"default":"latin small letter g with stroke","alternative":"latin small letter g bar","short":"g with stroke"}}},{"category":"Ll","key":"01FF","mappings":{"default":{"default":"latin small letter o with stroke and acute","short":"o with stroke and acute"}}},{"category":"Ll","key":"023C","mappings":{"default":{"default":"latin small letter c with stroke","short":"c with stroke"}}},{"category":"Ll","key":"0247","mappings":{"default":{"default":"latin small letter e with stroke","short":"e with stroke"}}},{"category":"Ll","key":"0249","mappings":{"default":{"default":"latin small letter j with stroke","short":"j with stroke"}}},{"category":"Ll","key":"024D","mappings":{"default":{"default":"latin small letter r with stroke","short":"r with stroke"}}},{"category":"Ll","key":"024F","mappings":{"default":{"default":"latin small letter y with stroke","short":"y with stroke"}}},{"category":"Ll","key":"025F","mappings":{"default":{"default":"latin small letter dotless j with stroke","alternative":"latin small letter dotless j bar","short":"dotless j with stroke"}}},{"category":"Ll","key":"0268","mappings":{"default":{"default":"latin small letter i with stroke","alternative":"latin small letter barred i","short":"i with stroke"}}},{"category":"Ll","key":"0284","mappings":{"default":{"default":"latin small letter dotless j with stroke and hook","alternative":"latin small letter dotless j bar hook","short":"dotless j with stroke and hook"}}},{"category":"Ll","key":"02A1","mappings":{"default":{"default":"latin letter glottal stop with stroke","alternative":"latin letter glottal stop bar","short":"latin letter glottal stop with stroke"}}},{"category":"Ll","key":"02A2","mappings":{"default":{"default":"latin letter reversed glottal stop with stroke","alternative":"latin letter reversed glottal stop bar","short":"latin letter reversed glottal stop with stroke"}}},{"category":"Ll","key":"1D13","mappings":{"default":{"default":"latin small letter sideways o with stroke","short":"sideways o with stroke"}}},{"category":"Ll","key":"1D7C","mappings":{"default":{"default":"latin small letter iota with stroke","short":"iota with stroke"}}},{"category":"Ll","key":"1D7D","mappings":{"default":{"default":"latin small letter p with stroke","short":"p with stroke"}}},{"category":"Ll","key":"1D7F","mappings":{"default":{"default":"latin small letter upsilon with stroke","short":"upsilon with stroke"}}},{"category":"Ll","key":"1E9C","mappings":{"default":{"default":"latin small letter long s with diagonal stroke","short":"long s with diagonal stroke"}}},{"category":"Ll","key":"1E9D","mappings":{"default":{"default":"latin small letter long s with high stroke","short":"long s with high stroke"}}},{"category":"Ll","key":"018D","mappings":{"default":{"default":"latin small letter turned delta","short":"turned delta"}}},{"category":"Ll","key":"1E9B","mappings":{"default":{"default":"latin small letter long s with dot above","short":"long s with dot above"}}},{"category":"Ll","key":"1E9F","mappings":{"default":{"default":"latin small letter delta","short":"delta"}}},{"category":"Ll","key":"0138","mappings":{"default":{"default":"latin small letter kra","short":"kra"}}},{"category":"Ll","key":"017F","mappings":{"default":{"default":"latin small letter long s","short":"long s"}}},{"category":"Ll","key":"0183","mappings":{"default":{"default":"latin small letter b with topbar","alternative":"latin small letter b topbar","short":"b with topbar"}}},{"category":"Ll","key":"0185","mappings":{"default":{"default":"latin small letter tone six","short":"tone six"}}},{"category":"Ll","key":"0188","mappings":{"default":{"default":"latin small letter c with hook","alternative":"latin small letter c hook","short":"c with hook"}}},{"category":"Ll","key":"018C","mappings":{"default":{"default":"latin small letter d with topbar","alternative":"latin small letter d topbar","short":"d with topbar"}}},{"category":"Ll","key":"0192","mappings":{"default":{"default":"latin small letter f with hook","alternative":"latin small letter script f","short":"f with hook"}}},{"category":"Ll","key":"0195","mappings":{"default":{"default":"latin small letter hv","alternative":"latin small letter h v","short":"hv"}}},{"category":"Ll","key":"0199","mappings":{"default":{"default":"latin small letter k with hook","alternative":"latin small letter k hook","short":"k with hook"}}},{"category":"Ll","key":"019A","mappings":{"default":{"default":"latin small letter l with bar","alternative":"latin small letter barred l","short":"l with bar"}}},{"category":"Ll","key":"019E","mappings":{"default":{"default":"latin small letter n with long right leg","short":"n with long right leg"}}},{"category":"Ll","key":"01A1","mappings":{"default":{"default":"latin small letter o with horn","alternative":"latin small letter o horn","short":"o with horn"}}},{"category":"Ll","key":"01A3","mappings":{"default":{"default":"latin small letter oi","alternative":"latin small letter o i","short":"oi"}}},{"category":"Ll","key":"01A5","mappings":{"default":{"default":"latin small letter p with hook","alternative":"latin small letter p hook","short":"p with hook"}}},{"category":"Ll","key":"01A8","mappings":{"default":{"default":"latin small letter tone two","short":"tone two"}}},{"category":"Ll","key":"01AA","mappings":{"default":{"default":"latin letter reversed esh loop","short":"latin letter reversed esh loop"}}},{"category":"Ll","key":"01AB","mappings":{"default":{"default":"latin small letter t with palatal hook","alternative":"latin small letter t palatal hook","short":"t with palatal hook"}}},{"category":"Ll","key":"01AD","mappings":{"default":{"default":"latin small letter t with hook","alternative":"latin small letter t hook","short":"t with hook"}}},{"category":"Ll","key":"01B0","mappings":{"default":{"default":"latin small letter u with horn","alternative":"latin small letter u horn","short":"u with horn"}}},{"category":"Ll","key":"01B4","mappings":{"default":{"default":"latin small letter y with hook","alternative":"latin small letter y hook","short":"y with hook"}}},{"category":"Ll","key":"01B9","mappings":{"default":{"default":"latin small letter ezh reversed","alternative":"latin small letter reversed yogh","short":"ezh reversed"}}},{"category":"Ll","key":"01BA","mappings":{"default":{"default":"latin small letter ezh with tail","alternative":"latin small letter yogh with tail","short":"ezh with tail"}}},{"category":"Ll","key":"01BD","mappings":{"default":{"default":"latin small letter tone five","short":"tone five"}}},{"category":"Ll","key":"01BF","mappings":{"default":{"default":"latin letter wynn","short":"latin letter wynn"}}},{"category":"Ll","key":"01C6","mappings":{"default":{"default":"latin small letter dz with caron","alternative":"latin small letter d z hacek","short":"dz with caron"}}},{"category":"Ll","key":"01C9","mappings":{"default":{"default":"latin small letter lj","alternative":"latin small letter l j","short":"lj"}}},{"category":"Ll","key":"01CC","mappings":{"default":{"default":"latin small letter nj","alternative":"latin small letter n j","short":"nj"}}},{"category":"Ll","key":"01E3","mappings":{"default":{"default":"latin small letter ae with macron","alternative":"latin small letter a e macron","short":"ae with macron"}}},{"category":"Ll","key":"01EF","mappings":{"default":{"default":"latin small letter ezh with caron","alternative":"latin small letter yogh hacek","short":"ezh with caron"}}},{"category":"Ll","key":"01F3","mappings":{"default":{"default":"latin small letter dz","short":"dz"}}},{"category":"Ll","key":"021D","mappings":{"default":{"default":"latin small letter yogh","short":"yogh"}}},{"category":"Ll","key":"026E","mappings":{"default":{"default":"latin small letter lezh","alternative":"latin small letter l yogh","short":"lezh"}}},{"category":"Ll","key":"0292","mappings":{"default":{"default":"latin small letter ezh","alternative":"latin small letter yogh","short":"ezh"}}},{"category":"Ll","key":"0293","mappings":{"default":{"default":"latin small letter ezh with curl","alternative":"latin small letter yogh curl","short":"ezh with curl"}}},{"category":"Ll","key":"02A4","mappings":{"default":{"default":"latin small letter dezh digraph","alternative":"latin small letter d yogh","short":"dezh digraph"}}},{"category":"Ll","key":"01DD","mappings":{"default":{"default":"latin small letter turned e","short":"turned e"}}},{"category":"Ll","key":"01FD","mappings":{"default":{"default":"latin small letter ae with acute","short":"ae with acute"}}},{"category":"Ll","key":"021D","mappings":{"default":{"default":"latin small letter yogh","short":"yogh"}}},{"category":"Ll","key":"0221","mappings":{"default":{"default":"latin small letter d with curl","short":"d with curl"}}},{"category":"Ll","key":"0223","mappings":{"default":{"default":"latin small letter ou","short":"ou"}}},{"category":"Ll","key":"0225","mappings":{"default":{"default":"latin small letter z with hook","short":"z with hook"}}},{"category":"Ll","key":"0234","mappings":{"default":{"default":"latin small letter l with curl","short":"l with curl"}}},{"category":"Ll","key":"0235","mappings":{"default":{"default":"latin small letter n with curl","short":"n with curl"}}},{"category":"Ll","key":"0236","mappings":{"default":{"default":"latin small letter t with curl","short":"t with curl"}}},{"category":"Ll","key":"0238","mappings":{"default":{"default":"latin small letter db digraph","short":"db digraph"}}},{"category":"Ll","key":"0239","mappings":{"default":{"default":"latin small letter qp digraph","short":"qp digraph"}}},{"category":"Ll","key":"023F","mappings":{"default":{"default":"latin small letter s with swash tail","short":"s with swash tail"}}},{"category":"Ll","key":"0240","mappings":{"default":{"default":"latin small letter z with swash tail","short":"z with swash tail"}}},{"category":"Ll","key":"0242","mappings":{"default":{"default":"latin small letter glottal stop","short":"glottal stop"}}},{"category":"Ll","key":"024B","mappings":{"default":{"default":"latin small letter q with hook tail","short":"q with hook tail"}}},{"category":"Ll","key":"0250","mappings":{"default":{"default":"latin small letter turned a","short":"turned a"}}},{"category":"Ll","key":"0251","mappings":{"default":{"default":"latin small letter alpha","alternative":"latin small letter script a","short":"alpha"}}},{"category":"Ll","key":"0252","mappings":{"default":{"default":"latin small letter turned alpha","alternative":"latin small letter turned script a","short":"turned alpha"}}},{"category":"Ll","key":"0253","mappings":{"default":{"default":"latin small letter b with hook","alternative":"latin small letter b hook","short":"b with hook"}}},{"category":"Ll","key":"0254","mappings":{"default":{"default":"latin small letter open o","short":"open o"}}},{"category":"Ll","key":"0255","mappings":{"default":{"default":"latin small letter c with curl","alternative":"latin small letter c curl","short":"c with curl"}}},{"category":"Ll","key":"0256","mappings":{"default":{"default":"latin small letter d with tail","alternative":"latin small letter d retroflex hook","short":"d with tail"}}},{"category":"Ll","key":"0257","mappings":{"default":{"default":"latin small letter d with hook","alternative":"latin small letter d hook","short":"d with hook"}}},{"category":"Ll","key":"0258","mappings":{"default":{"default":"latin small letter reversed e","short":"reversed e"}}},{"category":"Ll","key":"0259","mappings":{"default":{"default":"latin small letter schwa","short":"schwa"}}},{"category":"Ll","key":"025A","mappings":{"default":{"default":"latin small letter schwa with hook","alternative":"latin small letter schwa hook","short":"schwa with hook"}}},{"category":"Ll","key":"025B","mappings":{"default":{"default":"latin small letter open e","alternative":"latin small letter epsilon","short":"open e"}}},{"category":"Ll","key":"025C","mappings":{"default":{"default":"latin small letter reversed open e","alternative":"latin small letter reversed epsilon","short":"reversed open e"}}},{"category":"Ll","key":"025D","mappings":{"default":{"default":"latin small letter reversed open e with hook","alternative":"latin small letter reversed epsilon hook","short":"reversed open e with hook"}}},{"category":"Ll","key":"025E","mappings":{"default":{"default":"latin small letter closed reversed open e","alternative":"latin small letter closed reversed epsilon","short":"closed reversed open e"}}},{"category":"Ll","key":"0260","mappings":{"default":{"default":"latin small letter g with hook","alternative":"latin small letter g hook","short":"g with hook"}}},{"category":"Ll","key":"0261","mappings":{"default":{"default":"latin small letter script g","short":"script g"}}},{"category":"Ll","key":"0263","mappings":{"default":{"default":"latin small letter gamma","short":"gamma"}}},{"category":"Ll","key":"0264","mappings":{"default":{"default":"latin small letter rams horn","alternative":"latin small letter baby gamma","short":"rams horn"}}},{"category":"Ll","key":"0265","mappings":{"default":{"default":"latin small letter turned h","short":"turned h"}}},{"category":"Ll","key":"0266","mappings":{"default":{"default":"latin small letter h with hook","alternative":"latin small letter h hook","short":"h with hook"}}},{"category":"Ll","key":"0267","mappings":{"default":{"default":"latin small letter heng with hook","alternative":"latin small letter heng hook","short":"heng with hook"}}},{"category":"Ll","key":"0269","mappings":{"default":{"default":"latin small letter iota","short":"iota"}}},{"category":"Ll","key":"026B","mappings":{"default":{"default":"latin small letter l with middle tilde","short":"l with middle tilde"}}},{"category":"Ll","key":"026C","mappings":{"default":{"default":"latin small letter l with belt","alternative":"latin small letter l belt","short":"l with belt"}}},{"category":"Ll","key":"026D","mappings":{"default":{"default":"latin small letter l with retroflex hook","alternative":"latin small letter l retroflex hook","short":"l with retroflex hook"}}},{"category":"Ll","key":"026E","mappings":{"default":{"default":"latin small letter lezh","alternative":"latin small letter l yogh","short":"lezh"}}},{"category":"Ll","key":"026F","mappings":{"default":{"default":"latin small letter turned m","short":"turned m"}}},{"category":"Ll","key":"0270","mappings":{"default":{"default":"latin small letter turned m with long leg","short":"turned m with long leg"}}},{"category":"Ll","key":"0271","mappings":{"default":{"default":"latin small letter m with hook","alternative":"latin small letter m hook","short":"m with hook"}}},{"category":"Ll","key":"0272","mappings":{"default":{"default":"latin small letter n with left hook","alternative":"latin small letter n hook","short":"n with left hook"}}},{"category":"Ll","key":"0273","mappings":{"default":{"default":"latin small letter n with retroflex hook","alternative":"latin small letter n retroflex hook","short":"n with retroflex hook"}}},{"category":"Ll","key":"0275","mappings":{"default":{"default":"latin small letter barred o","short":"barred o"}}},{"category":"Ll","key":"0277","mappings":{"default":{"default":"latin small letter closed omega","short":"closed omega"}}},{"category":"Ll","key":"0278","mappings":{"default":{"default":"latin small letter phi","short":"phi"}}},{"category":"Ll","key":"0279","mappings":{"default":{"default":"latin small letter turned r","short":"turned r"}}},{"category":"Ll","key":"027A","mappings":{"default":{"default":"latin small letter turned r with long leg","short":"turned r with long leg"}}},{"category":"Ll","key":"027B","mappings":{"default":{"default":"latin small letter turned r with hook","alternative":"latin small letter turned r hook","short":"turned r with hook"}}},{"category":"Ll","key":"027C","mappings":{"default":{"default":"latin small letter r with long leg","short":"r with long leg"}}},{"category":"Ll","key":"027D","mappings":{"default":{"default":"latin small letter r with tail","alternative":"latin small letter r hook","short":"r with tail"}}},{"category":"Ll","key":"027E","mappings":{"default":{"default":"latin small letter r with fishhook","alternative":"latin small letter fishhook r","short":"r with fishhook"}}},{"category":"Ll","key":"027F","mappings":{"default":{"default":"latin small letter reversed r with fishhook","alternative":"latin small letter reversed fishhook r","short":"reversed r with fishhook"}}},{"category":"Ll","key":"0282","mappings":{"default":{"default":"latin small letter s with hook","alternative":"latin small letter s hook","short":"s with hook"}}},{"category":"Ll","key":"0283","mappings":{"default":{"default":"latin small letter esh","short":"esh"}}},{"category":"Ll","key":"0285","mappings":{"default":{"default":"latin small letter squat reversed esh","short":"squat reversed esh"}}},{"category":"Ll","key":"0286","mappings":{"default":{"default":"latin small letter esh with curl","alternative":"latin small letter esh curl","short":"esh with curl"}}},{"category":"Ll","key":"0287","mappings":{"default":{"default":"latin small letter turned t","short":"turned t"}}},{"category":"Ll","key":"0288","mappings":{"default":{"default":"latin small letter t with retroflex hook","alternative":"latin small letter t retroflex hook","short":"t with retroflex hook"}}},{"category":"Ll","key":"0289","mappings":{"default":{"default":"latin small letter u bar","short":"u bar"}}},{"category":"Ll","key":"028A","mappings":{"default":{"default":"latin small letter upsilon","short":"upsilon"}}},{"category":"Ll","key":"028B","mappings":{"default":{"default":"latin small letter v with hook","alternative":"latin small letter script v","short":"v with hook"}}},{"category":"Ll","key":"028C","mappings":{"default":{"default":"latin small letter turned v","short":"turned v"}}},{"category":"Ll","key":"028D","mappings":{"default":{"default":"latin small letter turned w","short":"turned w"}}},{"category":"Ll","key":"028E","mappings":{"default":{"default":"latin small letter turned y","short":"turned y"}}},{"category":"Ll","key":"0290","mappings":{"default":{"default":"latin small letter z with retroflex hook","alternative":"latin small letter z retroflex hook","short":"z with retroflex hook"}}},{"category":"Ll","key":"0291","mappings":{"default":{"default":"latin small letter z with curl","alternative":"latin small letter z curl","short":"z with curl"}}},{"category":"Ll","key":"0292","mappings":{"default":{"default":"latin small letter ezh","alternative":"latin small letter yogh","short":"ezh"}}},{"category":"Ll","key":"0293","mappings":{"default":{"default":"latin small letter ezh with curl","alternative":"latin small letter yogh curl","short":"ezh with curl"}}},{"category":"Ll","key":"0295","mappings":{"default":{"default":"latin letter pharyngeal voiced fricative","alternative":"latin letter reversed glottal stop","short":"latin letter pharyngeal voiced fricative"}}},{"category":"Ll","key":"0296","mappings":{"default":{"default":"latin letter inverted glottal stop","short":"latin letter inverted glottal stop"}}},{"category":"Ll","key":"0297","mappings":{"default":{"default":"latin letter stretched c","short":"latin letter stretched c"}}},{"category":"Ll","key":"0298","mappings":{"default":{"default":"latin letter bilabial click","alternative":"latin letter bullseye","short":"latin letter bilabial click"}}},{"category":"Ll","key":"029A","mappings":{"default":{"default":"latin small letter closed open e","alternative":"latin small letter closed epsilon","short":"closed open e"}}},{"category":"Ll","key":"029E","mappings":{"default":{"default":"latin small letter turned k","short":"turned k"}}},{"category":"Ll","key":"02A0","mappings":{"default":{"default":"latin small letter q with hook","alternative":"latin small letter q hook","short":"q with hook"}}},{"category":"Ll","key":"02A3","mappings":{"default":{"default":"latin small letter dz digraph","alternative":"latin small letter d z","short":"dz digraph"}}},{"category":"Ll","key":"02A4","mappings":{"default":{"default":"latin small letter dezh digraph","alternative":"latin small letter d yogh","short":"dezh digraph"}}},{"category":"Ll","key":"02A5","mappings":{"default":{"default":"latin small letter dz digraph with curl","alternative":"latin small letter d z curl","short":"dz digraph with curl"}}},{"category":"Ll","key":"02A6","mappings":{"default":{"default":"latin small letter ts digraph","alternative":"latin small letter t s","short":"ts digraph"}}},{"category":"Ll","key":"02A7","mappings":{"default":{"default":"latin small letter tesh digraph","alternative":"latin small letter t esh","short":"tesh digraph"}}},{"category":"Ll","key":"02A8","mappings":{"default":{"default":"latin small letter tc digraph with curl","alternative":"latin small letter t c curl","short":"tc digraph with curl"}}},{"category":"Ll","key":"02A9","mappings":{"default":{"default":"latin small letter feng digraph","short":"feng digraph"}}},{"category":"Ll","key":"02AA","mappings":{"default":{"default":"latin small letter ls digraph","short":"ls digraph"}}},{"category":"Ll","key":"02AB","mappings":{"default":{"default":"latin small letter lz digraph","short":"lz digraph"}}},{"category":"Ll","key":"02AC","mappings":{"default":{"default":"latin letter bilabial percussive","short":"latin letter bilabial percussive"}}},{"category":"Ll","key":"02AD","mappings":{"default":{"default":"latin letter bidental percussive","short":"latin letter bidental percussive"}}},{"category":"Ll","key":"02AE","mappings":{"default":{"default":"latin small letter turned h with fishhook","short":"turned h with fishhook"}}},{"category":"Ll","key":"02AF","mappings":{"default":{"default":"latin small letter turned h with fishhook and tail","short":"turned h with fishhook and tail"}}},{"category":"Ll","key":"1D02","mappings":{"default":{"default":"latin small letter turned ae","short":"turned ae"}}},{"category":"Ll","key":"1D08","mappings":{"default":{"default":"latin small letter turned open e","short":"turned open e"}}},{"category":"Ll","key":"1D09","mappings":{"default":{"default":"latin small letter turned i","short":"turned i"}}},{"category":"Ll","key":"1D11","mappings":{"default":{"default":"latin small letter sideways o","short":"sideways o"}}},{"category":"Ll","key":"1D12","mappings":{"default":{"default":"latin small letter sideways open o","short":"sideways open o"}}},{"category":"Ll","key":"1D14","mappings":{"default":{"default":"latin small letter turned oe","short":"turned oe"}}},{"category":"Ll","key":"1D16","mappings":{"default":{"default":"latin small letter top half o","short":"top half o"}}},{"category":"Ll","key":"1D17","mappings":{"default":{"default":"latin small letter bottom half o","short":"bottom half o"}}},{"category":"Ll","key":"1D1D","mappings":{"default":{"default":"latin small letter sideways u","short":"sideways u"}}},{"category":"Ll","key":"1D1E","mappings":{"default":{"default":"latin small letter sideways diaeresized u","short":"sideways diaeresized u"}}},{"category":"Ll","key":"1D1F","mappings":{"default":{"default":"latin small letter sideways turned m","short":"sideways turned m"}}},{"category":"Ll","key":"1D24","mappings":{"default":{"default":"latin letter voiced laryngeal spirant","short":"latin letter voiced laryngeal spirant"}}},{"category":"Ll","key":"1D25","mappings":{"default":{"default":"latin letter ain","short":"latin letter ain"}}},{"category":"Ll","key":"1D6B","mappings":{"default":{"default":"latin small letter ue","short":"ue"}}},{"category":"Ll","key":"1D6C","mappings":{"default":{"default":"latin small letter b with middle tilde","short":"b with middle tilde"}}},{"category":"Ll","key":"1D6D","mappings":{"default":{"default":"latin small letter d with middle tilde","short":"d with middle tilde"}}},{"category":"Ll","key":"1D6E","mappings":{"default":{"default":"latin small letter f with middle tilde","short":"f with middle tilde"}}},{"category":"Ll","key":"1D6F","mappings":{"default":{"default":"latin small letter m with middle tilde","short":"m with middle tilde"}}},{"category":"Ll","key":"1D70","mappings":{"default":{"default":"latin small letter n with middle tilde","short":"n with middle tilde"}}},{"category":"Ll","key":"1D71","mappings":{"default":{"default":"latin small letter p with middle tilde","short":"p with middle tilde"}}},{"category":"Ll","key":"1D72","mappings":{"default":{"default":"latin small letter r with middle tilde","short":"r with middle tilde"}}},{"category":"Ll","key":"1D73","mappings":{"default":{"default":"latin small letter r with fishhook and middle tilde","short":"r with fishhook and middle tilde"}}},{"category":"Ll","key":"1D74","mappings":{"default":{"default":"latin small letter s with middle tilde","short":"s with middle tilde"}}},{"category":"Ll","key":"1D75","mappings":{"default":{"default":"latin small letter t with middle tilde","short":"t with middle tilde"}}},{"category":"Ll","key":"1D76","mappings":{"default":{"default":"latin small letter z with middle tilde","short":"z with middle tilde"}}},{"category":"Ll","key":"1D77","mappings":{"default":{"default":"latin small letter turned g","short":"turned g"}}},{"category":"Ll","key":"1D79","mappings":{"default":{"default":"latin small letter insular g","short":"insular g"}}},{"category":"Ll","key":"1D7A","mappings":{"default":{"default":"latin small letter th with strikethrough","short":"th with strikethrough"}}},{"category":"Ll","key":"1D80","mappings":{"default":{"default":"latin small letter b with palatal hook","short":"b with palatal hook"}}},{"category":"Ll","key":"1D81","mappings":{"default":{"default":"latin small letter d with palatal hook","short":"d with palatal hook"}}},{"category":"Ll","key":"1D82","mappings":{"default":{"default":"latin small letter f with palatal hook","short":"f with palatal hook"}}},{"category":"Ll","key":"1D83","mappings":{"default":{"default":"latin small letter g with palatal hook","short":"g with palatal hook"}}},{"category":"Ll","key":"1D84","mappings":{"default":{"default":"latin small letter k with palatal hook","short":"k with palatal hook"}}},{"category":"Ll","key":"1D85","mappings":{"default":{"default":"latin small letter l with palatal hook","short":"l with palatal hook"}}},{"category":"Ll","key":"1D86","mappings":{"default":{"default":"latin small letter m with palatal hook","short":"m with palatal hook"}}},{"category":"Ll","key":"1D87","mappings":{"default":{"default":"latin small letter n with palatal hook","short":"n with palatal hook"}}},{"category":"Ll","key":"1D88","mappings":{"default":{"default":"latin small letter p with palatal hook","short":"p with palatal hook"}}},{"category":"Ll","key":"1D89","mappings":{"default":{"default":"latin small letter r with palatal hook","short":"r with palatal hook"}}},{"category":"Ll","key":"1D8A","mappings":{"default":{"default":"latin small letter s with palatal hook","short":"s with palatal hook"}}},{"category":"Ll","key":"1D8B","mappings":{"default":{"default":"latin small letter esh with palatal hook","short":"esh with palatal hook"}}},{"category":"Ll","key":"1D8C","mappings":{"default":{"default":"latin small letter v with palatal hook","short":"v with palatal hook"}}},{"category":"Ll","key":"1D8D","mappings":{"default":{"default":"latin small letter x with palatal hook","short":"x with palatal hook"}}},{"category":"Ll","key":"1D8E","mappings":{"default":{"default":"latin small letter z with palatal hook","short":"z with palatal hook"}}},{"category":"Ll","key":"1D8F","mappings":{"default":{"default":"latin small letter a with retroflex hook","short":"a with retroflex hook"}}},{"category":"Ll","key":"1D90","mappings":{"default":{"default":"latin small letter alpha with retroflex hook","short":"alpha with retroflex hook"}}},{"category":"Ll","key":"1D91","mappings":{"default":{"default":"latin small letter d with hook and tail","short":"d with hook and tail"}}},{"category":"Ll","key":"1D92","mappings":{"default":{"default":"latin small letter e with retroflex hook","short":"e with retroflex hook"}}},{"category":"Ll","key":"1D93","mappings":{"default":{"default":"latin small letter open e with retroflex hook","short":"open e with retroflex hook"}}},{"category":"Ll","key":"1D94","mappings":{"default":{"default":"latin small letter reversed open e with retroflex hook","short":"reversed open e with retroflex hook"}}},{"category":"Ll","key":"1D95","mappings":{"default":{"default":"latin small letter schwa with retroflex hook","short":"schwa with retroflex hook"}}},{"category":"Ll","key":"1D96","mappings":{"default":{"default":"latin small letter i with retroflex hook","short":"i with retroflex hook"}}},{"category":"Ll","key":"1D97","mappings":{"default":{"default":"latin small letter open o with retroflex hook","short":"open o with retroflex hook"}}},{"category":"Ll","key":"1D98","mappings":{"default":{"default":"latin small letter esh with retroflex hook","short":"esh with retroflex hook"}}},{"category":"Ll","key":"1D99","mappings":{"default":{"default":"latin small letter u with retroflex hook","short":"u with retroflex hook"}}},{"category":"Ll","key":"1D9A","mappings":{"default":{"default":"latin small letter ezh with retroflex hook","short":"ezh with retroflex hook"}}},{"category":"Ll","key":"0149","mappings":{"default":{"default":"latin small letter n preceded by apostrophe","alternative":"latin small letter apostrophe n","short":"n preceded by apostrophe"}}},{"category":"Ll","key":"014B","mappings":{"default":{"default":"latin small letter eng","short":"eng"}}}]
,
"en/latin-lower-single-accent.js": 
[{"locale":"en"},{"category":"Ll","key":"00E0","mappings":{"default":{"default":"latin small letter a with grave","alternative":"latin small letter a grave","short":"a grave"},"mathspeak":{"default":"modifying above a with grave","brief":"mod above a with grave","sbrief":"mod above a with grave"}}},{"category":"Ll","key":"00E1","mappings":{"default":{"default":"latin small letter a with acute","alternative":"latin small letter a acute","short":"a acute"},"mathspeak":{"default":"modifying above a with acute","brief":"mod above a with acute","sbrief":"mod above a with acute"}}},{"category":"Ll","key":"00E2","mappings":{"default":{"default":"latin small letter a with circumflex","alternative":"latin small letter a hat","short":"a hat"},"mathspeak":{"default":"modifying above a with caret","brief":"mod above a with caret","sbrief":"mod above a with caret"}}},{"category":"Ll","key":"00E3","mappings":{"default":{"default":"latin small letter a with tilde","alternative":"latin small letter a tilde","short":"a tilde"},"mathspeak":{"default":"a overtilde","brief":"a overtilde","sbrief":"a overtilde"}}},{"category":"Ll","key":"00E4","mappings":{"default":{"default":"latin small letter a with diaeresis","alternative":"latin small letter a double overdot","short":"a double overdot"},"mathspeak":{"default":"modifying above a with double dot","brief":"mod above a with double dot","sbrief":"mod above a with double dot"}}},{"category":"Ll","key":"00E5","mappings":{"default":{"default":"latin small letter a with ring above","alternative":"latin small letter a ring","short":"a ring"},"mathspeak":{"default":"modifying above a with ring","brief":"mod above a with ring","sbrief":"mod above a with ring"}}},{"category":"Ll","key":"00E7","mappings":{"default":{"default":"latin small letter c with cedilla","alternative":"latin small letter c cedilla","short":"c cedilla"},"mathspeak":{"default":"modifying above c with cedilla","brief":"mod above c with cedilla","sbrief":"mod above c with cedilla"}}},{"category":"Ll","key":"00E8","mappings":{"default":{"default":"latin small letter e with grave","alternative":"latin small letter e grave","short":"e grave"},"mathspeak":{"default":"modifying above e with grave","brief":"mod above e with grave","sbrief":"mod above e with grave"}}},{"category":"Ll","key":"00E9","mappings":{"default":{"default":"latin small letter e with acute","alternative":"latin small letter e acute","short":"e acute"},"mathspeak":{"default":"modifying above e with acute","brief":"mod above e with acute","sbrief":"mod above e with acute"}}},{"category":"Ll","key":"00EA","mappings":{"default":{"default":"latin small letter e with circumflex","alternative":"latin small letter e hat","short":"e hat"},"mathspeak":{"default":"modifying above e with caret","brief":"mod above e with caret","sbrief":"mod above e with caret"}}},{"category":"Ll","key":"00EB","mappings":{"default":{"default":"latin small letter e with diaeresis","alternative":"latin small letter e double overdot","short":"e double overdot"},"mathspeak":{"default":"modifying above e with double dot","brief":"mod above e with double dot","sbrief":"mod above e with double dot"}}},{"category":"Ll","key":"00EC","mappings":{"default":{"default":"latin small letter i with grave","alternative":"latin small letter i grave","short":"i grave"},"mathspeak":{"default":"modifying above i with grave","brief":"mod above i with grave","sbrief":"mod above i with grave"}}},{"category":"Ll","key":"00ED","mappings":{"default":{"default":"latin small letter i with acute","alternative":"latin small letter i acute","short":"i acute"},"mathspeak":{"default":"modifying above i with acute","brief":"mod above i with acute","sbrief":"mod above i with acute"}}},{"category":"Ll","key":"00EE","mappings":{"default":{"default":"latin small letter i with circumflex","alternative":"latin small letter i hat","short":"i hat"},"mathspeak":{"default":"modifying above i with caret","brief":"mod above i with caret","sbrief":"mod above i with caret"}}},{"category":"Ll","key":"00EF","mappings":{"default":{"default":"latin small letter i with diaeresis","alternative":"latin small letter i double overdot","short":"i double overdot"},"mathspeak":{"default":"modifying above i with double dot","brief":"mod above i with double dot","sbrief":"mod above i with double dot"}}},{"category":"Ll","key":"00F1","mappings":{"default":{"default":"latin small letter n with tilde","alternative":"latin small letter n tilde","short":"n tilde"},"mathspeak":{"default":"n overtilde","brief":"n overtilde","sbrief":"n overtilde"}}},{"category":"Ll","key":"00F2","mappings":{"default":{"default":"latin small letter o with grave","alternative":"latin small letter o grave","short":"o grave"},"mathspeak":{"default":"modifying above o with grave","brief":"mod above o with grave","sbrief":"mod above o with grave"}}},{"category":"Ll","key":"00F3","mappings":{"default":{"default":"latin small letter o with acute","alternative":"latin small letter o acute","short":"o acute"},"mathspeak":{"default":"modifying above o with acute","brief":"mod above o with acute","sbrief":"mod above o with acute"}}},{"category":"Ll","key":"00F4","mappings":{"default":{"default":"latin small letter o with circumflex","alternative":"latin small letter o hat","short":"o hat"},"mathspeak":{"default":"modifying above o with caret","brief":"mod above o with caret","sbrief":"mod above o with caret"}}},{"category":"Ll","key":"00F5","mappings":{"default":{"default":"latin small letter o with tilde","alternative":"latin small letter o tilde","short":"o tilde"},"mathspeak":{"default":"o overtilde","brief":"o overtilde","sbrief":"o overtilde"}}},{"category":"Ll","key":"00F6","mappings":{"default":{"default":"latin small letter o with diaeresis","alternative":"latin small letter o double overdot","short":"o double overdot"},"mathspeak":{"default":"modifying above o with double dot","brief":"mod above o with double dot","sbrief":"mod above o with double dot"}}},{"category":"Ll","key":"00F9","mappings":{"default":{"default":"latin small letter u with grave","alternative":"latin small letter u grave","short":"u grave"},"mathspeak":{"default":"modifying above u with grave","brief":"mod above u with grave","sbrief":"mod above u with grave"}}},{"category":"Ll","key":"00FA","mappings":{"default":{"default":"latin small letter u with acute","alternative":"latin small letter u acute","short":"u acute"},"mathspeak":{"default":"modifying above u with acute","brief":"mod above u with acute","sbrief":"mod above u with acute"}}},{"category":"Ll","key":"00FB","mappings":{"default":{"default":"latin small letter u with circumflex","alternative":"latin small letter u hat","short":"u hat"},"mathspeak":{"default":"modifying above u with caret","brief":"mod above u with caret","sbrief":"mod above u with caret"}}},{"category":"Ll","key":"00FC","mappings":{"default":{"default":"latin small letter u with diaeresis","alternative":"latin small letter u double overdot","short":"u double overdot"},"mathspeak":{"default":"modifying above u with double dot","brief":"mod above u with double dot","sbrief":"mod above u with double dot"}}},{"category":"Ll","key":"00FD","mappings":{"default":{"default":"latin small letter y with acute","alternative":"latin small letter y acute","short":"y acute"},"mathspeak":{"default":"modifying above y with acute","brief":"mod above y with acute","sbrief":"mod above y with acute"}}},{"category":"Ll","key":"00FF","mappings":{"default":{"default":"latin small letter y with diaeresis","alternative":"latin small letter y double overdot","short":"y double overdot"},"mathspeak":{"default":"modifying above y with double dot","brief":"mod above y with double dot","sbrief":"mod above y with double dot"}}},{"category":"Ll","key":"0101","mappings":{"default":{"default":"latin small letter a with macron","alternative":"latin small letter a overbar","short":"a overbar"},"mathspeak":{"default":"a overbar","brief":"a overbar","sbrief":"a overbar"}}},{"category":"Ll","key":"0103","mappings":{"default":{"default":"latin small letter a with breve","alternative":"latin small letter a breve","short":"a breve"},"mathspeak":{"default":"modifying above a with breve","brief":"mod above a with breve","sbrief":"mod above a with breve"}}},{"category":"Ll","key":"0105","mappings":{"default":{"default":"latin small letter a with ogonek","alternative":"latin small letter a ogonek","short":"a ogonek"},"mathspeak":{"default":"modifying above a with ogonek","brief":"mod above a with ogonek","sbrief":"mod above a with ogonek"}}},{"category":"Ll","key":"0107","mappings":{"default":{"default":"latin small letter c with acute","alternative":"latin small letter c acute","short":"c acute"},"mathspeak":{"default":"modifying above c with acute","brief":"mod above c with acute","sbrief":"mod above c with acute"}}},{"category":"Ll","key":"0109","mappings":{"default":{"default":"latin small letter c with circumflex","alternative":"latin small letter c hat","short":"c hat"},"mathspeak":{"default":"modifying above c with caret","brief":"mod above c with caret","sbrief":"mod above c with caret"}}},{"category":"Ll","key":"010B","mappings":{"default":{"default":"latin small letter c with dot above","alternative":"latin small letter c dot","short":"c overdot"},"mathspeak":{"default":"modifying above c with dot","brief":"mod above c with dot","sbrief":"mod above c with dot"}}},{"category":"Ll","key":"010D","mappings":{"default":{"default":"latin small letter c with caron","alternative":"latin small letter c hacek","short":"c caron"},"mathspeak":{"default":"modifying above c with caron","brief":"mod above c with caron","sbrief":"mod above c with caron"}}},{"category":"Ll","key":"010F","mappings":{"default":{"default":"latin small letter d with caron","alternative":"latin small letter d hacek","short":"d caron"},"mathspeak":{"default":"modifying above d with caron","brief":"mod above d with caron","sbrief":"mod above d with caron"}}},{"category":"Ll","key":"0113","mappings":{"default":{"default":"latin small letter e with macron","alternative":"latin small letter e overbar","short":"e overbar"},"mathspeak":{"default":"e overbar","brief":"e overbar","sbrief":"e overbar"}}},{"category":"Ll","key":"0115","mappings":{"default":{"default":"latin small letter e with breve","alternative":"latin small letter e breve","short":"e breve"},"mathspeak":{"default":"modifying above e with breve","brief":"mod above e with breve","sbrief":"mod above e with breve"}}},{"category":"Ll","key":"0117","mappings":{"default":{"default":"latin small letter e with dot above","alternative":"latin small letter e dot","short":"e overdot"},"mathspeak":{"default":"modifying above e with dot","brief":"mod above e with dot","sbrief":"mod above e with dot"}}},{"category":"Ll","key":"0119","mappings":{"default":{"default":"latin small letter e with ogonek","alternative":"latin small letter e ogonek","short":"e ogonek"},"mathspeak":{"default":"modifying above e with ogonek","brief":"mod above e with ogonek","sbrief":"mod above e with ogonek"}}},{"category":"Ll","key":"011B","mappings":{"default":{"default":"latin small letter e with caron","alternative":"latin small letter e hacek","short":"e caron"},"mathspeak":{"default":"modifying above e with caron","brief":"mod above e with caron","sbrief":"mod above e with caron"}}},{"category":"Ll","key":"011D","mappings":{"default":{"default":"latin small letter g with circumflex","alternative":"latin small letter g hat","short":"g hat"},"mathspeak":{"default":"modifying above g with caret","brief":"mod above g with caret","sbrief":"mod above g with caret"}}},{"category":"Ll","key":"011F","mappings":{"default":{"default":"latin small letter g with breve","alternative":"latin small letter g breve","short":"g breve"},"mathspeak":{"default":"modifying above g with breve","brief":"mod above g with breve","sbrief":"mod above g with breve"}}},{"category":"Ll","key":"0121","mappings":{"default":{"default":"latin small letter g with dot above","alternative":"latin small letter g dot","short":"g overdot"},"mathspeak":{"default":"modifying above g with dot","brief":"mod above g with dot","sbrief":"mod above g with dot"}}},{"category":"Ll","key":"0123","mappings":{"default":{"default":"latin small letter g with cedilla","alternative":"latin small letter g cedilla","short":"g cedilla"},"mathspeak":{"default":"modifying above g with cedilla","brief":"mod above g with cedilla","sbrief":"mod above g with cedilla"}}},{"category":"Ll","key":"0125","mappings":{"default":{"default":"latin small letter h with circumflex","alternative":"latin small letter h hat","short":"h hat"},"mathspeak":{"default":"modifying above h with caret","brief":"mod above h with caret","sbrief":"mod above h with caret"}}},{"category":"Ll","key":"0129","mappings":{"default":{"default":"latin small letter i with tilde","alternative":"latin small letter i tilde","short":"i tilde"},"mathspeak":{"default":"i overtilde","brief":"i overtilde","sbrief":"i overtilde"}}},{"category":"Ll","key":"012B","mappings":{"default":{"default":"latin small letter i with macron","alternative":"latin small letter i overbar","short":"i overbar"},"mathspeak":{"default":"i overbar","brief":"i overbar","sbrief":"i overbar"}}},{"category":"Ll","key":"012D","mappings":{"default":{"default":"latin small letter i with breve","alternative":"latin small letter i breve","short":"i breve"},"mathspeak":{"default":"modifying above i with breve","brief":"mod above i with breve","sbrief":"mod above i with breve"}}},{"category":"Ll","key":"012F","mappings":{"default":{"default":"latin small letter i with ogonek","alternative":"latin small letter i ogonek","short":"i ogonek"},"mathspeak":{"default":"modifying above i with ogonek","brief":"mod above i with ogonek","sbrief":"mod above i with ogonek"}}},{"category":"Ll","key":"0131","mappings":{"default":{"default":"latin small letter dotless i","alternative":"latin small letter dotless i","short":"dotless i"},"mathspeak":{"default":"modifying above d with tless i","brief":"mod above d with tless i","sbrief":"mod above d with tless i"}}},{"category":"Ll","key":"0135","mappings":{"default":{"default":"latin small letter j circumflex","alternative":"latin small letter j hat","short":"j hat"},"mathspeak":{"default":"modifying above j with caret","brief":"mod above j with caret","sbrief":"mod above j with caret"}}},{"category":"Ll","key":"0137","mappings":{"default":{"default":"latin small letter k with cedilla","alternative":"latin small letter k cedilla","short":"k cedilla"},"mathspeak":{"default":"modifying above k with cedilla","brief":"mod above k with cedilla","sbrief":"mod above k with cedilla"}}},{"category":"Ll","key":"013A","mappings":{"default":{"default":"latin small letter l with acute","alternative":"latin small letter l acute","short":"l acute"},"mathspeak":{"default":"modifying above l with acute","brief":"mod above l with acute","sbrief":"mod above l with acute"}}},{"category":"Ll","key":"013C","mappings":{"default":{"default":"latin small letter l with cedilla","alternative":"latin small letter l cedilla","short":"l cedilla"},"mathspeak":{"default":"modifying above l with cedilla","brief":"mod above l with cedilla","sbrief":"mod above l with cedilla"}}},{"category":"Ll","key":"013E","mappings":{"default":{"default":"latin small letter l with caron","alternative":"latin small letter l hacek","short":"l caron"},"mathspeak":{"default":"modifying above l with caron","brief":"mod above l with caron","sbrief":"mod above l with caron"}}},{"category":"Ll","key":"0140","mappings":{"default":{"default":"latin small letter l with middle dot","alternative":"latin small letter l middle dot","short":"l middle dot"},"mathspeak":{"default":"modifying above l with middle dot","brief":"mod above l with middle dot","sbrief":"mod above l with middle dot"}}},{"category":"Ll","key":"0144","mappings":{"default":{"default":"latin small letter n with acute","alternative":"latin small letter n acute","short":"n acute"},"mathspeak":{"default":"modifying above n with acute","brief":"mod above n with acute","sbrief":"mod above n with acute"}}},{"category":"Ll","key":"0146","mappings":{"default":{"default":"latin small letter n with cedilla","alternative":"latin small letter n cedilla","short":"n cedilla"},"mathspeak":{"default":"modifying above n with cedilla","brief":"mod above n with cedilla","sbrief":"mod above n with cedilla"}}},{"category":"Ll","key":"0148","mappings":{"default":{"default":"latin small letter n with caron","alternative":"latin small letter n hacek","short":"n caron"},"mathspeak":{"default":"modifying above n with caron","brief":"mod above n with caron","sbrief":"mod above n with caron"}}},{"category":"Ll","key":"014D","mappings":{"default":{"default":"latin small letter o macron","alternative":"latin small letter o overbar","short":"o overbar"},"mathspeak":{"default":"o overbar","brief":"o overbar","sbrief":"o overbar"}}},{"category":"Ll","key":"014F","mappings":{"default":{"default":"latin small letter o with breve","alternative":"latin small letter o breve","short":"o breve"},"mathspeak":{"default":"modifying above o with breve","brief":"mod above o with breve","sbrief":"mod above o with breve"}}},{"category":"Ll","key":"0151","mappings":{"default":{"default":"latin small letter o with double acute","alternative":"latin small letter o double acute","short":"o double acute"},"mathspeak":{"default":"modifying above o with double acute","brief":"mod above o with double acute","sbrief":"mod above o with double acute"}}},{"category":"Ll","key":"0155","mappings":{"default":{"default":"latin small letter r with acute","alternative":"latin small letter r acute","short":"r acute"},"mathspeak":{"default":"modifying above r with acute","brief":"mod above r with acute","sbrief":"mod above r with acute"}}},{"category":"Ll","key":"0157","mappings":{"default":{"default":"latin small letter r with cedilla","alternative":"latin small letter r cedilla","short":"r cedilla"},"mathspeak":{"default":"modifying above r with cedilla","brief":"mod above r with cedilla","sbrief":"mod above r with cedilla"}}},{"category":"Ll","key":"0159","mappings":{"default":{"default":"latin small letter r with caron","alternative":"latin small letter r hacek","short":"r caron"},"mathspeak":{"default":"modifying above r with caron","brief":"mod above r with caron","sbrief":"mod above r with caron"}}},{"category":"Ll","key":"015B","mappings":{"default":{"default":"latin small letter s with acute","alternative":"latin small letter s acute","short":"s acute"},"mathspeak":{"default":"modifying above s with acute","brief":"mod above s with acute","sbrief":"mod above s with acute"}}},{"category":"Ll","key":"015D","mappings":{"default":{"default":"latin small letter s with circumflex","alternative":"latin small letter s hat","short":"s hat"},"mathspeak":{"default":"modifying above s with caret","brief":"mod above s with caret","sbrief":"mod above s with caret"}}},{"category":"Ll","key":"015F","mappings":{"default":{"default":"latin small letter s with cedilla","alternative":"latin small letter s cedilla","short":"s cedilla"},"mathspeak":{"default":"modifying above s with cedilla","brief":"mod above s with cedilla","sbrief":"mod above s with cedilla"}}},{"category":"Ll","key":"0161","mappings":{"default":{"default":"latin small letter s with caron","alternative":"latin small letter s hacek","short":"s caron"},"mathspeak":{"default":"modifying above s with caron","brief":"mod above s with caron","sbrief":"mod above s with caron"}}},{"category":"Ll","key":"0163","mappings":{"default":{"default":"latin small letter t with cedilla","alternative":"latin small letter t cedilla","short":"t cedilla"},"mathspeak":{"default":"modifying above t with cedilla","brief":"mod above t with cedilla","sbrief":"mod above t with cedilla"}}},{"category":"Ll","key":"0165","mappings":{"default":{"default":"latin small letter t with caron","alternative":"latin small letter t hacek","short":"t caron"},"mathspeak":{"default":"modifying above t with caron","brief":"mod above t with caron","sbrief":"mod above t with caron"}}},{"category":"Ll","key":"0169","mappings":{"default":{"default":"latin small letter u with tilde","alternative":"latin small letter u tilde","short":"u tilde"},"mathspeak":{"default":"u overtilde","brief":"u overtilde","sbrief":"u overtilde"}}},{"category":"Ll","key":"016B","mappings":{"default":{"default":"latin small letter u with macron","alternative":"latin small letter u overbar","short":"u overbar"},"mathspeak":{"default":"u overbar","brief":"u overbar","sbrief":"u overbar"}}},{"category":"Ll","key":"016D","mappings":{"default":{"default":"latin small letter u with breve","alternative":"latin small letter u breve","short":"u breve"},"mathspeak":{"default":"modifying above u with breve","brief":"mod above u with breve","sbrief":"mod above u with breve"}}},{"category":"Ll","key":"016F","mappings":{"default":{"default":"latin small letter u with ring above","alternative":"latin small letter u ring","short":"u ring"},"mathspeak":{"default":"modifying above u with ring","brief":"mod above u with ring","sbrief":"mod above u with ring"}}},{"category":"Ll","key":"0171","mappings":{"default":{"default":"latin small letter u with double acute","alternative":"latin small letter u double acute","short":"u double acute"},"mathspeak":{"default":"modifying above u with double acute","brief":"mod above u with double acute","sbrief":"mod above u with double acute"}}},{"category":"Ll","key":"0173","mappings":{"default":{"default":"latin small letter u with ogonek","alternative":"latin small letter u ogonek","short":"u ogonek"},"mathspeak":{"default":"modifying above u with ogonek","brief":"mod above u with ogonek","sbrief":"mod above u with ogonek"}}},{"category":"Ll","key":"0175","mappings":{"default":{"default":"latin small letter w with circumflex","alternative":"latin small letter w hat","short":"w hat"},"mathspeak":{"default":"modifying above w with caret","brief":"mod above w with caret","sbrief":"mod above w with caret"}}},{"category":"Ll","key":"0177","mappings":{"default":{"default":"latin small letter y with circumflex","alternative":"latin small letter y hat","short":"y hat"},"mathspeak":{"default":"modifying above y with caret","brief":"mod above y with caret","sbrief":"mod above y with caret"}}},{"category":"Ll","key":"017A","mappings":{"default":{"default":"latin small letter z with acute","alternative":"latin small letter z acute","short":"z acute"},"mathspeak":{"default":"modifying above z with acute","brief":"mod above z with acute","sbrief":"mod above z with acute"}}},{"category":"Ll","key":"017C","mappings":{"default":{"default":"latin small letter z with dot above","alternative":"latin small letter z dot","short":"z overdot"},"mathspeak":{"default":"modifying above z with dot","brief":"mod above z with dot","sbrief":"mod above z with dot"}}},{"category":"Ll","key":"017E","mappings":{"default":{"default":"latin small letter z with caron","alternative":"latin small letter z hacek","short":"z caron"},"mathspeak":{"default":"modifying above z with caron","brief":"mod above z with caron","sbrief":"mod above z with caron"}}},{"category":"Ll","key":"01CE","mappings":{"default":{"default":"latin small letter a with caron","alternative":"latin small letter a hacek","short":"a caron"},"mathspeak":{"default":"modifying above a with caron","brief":"mod above a with caron","sbrief":"mod above a with caron"}}},{"category":"Ll","key":"01D0","mappings":{"default":{"default":"latin small letter i with caron","alternative":"latin small letter i hacek","short":"i caron"},"mathspeak":{"default":"modifying above i with caron","brief":"mod above i with caron","sbrief":"mod above i with caron"}}},{"category":"Ll","key":"01D2","mappings":{"default":{"default":"latin small letter o with caron","alternative":"latin small letter o hacek","short":"o caron"},"mathspeak":{"default":"modifying above o with caron","brief":"mod above o with caron","sbrief":"mod above o with caron"}}},{"category":"Ll","key":"01D4","mappings":{"default":{"default":"latin small letter u with caron","alternative":"latin small letter u hacek","short":"u caron"},"mathspeak":{"default":"modifying above u with caron","brief":"mod above u with caron","sbrief":"mod above u with caron"}}},{"category":"Ll","key":"01E7","mappings":{"default":{"default":"latin small letter g with caron","alternative":"latin small letter g hacek","short":"g caron"},"mathspeak":{"default":"modifying above g with caron","brief":"mod above g with caron","sbrief":"mod above g with caron"}}},{"category":"Ll","key":"01E9","mappings":{"default":{"default":"latin small letter k with caron","alternative":"latin small letter k hacek","short":"k caron"},"mathspeak":{"default":"modifying above k with caron","brief":"mod above k with caron","sbrief":"mod above k with caron"}}},{"category":"Ll","key":"01EB","mappings":{"default":{"default":"latin small letter o with ogonek","alternative":"latin small letter o ogonek","short":"o ogonek"},"mathspeak":{"default":"modifying above o with ogonek","brief":"mod above o with ogonek","sbrief":"mod above o with ogonek"}}},{"category":"Ll","key":"01F0","mappings":{"default":{"default":"latin small letter j with caron","alternative":"latin small letter j hacek","short":"j caron"},"mathspeak":{"default":"modifying above j with caron","brief":"mod above j with caron","sbrief":"mod above j with caron"}}},{"category":"Ll","key":"01F5","mappings":{"default":{"default":"latin small letter g with acute","alternative":"latin small letter g acute","short":"g acute"},"mathspeak":{"default":"modifying above g with acute","brief":"mod above g with acute","sbrief":"mod above g with acute"}}},{"category":"Ll","key":"01F9","mappings":{"default":{"default":"latin small letter n with grave","alternative":"latin small letter n grave","short":"n grave"},"mathspeak":{"default":"modifying above n with grave","brief":"mod above n with grave","sbrief":"mod above n with grave"}}},{"category":"Ll","key":"0201","mappings":{"default":{"default":"latin small letter a with double grave","alternative":"latin small letter a double grave","short":"a double grave"},"mathspeak":{"default":"modifying above a with double grave","brief":"mod above a with double grave","sbrief":"mod above a with double grave"}}},{"category":"Ll","key":"0203","mappings":{"default":{"default":"latin small letter a with inverted breve","alternative":"latin small letter a inverted breve","short":"a inverted breve"},"mathspeak":{"default":"modifying above a with inverted breve","brief":"mod above a with inverted breve","sbrief":"mod above a with inverted breve"}}},{"category":"Ll","key":"0205","mappings":{"default":{"default":"latin small letter e with double grave","alternative":"latin small letter e double grave","short":"e double grave"},"mathspeak":{"default":"modifying above e with double grave","brief":"mod above e with double grave","sbrief":"mod above e with double grave"}}},{"category":"Ll","key":"0207","mappings":{"default":{"default":"latin small letter e with inverted breve","alternative":"latin small letter e inverted breve","short":"e inverted breve"},"mathspeak":{"default":"modifying above e with inverted breve","brief":"mod above e with inverted breve","sbrief":"mod above e with inverted breve"}}},{"category":"Ll","key":"0209","mappings":{"default":{"default":"latin small letter i with double grave","alternative":"latin small letter i double grave","short":"i double grave"},"mathspeak":{"default":"modifying above i with double grave","brief":"mod above i with double grave","sbrief":"mod above i with double grave"}}},{"category":"Ll","key":"020B","mappings":{"default":{"default":"latin small letter i with inverted breve","alternative":"latin small letter i inverted breve","short":"i inverted breve"},"mathspeak":{"default":"modifying above i with inverted breve","brief":"mod above i with inverted breve","sbrief":"mod above i with inverted breve"}}},{"category":"Ll","key":"020D","mappings":{"default":{"default":"latin small letter o with double grave","alternative":"latin small letter o double grave","short":"o double grave"},"mathspeak":{"default":"modifying above o with double grave","brief":"mod above o with double grave","sbrief":"mod above o with double grave"}}},{"category":"Ll","key":"020F","mappings":{"default":{"default":"latin small letter o with inverted breve","alternative":"latin small letter o inverted breve","short":"o inverted breve"},"mathspeak":{"default":"modifying above o with inverted breve","brief":"mod above o with inverted breve","sbrief":"mod above o with inverted breve"}}},{"category":"Ll","key":"0211","mappings":{"default":{"default":"latin small letter r with double grave","alternative":"latin small letter r double grave","short":"r double grave"},"mathspeak":{"default":"modifying above r with double grave","brief":"mod above r with double grave","sbrief":"mod above r with double grave"}}},{"category":"Ll","key":"0213","mappings":{"default":{"default":"latin small letter r with inverted breve","alternative":"latin small letter r inverted breve","short":"r inverted breve"},"mathspeak":{"default":"modifying above r with inverted breve","brief":"mod above r with inverted breve","sbrief":"mod above r with inverted breve"}}},{"category":"Ll","key":"0215","mappings":{"default":{"default":"latin small letter u with double grave","alternative":"latin small letter u double grave","short":"u double grave"},"mathspeak":{"default":"modifying above u with double grave","brief":"mod above u with double grave","sbrief":"mod above u with double grave"}}},{"category":"Ll","key":"0217","mappings":{"default":{"default":"latin small letter u with inverted breve","alternative":"latin small letter u inverted breve","short":"u inverted breve"},"mathspeak":{"default":"modifying above u with inverted breve","brief":"mod above u with inverted breve","sbrief":"mod above u with inverted breve"}}},{"category":"Ll","key":"0219","mappings":{"default":{"default":"latin small letter s with comma below","alternative":"latin small letter s comma below","short":"s comma below"},"mathspeak":{"default":"modifying below s with comma below","brief":"mod below s with comma below","sbrief":"mod below s with comma below"}}},{"category":"Ll","key":"021B","mappings":{"default":{"default":"latin small letter t with comma below","alternative":"latin small letter t comma below","short":"t comma below"},"mathspeak":{"default":"modifying below t with comma below","brief":"mod below t with comma below","sbrief":"mod below t with comma below"}}},{"category":"Ll","key":"021F","mappings":{"default":{"default":"latin small letter h with caron","alternative":"latin small letter h caron","short":"h caron"},"mathspeak":{"default":"modifying above h with caron","brief":"mod above h with caron","sbrief":"mod above h with caron"}}},{"category":"Ll","key":"0227","mappings":{"default":{"default":"latin small letter a with dot above","alternative":"latin small letter a overdot","short":"a overdot"},"mathspeak":{"default":"modifying above a with dot","brief":"mod above a with dot","sbrief":"mod above a with dot"}}},{"category":"Ll","key":"0229","mappings":{"default":{"default":"latin small letter e with cedilla","alternative":"latin small letter e cedilla","short":"e cedilla"},"mathspeak":{"default":"modifying above e with cedilla","brief":"mod above e with cedilla","sbrief":"mod above e with cedilla"}}},{"category":"Ll","key":"022F","mappings":{"default":{"default":"latin small letter o with dot above","alternative":"latin small letter o overdot","short":"o overdot"},"mathspeak":{"default":"modifying above o with dot","brief":"mod above o with dot","sbrief":"mod above o with dot"}}},{"category":"Ll","key":"0233","mappings":{"default":{"default":"latin small letter y with macron","alternative":"latin small letter y overbar","short":"y overbar"},"mathspeak":{"default":"y overbar","brief":"y overbar","sbrief":"y overbar"}}},{"category":"Ll","key":"0237","mappings":{"default":{"default":"latin small letter dotless j","alternative":"latin small letter dotless j","short":"dotless j"},"mathspeak":{"default":"modifying above d with tless j","brief":"mod above d with tless j","sbrief":"mod above d with tless j"}}},{"category":"Ll","key":"1E01","mappings":{"default":{"default":"latin small letter a ring below","alternative":"latin small letter a ring below","short":"a ring below"},"mathspeak":{"default":"modifying below a with ring below","brief":"mod below a with ring below","sbrief":"mod below a with ring below"}}},{"category":"Ll","key":"1E03","mappings":{"default":{"default":"latin small letter b with dot above","alternative":"latin small letter b overdot","short":"b overdot"},"mathspeak":{"default":"modifying above b with dot","brief":"mod above b with dot","sbrief":"mod above b with dot"}}},{"category":"Ll","key":"1E05","mappings":{"default":{"default":"latin small letter b with dot below","alternative":"latin small letter b underdot","short":"b underdot"},"mathspeak":{"default":"modifying below b with dot","brief":"mod below b with dot","sbrief":"mod below b with dot"}}},{"category":"Ll","key":"1E07","mappings":{"default":{"default":"latin small letter b with line below","alternative":"latin small letter b underbar","short":"b underbar"},"mathspeak":{"default":"b underbar","brief":"b underbar","sbrief":"b underbar"}}},{"category":"Ll","key":"1E0B","mappings":{"default":{"default":"latin small letter d with dot above","alternative":"latin small letter d overdot","short":"d overdot"},"mathspeak":{"default":"modifying above d with dot","brief":"mod above d with dot","sbrief":"mod above d with dot"}}},{"category":"Ll","key":"1E0D","mappings":{"default":{"default":"latin small letter d with dot below","alternative":"latin small letter d underdot","short":"d underdot"},"mathspeak":{"default":"modifying below d with dot","brief":"mod below d with dot","sbrief":"mod below d with dot"}}},{"category":"Ll","key":"1E0F","mappings":{"default":{"default":"latin small letter d with line below","alternative":"latin small letter d underbar","short":"d underbar"},"mathspeak":{"default":"d underbar","brief":"d underbar","sbrief":"d underbar"}}},{"category":"Ll","key":"1E11","mappings":{"default":{"default":"latin small letter d with cedilla","alternative":"latin small letter d cedilla","short":"d cedilla"},"mathspeak":{"default":"modifying above d with cedilla","brief":"mod above d with cedilla","sbrief":"mod above d with cedilla"}}},{"category":"Ll","key":"1E13","mappings":{"default":{"default":"latin small letter d with circumflex below","alternative":"latin small letter d underhat","short":"d underhat"},"mathspeak":{"default":"modifying below d with caret","brief":"mod below d with caret","sbrief":"mod below d with caret"}}},{"category":"Ll","key":"1E19","mappings":{"default":{"default":"latin small letter e with circumflex below","alternative":"latin small letter e underhat","short":"e underhat"},"mathspeak":{"default":"modifying below e with caret","brief":"mod below e with caret","sbrief":"mod below e with caret"}}},{"category":"Ll","key":"1E1B","mappings":{"default":{"default":"latin small letter e with tilde below","alternative":"latin small letter e tilde below","short":"e tilde below"},"mathspeak":{"default":"e undertilde","brief":"e undertilde","sbrief":"e undertilde"}}},{"category":"Ll","key":"1E1F","mappings":{"default":{"default":"latin small letter f with dot above","alternative":"latin small letter f overdot","short":"f overdot"},"mathspeak":{"default":"modifying above f with dot","brief":"mod above f with dot","sbrief":"mod above f with dot"}}},{"category":"Ll","key":"1E21","mappings":{"default":{"default":"latin small letter g with macron","alternative":"latin small letter g overbar","short":"g overbar"},"mathspeak":{"default":"g overbar","brief":"g overbar","sbrief":"g overbar"}}},{"category":"Ll","key":"1E23","mappings":{"default":{"default":"latin small letter h with dot above","alternative":"latin small letter h overdot","short":"h overdot"},"mathspeak":{"default":"modifying above h with dot","brief":"mod above h with dot","sbrief":"mod above h with dot"}}},{"category":"Ll","key":"1E25","mappings":{"default":{"default":"latin small letter h with dot below","alternative":"latin small letter h underdot","short":"h underdot"},"mathspeak":{"default":"modifying below h with dot","brief":"mod below h with dot","sbrief":"mod below h with dot"}}},{"category":"Ll","key":"1E27","mappings":{"default":{"default":"latin small letter h with diaeresis","alternative":"latin small letter h double overdot","short":"h double overdot"},"mathspeak":{"default":"modifying above h with double dot","brief":"mod above h with double dot","sbrief":"mod above h with double dot"}}},{"category":"Ll","key":"1E29","mappings":{"default":{"default":"latin small letter h with cedilla","alternative":"latin small letter h cedilla","short":"h cedilla"},"mathspeak":{"default":"modifying above h with cedilla","brief":"mod above h with cedilla","sbrief":"mod above h with cedilla"}}},{"category":"Ll","key":"1E2B","mappings":{"default":{"default":"latin small letter h with breve below","alternative":"latin small letter h breve below","short":"h breve below"},"mathspeak":{"default":"modifying below h with breve below","brief":"mod below h with breve below","sbrief":"mod below h with breve below"}}},{"category":"Ll","key":"1E2D","mappings":{"default":{"default":"latin small letter i with tilde below","alternative":"latin small letter i tilde below","short":"i tilde below"},"mathspeak":{"default":"i undertilde","brief":"i undertilde","sbrief":"i undertilde"}}},{"category":"Ll","key":"1E31","mappings":{"default":{"default":"latin small letter k with acute","alternative":"latin small letter k acute","short":"k acute"},"mathspeak":{"default":"modifying above k with acute","brief":"mod above k with acute","sbrief":"mod above k with acute"}}},{"category":"Ll","key":"1E33","mappings":{"default":{"default":"latin small letter k with dot below","alternative":"latin small letter k underdot","short":"k underdot"},"mathspeak":{"default":"modifying below k with dot","brief":"mod below k with dot","sbrief":"mod below k with dot"}}},{"category":"Ll","key":"1E35","mappings":{"default":{"default":"latin small letter k with line below","alternative":"latin small letter k underbar","short":"k underbar"},"mathspeak":{"default":"k underbar","brief":"k underbar","sbrief":"k underbar"}}},{"category":"Ll","key":"1E37","mappings":{"default":{"default":"latin small letter l with dot below","alternative":"latin small letter l underdot","short":"l underdot"},"mathspeak":{"default":"modifying below l with dot","brief":"mod below l with dot","sbrief":"mod below l with dot"}}},{"category":"Ll","key":"1E3B","mappings":{"default":{"default":"latin small letter l with line below","alternative":"latin small letter l underbar","short":"l underbar"},"mathspeak":{"default":"l underbar","brief":"l underbar","sbrief":"l underbar"}}},{"category":"Ll","key":"1E3D","mappings":{"default":{"default":"latin small letter l with circumflex below","alternative":"latin small letter l underhat","short":"l underhat"},"mathspeak":{"default":"modifying below l with caret","brief":"mod below l with caret","sbrief":"mod below l with caret"}}},{"category":"Ll","key":"1E3F","mappings":{"default":{"default":"latin small letter m with acute","alternative":"latin small letter m acute","short":"m acute"},"mathspeak":{"default":"modifying above m with acute","brief":"mod above m with acute","sbrief":"mod above m with acute"}}},{"category":"Ll","key":"1E41","mappings":{"default":{"default":"latin small letter m with dot above","alternative":"latin small letter m overdot","short":"m overdot"},"mathspeak":{"default":"modifying above m with dot","brief":"mod above m with dot","sbrief":"mod above m with dot"}}},{"category":"Ll","key":"1E43","mappings":{"default":{"default":"latin small letter m with dot below","alternative":"latin small letter m underdot","short":"m underdot"},"mathspeak":{"default":"modifying below m with dot","brief":"mod below m with dot","sbrief":"mod below m with dot"}}},{"category":"Ll","key":"1E45","mappings":{"default":{"default":"latin small letter n with dot above","alternative":"latin small letter n overdot","short":"n overdot"},"mathspeak":{"default":"modifying above n with dot","brief":"mod above n with dot","sbrief":"mod above n with dot"}}},{"category":"Ll","key":"1E47","mappings":{"default":{"default":"latin small letter n with dot below","alternative":"latin small letter n underdot","short":"n underdot"},"mathspeak":{"default":"modifying below n with dot","brief":"mod below n with dot","sbrief":"mod below n with dot"}}},{"category":"Ll","key":"1E49","mappings":{"default":{"default":"latin small letter n with line below","alternative":"latin small letter n underbar","short":"n underbar"},"mathspeak":{"default":"n underbar","brief":"n underbar","sbrief":"n underbar"}}},{"category":"Ll","key":"1E4B","mappings":{"default":{"default":"latin small letter n with circumflex below","alternative":"latin small letter n underhat","short":"n underhat"},"mathspeak":{"default":"modifying below n with caret","brief":"mod below n with caret","sbrief":"mod below n with caret"}}},{"category":"Ll","key":"1E55","mappings":{"default":{"default":"latin small letter p with acute","alternative":"latin small letter p acute","short":"p acute"},"mathspeak":{"default":"modifying above p with acute","brief":"mod above p with acute","sbrief":"mod above p with acute"}}},{"category":"Ll","key":"1E57","mappings":{"default":{"default":"latin small letter p with dot above","alternative":"latin small letter p overdot","short":"p overdot"},"mathspeak":{"default":"modifying above p with dot","brief":"mod above p with dot","sbrief":"mod above p with dot"}}},{"category":"Ll","key":"1E59","mappings":{"default":{"default":"latin small letter r with dot above","alternative":"latin small letter r overdot","short":"r overdot"},"mathspeak":{"default":"modifying above r with dot","brief":"mod above r with dot","sbrief":"mod above r with dot"}}},{"category":"Ll","key":"1E5B","mappings":{"default":{"default":"latin small letter r with dot below","alternative":"latin small letter r underdot","short":"r underdot"},"mathspeak":{"default":"modifying below r with dot","brief":"mod below r with dot","sbrief":"mod below r with dot"}}},{"category":"Ll","key":"1E5F","mappings":{"default":{"default":"latin small letter r with line below","alternative":"latin small letter r underbar","short":"r underbar"},"mathspeak":{"default":"r underbar","brief":"r underbar","sbrief":"r underbar"}}},{"category":"Ll","key":"1E61","mappings":{"default":{"default":"latin small letter s with dot above","alternative":"latin small letter s overdot","short":"s overdot"},"mathspeak":{"default":"modifying above s with dot","brief":"mod above s with dot","sbrief":"mod above s with dot"}}},{"category":"Ll","key":"1E63","mappings":{"default":{"default":"latin small letter s with dot below","alternative":"latin small letter s underdot","short":"s underdot"},"mathspeak":{"default":"modifying below s with dot","brief":"mod below s with dot","sbrief":"mod below s with dot"}}},{"category":"Ll","key":"1E6B","mappings":{"default":{"default":"latin small letter t with dot above","alternative":"latin small letter t overdot","short":"t overdot"},"mathspeak":{"default":"modifying above t with dot","brief":"mod above t with dot","sbrief":"mod above t with dot"}}},{"category":"Ll","key":"1E6D","mappings":{"default":{"default":"latin small letter t with dot below","alternative":"latin small letter t underdot","short":"t underdot"},"mathspeak":{"default":"modifying below t with dot","brief":"mod below t with dot","sbrief":"mod below t with dot"}}},{"category":"Ll","key":"1E6F","mappings":{"default":{"default":"latin small letter t with line below","alternative":"latin small letter t underbar","short":"t underbar"},"mathspeak":{"default":"t underbar","brief":"t underbar","sbrief":"t underbar"}}},{"category":"Ll","key":"1E71","mappings":{"default":{"default":"latin small letter t with circumflex below","alternative":"latin small letter t underhat","short":"t underhat"},"mathspeak":{"default":"modifying below t with caret","brief":"mod below t with caret","sbrief":"mod below t with caret"}}},{"category":"Ll","key":"1E73","mappings":{"default":{"default":"latin small letter u with diaeresis below","alternative":"latin small letter u double underdot","short":"u double underdot"},"mathspeak":{"default":"modifying below u with double dot","brief":"mod below u with double dot","sbrief":"mod below u with double dot"}}},{"category":"Ll","key":"1E75","mappings":{"default":{"default":"latin small letter u with tilde below","alternative":"latin small letter u tilde below","short":"u tilde below"},"mathspeak":{"default":"u undertilde","brief":"u undertilde","sbrief":"u undertilde"}}},{"category":"Ll","key":"1E77","mappings":{"default":{"default":"latin small letter u with circumflex below","alternative":"latin small letter u underhat","short":"u underhat"},"mathspeak":{"default":"modifying below u with caret","brief":"mod below u with caret","sbrief":"mod below u with caret"}}},{"category":"Ll","key":"1E7D","mappings":{"default":{"default":"latin small letter v with tilde","alternative":"latin small letter v tilde","short":"v tilde"},"mathspeak":{"default":"v overtilde","brief":"v overtilde","sbrief":"v overtilde"}}},{"category":"Ll","key":"1E7F","mappings":{"default":{"default":"latin small letter v with dot below","alternative":"latin small letter v underdot","short":"v underdot"},"mathspeak":{"default":"modifying below v with dot","brief":"mod below v with dot","sbrief":"mod below v with dot"}}},{"category":"Ll","key":"1E81","mappings":{"default":{"default":"latin small letter w with grave","alternative":"latin small letter w grave","short":"w grave"},"mathspeak":{"default":"modifying above w with grave","brief":"mod above w with grave","sbrief":"mod above w with grave"}}},{"category":"Ll","key":"1E83","mappings":{"default":{"default":"latin small letter w with acute","alternative":"latin small letter w acute","short":"w acute"},"mathspeak":{"default":"modifying above w with acute","brief":"mod above w with acute","sbrief":"mod above w with acute"}}},{"category":"Ll","key":"1E85","mappings":{"default":{"default":"latin small letter w with diaeresis","alternative":"latin small letter w double overdot","short":"w double overdot"},"mathspeak":{"default":"modifying above w with double dot","brief":"mod above w with double dot","sbrief":"mod above w with double dot"}}},{"category":"Ll","key":"1E87","mappings":{"default":{"default":"latin small letter w with dot above","alternative":"latin small letter w overdot","short":"w overdot"},"mathspeak":{"default":"modifying above w with dot","brief":"mod above w with dot","sbrief":"mod above w with dot"}}},{"category":"Ll","key":"1E89","mappings":{"default":{"default":"latin small letter w with dot below","alternative":"latin small letter w underdot","short":"w underdot"},"mathspeak":{"default":"modifying below w with dot","brief":"mod below w with dot","sbrief":"mod below w with dot"}}},{"category":"Ll","key":"1E8B","mappings":{"default":{"default":"latin small letter x with dot above","alternative":"latin small letter x overdot","short":"x overdot"},"mathspeak":{"default":"modifying above x with dot","brief":"mod above x with dot","sbrief":"mod above x with dot"}}},{"category":"Ll","key":"1E8D","mappings":{"default":{"default":"latin small letter x with diaeresis","alternative":"latin small letter x double overdot","short":"x double overdot"},"mathspeak":{"default":"modifying above x with double dot","brief":"mod above x with double dot","sbrief":"mod above x with double dot"}}},{"category":"Ll","key":"1E8F","mappings":{"default":{"default":"latin small letter y with dot above","alternative":"latin small letter y overdot","short":"y overdot"},"mathspeak":{"default":"modifying above y with dot","brief":"mod above y with dot","sbrief":"mod above y with dot"}}},{"category":"Ll","key":"1E91","mappings":{"default":{"default":"latin small letter z with circumflex","alternative":"latin small letter z hat","short":"z hat"},"mathspeak":{"default":"modifying above z with caret","brief":"mod above z with caret","sbrief":"mod above z with caret"}}},{"category":"Ll","key":"1E93","mappings":{"default":{"default":"latin small letter z with dot below","alternative":"latin small letter z underdot","short":"z underdot"},"mathspeak":{"default":"modifying below z with dot","brief":"mod below z with dot","sbrief":"mod below z with dot"}}},{"category":"Ll","key":"1E95","mappings":{"default":{"default":"latin small letter z with line below","alternative":"latin small letter z underbar","short":"z underbar"},"mathspeak":{"default":"z underbar","brief":"z underbar","sbrief":"z underbar"}}},{"category":"Ll","key":"1E96","mappings":{"default":{"default":"latin small letter h with line below","alternative":"latin small letter h underbar","short":"h underbar"},"mathspeak":{"default":"h underbar","brief":"h underbar","sbrief":"h underbar"}}},{"category":"Ll","key":"1E97","mappings":{"default":{"default":"latin small letter t with diaeresis","alternative":"latin small letter t double overdot","short":"t double overdot"},"mathspeak":{"default":"modifying above t with double dot","brief":"mod above t with double dot","sbrief":"mod above t with double dot"}}},{"category":"Ll","key":"1E98","mappings":{"default":{"default":"latin small letter w with ring above","alternative":"latin small letter w ring","short":"w ring"},"mathspeak":{"default":"modifying above w with ring","brief":"mod above w with ring","sbrief":"mod above w with ring"}}},{"category":"Ll","key":"1E99","mappings":{"default":{"default":"latin small letter y with ring above","alternative":"latin small letter y ring","short":"y ring"},"mathspeak":{"default":"modifying above y with ring","brief":"mod above y with ring","sbrief":"mod above y with ring"}}},{"category":"Ll","key":"1E9A","mappings":{"default":{"default":"latin small letter a with right half ring","alternative":"latin small letter a right half ring","short":"a right half ring"},"mathspeak":{"default":"modifying above a with right half ring","brief":"mod above a with right half ring","sbrief":"mod above a with right half ring"}}},{"category":"Ll","key":"1EA1","mappings":{"default":{"default":"latin small letter a with dot below","alternative":"latin small letter a underdot","short":"a underdot"},"mathspeak":{"default":"modifying below a with dot","brief":"mod below a with dot","sbrief":"mod below a with dot"}}},{"category":"Ll","key":"1EA3","mappings":{"default":{"default":"latin small letter a with hook above","alternative":"latin small letter a hook","short":"a hook"},"mathspeak":{"default":"modifying above a with hook","brief":"mod above a with hook","sbrief":"mod above a with hook"}}},{"category":"Ll","key":"1EB9","mappings":{"default":{"default":"latin small letter e with dot below","alternative":"latin small letter e underdot","short":"e underdot"},"mathspeak":{"default":"modifying below e with dot","brief":"mod below e with dot","sbrief":"mod below e with dot"}}},{"category":"Ll","key":"1EBB","mappings":{"default":{"default":"latin small letter e with hook above","alternative":"latin small letter e hook","short":"e hook"},"mathspeak":{"default":"modifying above e with hook","brief":"mod above e with hook","sbrief":"mod above e with hook"}}},{"category":"Ll","key":"1EBD","mappings":{"default":{"default":"latin small letter e with tilde","alternative":"latin small letter e tilde","short":"e tilde"},"mathspeak":{"default":"e overtilde","brief":"e overtilde","sbrief":"e overtilde"}}},{"category":"Ll","key":"1EC9","mappings":{"default":{"default":"latin small letter i with hook above","alternative":"latin small letter i hook","short":"i hook"},"mathspeak":{"default":"modifying above i with hook","brief":"mod above i with hook","sbrief":"mod above i with hook"}}},{"category":"Ll","key":"1ECB","mappings":{"default":{"default":"latin small letter i with dot below","alternative":"latin small letter i underdot","short":"i underdot"},"mathspeak":{"default":"modifying below i with dot","brief":"mod below i with dot","sbrief":"mod below i with dot"}}},{"category":"Ll","key":"1ECD","mappings":{"default":{"default":"latin small letter o with dot below","alternative":"latin small letter o underdot","short":"o underdot"},"mathspeak":{"default":"modifying below o with dot","brief":"mod below o with dot","sbrief":"mod below o with dot"}}},{"category":"Ll","key":"1ECF","mappings":{"default":{"default":"latin small letter o with hook above","alternative":"latin small letter o hook","short":"o hook"},"mathspeak":{"default":"modifying above o with hook","brief":"mod above o with hook","sbrief":"mod above o with hook"}}},{"category":"Ll","key":"1EE5","mappings":{"default":{"default":"latin small letter u with dot below","alternative":"latin small letter u underdot","short":"u underdot"},"mathspeak":{"default":"modifying below u with dot","brief":"mod below u with dot","sbrief":"mod below u with dot"}}},{"category":"Ll","key":"1EE7","mappings":{"default":{"default":"latin small letter u with hook above","alternative":"latin small letter u hook","short":"u hook"},"mathspeak":{"default":"modifying above u with hook","brief":"mod above u with hook","sbrief":"mod above u with hook"}}},{"category":"Ll","key":"1EF3","mappings":{"default":{"default":"latin small letter y with grave","alternative":"latin small letter y grave","short":"y grave"},"mathspeak":{"default":"modifying above y with grave","brief":"mod above y with grave","sbrief":"mod above y with grave"}}},{"category":"Ll","key":"1EF5","mappings":{"default":{"default":"latin small letter y with dot below","alternative":"latin small letter y underdot","short":"y underdot"},"mathspeak":{"default":"modifying below y with dot","brief":"mod below y with dot","sbrief":"mod below y with dot"}}},{"category":"Ll","key":"1EF7","mappings":{"default":{"default":"latin small letter y with hook above","alternative":"latin small letter y hook","short":"y hook"},"mathspeak":{"default":"modifying above y with hook","brief":"mod above y with hook","sbrief":"mod above y with hook"}}},{"category":"Ll","key":"1EF9","mappings":{"default":{"default":"latin small letter y with tilde","alternative":"latin small letter y tilde","short":"y tilde"},"mathspeak":{"default":"y overtilde","brief":"y overtilde","sbrief":"y overtilde"}}}]
,
"en/latin-mathfonts-bold-fraktur.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital a","short":"bold fraktur cap a"},"mathspeak":{"default":"bold fraktur upper A"}},"key":"1D56C"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital b","short":"bold fraktur cap b"},"mathspeak":{"default":"bold fraktur upper B"}},"key":"1D56D"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital c","short":"bold fraktur cap c"},"mathspeak":{"default":"bold fraktur upper C"}},"key":"1D56E"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital d","short":"bold fraktur cap d"},"mathspeak":{"default":"bold fraktur upper D"}},"key":"1D56F"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital e","short":"bold fraktur cap e"},"mathspeak":{"default":"bold fraktur upper E"}},"key":"1D570"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital f","short":"bold fraktur cap f"},"mathspeak":{"default":"bold fraktur upper F"}},"key":"1D571"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital g","short":"bold fraktur cap g"},"mathspeak":{"default":"bold fraktur upper G"}},"key":"1D572"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital h","short":"bold fraktur cap h"},"mathspeak":{"default":"bold fraktur upper H"}},"key":"1D573"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital i","short":"bold fraktur cap i"},"mathspeak":{"default":"bold fraktur upper I"}},"key":"1D574"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital j","short":"bold fraktur cap j"},"mathspeak":{"default":"bold fraktur upper J"}},"key":"1D575"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital k","short":"bold fraktur cap k"},"mathspeak":{"default":"bold fraktur upper K"}},"key":"1D576"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital l","short":"bold fraktur cap l"},"mathspeak":{"default":"bold fraktur upper L"}},"key":"1D577"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital m","short":"bold fraktur cap m"},"mathspeak":{"default":"bold fraktur upper M"}},"key":"1D578"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital n","short":"bold fraktur cap n"},"mathspeak":{"default":"bold fraktur upper N"}},"key":"1D579"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital o","short":"bold fraktur cap o"},"mathspeak":{"default":"bold fraktur upper O"}},"key":"1D57A"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital p","short":"bold fraktur cap p"},"mathspeak":{"default":"bold fraktur upper P"}},"key":"1D57B"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital q","short":"bold fraktur cap q"},"mathspeak":{"default":"bold fraktur upper Q"}},"key":"1D57C"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital r","short":"bold fraktur cap r"},"mathspeak":{"default":"bold fraktur upper R"}},"key":"1D57D"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital s","short":"bold fraktur cap s"},"mathspeak":{"default":"bold fraktur upper S"}},"key":"1D57E"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital t","short":"bold fraktur cap t"},"mathspeak":{"default":"bold fraktur upper T"}},"key":"1D57F"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital u","short":"bold fraktur cap u"},"mathspeak":{"default":"bold fraktur upper U"}},"key":"1D580"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital v","short":"bold fraktur cap v"},"mathspeak":{"default":"bold fraktur upper V"}},"key":"1D581"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital w","short":"bold fraktur cap w"},"mathspeak":{"default":"bold fraktur upper W"}},"key":"1D582"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital x","short":"bold fraktur cap x"},"mathspeak":{"default":"bold fraktur upper X"}},"key":"1D583"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital y","short":"bold fraktur cap y"},"mathspeak":{"default":"bold fraktur upper Y"}},"key":"1D584"},{"category":"Lu","mappings":{"default":{"default":"bold fraktur capital z","short":"bold fraktur cap z"},"mathspeak":{"default":"bold fraktur upper Z"}},"key":"1D585"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small a","short":"bold fraktur a"}},"key":"1D586"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small b","short":"bold fraktur b"}},"key":"1D587"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small c","short":"bold fraktur c"}},"key":"1D588"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small d","short":"bold fraktur d"}},"key":"1D589"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small e","short":"bold fraktur e"}},"key":"1D58A"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small f","short":"bold fraktur f"}},"key":"1D58B"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small g","short":"bold fraktur g"}},"key":"1D58C"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small h","short":"bold fraktur h"}},"key":"1D58D"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small i","short":"bold fraktur i"}},"key":"1D58E"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small j","short":"bold fraktur j"}},"key":"1D58F"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small k","short":"bold fraktur k"}},"key":"1D590"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small l","short":"bold fraktur l"}},"key":"1D591"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small m","short":"bold fraktur m"}},"key":"1D592"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small n","short":"bold fraktur n"}},"key":"1D593"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small o","short":"bold fraktur o"}},"key":"1D594"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small p","short":"bold fraktur p"}},"key":"1D595"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small q","short":"bold fraktur q"}},"key":"1D596"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small r","short":"bold fraktur r"}},"key":"1D597"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small s","short":"bold fraktur s"}},"key":"1D598"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small t","short":"bold fraktur t"}},"key":"1D599"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small u","short":"bold fraktur u"}},"key":"1D59A"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small v","short":"bold fraktur v"}},"key":"1D59B"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small w","short":"bold fraktur w"}},"key":"1D59C"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small x","short":"bold fraktur x"}},"key":"1D59D"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small y","short":"bold fraktur y"}},"key":"1D59E"},{"category":"Ll","mappings":{"default":{"default":"bold fraktur small z","short":"bold fraktur z"}},"key":"1D59F"}]
,
"en/latin-mathfonts-bold-script.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"bold script capital a","short":"bold script cap a"},"mathspeak":{"default":"bold script upper A"}},"key":"1D4D0"},{"category":"Lu","mappings":{"default":{"default":"bold script capital b","short":"bold script cap b"},"mathspeak":{"default":"bold script upper B"}},"key":"1D4D1"},{"category":"Lu","mappings":{"default":{"default":"bold script capital c","short":"bold script cap c"},"mathspeak":{"default":"bold script upper C"}},"key":"1D4D2"},{"category":"Lu","mappings":{"default":{"default":"bold script capital d","short":"bold script cap d"},"mathspeak":{"default":"bold script upper D"}},"key":"1D4D3"},{"category":"Lu","mappings":{"default":{"default":"bold script capital e","short":"bold script cap e"},"mathspeak":{"default":"bold script upper E"}},"key":"1D4D4"},{"category":"Lu","mappings":{"default":{"default":"bold script capital f","short":"bold script cap f"},"mathspeak":{"default":"bold script upper F"}},"key":"1D4D5"},{"category":"Lu","mappings":{"default":{"default":"bold script capital g","short":"bold script cap g"},"mathspeak":{"default":"bold script upper G"}},"key":"1D4D6"},{"category":"Lu","mappings":{"default":{"default":"bold script capital h","short":"bold script cap h"},"mathspeak":{"default":"bold script upper H"}},"key":"1D4D7"},{"category":"Lu","mappings":{"default":{"default":"bold script capital i","short":"bold script cap i"},"mathspeak":{"default":"bold script upper I"}},"key":"1D4D8"},{"category":"Lu","mappings":{"default":{"default":"bold script capital j","short":"bold script cap j"},"mathspeak":{"default":"bold script upper J"}},"key":"1D4D9"},{"category":"Lu","mappings":{"default":{"default":"bold script capital k","short":"bold script cap k"},"mathspeak":{"default":"bold script upper K"}},"key":"1D4DA"},{"category":"Lu","mappings":{"default":{"default":"bold script capital l","short":"bold script cap l"},"mathspeak":{"default":"bold script upper L"}},"key":"1D4DB"},{"category":"Lu","mappings":{"default":{"default":"bold script capital m","short":"bold script cap m"},"mathspeak":{"default":"bold script upper M"}},"key":"1D4DC"},{"category":"Lu","mappings":{"default":{"default":"bold script capital n","short":"bold script cap n"},"mathspeak":{"default":"bold script upper N"}},"key":"1D4DD"},{"category":"Lu","mappings":{"default":{"default":"bold script capital o","short":"bold script cap o"},"mathspeak":{"default":"bold script upper O"}},"key":"1D4DE"},{"category":"Lu","mappings":{"default":{"default":"bold script capital p","short":"bold script cap p"},"mathspeak":{"default":"bold script upper P"}},"key":"1D4DF"},{"category":"Lu","mappings":{"default":{"default":"bold script capital q","short":"bold script cap q"},"mathspeak":{"default":"bold script upper Q"}},"key":"1D4E0"},{"category":"Lu","mappings":{"default":{"default":"bold script capital r","short":"bold script cap r"},"mathspeak":{"default":"bold script upper R"}},"key":"1D4E1"},{"category":"Lu","mappings":{"default":{"default":"bold script capital s","short":"bold script cap s"},"mathspeak":{"default":"bold script upper S"}},"key":"1D4E2"},{"category":"Lu","mappings":{"default":{"default":"bold script capital t","short":"bold script cap t"},"mathspeak":{"default":"bold script upper T"}},"key":"1D4E3"},{"category":"Lu","mappings":{"default":{"default":"bold script capital u","short":"bold script cap u"},"mathspeak":{"default":"bold script upper U"}},"key":"1D4E4"},{"category":"Lu","mappings":{"default":{"default":"bold script capital v","short":"bold script cap v"},"mathspeak":{"default":"bold script upper V"}},"key":"1D4E5"},{"category":"Lu","mappings":{"default":{"default":"bold script capital w","short":"bold script cap w"},"mathspeak":{"default":"bold script upper W"}},"key":"1D4E6"},{"category":"Lu","mappings":{"default":{"default":"bold script capital x","short":"bold script cap x"},"mathspeak":{"default":"bold script upper X"}},"key":"1D4E7"},{"category":"Lu","mappings":{"default":{"default":"bold script capital y","short":"bold script cap y"},"mathspeak":{"default":"bold script upper Y"}},"key":"1D4E8"},{"category":"Lu","mappings":{"default":{"default":"bold script capital z","short":"bold script cap z"},"mathspeak":{"default":"bold script upper Z"}},"key":"1D4E9"},{"category":"Ll","mappings":{"default":{"default":"bold script small a","short":"bold script a"}},"key":"1D4EA"},{"category":"Ll","mappings":{"default":{"default":"bold script small b","short":"bold script b"}},"key":"1D4EB"},{"category":"Ll","mappings":{"default":{"default":"bold script small c","short":"bold script c"}},"key":"1D4EC"},{"category":"Ll","mappings":{"default":{"default":"bold script small d","short":"bold script d"}},"key":"1D4ED"},{"category":"Ll","mappings":{"default":{"default":"bold script small e","short":"bold script e"}},"key":"1D4EE"},{"category":"Ll","mappings":{"default":{"default":"bold script small f","short":"bold script f"}},"key":"1D4EF"},{"category":"Ll","mappings":{"default":{"default":"bold script small g","short":"bold script g"}},"key":"1D4F0"},{"category":"Ll","mappings":{"default":{"default":"bold script small h","short":"bold script h"}},"key":"1D4F1"},{"category":"Ll","mappings":{"default":{"default":"bold script small i","short":"bold script i"}},"key":"1D4F2"},{"category":"Ll","mappings":{"default":{"default":"bold script small j","short":"bold script j"}},"key":"1D4F3"},{"category":"Ll","mappings":{"default":{"default":"bold script small k","short":"bold script k"}},"key":"1D4F4"},{"category":"Ll","mappings":{"default":{"default":"bold script small l","short":"bold script l"}},"key":"1D4F5"},{"category":"Ll","mappings":{"default":{"default":"bold script small m","short":"bold script m"}},"key":"1D4F6"},{"category":"Ll","mappings":{"default":{"default":"bold script small n","short":"bold script n"}},"key":"1D4F7"},{"category":"Ll","mappings":{"default":{"default":"bold script small o","short":"bold script o"}},"key":"1D4F8"},{"category":"Ll","mappings":{"default":{"default":"bold script small p","short":"bold script p"}},"key":"1D4F9"},{"category":"Ll","mappings":{"default":{"default":"bold script small q","short":"bold script q"}},"key":"1D4FA"},{"category":"Ll","mappings":{"default":{"default":"bold script small r","short":"bold script r"}},"key":"1D4FB"},{"category":"Ll","mappings":{"default":{"default":"bold script small s","short":"bold script s"}},"key":"1D4FC"},{"category":"Ll","mappings":{"default":{"default":"bold script small t","short":"bold script t"}},"key":"1D4FD"},{"category":"Ll","mappings":{"default":{"default":"bold script small u","short":"bold script u"}},"key":"1D4FE"},{"category":"Ll","mappings":{"default":{"default":"bold script small v","short":"bold script v"}},"key":"1D4FF"},{"category":"Ll","mappings":{"default":{"default":"bold script small w","short":"bold script w"}},"key":"1D500"},{"category":"Ll","mappings":{"default":{"default":"bold script small x","short":"bold script x"}},"key":"1D501"},{"category":"Ll","mappings":{"default":{"default":"bold script small y","short":"bold script y"}},"key":"1D502"},{"category":"Ll","mappings":{"default":{"default":"bold script small z","short":"bold script z"}},"key":"1D503"}]
,
"en/latin-mathfonts-bold.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"bold capital a","short":"bold cap a"},"mathspeak":{"default":"bold upper A"}},"key":"1D400"},{"category":"Lu","mappings":{"default":{"default":"bold capital b","short":"bold cap b"},"mathspeak":{"default":"bold upper B"}},"key":"1D401"},{"category":"Lu","mappings":{"default":{"default":"bold capital c","short":"bold cap c"},"mathspeak":{"default":"bold upper C"}},"key":"1D402"},{"category":"Lu","mappings":{"default":{"default":"bold capital d","short":"bold cap d"},"mathspeak":{"default":"bold upper D"}},"key":"1D403"},{"category":"Lu","mappings":{"default":{"default":"bold capital e","short":"bold cap e"},"mathspeak":{"default":"bold upper E"}},"key":"1D404"},{"category":"Lu","mappings":{"default":{"default":"bold capital f","short":"bold cap f"},"mathspeak":{"default":"bold upper F"}},"key":"1D405"},{"category":"Lu","mappings":{"default":{"default":"bold capital g","short":"bold cap g"},"mathspeak":{"default":"bold upper G"}},"key":"1D406"},{"category":"Lu","mappings":{"default":{"default":"bold capital h","short":"bold cap h"},"mathspeak":{"default":"bold upper H"}},"key":"1D407"},{"category":"Lu","mappings":{"default":{"default":"bold capital i","short":"bold cap i"},"mathspeak":{"default":"bold upper I"}},"key":"1D408"},{"category":"Lu","mappings":{"default":{"default":"bold capital j","short":"bold cap j"},"mathspeak":{"default":"bold upper J"}},"key":"1D409"},{"category":"Lu","mappings":{"default":{"default":"bold capital k","short":"bold cap k"},"mathspeak":{"default":"bold upper K"}},"key":"1D40A"},{"category":"Lu","mappings":{"default":{"default":"bold capital l","short":"bold cap l"},"mathspeak":{"default":"bold upper L"}},"key":"1D40B"},{"category":"Lu","mappings":{"default":{"default":"bold capital m","short":"bold cap m"},"mathspeak":{"default":"bold upper M"}},"key":"1D40C"},{"category":"Lu","mappings":{"default":{"default":"bold capital n","short":"bold cap n"},"mathspeak":{"default":"bold upper N"}},"key":"1D40D"},{"category":"Lu","mappings":{"default":{"default":"bold capital o","short":"bold cap o"},"mathspeak":{"default":"bold upper O"}},"key":"1D40E"},{"category":"Lu","mappings":{"default":{"default":"bold capital p","short":"bold cap p"},"mathspeak":{"default":"bold upper P"}},"key":"1D40F"},{"category":"Lu","mappings":{"default":{"default":"bold capital q","short":"bold cap q"},"mathspeak":{"default":"bold upper Q"}},"key":"1D410"},{"category":"Lu","mappings":{"default":{"default":"bold capital r","short":"bold cap r"},"mathspeak":{"default":"bold upper R"}},"key":"1D411"},{"category":"Lu","mappings":{"default":{"default":"bold capital s","short":"bold cap s"},"mathspeak":{"default":"bold upper S"}},"key":"1D412"},{"category":"Lu","mappings":{"default":{"default":"bold capital t","short":"bold cap t"},"mathspeak":{"default":"bold upper T"}},"key":"1D413"},{"category":"Lu","mappings":{"default":{"default":"bold capital u","short":"bold cap u"},"mathspeak":{"default":"bold upper U"}},"key":"1D414"},{"category":"Lu","mappings":{"default":{"default":"bold capital v","short":"bold cap v"},"mathspeak":{"default":"bold upper V"}},"key":"1D415"},{"category":"Lu","mappings":{"default":{"default":"bold capital w","short":"bold cap w"},"mathspeak":{"default":"bold upper W"}},"key":"1D416"},{"category":"Lu","mappings":{"default":{"default":"bold capital x","short":"bold cap x"},"mathspeak":{"default":"bold upper X"}},"key":"1D417"},{"category":"Lu","mappings":{"default":{"default":"bold capital y","short":"bold cap y"},"mathspeak":{"default":"bold upper Y"}},"key":"1D418"},{"category":"Lu","mappings":{"default":{"default":"bold capital z","short":"bold cap z"},"mathspeak":{"default":"bold upper Z"}},"key":"1D419"},{"category":"Ll","mappings":{"default":{"default":"bold small a","short":"bold a"}},"key":"1D41A"},{"category":"Ll","mappings":{"default":{"default":"bold small b","short":"bold b"}},"key":"1D41B"},{"category":"Ll","mappings":{"default":{"default":"bold small c","short":"bold c"}},"key":"1D41C"},{"category":"Ll","mappings":{"default":{"default":"bold small d","short":"bold d"}},"key":"1D41D"},{"category":"Ll","mappings":{"default":{"default":"bold small e","short":"bold e"}},"key":"1D41E"},{"category":"Ll","mappings":{"default":{"default":"bold small f","short":"bold f"}},"key":"1D41F"},{"category":"Ll","mappings":{"default":{"default":"bold small g","short":"bold g"}},"key":"1D420"},{"category":"Ll","mappings":{"default":{"default":"bold small h","short":"bold h"}},"key":"1D421"},{"category":"Ll","mappings":{"default":{"default":"bold small i","short":"bold i"}},"key":"1D422"},{"category":"Ll","mappings":{"default":{"default":"bold small j","short":"bold j"}},"key":"1D423"},{"category":"Ll","mappings":{"default":{"default":"bold small k","short":"bold k"}},"key":"1D424"},{"category":"Ll","mappings":{"default":{"default":"bold small l","short":"bold l"}},"key":"1D425"},{"category":"Ll","mappings":{"default":{"default":"bold small m","short":"bold m"}},"key":"1D426"},{"category":"Ll","mappings":{"default":{"default":"bold small n","short":"bold n"}},"key":"1D427"},{"category":"Ll","mappings":{"default":{"default":"bold small o","short":"bold o"}},"key":"1D428"},{"category":"Ll","mappings":{"default":{"default":"bold small p","short":"bold p"}},"key":"1D429"},{"category":"Ll","mappings":{"default":{"default":"bold small q","short":"bold q"}},"key":"1D42A"},{"category":"Ll","mappings":{"default":{"default":"bold small r","short":"bold r"}},"key":"1D42B"},{"category":"Ll","mappings":{"default":{"default":"bold small s","short":"bold s"}},"key":"1D42C"},{"category":"Ll","mappings":{"default":{"default":"bold small t","short":"bold t"}},"key":"1D42D"},{"category":"Ll","mappings":{"default":{"default":"bold small u","short":"bold u"}},"key":"1D42E"},{"category":"Ll","mappings":{"default":{"default":"bold small v","short":"bold v"}},"key":"1D42F"},{"category":"Ll","mappings":{"default":{"default":"bold small w","short":"bold w"}},"key":"1D430"},{"category":"Ll","mappings":{"default":{"default":"bold small x","short":"bold x"}},"key":"1D431"},{"category":"Ll","mappings":{"default":{"default":"bold small y","short":"bold y"}},"key":"1D432"},{"category":"Ll","mappings":{"default":{"default":"bold small z","short":"bold z"}},"key":"1D433"}]
,
"en/latin-mathfonts-double-struck.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"double struck capital a","short":"double struck cap a"},"mathspeak":{"default":"double struck upper A"}},"key":"1D538"},{"category":"Lu","mappings":{"default":{"default":"double struck capital b","short":"double struck cap b"},"mathspeak":{"default":"double struck upper B"}},"key":"1D539"},{"category":"Lu","mappings":{"default":{"default":"double struck capital c","short":"double struck cap c"},"mathspeak":{"default":"double struck upper C"}},"key":"2102"},{"category":"Lu","mappings":{"default":{"default":"double struck capital d","short":"double struck cap d"},"mathspeak":{"default":"double struck upper D"}},"key":"1D53B"},{"category":"Lu","mappings":{"default":{"default":"double struck capital e","short":"double struck cap e"},"mathspeak":{"default":"double struck upper E"}},"key":"1D53C"},{"category":"Lu","mappings":{"default":{"default":"double struck capital f","short":"double struck cap f"},"mathspeak":{"default":"double struck upper F"}},"key":"1D53D"},{"category":"Lu","mappings":{"default":{"default":"double struck capital g","short":"double struck cap g"},"mathspeak":{"default":"double struck upper G"}},"key":"1D53E"},{"category":"Lu","mappings":{"default":{"default":"double struck capital h","short":"double struck cap h"},"mathspeak":{"default":"double struck upper H"}},"key":"210D"},{"category":"Lu","mappings":{"default":{"default":"double struck capital i","short":"double struck cap i"},"mathspeak":{"default":"double struck upper I"}},"key":"1D540"},{"category":"Lu","mappings":{"default":{"default":"double struck capital j","short":"double struck cap j"},"mathspeak":{"default":"double struck upper J"}},"key":"1D541"},{"category":"Lu","mappings":{"default":{"default":"double struck capital k","short":"double struck cap k"},"mathspeak":{"default":"double struck upper K"}},"key":"1D542"},{"category":"Lu","mappings":{"default":{"default":"double struck capital l","short":"double struck cap l"},"mathspeak":{"default":"double struck upper L"}},"key":"1D543"},{"category":"Lu","mappings":{"default":{"default":"double struck capital m","short":"double struck cap m"},"mathspeak":{"default":"double struck upper M"}},"key":"1D544"},{"category":"Lu","mappings":{"default":{"default":"double struck capital n","short":"double struck cap n"},"mathspeak":{"default":"double struck upper N"}},"key":"2115"},{"category":"Lu","mappings":{"default":{"default":"double struck capital o","short":"double struck cap o"},"mathspeak":{"default":"double struck upper O"}},"key":"1D546"},{"category":"Lu","mappings":{"default":{"default":"double struck capital p","short":"double struck cap p"},"mathspeak":{"default":"double struck upper P"}},"key":"2119"},{"category":"Lu","mappings":{"default":{"default":"double struck capital q","short":"double struck cap q"},"mathspeak":{"default":"double struck upper Q"}},"key":"211A"},{"category":"Lu","mappings":{"default":{"default":"double struck capital r","short":"double struck cap r"},"mathspeak":{"default":"double struck upper R"}},"key":"211D"},{"category":"Lu","mappings":{"default":{"default":"double struck capital s","short":"double struck cap s"},"mathspeak":{"default":"double struck upper S"}},"key":"1D54A"},{"category":"Lu","mappings":{"default":{"default":"double struck capital t","short":"double struck cap t"},"mathspeak":{"default":"double struck upper T"}},"key":"1D54B"},{"category":"Lu","mappings":{"default":{"default":"double struck capital u","short":"double struck cap u"},"mathspeak":{"default":"double struck upper U"}},"key":"1D54C"},{"category":"Lu","mappings":{"default":{"default":"double struck capital v","short":"double struck cap v"},"mathspeak":{"default":"double struck upper V"}},"key":"1D54D"},{"category":"Lu","mappings":{"default":{"default":"double struck capital w","short":"double struck cap w"},"mathspeak":{"default":"double struck upper W"}},"key":"1D54E"},{"category":"Lu","mappings":{"default":{"default":"double struck capital x","short":"double struck cap x"},"mathspeak":{"default":"double struck upper X"}},"key":"1D54F"},{"category":"Lu","mappings":{"default":{"default":"double struck capital y","short":"double struck cap y"},"mathspeak":{"default":"double struck upper Y"}},"key":"1D550"},{"category":"Lu","mappings":{"default":{"default":"double struck capital z","short":"double struck cap z"},"mathspeak":{"default":"double struck upper Z"}},"key":"2124"},{"category":"Ll","mappings":{"default":{"default":"double struck small a","short":"double struck a"}},"key":"1D552"},{"category":"Ll","mappings":{"default":{"default":"double struck small b","short":"double struck b"}},"key":"1D553"},{"category":"Ll","mappings":{"default":{"default":"double struck small c","short":"double struck c"}},"key":"1D554"},{"category":"Ll","mappings":{"default":{"default":"double struck small d","short":"double struck d"}},"key":"1D555"},{"category":"Ll","mappings":{"default":{"default":"double struck small e","short":"double struck e"}},"key":"1D556"},{"category":"Ll","mappings":{"default":{"default":"double struck small f","short":"double struck f"}},"key":"1D557"},{"category":"Ll","mappings":{"default":{"default":"double struck small g","short":"double struck g"}},"key":"1D558"},{"category":"Ll","mappings":{"default":{"default":"double struck small h","short":"double struck h"}},"key":"1D559"},{"category":"Ll","mappings":{"default":{"default":"double struck small i","short":"double struck i"}},"key":"1D55A"},{"category":"Ll","mappings":{"default":{"default":"double struck small j","short":"double struck j"}},"key":"1D55B"},{"category":"Ll","mappings":{"default":{"default":"double struck small k","short":"double struck k"}},"key":"1D55C"},{"category":"Ll","mappings":{"default":{"default":"double struck small l","short":"double struck l"}},"key":"1D55D"},{"category":"Ll","mappings":{"default":{"default":"double struck small m","short":"double struck m"}},"key":"1D55E"},{"category":"Ll","mappings":{"default":{"default":"double struck small n","short":"double struck n"}},"key":"1D55F"},{"category":"Ll","mappings":{"default":{"default":"double struck small o","short":"double struck o"}},"key":"1D560"},{"category":"Ll","mappings":{"default":{"default":"double struck small p","short":"double struck p"}},"key":"1D561"},{"category":"Ll","mappings":{"default":{"default":"double struck small q","short":"double struck q"}},"key":"1D562"},{"category":"Ll","mappings":{"default":{"default":"double struck small r","short":"double struck r"}},"key":"1D563"},{"category":"Ll","mappings":{"default":{"default":"double struck small s","short":"double struck s"}},"key":"1D564"},{"category":"Ll","mappings":{"default":{"default":"double struck small t","short":"double struck t"}},"key":"1D565"},{"category":"Ll","mappings":{"default":{"default":"double struck small u","short":"double struck u"}},"key":"1D566"},{"category":"Ll","mappings":{"default":{"default":"double struck small v","short":"double struck v"}},"key":"1D567"},{"category":"Ll","mappings":{"default":{"default":"double struck small w","short":"double struck w"}},"key":"1D568"},{"category":"Ll","mappings":{"default":{"default":"double struck small x","short":"double struck x"}},"key":"1D569"},{"category":"Ll","mappings":{"default":{"default":"double struck small y","short":"double struck y"}},"key":"1D56A"},{"category":"Ll","mappings":{"default":{"default":"double struck small z","short":"double struck z"}},"key":"1D56B"}]
,
"en/latin-mathfonts-fraktur.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital a","short":"fraktur cap a"},"mathspeak":{"default":"fraktur upper A"}},"key":"1D504"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital b","short":"fraktur cap b"},"mathspeak":{"default":"fraktur upper B"}},"key":"1D505"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital c","short":"fraktur cap c"},"mathspeak":{"default":"fraktur upper C"}},"key":"212D"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital d","short":"fraktur cap d"},"mathspeak":{"default":"fraktur upper D"}},"key":"1D507"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital e","short":"fraktur cap e"},"mathspeak":{"default":"fraktur upper E"}},"key":"1D508"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital f","short":"fraktur cap f"},"mathspeak":{"default":"fraktur upper F"}},"key":"1D509"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital g","short":"fraktur cap g"},"mathspeak":{"default":"fraktur upper G"}},"key":"1D50A"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital h","short":"fraktur cap h"},"mathspeak":{"default":"fraktur upper H"}},"key":"210C"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital i","short":"fraktur cap i"},"mathspeak":{"default":"fraktur upper I"}},"key":"2111"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital j","short":"fraktur cap j"},"mathspeak":{"default":"fraktur upper J"}},"key":"1D50D"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital k","short":"fraktur cap k"},"mathspeak":{"default":"fraktur upper K"}},"key":"1D50E"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital l","short":"fraktur cap l"},"mathspeak":{"default":"fraktur upper L"}},"key":"1D50F"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital m","short":"fraktur cap m"},"mathspeak":{"default":"fraktur upper M"}},"key":"1D510"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital n","short":"fraktur cap n"},"mathspeak":{"default":"fraktur upper N"}},"key":"1D511"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital o","short":"fraktur cap o"},"mathspeak":{"default":"fraktur upper O"}},"key":"1D512"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital p","short":"fraktur cap p"},"mathspeak":{"default":"fraktur upper P"}},"key":"1D513"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital q","short":"fraktur cap q"},"mathspeak":{"default":"fraktur upper Q"}},"key":"1D514"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital r","short":"fraktur cap r"},"mathspeak":{"default":"fraktur upper R"}},"key":"211C"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital s","short":"fraktur cap s"},"mathspeak":{"default":"fraktur upper S"}},"key":"1D516"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital t","short":"fraktur cap t"},"mathspeak":{"default":"fraktur upper T"}},"key":"1D517"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital u","short":"fraktur cap u"},"mathspeak":{"default":"fraktur upper U"}},"key":"1D518"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital v","short":"fraktur cap v"},"mathspeak":{"default":"fraktur upper V"}},"key":"1D519"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital w","short":"fraktur cap w"},"mathspeak":{"default":"fraktur upper W"}},"key":"1D51A"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital x","short":"fraktur cap x"},"mathspeak":{"default":"fraktur upper X"}},"key":"1D51B"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital y","short":"fraktur cap y"},"mathspeak":{"default":"fraktur upper Y"}},"key":"1D51C"},{"category":"Lu","mappings":{"default":{"default":"fraktur capital z","short":"fraktur cap z"},"mathspeak":{"default":"fraktur upper Z"}},"key":"2128"},{"category":"Ll","mappings":{"default":{"default":"fraktur small a","short":"fraktur a"}},"key":"1D51E"},{"category":"Ll","mappings":{"default":{"default":"fraktur small b","short":"fraktur b"}},"key":"1D51F"},{"category":"Ll","mappings":{"default":{"default":"fraktur small c","short":"fraktur c"}},"key":"1D520"},{"category":"Ll","mappings":{"default":{"default":"fraktur small d","short":"fraktur d"}},"key":"1D521"},{"category":"Ll","mappings":{"default":{"default":"fraktur small e","short":"fraktur e"}},"key":"1D522"},{"category":"Ll","mappings":{"default":{"default":"fraktur small f","short":"fraktur f"}},"key":"1D523"},{"category":"Ll","mappings":{"default":{"default":"fraktur small g","short":"fraktur g"}},"key":"1D524"},{"category":"Ll","mappings":{"default":{"default":"fraktur small h","short":"fraktur h"}},"key":"1D525"},{"category":"Ll","mappings":{"default":{"default":"fraktur small i","short":"fraktur i"}},"key":"1D526"},{"category":"Ll","mappings":{"default":{"default":"fraktur small j","short":"fraktur j"}},"key":"1D527"},{"category":"Ll","mappings":{"default":{"default":"fraktur small k","short":"fraktur k"}},"key":"1D528"},{"category":"Ll","mappings":{"default":{"default":"fraktur small l","short":"fraktur l"}},"key":"1D529"},{"category":"Ll","mappings":{"default":{"default":"fraktur small m","short":"fraktur m"}},"key":"1D52A"},{"category":"Ll","mappings":{"default":{"default":"fraktur small n","short":"fraktur n"}},"key":"1D52B"},{"category":"Ll","mappings":{"default":{"default":"fraktur small o","short":"fraktur o"}},"key":"1D52C"},{"category":"Ll","mappings":{"default":{"default":"fraktur small p","short":"fraktur p"}},"key":"1D52D"},{"category":"Ll","mappings":{"default":{"default":"fraktur small q","short":"fraktur q"}},"key":"1D52E"},{"category":"Ll","mappings":{"default":{"default":"fraktur small r","short":"fraktur r"}},"key":"1D52F"},{"category":"Ll","mappings":{"default":{"default":"fraktur small s","short":"fraktur s"}},"key":"1D530"},{"category":"Ll","mappings":{"default":{"default":"fraktur small t","short":"fraktur t"}},"key":"1D531"},{"category":"Ll","mappings":{"default":{"default":"fraktur small u","short":"fraktur u"}},"key":"1D532"},{"category":"Ll","mappings":{"default":{"default":"fraktur small v","short":"fraktur v"}},"key":"1D533"},{"category":"Ll","mappings":{"default":{"default":"fraktur small w","short":"fraktur w"}},"key":"1D534"},{"category":"Ll","mappings":{"default":{"default":"fraktur small x","short":"fraktur x"}},"key":"1D535"},{"category":"Ll","mappings":{"default":{"default":"fraktur small y","short":"fraktur y"}},"key":"1D536"},{"category":"Ll","mappings":{"default":{"default":"fraktur small z","short":"fraktur z"}},"key":"1D537"}]
,
"en/latin-mathfonts-italic.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"italic capital a","short":"italic cap a"},"mathspeak":{"default":"italic upper A"}},"key":"1D434"},{"category":"Lu","mappings":{"default":{"default":"italic capital b","short":"italic cap b"},"mathspeak":{"default":"italic upper B"}},"key":"1D435"},{"category":"Lu","mappings":{"default":{"default":"italic capital c","short":"italic cap c"},"mathspeak":{"default":"italic upper C"}},"key":"1D436"},{"category":"Lu","mappings":{"default":{"default":"italic capital d","short":"italic cap d"},"mathspeak":{"default":"italic upper D"}},"key":"1D437"},{"category":"Lu","mappings":{"default":{"default":"italic capital e","short":"italic cap e"},"mathspeak":{"default":"italic upper E"}},"key":"1D438"},{"category":"Lu","mappings":{"default":{"default":"italic capital f","short":"italic cap f"},"mathspeak":{"default":"italic upper F"}},"key":"1D439"},{"category":"Lu","mappings":{"default":{"default":"italic capital g","short":"italic cap g"},"mathspeak":{"default":"italic upper G"}},"key":"1D43A"},{"category":"Lu","mappings":{"default":{"default":"italic capital h","short":"italic cap h"},"mathspeak":{"default":"italic upper H"}},"key":"1D43B"},{"category":"Lu","mappings":{"default":{"default":"italic capital i","short":"italic cap i"},"mathspeak":{"default":"italic upper I"}},"key":"1D43C"},{"category":"Lu","mappings":{"default":{"default":"italic capital j","short":"italic cap j"},"mathspeak":{"default":"italic upper J"}},"key":"1D43D"},{"category":"Lu","mappings":{"default":{"default":"italic capital k","short":"italic cap k"},"mathspeak":{"default":"italic upper K"}},"key":"1D43E"},{"category":"Lu","mappings":{"default":{"default":"italic capital l","short":"italic cap l"},"mathspeak":{"default":"italic upper L"}},"key":"1D43F"},{"category":"Lu","mappings":{"default":{"default":"italic capital m","short":"italic cap m"},"mathspeak":{"default":"italic upper M"}},"key":"1D440"},{"category":"Lu","mappings":{"default":{"default":"italic capital n","short":"italic cap n"},"mathspeak":{"default":"italic upper N"}},"key":"1D441"},{"category":"Lu","mappings":{"default":{"default":"italic capital o","short":"italic cap o"},"mathspeak":{"default":"italic upper O"}},"key":"1D442"},{"category":"Lu","mappings":{"default":{"default":"italic capital p","short":"italic cap p"},"mathspeak":{"default":"italic upper P"}},"key":"1D443"},{"category":"Lu","mappings":{"default":{"default":"italic capital q","short":"italic cap q"},"mathspeak":{"default":"italic upper Q"}},"key":"1D444"},{"category":"Lu","mappings":{"default":{"default":"italic capital r","short":"italic cap r"},"mathspeak":{"default":"italic upper R"}},"key":"1D445"},{"category":"Lu","mappings":{"default":{"default":"italic capital s","short":"italic cap s"},"mathspeak":{"default":"italic upper S"}},"key":"1D446"},{"category":"Lu","mappings":{"default":{"default":"italic capital t","short":"italic cap t"},"mathspeak":{"default":"italic upper T"}},"key":"1D447"},{"category":"Lu","mappings":{"default":{"default":"italic capital u","short":"italic cap u"},"mathspeak":{"default":"italic upper U"}},"key":"1D448"},{"category":"Lu","mappings":{"default":{"default":"italic capital v","short":"italic cap v"},"mathspeak":{"default":"italic upper V"}},"key":"1D449"},{"category":"Lu","mappings":{"default":{"default":"italic capital w","short":"italic cap w"},"mathspeak":{"default":"italic upper W"}},"key":"1D44A"},{"category":"Lu","mappings":{"default":{"default":"italic capital x","short":"italic cap x"},"mathspeak":{"default":"italic upper X"}},"key":"1D44B"},{"category":"Lu","mappings":{"default":{"default":"italic capital y","short":"italic cap y"},"mathspeak":{"default":"italic upper Y"}},"key":"1D44C"},{"category":"Lu","mappings":{"default":{"default":"italic capital z","short":"italic cap z"},"mathspeak":{"default":"italic upper Z"}},"key":"1D44D"},{"category":"Ll","mappings":{"default":{"default":"italic small a","short":"italic a"}},"key":"1D44E"},{"category":"Ll","mappings":{"default":{"default":"italic small b","short":"italic b"}},"key":"1D44F"},{"category":"Ll","mappings":{"default":{"default":"italic small c","short":"italic c"}},"key":"1D450"},{"category":"Ll","mappings":{"default":{"default":"italic small d","short":"italic d"}},"key":"1D451"},{"category":"Ll","mappings":{"default":{"default":"italic small e","short":"italic e"}},"key":"1D452"},{"category":"Ll","mappings":{"default":{"default":"italic small f","short":"italic f"}},"key":"1D453"},{"category":"Ll","mappings":{"default":{"default":"italic small g","short":"italic g"}},"key":"1D454"},{"category":"Ll","mappings":{"default":{"default":"italic small h","short":"italic h"},"physics":{"default":"planck constant"}},"key":"210E"},{"category":"Ll","mappings":{"default":{"default":"italic small i","short":"italic i"}},"key":"1D456"},{"category":"Ll","mappings":{"default":{"default":"italic small j","short":"italic j"}},"key":"1D457"},{"category":"Ll","mappings":{"default":{"default":"italic small k","short":"italic k"}},"key":"1D458"},{"category":"Ll","mappings":{"default":{"default":"italic small l","short":"italic l"}},"key":"1D459"},{"category":"Ll","mappings":{"default":{"default":"italic small m","short":"italic m"}},"key":"1D45A"},{"category":"Ll","mappings":{"default":{"default":"italic small n","short":"italic n"}},"key":"1D45B"},{"category":"Ll","mappings":{"default":{"default":"italic small o","short":"italic o"}},"key":"1D45C"},{"category":"Ll","mappings":{"default":{"default":"italic small p","short":"italic p"}},"key":"1D45D"},{"category":"Ll","mappings":{"default":{"default":"italic small q","short":"italic q"}},"key":"1D45E"},{"category":"Ll","mappings":{"default":{"default":"italic small r","short":"italic r"}},"key":"1D45F"},{"category":"Ll","mappings":{"default":{"default":"italic small s","short":"italic s"}},"key":"1D460"},{"category":"Ll","mappings":{"default":{"default":"italic small t","short":"italic t"}},"key":"1D461"},{"category":"Ll","mappings":{"default":{"default":"italic small u","short":"italic u"}},"key":"1D462"},{"category":"Ll","mappings":{"default":{"default":"italic small v","short":"italic v"}},"key":"1D463"},{"category":"Ll","mappings":{"default":{"default":"italic small w","short":"italic w"}},"key":"1D464"},{"category":"Ll","mappings":{"default":{"default":"italic small x","short":"italic x"}},"key":"1D465"},{"category":"Ll","mappings":{"default":{"default":"italic small y","short":"italic y"}},"key":"1D466"},{"category":"Ll","mappings":{"default":{"default":"italic small z","short":"italic z"}},"key":"1D467"}]
,
"en/latin-mathfonts-monospace.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"monospace capital a","short":"monospace cap a"},"mathspeak":{"default":"monospace upper A"}},"key":"1D670"},{"category":"Lu","mappings":{"default":{"default":"monospace capital b","short":"monospace cap b"},"mathspeak":{"default":"monospace upper B"}},"key":"1D671"},{"category":"Lu","mappings":{"default":{"default":"monospace capital c","short":"monospace cap c"},"mathspeak":{"default":"monospace upper C"}},"key":"1D672"},{"category":"Lu","mappings":{"default":{"default":"monospace capital d","short":"monospace cap d"},"mathspeak":{"default":"monospace upper D"}},"key":"1D673"},{"category":"Lu","mappings":{"default":{"default":"monospace capital e","short":"monospace cap e"},"mathspeak":{"default":"monospace upper E"}},"key":"1D674"},{"category":"Lu","mappings":{"default":{"default":"monospace capital f","short":"monospace cap f"},"mathspeak":{"default":"monospace upper F"}},"key":"1D675"},{"category":"Lu","mappings":{"default":{"default":"monospace capital g","short":"monospace cap g"},"mathspeak":{"default":"monospace upper G"}},"key":"1D676"},{"category":"Lu","mappings":{"default":{"default":"monospace capital h","short":"monospace cap h"},"mathspeak":{"default":"monospace upper H"}},"key":"1D677"},{"category":"Lu","mappings":{"default":{"default":"monospace capital i","short":"monospace cap i"},"mathspeak":{"default":"monospace upper I"}},"key":"1D678"},{"category":"Lu","mappings":{"default":{"default":"monospace capital j","short":"monospace cap j"},"mathspeak":{"default":"monospace upper J"}},"key":"1D679"},{"category":"Lu","mappings":{"default":{"default":"monospace capital k","short":"monospace cap k"},"mathspeak":{"default":"monospace upper K"}},"key":"1D67A"},{"category":"Lu","mappings":{"default":{"default":"monospace capital l","short":"monospace cap l"},"mathspeak":{"default":"monospace upper L"}},"key":"1D67B"},{"category":"Lu","mappings":{"default":{"default":"monospace capital m","short":"monospace cap m"},"mathspeak":{"default":"monospace upper M"}},"key":"1D67C"},{"category":"Lu","mappings":{"default":{"default":"monospace capital n","short":"monospace cap n"},"mathspeak":{"default":"monospace upper N"}},"key":"1D67D"},{"category":"Lu","mappings":{"default":{"default":"monospace capital o","short":"monospace cap o"},"mathspeak":{"default":"monospace upper O"}},"key":"1D67E"},{"category":"Lu","mappings":{"default":{"default":"monospace capital p","short":"monospace cap p"},"mathspeak":{"default":"monospace upper P"}},"key":"1D67F"},{"category":"Lu","mappings":{"default":{"default":"monospace capital q","short":"monospace cap q"},"mathspeak":{"default":"monospace upper Q"}},"key":"1D680"},{"category":"Lu","mappings":{"default":{"default":"monospace capital r","short":"monospace cap r"},"mathspeak":{"default":"monospace upper R"}},"key":"1D681"},{"category":"Lu","mappings":{"default":{"default":"monospace capital s","short":"monospace cap s"},"mathspeak":{"default":"monospace upper S"}},"key":"1D682"},{"category":"Lu","mappings":{"default":{"default":"monospace capital t","short":"monospace cap t"},"mathspeak":{"default":"monospace upper T"}},"key":"1D683"},{"category":"Lu","mappings":{"default":{"default":"monospace capital u","short":"monospace cap u"},"mathspeak":{"default":"monospace upper U"}},"key":"1D684"},{"category":"Lu","mappings":{"default":{"default":"monospace capital v","short":"monospace cap v"},"mathspeak":{"default":"monospace upper V"}},"key":"1D685"},{"category":"Lu","mappings":{"default":{"default":"monospace capital w","short":"monospace cap w"},"mathspeak":{"default":"monospace upper W"}},"key":"1D686"},{"category":"Lu","mappings":{"default":{"default":"monospace capital x","short":"monospace cap x"},"mathspeak":{"default":"monospace upper X"}},"key":"1D687"},{"category":"Lu","mappings":{"default":{"default":"monospace capital y","short":"monospace cap y"},"mathspeak":{"default":"monospace upper Y"}},"key":"1D688"},{"category":"Lu","mappings":{"default":{"default":"monospace capital z","short":"monospace cap z"},"mathspeak":{"default":"monospace upper Z"}},"key":"1D689"},{"category":"Ll","mappings":{"default":{"default":"monospace small a","short":"monospace a"}},"key":"1D68A"},{"category":"Ll","mappings":{"default":{"default":"monospace small b","short":"monospace b"}},"key":"1D68B"},{"category":"Ll","mappings":{"default":{"default":"monospace small c","short":"monospace c"}},"key":"1D68C"},{"category":"Ll","mappings":{"default":{"default":"monospace small d","short":"monospace d"}},"key":"1D68D"},{"category":"Ll","mappings":{"default":{"default":"monospace small e","short":"monospace e"}},"key":"1D68E"},{"category":"Ll","mappings":{"default":{"default":"monospace small f","short":"monospace f"}},"key":"1D68F"},{"category":"Ll","mappings":{"default":{"default":"monospace small g","short":"monospace g"}},"key":"1D690"},{"category":"Ll","mappings":{"default":{"default":"monospace small h","short":"monospace h"}},"key":"1D691"},{"category":"Ll","mappings":{"default":{"default":"monospace small i","short":"monospace i"}},"key":"1D692"},{"category":"Ll","mappings":{"default":{"default":"monospace small j","short":"monospace j"}},"key":"1D693"},{"category":"Ll","mappings":{"default":{"default":"monospace small k","short":"monospace k"}},"key":"1D694"},{"category":"Ll","mappings":{"default":{"default":"monospace small l","short":"monospace l"}},"key":"1D695"},{"category":"Ll","mappings":{"default":{"default":"monospace small m","short":"monospace m"}},"key":"1D696"},{"category":"Ll","mappings":{"default":{"default":"monospace small n","short":"monospace n"}},"key":"1D697"},{"category":"Ll","mappings":{"default":{"default":"monospace small o","short":"monospace o"}},"key":"1D698"},{"category":"Ll","mappings":{"default":{"default":"monospace small p","short":"monospace p"}},"key":"1D699"},{"category":"Ll","mappings":{"default":{"default":"monospace small q","short":"monospace q"}},"key":"1D69A"},{"category":"Ll","mappings":{"default":{"default":"monospace small r","short":"monospace r"}},"key":"1D69B"},{"category":"Ll","mappings":{"default":{"default":"monospace small s","short":"monospace s"}},"key":"1D69C"},{"category":"Ll","mappings":{"default":{"default":"monospace small t","short":"monospace t"}},"key":"1D69D"},{"category":"Ll","mappings":{"default":{"default":"monospace small u","short":"monospace u"}},"key":"1D69E"},{"category":"Ll","mappings":{"default":{"default":"monospace small v","short":"monospace v"}},"key":"1D69F"},{"category":"Ll","mappings":{"default":{"default":"monospace small w","short":"monospace w"}},"key":"1D6A0"},{"category":"Ll","mappings":{"default":{"default":"monospace small x","short":"monospace x"}},"key":"1D6A1"},{"category":"Ll","mappings":{"default":{"default":"monospace small y","short":"monospace y"}},"key":"1D6A2"},{"category":"Ll","mappings":{"default":{"default":"monospace small z","short":"monospace z"}},"key":"1D6A3"}]
,
"en/latin-mathfonts-sans-serif-bold.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital a","short":"sans serif bold cap a"},"mathspeak":{"default":"sans serif bold upper A"}},"key":"1D5D4"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital b","short":"sans serif bold cap b"},"mathspeak":{"default":"sans serif bold upper B"}},"key":"1D5D5"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital c","short":"sans serif bold cap c"},"mathspeak":{"default":"sans serif bold upper C"}},"key":"1D5D6"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital d","short":"sans serif bold cap d"},"mathspeak":{"default":"sans serif bold upper D"}},"key":"1D5D7"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital e","short":"sans serif bold cap e"},"mathspeak":{"default":"sans serif bold upper E"}},"key":"1D5D8"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital f","short":"sans serif bold cap f"},"mathspeak":{"default":"sans serif bold upper F"}},"key":"1D5D9"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital g","short":"sans serif bold cap g"},"mathspeak":{"default":"sans serif bold upper G"}},"key":"1D5DA"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital h","short":"sans serif bold cap h"},"mathspeak":{"default":"sans serif bold upper H"}},"key":"1D5DB"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital i","short":"sans serif bold cap i"},"mathspeak":{"default":"sans serif bold upper I"}},"key":"1D5DC"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital j","short":"sans serif bold cap j"},"mathspeak":{"default":"sans serif bold upper J"}},"key":"1D5DD"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital k","short":"sans serif bold cap k"},"mathspeak":{"default":"sans serif bold upper K"}},"key":"1D5DE"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital l","short":"sans serif bold cap l"},"mathspeak":{"default":"sans serif bold upper L"}},"key":"1D5DF"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital m","short":"sans serif bold cap m"},"mathspeak":{"default":"sans serif bold upper M"}},"key":"1D5E0"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital n","short":"sans serif bold cap n"},"mathspeak":{"default":"sans serif bold upper N"}},"key":"1D5E1"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital o","short":"sans serif bold cap o"},"mathspeak":{"default":"sans serif bold upper O"}},"key":"1D5E2"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital p","short":"sans serif bold cap p"},"mathspeak":{"default":"sans serif bold upper P"}},"key":"1D5E3"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital q","short":"sans serif bold cap q"},"mathspeak":{"default":"sans serif bold upper Q"}},"key":"1D5E4"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital r","short":"sans serif bold cap r"},"mathspeak":{"default":"sans serif bold upper R"}},"key":"1D5E5"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital s","short":"sans serif bold cap s"},"mathspeak":{"default":"sans serif bold upper S"}},"key":"1D5E6"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital t","short":"sans serif bold cap t"},"mathspeak":{"default":"sans serif bold upper T"}},"key":"1D5E7"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital u","short":"sans serif bold cap u"},"mathspeak":{"default":"sans serif bold upper U"}},"key":"1D5E8"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital v","short":"sans serif bold cap v"},"mathspeak":{"default":"sans serif bold upper V"}},"key":"1D5E9"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital w","short":"sans serif bold cap w"},"mathspeak":{"default":"sans serif bold upper W"}},"key":"1D5EA"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital x","short":"sans serif bold cap x"},"mathspeak":{"default":"sans serif bold upper X"}},"key":"1D5EB"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital y","short":"sans serif bold cap y"},"mathspeak":{"default":"sans serif bold upper Y"}},"key":"1D5EC"},{"category":"Lu","mappings":{"default":{"default":"sans serif bold capital z","short":"sans serif bold cap z"},"mathspeak":{"default":"sans serif bold upper Z"}},"key":"1D5ED"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small a","short":"sans serif bold a"}},"key":"1D5EE"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small b","short":"sans serif bold b"}},"key":"1D5EF"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small c","short":"sans serif bold c"}},"key":"1D5F0"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small d","short":"sans serif bold d"}},"key":"1D5F1"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small e","short":"sans serif bold e"}},"key":"1D5F2"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small f","short":"sans serif bold f"}},"key":"1D5F3"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small g","short":"sans serif bold g"}},"key":"1D5F4"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small h","short":"sans serif bold h"}},"key":"1D5F5"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small i","short":"sans serif bold i"}},"key":"1D5F6"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small j","short":"sans serif bold j"}},"key":"1D5F7"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small k","short":"sans serif bold k"}},"key":"1D5F8"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small l","short":"sans serif bold l"}},"key":"1D5F9"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small m","short":"sans serif bold m"}},"key":"1D5FA"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small n","short":"sans serif bold n"}},"key":"1D5FB"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small o","short":"sans serif bold o"}},"key":"1D5FC"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small p","short":"sans serif bold p"}},"key":"1D5FD"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small q","short":"sans serif bold q"}},"key":"1D5FE"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small r","short":"sans serif bold r"}},"key":"1D5FF"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small s","short":"sans serif bold s"}},"key":"1D600"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small t","short":"sans serif bold t"}},"key":"1D601"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small u","short":"sans serif bold u"}},"key":"1D602"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small v","short":"sans serif bold v"}},"key":"1D603"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small w","short":"sans serif bold w"}},"key":"1D604"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small x","short":"sans serif bold x"}},"key":"1D605"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small y","short":"sans serif bold y"}},"key":"1D606"},{"category":"Ll","mappings":{"default":{"default":"sans serif bold small z","short":"sans serif bold z"}},"key":"1D607"}]
,
"en/latin-mathfonts-sans-serif-italic.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital a","short":"sans serif italic cap a"},"mathspeak":{"default":"sans serif italic upper A"}},"key":"1D608"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital b","short":"sans serif italic cap b"},"mathspeak":{"default":"sans serif italic upper B"}},"key":"1D609"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital c","short":"sans serif italic cap c"},"mathspeak":{"default":"sans serif italic upper C"}},"key":"1D60A"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital d","short":"sans serif italic cap d"},"mathspeak":{"default":"sans serif italic upper D"}},"key":"1D60B"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital e","short":"sans serif italic cap e"},"mathspeak":{"default":"sans serif italic upper E"}},"key":"1D60C"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital f","short":"sans serif italic cap f"},"mathspeak":{"default":"sans serif italic upper F"}},"key":"1D60D"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital g","short":"sans serif italic cap g"},"mathspeak":{"default":"sans serif italic upper G"}},"key":"1D60E"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital h","short":"sans serif italic cap h"},"mathspeak":{"default":"sans serif italic upper H"}},"key":"1D60F"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital i","short":"sans serif italic cap i"},"mathspeak":{"default":"sans serif italic upper I"}},"key":"1D610"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital j","short":"sans serif italic cap j"},"mathspeak":{"default":"sans serif italic upper J"}},"key":"1D611"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital k","short":"sans serif italic cap k"},"mathspeak":{"default":"sans serif italic upper K"}},"key":"1D612"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital l","short":"sans serif italic cap l"},"mathspeak":{"default":"sans serif italic upper L"}},"key":"1D613"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital m","short":"sans serif italic cap m"},"mathspeak":{"default":"sans serif italic upper M"}},"key":"1D614"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital n","short":"sans serif italic cap n"},"mathspeak":{"default":"sans serif italic upper N"}},"key":"1D615"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital o","short":"sans serif italic cap o"},"mathspeak":{"default":"sans serif italic upper O"}},"key":"1D616"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital p","short":"sans serif italic cap p"},"mathspeak":{"default":"sans serif italic upper P"}},"key":"1D617"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital q","short":"sans serif italic cap q"},"mathspeak":{"default":"sans serif italic upper Q"}},"key":"1D618"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital r","short":"sans serif italic cap r"},"mathspeak":{"default":"sans serif italic upper R"}},"key":"1D619"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital s","short":"sans serif italic cap s"},"mathspeak":{"default":"sans serif italic upper S"}},"key":"1D61A"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital t","short":"sans serif italic cap t"},"mathspeak":{"default":"sans serif italic upper T"}},"key":"1D61B"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital u","short":"sans serif italic cap u"},"mathspeak":{"default":"sans serif italic upper U"}},"key":"1D61C"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital v","short":"sans serif italic cap v"},"mathspeak":{"default":"sans serif italic upper V"}},"key":"1D61D"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital w","short":"sans serif italic cap w"},"mathspeak":{"default":"sans serif italic upper W"}},"key":"1D61E"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital x","short":"sans serif italic cap x"},"mathspeak":{"default":"sans serif italic upper X"}},"key":"1D61F"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital y","short":"sans serif italic cap y"},"mathspeak":{"default":"sans serif italic upper Y"}},"key":"1D620"},{"category":"Lu","mappings":{"default":{"default":"sans serif italic capital z","short":"sans serif italic cap z"},"mathspeak":{"default":"sans serif italic upper Z"}},"key":"1D621"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small a","short":"sans serif italic a"}},"key":"1D622"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small b","short":"sans serif italic b"}},"key":"1D623"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small c","short":"sans serif italic c"}},"key":"1D624"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small d","short":"sans serif italic d"}},"key":"1D625"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small e","short":"sans serif italic e"}},"key":"1D626"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small f","short":"sans serif italic f"}},"key":"1D627"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small g","short":"sans serif italic g"}},"key":"1D628"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small h","short":"sans serif italic h"}},"key":"1D629"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small i","short":"sans serif italic i"}},"key":"1D62A"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small j","short":"sans serif italic j"}},"key":"1D62B"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small k","short":"sans serif italic k"}},"key":"1D62C"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small l","short":"sans serif italic l"}},"key":"1D62D"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small m","short":"sans serif italic m"}},"key":"1D62E"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small n","short":"sans serif italic n"}},"key":"1D62F"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small o","short":"sans serif italic o"}},"key":"1D630"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small p","short":"sans serif italic p"}},"key":"1D631"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small q","short":"sans serif italic q"}},"key":"1D632"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small r","short":"sans serif italic r"}},"key":"1D633"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small s","short":"sans serif italic s"}},"key":"1D634"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small t","short":"sans serif italic t"}},"key":"1D635"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small u","short":"sans serif italic u"}},"key":"1D636"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small v","short":"sans serif italic v"}},"key":"1D637"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small w","short":"sans serif italic w"}},"key":"1D638"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small x","short":"sans serif italic x"}},"key":"1D639"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small y","short":"sans serif italic y"}},"key":"1D63A"},{"category":"Ll","mappings":{"default":{"default":"sans serif italic small z","short":"sans serif italic z"}},"key":"1D63B"}]
,
"en/latin-mathfonts-sans-serif.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital a","short":"sans serif cap a"},"mathspeak":{"default":"sans serif upper A"}},"key":"1D5A0"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital b","short":"sans serif cap b"},"mathspeak":{"default":"sans serif upper B"}},"key":"1D5A1"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital c","short":"sans serif cap c"},"mathspeak":{"default":"sans serif upper C"}},"key":"1D5A2"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital d","short":"sans serif cap d"},"mathspeak":{"default":"sans serif upper D"}},"key":"1D5A3"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital e","short":"sans serif cap e"},"mathspeak":{"default":"sans serif upper E"}},"key":"1D5A4"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital f","short":"sans serif cap f"},"mathspeak":{"default":"sans serif upper F"}},"key":"1D5A5"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital g","short":"sans serif cap g"},"mathspeak":{"default":"sans serif upper G"}},"key":"1D5A6"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital h","short":"sans serif cap h"},"mathspeak":{"default":"sans serif upper H"}},"key":"1D5A7"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital i","short":"sans serif cap i"},"mathspeak":{"default":"sans serif upper I"}},"key":"1D5A8"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital j","short":"sans serif cap j"},"mathspeak":{"default":"sans serif upper J"}},"key":"1D5A9"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital k","short":"sans serif cap k"},"mathspeak":{"default":"sans serif upper K"}},"key":"1D5AA"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital l","short":"sans serif cap l"},"mathspeak":{"default":"sans serif upper L"}},"key":"1D5AB"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital m","short":"sans serif cap m"},"mathspeak":{"default":"sans serif upper M"}},"key":"1D5AC"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital n","short":"sans serif cap n"},"mathspeak":{"default":"sans serif upper N"}},"key":"1D5AD"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital o","short":"sans serif cap o"},"mathspeak":{"default":"sans serif upper O"}},"key":"1D5AE"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital p","short":"sans serif cap p"},"mathspeak":{"default":"sans serif upper P"}},"key":"1D5AF"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital q","short":"sans serif cap q"},"mathspeak":{"default":"sans serif upper Q"}},"key":"1D5B0"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital r","short":"sans serif cap r"},"mathspeak":{"default":"sans serif upper R"}},"key":"1D5B1"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital s","short":"sans serif cap s"},"mathspeak":{"default":"sans serif upper S"}},"key":"1D5B2"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital t","short":"sans serif cap t"},"mathspeak":{"default":"sans serif upper T"}},"key":"1D5B3"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital u","short":"sans serif cap u"},"mathspeak":{"default":"sans serif upper U"}},"key":"1D5B4"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital v","short":"sans serif cap v"},"mathspeak":{"default":"sans serif upper V"}},"key":"1D5B5"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital w","short":"sans serif cap w"},"mathspeak":{"default":"sans serif upper W"}},"key":"1D5B6"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital x","short":"sans serif cap x"},"mathspeak":{"default":"sans serif upper X"}},"key":"1D5B7"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital y","short":"sans serif cap y"},"mathspeak":{"default":"sans serif upper Y"}},"key":"1D5B8"},{"category":"Lu","mappings":{"default":{"default":"sans serif capital z","short":"sans serif cap z"},"mathspeak":{"default":"sans serif upper Z"}},"key":"1D5B9"},{"category":"Ll","mappings":{"default":{"default":"sans serif small a","short":"sans serif a"}},"key":"1D5BA"},{"category":"Ll","mappings":{"default":{"default":"sans serif small b","short":"sans serif b"}},"key":"1D5BB"},{"category":"Ll","mappings":{"default":{"default":"sans serif small c","short":"sans serif c"}},"key":"1D5BC"},{"category":"Ll","mappings":{"default":{"default":"sans serif small d","short":"sans serif d"}},"key":"1D5BD"},{"category":"Ll","mappings":{"default":{"default":"sans serif small e","short":"sans serif e"}},"key":"1D5BE"},{"category":"Ll","mappings":{"default":{"default":"sans serif small f","short":"sans serif f"}},"key":"1D5BF"},{"category":"Ll","mappings":{"default":{"default":"sans serif small g","short":"sans serif g"}},"key":"1D5C0"},{"category":"Ll","mappings":{"default":{"default":"sans serif small h","short":"sans serif h"}},"key":"1D5C1"},{"category":"Ll","mappings":{"default":{"default":"sans serif small i","short":"sans serif i"}},"key":"1D5C2"},{"category":"Ll","mappings":{"default":{"default":"sans serif small j","short":"sans serif j"}},"key":"1D5C3"},{"category":"Ll","mappings":{"default":{"default":"sans serif small k","short":"sans serif k"}},"key":"1D5C4"},{"category":"Ll","mappings":{"default":{"default":"sans serif small l","short":"sans serif l"}},"key":"1D5C5"},{"category":"Ll","mappings":{"default":{"default":"sans serif small m","short":"sans serif m"}},"key":"1D5C6"},{"category":"Ll","mappings":{"default":{"default":"sans serif small n","short":"sans serif n"}},"key":"1D5C7"},{"category":"Ll","mappings":{"default":{"default":"sans serif small o","short":"sans serif o"}},"key":"1D5C8"},{"category":"Ll","mappings":{"default":{"default":"sans serif small p","short":"sans serif p"}},"key":"1D5C9"},{"category":"Ll","mappings":{"default":{"default":"sans serif small q","short":"sans serif q"}},"key":"1D5CA"},{"category":"Ll","mappings":{"default":{"default":"sans serif small r","short":"sans serif r"}},"key":"1D5CB"},{"category":"Ll","mappings":{"default":{"default":"sans serif small s","short":"sans serif s"}},"key":"1D5CC"},{"category":"Ll","mappings":{"default":{"default":"sans serif small t","short":"sans serif t"}},"key":"1D5CD"},{"category":"Ll","mappings":{"default":{"default":"sans serif small u","short":"sans serif u"}},"key":"1D5CE"},{"category":"Ll","mappings":{"default":{"default":"sans serif small v","short":"sans serif v"}},"key":"1D5CF"},{"category":"Ll","mappings":{"default":{"default":"sans serif small w","short":"sans serif w"}},"key":"1D5D0"},{"category":"Ll","mappings":{"default":{"default":"sans serif small x","short":"sans serif x"}},"key":"1D5D1"},{"category":"Ll","mappings":{"default":{"default":"sans serif small y","short":"sans serif y"}},"key":"1D5D2"},{"category":"Ll","mappings":{"default":{"default":"sans serif small z","short":"sans serif z"}},"key":"1D5D3"}]
,
"en/latin-mathfonts-script.js": 
[{"locale":"en"},{"category":"Lu","mappings":{"default":{"default":"script capital a","short":"script cap a"},"mathspeak":{"default":"script upper A"}},"key":"1D49C"},{"category":"Lu","mappings":{"default":{"default":"script capital b","short":"script cap b"},"mathspeak":{"default":"script upper B"}},"key":"212C"},{"category":"Lu","mappings":{"default":{"default":"script capital c","short":"script cap c"},"mathspeak":{"default":"script upper C"}},"key":"1D49E"},{"category":"Lu","mappings":{"default":{"default":"script capital d","short":"script cap d"},"mathspeak":{"default":"script upper D"}},"key":"1D49F"},{"category":"Lu","mappings":{"default":{"default":"script capital e","short":"script cap e"},"mathspeak":{"default":"script upper E"}},"key":"2130"},{"category":"Lu","mappings":{"default":{"default":"script capital f","short":"script cap f"},"mathspeak":{"default":"script upper F"}},"key":"2131"},{"category":"Lu","mappings":{"default":{"default":"script capital g","short":"script cap g"},"mathspeak":{"default":"script upper G"}},"key":"1D4A2"},{"category":"Lu","mappings":{"default":{"default":"script capital h","short":"script cap h"},"mathspeak":{"default":"script upper H"}},"key":"210B"},{"category":"Lu","mappings":{"default":{"default":"script capital i","short":"script cap i"},"mathspeak":{"default":"script upper I"}},"key":"2110"},{"category":"Lu","mappings":{"default":{"default":"script capital j","short":"script cap j"},"mathspeak":{"default":"script upper J"}},"key":"1D4A5"},{"category":"Lu","mappings":{"default":{"default":"script capital k","short":"script cap k"},"mathspeak":{"default":"script upper K"}},"key":"1D4A6"},{"category":"Lu","mappings":{"default":{"default":"script capital l","short":"script cap l"},"mathspeak":{"default":"script upper L"}},"key":"2112"},{"category":"Lu","mappings":{"default":{"default":"script capital m","short":"script cap m"},"mathspeak":{"default":"script upper M"}},"key":"2133"},{"category":"Lu","mappings":{"default":{"default":"script capital n","short":"script cap n"},"mathspeak":{"default":"script upper N"}},"key":"1D4A9"},{"category":"Lu","mappings":{"default":{"default":"script capital o","short":"script cap o"},"mathspeak":{"default":"script upper O"}},"key":"1D4AA"},{"category":"Lu","mappings":{"default":{"default":"script capital p","short":"script cap p"},"mathspeak":{"default":"script upper P"}},"key":"1D4AB"},{"category":"Lu","mappings":{"default":{"default":"script capital q","short":"script cap q"},"mathspeak":{"default":"script upper Q"}},"key":"1D4AC"},{"category":"Lu","mappings":{"default":{"default":"script capital r","short":"script cap r"},"mathspeak":{"default":"script upper R"}},"key":"211B"},{"category":"Lu","mappings":{"default":{"default":"script capital s","short":"script cap s"},"mathspeak":{"default":"script upper S"}},"key":"1D4AE"},{"category":"Lu","mappings":{"default":{"default":"script capital t","short":"script cap t"},"mathspeak":{"default":"script upper T"}},"key":"1D4AF"},{"category":"Lu","mappings":{"default":{"default":"script capital u","short":"script cap u"},"mathspeak":{"default":"script upper U"}},"key":"1D4B0"},{"category":"Lu","mappings":{"default":{"default":"script capital v","short":"script cap v"},"mathspeak":{"default":"script upper V"}},"key":"1D4B1"},{"category":"Lu","mappings":{"default":{"default":"script capital w","short":"script cap w"},"mathspeak":{"default":"script upper W"}},"key":"1D4B2"},{"category":"Lu","mappings":{"default":{"default":"script capital x","short":"script cap x"},"mathspeak":{"default":"script upper X"}},"key":"1D4B3"},{"category":"Lu","mappings":{"default":{"default":"script capital y","short":"script cap y"},"mathspeak":{"default":"script upper Y"}},"key":"1D4B4"},{"category":"Lu","mappings":{"default":{"default":"script capital z","short":"script cap z"},"mathspeak":{"default":"script upper Z"}},"key":"1D4B5"},{"category":"Ll","mappings":{"default":{"default":"script small a","short":"script a"}},"key":"1D4B6"},{"category":"Ll","mappings":{"default":{"default":"script small b","short":"script b"}},"key":"1D4B7"},{"category":"Ll","mappings":{"default":{"default":"script small c","short":"script c"}},"key":"1D4B8"},{"category":"Ll","mappings":{"default":{"default":"script small d","short":"script d"}},"key":"1D4B9"},{"category":"Ll","mappings":{"default":{"default":"script small e","short":"script e"}},"key":"212F"},{"category":"Ll","mappings":{"default":{"default":"script small f","short":"script f"}},"key":"1D4BB"},{"category":"Ll","mappings":{"default":{"default":"script small g","short":"script g"}},"key":"210A"},{"category":"Ll","mappings":{"default":{"default":"script small h","short":"script h"}},"key":"1D4BD"},{"category":"Ll","mappings":{"default":{"default":"script small i","short":"script i"}},"key":"1D4BE"},{"category":"Ll","mappings":{"default":{"default":"script small j","short":"script j"}},"key":"1D4BF"},{"category":"Ll","mappings":{"default":{"default":"script small k","short":"script k"}},"key":"1D4C0"},{"category":"Ll","mappings":{"default":{"default":"script small l","short":"script l"}},"key":"1D4C1"},{"category":"Ll","mappings":{"default":{"default":"script small m","short":"script m"}},"key":"1D4C2"},{"category":"Ll","mappings":{"default":{"default":"script small n","short":"script n"}},"key":"1D4C3"},{"category":"Ll","mappings":{"default":{"default":"script small o","short":"script o"}},"key":"2134"},{"category":"Ll","mappings":{"default":{"default":"script small p","short":"script p"}},"key":"1D4C5"},{"category":"Ll","mappings":{"default":{"default":"script small q","short":"script q"}},"key":"1D4C6"},{"category":"Ll","mappings":{"default":{"default":"script small r","short":"script r"}},"key":"1D4C7"},{"category":"Ll","mappings":{"default":{"default":"script small s","short":"script s"}},"key":"1D4C8"},{"category":"Ll","mappings":{"default":{"default":"script small t","short":"script t"}},"key":"1D4C9"},{"category":"Ll","mappings":{"default":{"default":"script small u","short":"script u"}},"key":"1D4CA"},{"category":"Ll","mappings":{"default":{"default":"script small v","short":"script v"}},"key":"1D4CB"},{"category":"Ll","mappings":{"default":{"default":"script small w","short":"script w"}},"key":"1D4CC"},{"category":"Ll","mappings":{"default":{"default":"script small x","short":"script x"}},"key":"1D4CD"},{"category":"Ll","mappings":{"default":{"default":"script small y","short":"script y"}},"key":"1D4CE"},{"category":"Ll","mappings":{"default":{"default":"script small z","short":"script z"}},"key":"1D4CF"}]
,
"en/latin-rest.js": 
[{"locale":"en"},{"category":"Mn","key":"0363","mappings":{"default":{"default":"combining latin small letter a","short":"combining a"}}},{"category":"Mn","key":"0364","mappings":{"default":{"default":"combining latin small letter e","short":"combining e"}}},{"category":"Mn","key":"0365","mappings":{"default":{"default":"combining latin small letter i","short":"combining i"}}},{"category":"Mn","key":"0366","mappings":{"default":{"default":"combining latin small letter o","short":"combining o"}}},{"category":"Mn","key":"0367","mappings":{"default":{"default":"combining latin small letter u","short":"combining u"}}},{"category":"Mn","key":"0368","mappings":{"default":{"default":"combining latin small letter c","short":"combining c"}}},{"category":"Mn","key":"0369","mappings":{"default":{"default":"combining latin small letter d","short":"combining d"}}},{"category":"Mn","key":"036A","mappings":{"default":{"default":"combining latin small letter h","short":"combining h"}}},{"category":"Mn","key":"036B","mappings":{"default":{"default":"combining latin small letter m","short":"combining m"}}},{"category":"Mn","key":"036C","mappings":{"default":{"default":"combining latin small letter r","short":"combining r"}}},{"category":"Mn","key":"036D","mappings":{"default":{"default":"combining latin small letter t","short":"combining t"}}},{"category":"Mn","key":"036E","mappings":{"default":{"default":"combining latin small letter v","short":"combining v"}}},{"category":"Mn","key":"036F","mappings":{"default":{"default":"combining latin small letter x","short":"combining x"}}},{"category":"Lm","key":"1D62","mappings":{"default":{"default":"latin subscript small letter i","short":"subscript i"}}},{"category":"Lm","key":"1D63","mappings":{"default":{"default":"latin subscript small letter r","short":"subscript r"}}},{"category":"Lm","key":"1D64","mappings":{"default":{"default":"latin subscript small letter u","short":"subscript u"}}},{"category":"Lm","key":"1D65","mappings":{"default":{"default":"latin subscript small letter v","short":"subscript v"}}},{"category":"Mn","key":"1DCA","mappings":{"default":{"default":"combining latin small letter r below","short":"combining r below"}}},{"category":"Mn","key":"1DD3","mappings":{"default":{"default":"combining latin small letter flattened open a above","short":"combining flattened open a above"}}},{"category":"Mn","key":"1DD4","mappings":{"default":{"default":"combining latin small letter ae","short":"combining ae"}}},{"category":"Mn","key":"1DD5","mappings":{"default":{"default":"combining latin small letter ao","short":"combining ao"}}},{"category":"Mn","key":"1DD6","mappings":{"default":{"default":"combining latin small letter av","short":"combining av"}}},{"category":"Mn","key":"1DD7","mappings":{"default":{"default":"combining latin small letter c cedilla","short":"combining c cedilla"}}},{"category":"Mn","key":"1DD8","mappings":{"default":{"default":"combining latin small letter insular d","short":"combining insular d"}}},{"category":"Mn","key":"1DD9","mappings":{"default":{"default":"combining latin small letter eth","short":"combining eth"}}},{"category":"Mn","key":"1DDA","mappings":{"default":{"default":"combining latin small letter g","short":"combining g"}}},{"category":"Mn","key":"1DDB","mappings":{"default":{"default":"combining latin letter small capital g","short":"combining small cap g"},"mathspeak":{"default":"combining small upper G"}}},{"category":"Mn","key":"1DDC","mappings":{"default":{"default":"combining latin small letter k","short":"combining k"}}},{"category":"Mn","key":"1DDD","mappings":{"default":{"default":"combining latin small letter l","short":"combining l"}}},{"category":"Mn","key":"1DDE","mappings":{"default":{"default":"combining latin letter small capital l","short":"combining small cap l"},"mathspeak":{"default":"combining small upper L"}}},{"category":"Mn","key":"1DDF","mappings":{"default":{"default":"combining latin letter small capital m","short":"combining small cap m"},"mathspeak":{"default":"combining small upper M"}}},{"category":"Mn","key":"1DE0","mappings":{"default":{"default":"combining latin small letter n","short":"combining n"}}},{"category":"Mn","key":"1DE1","mappings":{"default":{"default":"combining latin letter small capital n","short":"combining small cap n"},"mathspeak":{"default":"combining small upper N"}}},{"category":"Mn","key":"1DE2","mappings":{"default":{"default":"combining latin letter small capital r","short":"combining small cap r"},"mathspeak":{"default":"combining small upper R"}}},{"category":"Mn","key":"1DE3","mappings":{"default":{"default":"combining latin small letter r rotunda","short":"combining r rotunda"}}},{"category":"Mn","key":"1DE4","mappings":{"default":{"default":"combining latin small letter s","short":"combining s"}}},{"category":"Mn","key":"1DE5","mappings":{"default":{"default":"combining latin small letter long s","short":"combining long s"}}},{"category":"Mn","key":"1DE6","mappings":{"default":{"default":"combining latin small letter z","short":"combining z"}}},{"category":"Lm","key":"2071","mappings":{"default":{"default":"superscript latin small letter i","short":"superscript i"}}},{"category":"Lm","key":"207F","mappings":{"default":{"default":"superscript latin small letter n","short":"superscript n"}}},{"category":"Lm","key":"2090","mappings":{"default":{"default":"latin subscript small letter a","short":"subscript a"}}},{"category":"Lm","key":"2091","mappings":{"default":{"default":"latin subscript small letter e","short":"subscript e"}}},{"category":"Lm","key":"2092","mappings":{"default":{"default":"latin subscript small letter o","short":"subscript o"}}},{"category":"Lm","key":"2093","mappings":{"default":{"default":"latin subscript small letter x","short":"subscript x"}}},{"category":"Lm","key":"2094","mappings":{"default":{"default":"latin subscript small letter schwa","short":"subscript schwa"}}},{"category":"Lm","key":"2095","mappings":{"default":{"default":"latin subscript small letter h","short":"subscript h"}}},{"category":"Lm","key":"2096","mappings":{"default":{"default":"latin subscript small letter k","short":"subscript k"}}},{"category":"Lm","key":"2097","mappings":{"default":{"default":"latin subscript small letter l","short":"subscript l"}}},{"category":"Lm","key":"2098","mappings":{"default":{"default":"latin subscript small letter m","short":"subscript m"}}},{"category":"Lm","key":"2099","mappings":{"default":{"default":"latin subscript small letter n","short":"subscript n"}}},{"category":"Lm","key":"209A","mappings":{"default":{"default":"latin subscript small letter p","short":"subscript p"}}},{"category":"Lm","key":"209B","mappings":{"default":{"default":"latin subscript small letter s","short":"subscript s"}}},{"category":"Lm","key":"209C","mappings":{"default":{"default":"latin subscript small letter t","short":"subscript t"}}},{"category":"So","key":"249C","mappings":{"default":{"default":"parenthesized latin small letter a","short":"parenthesized a"}}},{"category":"So","key":"249D","mappings":{"default":{"default":"parenthesized latin small letter b","short":"parenthesized b"}}},{"category":"So","key":"249E","mappings":{"default":{"default":"parenthesized latin small letter c","short":"parenthesized c"}}},{"category":"So","key":"249F","mappings":{"default":{"default":"parenthesized latin small letter d","short":"parenthesized d"}}},{"category":"So","key":"24A0","mappings":{"default":{"default":"parenthesized latin small letter e","short":"parenthesized e"}}},{"category":"So","key":"24A1","mappings":{"default":{"default":"parenthesized latin small letter f","short":"parenthesized f"}}},{"category":"So","key":"24A2","mappings":{"default":{"default":"parenthesized latin small letter g","short":"parenthesized g"}}},{"category":"So","key":"24A3","mappings":{"default":{"default":"parenthesized latin small letter h","short":"parenthesized h"}}},{"category":"So","key":"24A4","mappings":{"default":{"default":"parenthesized latin small letter i","short":"parenthesized i"}}},{"category":"So","key":"24A5","mappings":{"default":{"default":"parenthesized latin small letter j","short":"parenthesized j"}}},{"category":"So","key":"24A6","mappings":{"default":{"default":"parenthesized latin small letter k","short":"parenthesized k"}}},{"category":"So","key":"24A7","mappings":{"default":{"default":"parenthesized latin small letter l","short":"parenthesized l"}}},{"category":"So","key":"24A8","mappings":{"default":{"default":"parenthesized latin small letter m","short":"parenthesized m"}}},{"category":"So","key":"24A9","mappings":{"default":{"default":"parenthesized latin small letter n","short":"parenthesized n"}}},{"category":"So","key":"24AA","mappings":{"default":{"default":"parenthesized latin small letter o","short":"parenthesized o"}}},{"category":"So","key":"24AB","mappings":{"default":{"default":"parenthesized latin small letter p","short":"parenthesized p"}}},{"category":"So","key":"24AC","mappings":{"default":{"default":"parenthesized latin small letter q","short":"parenthesized q"}}},{"category":"So","key":"24AD","mappings":{"default":{"default":"parenthesized latin small letter r","short":"parenthesized r"}}},{"category":"So","key":"24AE","mappings":{"default":{"default":"parenthesized latin small letter s","short":"parenthesized s"}}},{"category":"So","key":"24AF","mappings":{"default":{"default":"parenthesized latin small letter t","short":"parenthesized t"}}},{"category":"So","key":"24B0","mappings":{"default":{"default":"parenthesized latin small letter u","short":"parenthesized u"}}},{"category":"So","key":"24B1","mappings":{"default":{"default":"parenthesized latin small letter v","short":"parenthesized v"}}},{"category":"So","key":"24B2","mappings":{"default":{"default":"parenthesized latin small letter w","short":"parenthesized w"}}},{"category":"So","key":"24B3","mappings":{"default":{"default":"parenthesized latin small letter x","short":"parenthesized x"}}},{"category":"So","key":"24B4","mappings":{"default":{"default":"parenthesized latin small letter y","short":"parenthesized y"}}},{"category":"So","key":"24B5","mappings":{"default":{"default":"parenthesized latin small letter z","short":"parenthesized z"}}},{"category":"So","key":"24B6","mappings":{"default":{"default":"circled latin capital letter a","short":"circled cap a"},"mathspeak":{"default":"circled upper A"}}},{"category":"So","key":"24B7","mappings":{"default":{"default":"circled latin capital letter b","short":"circled cap b"},"mathspeak":{"default":"circled upper B"}}},{"category":"So","key":"24B8","mappings":{"default":{"default":"circled latin capital letter c","short":"circled cap c"},"mathspeak":{"default":"circled upper C"}}},{"category":"So","key":"24B9","mappings":{"default":{"default":"circled latin capital letter d","short":"circled cap d"},"mathspeak":{"default":"circled upper D"}}},{"category":"So","key":"24BA","mappings":{"default":{"default":"circled latin capital letter e","short":"circled cap e"},"mathspeak":{"default":"circled upper E"}}},{"category":"So","key":"24BB","mappings":{"default":{"default":"circled latin capital letter f","short":"circled cap f"},"mathspeak":{"default":"circled upper F"}}},{"category":"So","key":"24BC","mappings":{"default":{"default":"circled latin capital letter g","short":"circled cap g"},"mathspeak":{"default":"circled upper G"}}},{"category":"So","key":"24BD","mappings":{"default":{"default":"circled latin capital letter h","short":"circled cap h"},"mathspeak":{"default":"circled upper H"}}},{"category":"So","key":"24BE","mappings":{"default":{"default":"circled latin capital letter i","short":"circled cap i"},"mathspeak":{"default":"circled upper I"}}},{"category":"So","key":"24BF","mappings":{"default":{"default":"circled latin capital letter j","short":"circled cap j"},"mathspeak":{"default":"circled upper J"}}},{"category":"So","key":"24C0","mappings":{"default":{"default":"circled latin capital letter k","short":"circled cap k"},"mathspeak":{"default":"circled upper K"}}},{"category":"So","key":"24C1","mappings":{"default":{"default":"circled latin capital letter l","short":"circled cap l"},"mathspeak":{"default":"circled upper L"}}},{"category":"So","key":"24C2","mappings":{"default":{"default":"circled latin capital letter m","short":"circled cap m"},"mathspeak":{"default":"circled upper M"}}},{"category":"So","key":"24C3","mappings":{"default":{"default":"circled latin capital letter n","short":"circled cap n"},"mathspeak":{"default":"circled upper N"}}},{"category":"So","key":"24C4","mappings":{"default":{"default":"circled latin capital letter o","short":"circled cap o"},"mathspeak":{"default":"circled upper O"}}},{"category":"So","key":"24C5","mappings":{"default":{"default":"circled latin capital letter p","short":"circled cap p"},"mathspeak":{"default":"circled upper P"}}},{"category":"So","key":"24C6","mappings":{"default":{"default":"circled latin capital letter q","short":"circled cap q"},"mathspeak":{"default":"circled upper Q"}}},{"category":"So","key":"24C7","mappings":{"default":{"default":"circled latin capital letter r","short":"circled cap r"},"mathspeak":{"default":"circled upper R"}}},{"category":"So","key":"24C8","mappings":{"default":{"default":"circled latin capital letter s","short":"circled cap s"},"mathspeak":{"default":"circled upper S"}}},{"category":"So","key":"24C9","mappings":{"default":{"default":"circled latin capital letter t","short":"circled cap t"},"mathspeak":{"default":"circled upper T"}}},{"category":"So","key":"24CA","mappings":{"default":{"default":"circled latin capital letter u","short":"circled cap u"},"mathspeak":{"default":"circled upper U"}}},{"category":"So","key":"24CB","mappings":{"default":{"default":"circled latin capital letter v","short":"circled cap v"},"mathspeak":{"default":"circled upper V"}}},{"category":"So","key":"24CC","mappings":{"default":{"default":"circled latin capital letter w","short":"circled cap w"},"mathspeak":{"default":"circled upper W"}}},{"category":"So","key":"24CD","mappings":{"default":{"default":"circled latin capital letter x","short":"circled cap x"},"mathspeak":{"default":"circled upper X"}}},{"category":"So","key":"24CE","mappings":{"default":{"default":"circled latin capital letter y","short":"circled cap y"},"mathspeak":{"default":"circled upper Y"}}},{"category":"So","key":"24CF","mappings":{"default":{"default":"circled latin capital letter z","short":"circled cap z"},"mathspeak":{"default":"circled upper Z"}}},{"category":"So","key":"24D0","mappings":{"default":{"default":"circled latin small letter a","short":"circled a"}}},{"category":"So","key":"24D1","mappings":{"default":{"default":"circled latin small letter b","short":"circled b"}}},{"category":"So","key":"24D2","mappings":{"default":{"default":"circled latin small letter c","short":"circled c"}}},{"category":"So","key":"24D3","mappings":{"default":{"default":"circled latin small letter d","short":"circled d"}}},{"category":"So","key":"24D4","mappings":{"default":{"default":"circled latin small letter e","short":"circled e"}}},{"category":"So","key":"24D5","mappings":{"default":{"default":"circled latin small letter f","short":"circled f"}}},{"category":"So","key":"24D6","mappings":{"default":{"default":"circled latin small letter g","short":"circled g"}}},{"category":"So","key":"24D7","mappings":{"default":{"default":"circled latin small letter h","short":"circled h"}}},{"category":"So","key":"24D8","mappings":{"default":{"default":"circled latin small letter i","short":"circled i"}}},{"category":"So","key":"24D9","mappings":{"default":{"default":"circled latin small letter j","short":"circled j"}}},{"category":"So","key":"24DA","mappings":{"default":{"default":"circled latin small letter k","short":"circled k"}}},{"category":"So","key":"24DB","mappings":{"default":{"default":"circled latin small letter l","short":"circled l"}}},{"category":"So","key":"24DC","mappings":{"default":{"default":"circled latin small letter m","short":"circled m"}}},{"category":"So","key":"24DD","mappings":{"default":{"default":"circled latin small letter n","short":"circled n"}}},{"category":"So","key":"24DE","mappings":{"default":{"default":"circled latin small letter o","short":"circled o"}}},{"category":"So","key":"24DF","mappings":{"default":{"default":"circled latin small letter p","short":"circled p"}}},{"category":"So","key":"24E0","mappings":{"default":{"default":"circled latin small letter q","short":"circled q"}}},{"category":"So","key":"24E1","mappings":{"default":{"default":"circled latin small letter r","short":"circled r"}}},{"category":"So","key":"24E2","mappings":{"default":{"default":"circled latin small letter s","short":"circled s"}}},{"category":"So","key":"24E3","mappings":{"default":{"default":"circled latin small letter t","short":"circled t"}}},{"category":"So","key":"24E4","mappings":{"default":{"default":"circled latin small letter u","short":"circled u"}}},{"category":"So","key":"24E5","mappings":{"default":{"default":"circled latin small letter v","short":"circled v"}}},{"category":"So","key":"24E6","mappings":{"default":{"default":"circled latin small letter w","short":"circled w"}}},{"category":"So","key":"24E7","mappings":{"default":{"default":"circled latin small letter x","short":"circled x"}}},{"category":"So","key":"24E8","mappings":{"default":{"default":"circled latin small letter y","short":"circled y"}}},{"category":"So","key":"24E9","mappings":{"default":{"default":"circled latin small letter z","short":"circled z"}}},{"category":"Lm","key":"2C7C","mappings":{"default":{"default":"latin subscript small letter j","short":"subscript j"}}},{"category":"So","key":"1F110","mappings":{"default":{"default":"parenthesized latin capital letter a","short":"parenthesized cap a"},"mathspeak":{"default":"parenthesized upper A"}}},{"category":"So","key":"1F111","mappings":{"default":{"default":"parenthesized latin capital letter b","short":"parenthesized cap b"},"mathspeak":{"default":"parenthesized upper B"}}},{"category":"So","key":"1F112","mappings":{"default":{"default":"parenthesized latin capital letter c","short":"parenthesized cap c"},"mathspeak":{"default":"parenthesized upper C"}}},{"category":"So","key":"1F113","mappings":{"default":{"default":"parenthesized latin capital letter d","short":"parenthesized cap d"},"mathspeak":{"default":"parenthesized upper D"}}},{"category":"So","key":"1F114","mappings":{"default":{"default":"parenthesized latin capital letter e","short":"parenthesized cap e"},"mathspeak":{"default":"parenthesized upper E"}}},{"category":"So","key":"1F115","mappings":{"default":{"default":"parenthesized latin capital letter f","short":"parenthesized cap f"},"mathspeak":{"default":"parenthesized upper F"}}},{"category":"So","key":"1F116","mappings":{"default":{"default":"parenthesized latin capital letter g","short":"parenthesized cap g"},"mathspeak":{"default":"parenthesized upper G"}}},{"category":"So","key":"1F117","mappings":{"default":{"default":"parenthesized latin capital letter h","short":"parenthesized cap h"},"mathspeak":{"default":"parenthesized upper H"}}},{"category":"So","key":"1F118","mappings":{"default":{"default":"parenthesized latin capital letter i","short":"parenthesized cap i"},"mathspeak":{"default":"parenthesized upper I"}}},{"category":"So","key":"1F119","mappings":{"default":{"default":"parenthesized latin capital letter j","short":"parenthesized cap j"},"mathspeak":{"default":"parenthesized upper J"}}},{"category":"So","key":"1F11A","mappings":{"default":{"default":"parenthesized latin capital letter k","short":"parenthesized cap k"},"mathspeak":{"default":"parenthesized upper K"}}},{"category":"So","key":"1F11B","mappings":{"default":{"default":"parenthesized latin capital letter l","short":"parenthesized cap l"},"mathspeak":{"default":"parenthesized upper L"}}},{"category":"So","key":"1F11C","mappings":{"default":{"default":"parenthesized latin capital letter m","short":"parenthesized cap m"},"mathspeak":{"default":"parenthesized upper M"}}},{"category":"So","key":"1F11D","mappings":{"default":{"default":"parenthesized latin capital letter n","short":"parenthesized cap n"},"mathspeak":{"default":"parenthesized upper N"}}},{"category":"So","key":"1F11E","mappings":{"default":{"default":"parenthesized latin capital letter o","short":"parenthesized cap o"},"mathspeak":{"default":"parenthesized upper O"}}},{"category":"So","key":"1F11F","mappings":{"default":{"default":"parenthesized latin capital letter p","short":"parenthesized cap p"},"mathspeak":{"default":"parenthesized upper P"}}},{"category":"So","key":"1F120","mappings":{"default":{"default":"parenthesized latin capital letter q","short":"parenthesized cap q"},"mathspeak":{"default":"parenthesized upper Q"}}},{"category":"So","key":"1F121","mappings":{"default":{"default":"parenthesized latin capital letter r","short":"parenthesized cap r"},"mathspeak":{"default":"parenthesized upper R"}}},{"category":"So","key":"1F122","mappings":{"default":{"default":"parenthesized latin capital letter s","short":"parenthesized cap s"},"mathspeak":{"default":"parenthesized upper S"}}},{"category":"So","key":"1F123","mappings":{"default":{"default":"parenthesized latin capital letter t","short":"parenthesized cap t"},"mathspeak":{"default":"parenthesized upper T"}}},{"category":"So","key":"1F124","mappings":{"default":{"default":"parenthesized latin capital letter u","short":"parenthesized cap u"},"mathspeak":{"default":"parenthesized upper U"}}},{"category":"So","key":"1F125","mappings":{"default":{"default":"parenthesized latin capital letter v","short":"parenthesized cap v"},"mathspeak":{"default":"parenthesized upper V"}}},{"category":"So","key":"1F126","mappings":{"default":{"default":"parenthesized latin capital letter w","short":"parenthesized cap w"},"mathspeak":{"default":"parenthesized upper W"}}},{"category":"So","key":"1F127","mappings":{"default":{"default":"parenthesized latin capital letter x","short":"parenthesized cap x"},"mathspeak":{"default":"parenthesized upper X"}}},{"category":"So","key":"1F128","mappings":{"default":{"default":"parenthesized latin capital letter y","short":"parenthesized cap y"},"mathspeak":{"default":"parenthesized upper Y"}}},{"category":"So","key":"1F129","mappings":{"default":{"default":"parenthesized latin capital letter z","short":"parenthesized cap z"},"mathspeak":{"default":"parenthesized upper Z"}}},{"category":"So","key":"1F12A","mappings":{"default":{"default":"tortoise shell bracketed latin capital letter s","short":"tortoise shell bracketed cap s"},"mathspeak":{"default":"tortoise shell bracketed upper S"}}},{"category":"So","key":"1F12B","mappings":{"default":{"default":"circled italic latin capital letter c","short":"circled italic cap c"},"mathspeak":{"default":"circled italic upper C"}}},{"category":"So","key":"1F12C","mappings":{"default":{"default":"circled italic latin capital letter r","short":"circled italic cap r"},"mathspeak":{"default":"circled italic upper R"}}},{"category":"So","key":"1F130","mappings":{"default":{"default":"squared latin capital letter a","short":"squared cap a"},"mathspeak":{"default":"squared upper A"}}},{"category":"So","key":"1F131","mappings":{"default":{"default":"squared latin capital letter b","short":"squared cap b"},"mathspeak":{"default":"squared upper B"}}},{"category":"So","key":"1F132","mappings":{"default":{"default":"squared latin capital letter c","short":"squared cap c"},"mathspeak":{"default":"squared upper C"}}},{"category":"So","key":"1F133","mappings":{"default":{"default":"squared latin capital letter d","short":"squared cap d"},"mathspeak":{"default":"squared upper D"}}},{"category":"So","key":"1F134","mappings":{"default":{"default":"squared latin capital letter e","short":"squared cap e"},"mathspeak":{"default":"squared upper E"}}},{"category":"So","key":"1F135","mappings":{"default":{"default":"squared latin capital letter f","short":"squared cap f"},"mathspeak":{"default":"squared upper F"}}},{"category":"So","key":"1F136","mappings":{"default":{"default":"squared latin capital letter g","short":"squared cap g"},"mathspeak":{"default":"squared upper G"}}},{"category":"So","key":"1F137","mappings":{"default":{"default":"squared latin capital letter h","short":"squared cap h"},"mathspeak":{"default":"squared upper H"}}},{"category":"So","key":"1F138","mappings":{"default":{"default":"squared latin capital letter i","short":"squared cap i"},"mathspeak":{"default":"squared upper I"}}},{"category":"So","key":"1F139","mappings":{"default":{"default":"squared latin capital letter j","short":"squared cap j"},"mathspeak":{"default":"squared upper J"}}},{"category":"So","key":"1F13A","mappings":{"default":{"default":"squared latin capital letter k","short":"squared cap k"},"mathspeak":{"default":"squared upper K"}}},{"category":"So","key":"1F13B","mappings":{"default":{"default":"squared latin capital letter l","short":"squared cap l"},"mathspeak":{"default":"squared upper L"}}},{"category":"So","key":"1F13C","mappings":{"default":{"default":"squared latin capital letter m","short":"squared cap m"},"mathspeak":{"default":"squared upper M"}}},{"category":"So","key":"1F13D","mappings":{"default":{"default":"squared latin capital letter n","short":"squared cap n"},"mathspeak":{"default":"squared upper N"}}},{"category":"So","key":"1F13E","mappings":{"default":{"default":"squared latin capital letter o","short":"squared cap o"},"mathspeak":{"default":"squared upper O"}}},{"category":"So","key":"1F13F","mappings":{"default":{"default":"squared latin capital letter p","short":"squared cap p"},"mathspeak":{"default":"squared upper P"}}},{"category":"So","key":"1F140","mappings":{"default":{"default":"squared latin capital letter q","short":"squared cap q"},"mathspeak":{"default":"squared upper Q"}}},{"category":"So","key":"1F141","mappings":{"default":{"default":"squared latin capital letter r","short":"squared cap r"},"mathspeak":{"default":"squared upper R"}}},{"category":"So","key":"1F142","mappings":{"default":{"default":"squared latin capital letter s","short":"squared cap s"},"mathspeak":{"default":"squared upper S"}}},{"category":"So","key":"1F143","mappings":{"default":{"default":"squared latin capital letter t","short":"squared cap t"},"mathspeak":{"default":"squared upper T"}}},{"category":"So","key":"1F144","mappings":{"default":{"default":"squared latin capital letter u","short":"squared cap u"},"mathspeak":{"default":"squared upper U"}}},{"category":"So","key":"1F145","mappings":{"default":{"default":"squared latin capital letter v","short":"squared cap v"},"mathspeak":{"default":"squared upper V"}}},{"category":"So","key":"1F146","mappings":{"default":{"default":"squared latin capital letter w","short":"squared cap w"},"mathspeak":{"default":"squared upper W"}}},{"category":"So","key":"1F147","mappings":{"default":{"default":"squared latin capital letter x","short":"squared cap x"},"mathspeak":{"default":"squared upper X"}}},{"category":"So","key":"1F148","mappings":{"default":{"default":"squared latin capital letter y","short":"squared cap y"},"mathspeak":{"default":"squared upper Y"}}},{"category":"So","key":"1F149","mappings":{"default":{"default":"squared latin capital letter z","short":"squared cap z"},"mathspeak":{"default":"squared upper Z"}}},{"category":"So","key":"1F150","mappings":{"default":{"default":"negative circled latin capital letter a","short":"negative circled cap a"},"mathspeak":{"default":"negative circled upper A"}}},{"category":"So","key":"1F151","mappings":{"default":{"default":"negative circled latin capital letter b","short":"negative circled cap b"},"mathspeak":{"default":"negative circled upper B"}}},{"category":"So","key":"1F152","mappings":{"default":{"default":"negative circled latin capital letter c","short":"negative circled cap c"},"mathspeak":{"default":"negative circled upper C"}}},{"category":"So","key":"1F153","mappings":{"default":{"default":"negative circled latin capital letter d","short":"negative circled cap d"},"mathspeak":{"default":"negative circled upper D"}}},{"category":"So","key":"1F154","mappings":{"default":{"default":"negative circled latin capital letter e","short":"negative circled cap e"},"mathspeak":{"default":"negative circled upper E"}}},{"category":"So","key":"1F155","mappings":{"default":{"default":"negative circled latin capital letter f","short":"negative circled cap f"},"mathspeak":{"default":"negative circled upper F"}}},{"category":"So","key":"1F156","mappings":{"default":{"default":"negative circled latin capital letter g","short":"negative circled cap g"},"mathspeak":{"default":"negative circled upper G"}}},{"category":"So","key":"1F157","mappings":{"default":{"default":"negative circled latin capital letter h","short":"negative circled cap h"},"mathspeak":{"default":"negative circled upper H"}}},{"category":"So","key":"1F158","mappings":{"default":{"default":"negative circled latin capital letter i","short":"negative circled cap i"},"mathspeak":{"default":"negative circled upper I"}}},{"category":"So","key":"1F159","mappings":{"default":{"default":"negative circled latin capital letter j","short":"negative circled cap j"},"mathspeak":{"default":"negative circled upper J"}}},{"category":"So","key":"1F15A","mappings":{"default":{"default":"negative circled latin capital letter k","short":"negative circled cap k"},"mathspeak":{"default":"negative circled upper K"}}},{"category":"So","key":"1F15B","mappings":{"default":{"default":"negative circled latin capital letter l","short":"negative circled cap l"},"mathspeak":{"default":"negative circled upper L"}}},{"category":"So","key":"1F15C","mappings":{"default":{"default":"negative circled latin capital letter m","short":"negative circled cap m"},"mathspeak":{"default":"negative circled upper M"}}},{"category":"So","key":"1F15D","mappings":{"default":{"default":"negative circled latin capital letter n","short":"negative circled cap n"},"mathspeak":{"default":"negative circled upper N"}}},{"category":"So","key":"1F15E","mappings":{"default":{"default":"negative circled latin capital letter o","short":"negative circled cap o"},"mathspeak":{"default":"negative circled upper O"}}},{"category":"So","key":"1F15F","mappings":{"default":{"default":"negative circled latin capital letter p","short":"negative circled cap p"},"mathspeak":{"default":"negative circled upper P"}}},{"category":"So","key":"1F160","mappings":{"default":{"default":"negative circled latin capital letter q","short":"negative circled cap q"},"mathspeak":{"default":"negative circled upper Q"}}},{"category":"So","key":"1F161","mappings":{"default":{"default":"negative circled latin capital letter r","short":"negative circled cap r"},"mathspeak":{"default":"negative circled upper R"}}},{"category":"So","key":"1F162","mappings":{"default":{"default":"negative circled latin capital letter s","short":"negative circled cap s"},"mathspeak":{"default":"negative circled upper S"}}},{"category":"So","key":"1F163","mappings":{"default":{"default":"negative circled latin capital letter t","short":"negative circled cap t"},"mathspeak":{"default":"negative circled upper T"}}},{"category":"So","key":"1F164","mappings":{"default":{"default":"negative circled latin capital letter u","short":"negative circled cap u"},"mathspeak":{"default":"negative circled upper U"}}},{"category":"So","key":"1F165","mappings":{"default":{"default":"negative circled latin capital letter v","short":"negative circled cap v"},"mathspeak":{"default":"negative circled upper V"}}},{"category":"So","key":"1F166","mappings":{"default":{"default":"negative circled latin capital letter w","short":"negative circled cap w"},"mathspeak":{"default":"negative circled upper W"}}},{"category":"So","key":"1F167","mappings":{"default":{"default":"negative circled latin capital letter x","short":"negative circled cap x"},"mathspeak":{"default":"negative circled upper X"}}},{"category":"So","key":"1F168","mappings":{"default":{"default":"negative circled latin capital letter y","short":"negative circled cap y"},"mathspeak":{"default":"negative circled upper Y"}}},{"category":"So","key":"1F169","mappings":{"default":{"default":"negative circled latin capital letter z","short":"negative circled cap z"},"mathspeak":{"default":"negative circled upper Z"}}},{"category":"So","key":"1F170","mappings":{"default":{"default":"negative squared latin capital letter a","short":"negative squared cap a"},"mathspeak":{"default":"negative squared upper A"}}},{"category":"So","key":"1F171","mappings":{"default":{"default":"negative squared latin capital letter b","short":"negative squared cap b"},"mathspeak":{"default":"negative squared upper B"}}},{"category":"So","key":"1F172","mappings":{"default":{"default":"negative squared latin capital letter c","short":"negative squared cap c"},"mathspeak":{"default":"negative squared upper C"}}},{"category":"So","key":"1F173","mappings":{"default":{"default":"negative squared latin capital letter d","short":"negative squared cap d"},"mathspeak":{"default":"negative squared upper D"}}},{"category":"So","key":"1F174","mappings":{"default":{"default":"negative squared latin capital letter e","short":"negative squared cap e"},"mathspeak":{"default":"negative squared upper E"}}},{"category":"So","key":"1F175","mappings":{"default":{"default":"negative squared latin capital letter f","short":"negative squared cap f"},"mathspeak":{"default":"negative squared upper F"}}},{"category":"So","key":"1F176","mappings":{"default":{"default":"negative squared latin capital letter g","short":"negative squared cap g"},"mathspeak":{"default":"negative squared upper G"}}},{"category":"So","key":"1F177","mappings":{"default":{"default":"negative squared latin capital letter h","short":"negative squared cap h"},"mathspeak":{"default":"negative squared upper H"}}},{"category":"So","key":"1F178","mappings":{"default":{"default":"negative squared latin capital letter i","short":"negative squared cap i"},"mathspeak":{"default":"negative squared upper I"}}},{"category":"So","key":"1F179","mappings":{"default":{"default":"negative squared latin capital letter j","short":"negative squared cap j"},"mathspeak":{"default":"negative squared upper J"}}},{"category":"So","key":"1F17A","mappings":{"default":{"default":"negative squared latin capital letter k","short":"negative squared cap k"},"mathspeak":{"default":"negative squared upper K"}}},{"category":"So","key":"1F17B","mappings":{"default":{"default":"negative squared latin capital letter l","short":"negative squared cap l"},"mathspeak":{"default":"negative squared upper L"}}},{"category":"So","key":"1F17C","mappings":{"default":{"default":"negative squared latin capital letter m","short":"negative squared cap m"},"mathspeak":{"default":"negative squared upper M"}}},{"category":"So","key":"1F17D","mappings":{"default":{"default":"negative squared latin capital letter n","short":"negative squared cap n"},"mathspeak":{"default":"negative squared upper N"}}},{"category":"So","key":"1F17E","mappings":{"default":{"default":"negative squared latin capital letter o","short":"negative squared cap o"},"mathspeak":{"default":"negative squared upper O"}}},{"category":"So","key":"1F17F","mappings":{"default":{"default":"negative squared latin capital letter p","short":"negative squared cap p"},"mathspeak":{"default":"negative squared upper P"}}},{"category":"So","key":"1F180","mappings":{"default":{"default":"negative squared latin capital letter q","short":"negative squared cap q"},"mathspeak":{"default":"negative squared upper Q"}}},{"category":"So","key":"1F181","mappings":{"default":{"default":"negative squared latin capital letter r","short":"negative squared cap r"},"mathspeak":{"default":"negative squared upper R"}}},{"category":"So","key":"1F182","mappings":{"default":{"default":"negative squared latin capital letter s","short":"negative squared cap s"},"mathspeak":{"default":"negative squared upper S"}}},{"category":"So","key":"1F183","mappings":{"default":{"default":"negative squared latin capital letter t","short":"negative squared cap t"},"mathspeak":{"default":"negative squared upper T"}}},{"category":"So","key":"1F184","mappings":{"default":{"default":"negative squared latin capital letter u","short":"negative squared cap u"},"mathspeak":{"default":"negative squared upper U"}}},{"category":"So","key":"1F185","mappings":{"default":{"default":"negative squared latin capital letter v","short":"negative squared cap v"},"mathspeak":{"default":"negative squared upper V"}}},{"category":"So","key":"1F186","mappings":{"default":{"default":"negative squared latin capital letter w","short":"negative squared cap w"},"mathspeak":{"default":"negative squared upper W"}}},{"category":"So","key":"1F187","mappings":{"default":{"default":"negative squared latin capital letter x","short":"negative squared cap x"},"mathspeak":{"default":"negative squared upper X"}}},{"category":"So","key":"1F188","mappings":{"default":{"default":"negative squared latin capital letter y","short":"negative squared cap y"},"mathspeak":{"default":"negative squared upper Y"}}},{"category":"So","key":"1F189","mappings":{"default":{"default":"negative squared latin capital letter z","short":"negative squared cap z"},"mathspeak":{"default":"negative squared upper Z"}}},{"category":"So","key":"1F18A","mappings":{"default":{"default":"crossed negative squared latin capital letter p","short":"crossed negative squared cap p"},"mathspeak":{"default":"crossed negative squared upper P"}}}]
,
"en/latin-upper-double-accent.js": 
[{"locale":"en"},{"category":"Lu","key":"01D5","mappings":{"default":{"default":"latin capital letter u with diaeresis and macron","alternative":"latin capital letter u double overdot overbar","short":"cap u double overdot overbar"},"mathspeak":{"default":"upper U double overdot overbar"}}},{"category":"Lu","key":"01D7","mappings":{"default":{"default":"latin capital letter u with diaeresis and acute","alternative":"latin capital letter u double overdot acute","short":"cap u double overdot acute"},"mathspeak":{"default":"upper U double overdot acute"}}},{"category":"Lu","key":"01D9","mappings":{"default":{"default":"latin capital letter u with diaeresis and caron","alternative":"latin capital letter u double overdot hacek","short":"cap u double overdot caron"},"mathspeak":{"default":"upper U double overdot caron"}}},{"category":"Lu","key":"01DB","mappings":{"default":{"default":"latin capital letter u with diaeresis and grave","alternative":"latin capital letter u double overdot grave","short":"cap u double overdot grave"},"mathspeak":{"default":"upper U double overdot grave"}}},{"category":"Lu","key":"01DE","mappings":{"default":{"default":"latin capital letter a with diaeresis and macron","alternative":"latin capital letter a double overdot overbar","short":"cap a double overdot overbar"},"mathspeak":{"default":"upper A double overdot overbar"}}},{"category":"Lu","key":"01E0","mappings":{"default":{"default":"latin capital letter a with dot above and macron","alternative":"latin capital letter a dot overbar","short":"cap a overdot overbar"},"mathspeak":{"default":"upper A overdot overbar"}}},{"category":"Lu","key":"01EC","mappings":{"default":{"default":"latin capital letter o with ogonek and macron","alternative":"latin capital letter o ogonek overbar","short":"cap o ogonek overbar"},"mathspeak":{"default":"upper O ogonek overbar"}}},{"category":"Lu","key":"01FA","mappings":{"default":{"default":"latin capital letter a with ring above and acute","alternative":"latin capital letter a ring acute","short":"cap a ring acute"},"mathspeak":{"default":"upper A ring acute"}}},{"category":"Lu","key":"022A","mappings":{"default":{"default":"latin capital letter o with diaeresis and macron","alternative":"latin capital letter o double overdot overbar","short":"cap o double overdot overbar"},"mathspeak":{"default":"upper O double overdot overbar"}}},{"category":"Lu","key":"022C","mappings":{"default":{"default":"latin capital letter o with tilde and macron","alternative":"latin capital letter o tilde overbar","short":"cap o tilde overbar"},"mathspeak":{"default":"upper O tilde overbar"}}},{"category":"Lu","key":"0230","mappings":{"default":{"default":"latin capital letter o with dot above and macron","alternative":"latin capital letter o overdot overbar","short":"cap o overdot overbar"},"mathspeak":{"default":"upper O overdot overbar"}}},{"category":"Lu","key":"1E08","mappings":{"default":{"default":"latin capital letter c with cedilla and acute","alternative":"latin capital letter c cedilla acute","short":"cap c cedilla acute"},"mathspeak":{"default":"upper C cedilla acute"}}},{"category":"Lu","key":"1E14","mappings":{"default":{"default":"latin capital letter e with macron and grave","alternative":"latin capital letter e overbar grave","short":"cap e overbar grave"},"mathspeak":{"default":"upper E overbar grave"}}},{"category":"Lu","key":"1E16","mappings":{"default":{"default":"latin capital letter e with macron and acute","alternative":"latin capital letter e overbar acute","short":"cap e overbar acute"},"mathspeak":{"default":"upper E overbar acute"}}},{"category":"Lu","key":"1E1C","mappings":{"default":{"default":"latin capital letter e with cedilla and breve","alternative":"latin capital letter e cedilla breve","short":"cap e cedilla breve"},"mathspeak":{"default":"upper E cedilla breve"}}},{"category":"Lu","key":"1E2E","mappings":{"default":{"default":"latin capital letter i with diaeresis and acute","alternative":"latin capital letter i double overdot acute","short":"cap i double overdot acute"},"mathspeak":{"default":"upper I double overdot acute"}}},{"category":"Lu","key":"1E38","mappings":{"default":{"default":"latin capital letter l with dot below and macron","alternative":"latin capital letter l underdot overbar","short":"cap l underdot overbar"},"mathspeak":{"default":"upper L underdot overbar"}}},{"category":"Lu","key":"1E4C","mappings":{"default":{"default":"latin capital letter o with tilde and acute","alternative":"latin capital letter o tilde acute","short":"cap o tilde acute"},"mathspeak":{"default":"upper O tilde acute"}}},{"category":"Lu","key":"1E4E","mappings":{"default":{"default":"latin capital letter o with tilde and diaeresis","alternative":"latin capital letter o tilde double overdot","short":"cap o tilde double overdot"},"mathspeak":{"default":"upper O tilde double overdot"}}},{"category":"Lu","key":"1E50","mappings":{"default":{"default":"latin capital letter o with macron and grave","alternative":"latin capital letter o overbar grave","short":"cap o overbar grave"},"mathspeak":{"default":"upper O overbar grave"}}},{"category":"Lu","key":"1E52","mappings":{"default":{"default":"latin capital letter o with macron and acute","alternative":"latin capital letter o overbar acute","short":"cap o overbar acute"},"mathspeak":{"default":"upper O overbar acute"}}},{"category":"Lu","key":"1E5C","mappings":{"default":{"default":"latin capital letter r with dot below and macron","alternative":"cap r underdot and overbar","short":"cap r overbar underdot"},"mathspeak":{"default":"upper R overbar underdot"}}},{"category":"Lu","key":"1E64","mappings":{"default":{"default":"latin capital letter s with acute dot above","alternative":"latin capital letter s acute overdot","short":"cap s acute overdot"},"mathspeak":{"default":"upper S acute overdot"}}},{"category":"Lu","key":"1E66","mappings":{"default":{"default":"latin capital letter s with caron and dot above","alternative":"latin capital letter s caron overdot","short":"cap s caron overdot"},"mathspeak":{"default":"upper S caron overdot"}}},{"category":"Lu","key":"1E68","mappings":{"default":{"default":"latin capital letter s with dot below and dot above","alternative":"latin capital letter s underdot overdot","short":"cap s underdot overdot"},"mathspeak":{"default":"upper S underdot overdot"}}},{"category":"Lu","key":"1E78","mappings":{"default":{"default":"latin capital letter u with tilde and acute","alternative":"latin capital letter u tilde acute","short":"cap u tilde acute"},"mathspeak":{"default":"upper U tilde acute"}}},{"category":"Lu","key":"1E7A","mappings":{"default":{"default":"latin capital letter u with macron and diaeresis","alternative":"latin capital letter u overbar double overdot","short":"cap u overbar double overdot"},"mathspeak":{"default":"upper U overbar double overdot"}}},{"category":"Lu","key":"1EA4","mappings":{"default":{"default":"latin capital letter a with circumflex and acute","alternative":"latin capital letter a hat acute","short":"cap a hat acute"},"mathspeak":{"default":"upper A hat acute"}}},{"category":"Lu","key":"1EA6","mappings":{"default":{"default":"latin capital letter a with circumflex and grave","alternative":"latin capital letter a hat grave","short":"cap a hat grave"},"mathspeak":{"default":"upper A hat grave"}}},{"category":"Lu","key":"1EA8","mappings":{"default":{"default":"latin capital letter a with circumflex and hook above","alternative":"latin capital letter a hat hook","short":"cap a hat hook"},"mathspeak":{"default":"upper A hat hook"}}},{"category":"Lu","key":"1EAA","mappings":{"default":{"default":"latin capital letter a with circumflex and tilde","alternative":"latin capital letter a hat tilde","short":"cap a hat tilde"},"mathspeak":{"default":"upper A hat tilde"}}},{"category":"Lu","key":"1EAC","mappings":{"default":{"default":"latin capital letter a with circumflex and dot below","alternative":"latin capital letter a hat underdot","short":"cap a hat underdot"},"mathspeak":{"default":"upper A hat underdot"}}},{"category":"Lu","key":"1EAE","mappings":{"default":{"default":"latin capital letter a with breve and acute","alternative":"latin capital letter a breve acute","short":"cap a breve acute"},"mathspeak":{"default":"upper A breve acute"}}},{"category":"Lu","key":"1EB0","mappings":{"default":{"default":"latin capital letter a with breve and grave","alternative":"latin capital letter a breve grave","short":"cap a breve grave"},"mathspeak":{"default":"upper A breve grave"}}},{"category":"Lu","key":"1EB2","mappings":{"default":{"default":"latin capital letter a with breve and hook above","alternative":"latin capital letter a breve hook","short":"cap a breve hook"},"mathspeak":{"default":"upper A breve hook"}}},{"category":"Lu","key":"1EB4","mappings":{"default":{"default":"latin capital letter a with breve and tilde","alternative":"latin capital letter a breve tilde","short":"cap a breve tilde"},"mathspeak":{"default":"upper A breve tilde"}}},{"category":"Lu","key":"1EB6","mappings":{"default":{"default":"latin capital letter a with breve and dot below","alternative":"latin capital letter a breve underdot","short":"cap a breve underdot"},"mathspeak":{"default":"upper A breve underdot"}}},{"category":"Lu","key":"1EBE","mappings":{"default":{"default":"latin capital letter e with circumflex and acute","alternative":"latin capital letter e hat acute","short":"cap e hat acute"},"mathspeak":{"default":"upper E hat acute"}}},{"category":"Lu","key":"1EC0","mappings":{"default":{"default":"latin capital letter e with circumflex and grave","alternative":"latin capital letter e hat grave","short":"cap e hat grave"},"mathspeak":{"default":"upper E hat grave"}}},{"category":"Lu","key":"1EC2","mappings":{"default":{"default":"latin capital letter e with circumflex and hook above","alternative":"latin capital letter e hat hook","short":"cap e hat hook"},"mathspeak":{"default":"upper E hat hook"}}},{"category":"Lu","key":"1EC4","mappings":{"default":{"default":"latin capital letter e with circumflex and tilde","alternative":"latin capital letter e hat tilde","short":"cap e hat tilde"},"mathspeak":{"default":"upper E hat tilde"}}},{"category":"Lu","key":"1EC6","mappings":{"default":{"default":"latin capital letter e with circumflex and dot below","alternative":"latin capital letter e hat underdot","short":"cap e hat underdot"},"mathspeak":{"default":"upper E hat underdot"}}},{"category":"Lu","key":"1ED0","mappings":{"default":{"default":"latin capital letter o with circumflex and acute","alternative":"latin capital letter o hat acute","short":"cap o hat acute"},"mathspeak":{"default":"upper O hat acute"}}},{"category":"Lu","key":"1ED2","mappings":{"default":{"default":"latin capital letter o with circumflex and grave","alternative":"latin capital letter o hat grave","short":"cap o hat grave"},"mathspeak":{"default":"upper O hat grave"}}},{"category":"Lu","key":"1ED4","mappings":{"default":{"default":"latin capital letter o with circumflex and hook above","alternative":"latin capital letter o hat hook","short":"cap o hat hook"},"mathspeak":{"default":"upper O hat hook"}}},{"category":"Lu","key":"1ED6","mappings":{"default":{"default":"latin capital letter o with circumflex and tilde","alternative":"latin capital letter o hat tilde","short":"cap o hat tilde"},"mathspeak":{"default":"upper O hat tilde"}}},{"category":"Lu","key":"1ED8","mappings":{"default":{"default":"latin capital letter o with circumflex and dot below","alternative":"latin capital letter o hat underdot","short":"cap o hat underdot"},"mathspeak":{"default":"upper O hat underdot"}}},{"category":"Lu","key":"1EDA","mappings":{"default":{"default":"latin capital letter o with horn and acute","alternative":"latin capital letter o acute prime","short":"cap o acute prime"},"mathspeak":{"default":"upper O acute prime"}}},{"category":"Lu","key":"1EDC","mappings":{"default":{"default":"latin capital letter o with horn and grave","alternative":"latin capital letter o grave prime","short":"cap o grave prime"},"mathspeak":{"default":"upper O grave prime"}}},{"category":"Lu","key":"1EDE","mappings":{"default":{"default":"latin capital letter o with horn and hook above","alternative":"latin capital letter o hook prime","short":"cap o hook prime"},"mathspeak":{"default":"upper O hook prime"}}},{"category":"Lu","key":"1EE0","mappings":{"default":{"default":"latin capital letter o with horn and tilde","alternative":"latin capital letter o tilde prime","short":"cap o tilde prime"},"mathspeak":{"default":"upper O tilde prime"}}},{"category":"Lu","key":"1EE2","mappings":{"default":{"default":"latin capital letter o with horn and dot below","alternative":"latin capital letter o underdot prime","short":"cap o underdot prime"},"mathspeak":{"default":"upper O underdot prime"}}},{"category":"Lu","key":"1EE8","mappings":{"default":{"default":"latin capital letter u with horn and acute","alternative":"latin capital letter u acute prime","short":"cap u acute prime"},"mathspeak":{"default":"upper U acute prime"}}},{"category":"Lu","key":"1EEA","mappings":{"default":{"default":"latin capital letter u with horn and grave","alternative":"latin capital letter u grave prime","short":"cap u grave prime"},"mathspeak":{"default":"upper U grave prime"}}},{"category":"Lu","key":"1EEC","mappings":{"default":{"default":"latin capital letter u with horn and hook above","alternative":"latin capital letter u hook prime","short":"cap u hook prime"},"mathspeak":{"default":"upper U hook prime"}}},{"category":"Lu","key":"1EEE","mappings":{"default":{"default":"latin capital letter u with horn and tilde","alternative":"latin capital letter u tilde prime","short":"cap u tilde prime"},"mathspeak":{"default":"upper U tilde prime"}}},{"category":"Lu","key":"1EF0","mappings":{"default":{"default":"latin capital letter u with horn and dot below","alternative":"latin capital letter u underdot prime","short":"cap u underdot prime"},"mathspeak":{"default":"upper U underdot prime"}}}]
,
"en/latin-upper-normal.js": 
[{"locale":"en"},{"category":"Lu","key":"0041","mappings":{"default":{"default":"latin capital letter a","short":"cap a"},"mathspeak":{"default":"upper A"}}},{"category":"Lu","key":"0042","mappings":{"default":{"default":"latin capital letter b","short":"cap b"},"mathspeak":{"default":"upper B"}}},{"category":"Lu","key":"0043","mappings":{"default":{"default":"latin capital letter c","short":"cap c"},"mathspeak":{"default":"upper C"}}},{"category":"Lu","key":"0044","mappings":{"default":{"default":"latin capital letter d","short":"cap d"},"mathspeak":{"default":"upper D"}}},{"category":"Lu","key":"0045","mappings":{"default":{"default":"latin capital letter e","short":"cap e"},"mathspeak":{"default":"upper E"}}},{"category":"Lu","key":"0046","mappings":{"default":{"default":"latin capital letter f","short":"cap f"},"mathspeak":{"default":"upper F"}}},{"category":"Lu","key":"0047","mappings":{"default":{"default":"latin capital letter g","short":"cap g"},"mathspeak":{"default":"upper G"}}},{"category":"Lu","key":"0048","mappings":{"default":{"default":"latin capital letter h","short":"cap h"},"mathspeak":{"default":"upper H"}}},{"category":"Lu","key":"0049","mappings":{"default":{"default":"latin capital letter i","short":"cap i"},"mathspeak":{"default":"upper I"}}},{"category":"Lu","key":"004A","mappings":{"default":{"default":"latin capital letter j","short":"cap j"},"mathspeak":{"default":"upper J"}}},{"category":"Lu","key":"004B","mappings":{"default":{"default":"latin capital letter k","short":"cap k"},"mathspeak":{"default":"upper K"}}},{"category":"Lu","key":"004C","mappings":{"default":{"default":"latin capital letter l","short":"cap l"},"mathspeak":{"default":"upper L"}}},{"category":"Lu","key":"004D","mappings":{"default":{"default":"latin capital letter m","short":"cap m"},"mathspeak":{"default":"upper M"}}},{"category":"Lu","key":"004E","mappings":{"default":{"default":"latin capital letter n","short":"cap n"},"mathspeak":{"default":"upper N"}}},{"category":"Lu","key":"004F","mappings":{"default":{"default":"latin capital letter o","short":"cap o"},"mathspeak":{"default":"upper O"}}},{"category":"Lu","key":"0050","mappings":{"default":{"default":"latin capital letter p","short":"cap p"},"mathspeak":{"default":"upper P"}}},{"category":"Lu","key":"0051","mappings":{"default":{"default":"latin capital letter q","short":"cap q"},"mathspeak":{"default":"upper Q"}}},{"category":"Lu","key":"0052","mappings":{"default":{"default":"latin capital letter r","short":"cap r"},"mathspeak":{"default":"upper R"}}},{"category":"Lu","key":"0053","mappings":{"default":{"default":"latin capital letter s","short":"cap s"},"mathspeak":{"default":"upper S"}}},{"category":"Lu","key":"0054","mappings":{"default":{"default":"latin capital letter t","short":"cap t"},"mathspeak":{"default":"upper T"}}},{"category":"Lu","key":"0055","mappings":{"default":{"default":"latin capital letter u","short":"cap u"},"mathspeak":{"default":"upper U"}}},{"category":"Lu","key":"0056","mappings":{"default":{"default":"latin capital letter v","short":"cap v"},"mathspeak":{"default":"upper V"}}},{"category":"Lu","key":"0057","mappings":{"default":{"default":"latin capital letter w","short":"cap w"},"mathspeak":{"default":"upper W"}}},{"category":"Lu","key":"0058","mappings":{"default":{"default":"latin capital letter x","short":"cap x"},"mathspeak":{"default":"upper X"}}},{"category":"Lu","key":"0059","mappings":{"default":{"default":"latin capital letter y","short":"cap y"},"mathspeak":{"default":"upper Y"}}},{"category":"Lu","key":"005A","mappings":{"default":{"default":"latin capital letter z","short":"cap z"},"mathspeak":{"default":"upper Z"}}},{"category":"Lu","key":"FF21","mappings":{"default":{"default":"fullwidth latin capital letter a","alternative":"fullwidth latin cap a","short":"cap a"},"mathspeak":{"default":"upper A"}}},{"category":"Lu","key":"FF22","mappings":{"default":{"default":"fullwidth latin capital letter b","alternative":"fullwidth latin cap b","short":"cap b"},"mathspeak":{"default":"upper B"}}},{"category":"Lu","key":"FF23","mappings":{"default":{"default":"fullwidth latin capital letter c","alternative":"fullwidth latin cap c","short":"cap c"},"mathspeak":{"default":"upper C"}}},{"category":"Lu","key":"FF24","mappings":{"default":{"default":"fullwidth latin capital letter d","alternative":"fullwidth latin cap d","short":"cap d"},"mathspeak":{"default":"upper D"}}},{"category":"Lu","key":"FF25","mappings":{"default":{"default":"fullwidth latin capital letter e","alternative":"fullwidth latin cap e","short":"cap e"},"mathspeak":{"default":"upper E"}}},{"category":"Lu","key":"FF26","mappings":{"default":{"default":"fullwidth latin capital letter f","alternative":"fullwidth latin cap f","short":"cap f"},"mathspeak":{"default":"upper F"}}},{"category":"Lu","key":"FF27","mappings":{"default":{"default":"fullwidth latin capital letter g","alternative":"fullwidth latin cap g","short":"cap g"},"mathspeak":{"default":"upper G"}}},{"category":"Lu","key":"FF28","mappings":{"default":{"default":"fullwidth latin capital letter h","alternative":"fullwidth latin cap h","short":"cap h"},"mathspeak":{"default":"upper H"}}},{"category":"Lu","key":"FF29","mappings":{"default":{"default":"fullwidth latin capital letter i","alternative":"fullwidth latin cap i","short":"cap i"},"mathspeak":{"default":"upper I"}}},{"category":"Lu","key":"FF2A","mappings":{"default":{"default":"fullwidth latin capital letter j","alternative":"fullwidth latin cap j","short":"cap j"},"mathspeak":{"default":"upper J"}}},{"category":"Lu","key":"FF2B","mappings":{"default":{"default":"fullwidth latin capital letter k","alternative":"fullwidth latin cap k","short":"cap k"},"mathspeak":{"default":"upper K"}}},{"category":"Lu","key":"FF2C","mappings":{"default":{"default":"fullwidth latin capital letter l","alternative":"fullwidth latin cap l","short":"cap l"},"mathspeak":{"default":"upper L"}}},{"category":"Lu","key":"FF2D","mappings":{"default":{"default":"fullwidth latin capital letter m","alternative":"fullwidth latin cap m","short":"cap m"},"mathspeak":{"default":"upper M"}}},{"category":"Lu","key":"FF2E","mappings":{"default":{"default":"fullwidth latin capital letter n","alternative":"fullwidth latin cap n","short":"cap n"},"mathspeak":{"default":"upper N"}}},{"category":"Lu","key":"FF2F","mappings":{"default":{"default":"fullwidth latin capital letter o","alternative":"fullwidth latin cap o","short":"cap o"},"mathspeak":{"default":"upper O"}}},{"category":"Lu","key":"FF30","mappings":{"default":{"default":"fullwidth latin capital letter p","alternative":"fullwidth latin cap p","short":"cap p"},"mathspeak":{"default":"upper P"}}},{"category":"Lu","key":"FF31","mappings":{"default":{"default":"fullwidth latin capital letter q","alternative":"fullwidth latin cap q","short":"cap q"},"mathspeak":{"default":"upper Q"}}},{"category":"Lu","key":"FF32","mappings":{"default":{"default":"fullwidth latin capital letter r","alternative":"fullwidth latin cap r","short":"cap r"},"mathspeak":{"default":"upper R"}}},{"category":"Lu","key":"FF33","mappings":{"default":{"default":"fullwidth latin capital letter s","alternative":"fullwidth latin cap s","short":"cap s"},"mathspeak":{"default":"upper S"}}},{"category":"Lu","key":"FF34","mappings":{"default":{"default":"fullwidth latin capital letter t","alternative":"fullwidth latin cap t","short":"cap t"},"mathspeak":{"default":"upper T"}}},{"category":"Lu","key":"FF35","mappings":{"default":{"default":"fullwidth latin capital letter u","alternative":"fullwidth latin cap u","short":"cap u"},"mathspeak":{"default":"upper U"}}},{"category":"Lu","key":"FF36","mappings":{"default":{"default":"fullwidth latin capital letter v","alternative":"fullwidth latin cap v","short":"cap v"},"mathspeak":{"default":"upper V"}}},{"category":"Lu","key":"FF37","mappings":{"default":{"default":"fullwidth latin capital letter w","alternative":"fullwidth latin cap w","short":"cap w"},"mathspeak":{"default":"upper W"}}},{"category":"Lu","key":"FF38","mappings":{"default":{"default":"fullwidth latin capital letter x","alternative":"fullwidth latin cap x","short":"cap x"},"mathspeak":{"default":"upper X"}}},{"category":"Lu","key":"FF39","mappings":{"default":{"default":"fullwidth latin capital letter y","alternative":"fullwidth latin cap y","short":"cap y"},"mathspeak":{"default":"upper Y"}}},{"category":"Lu","key":"FF3A","mappings":{"default":{"default":"fullwidth latin capital letter z","alternative":"fullwidth latin cap z","short":"cap z"},"mathspeak":{"default":"upper Z"}}}]
,
"en/latin-upper-single-accent.js": 
[{"locale":"en"},{"category":"Lu","key":"00C0","mappings":{"default":{"default":"latin capital letter a with grave","alternative":"latin capital letter a grave","short":"cap a grave"},"mathspeak":{"default":"modifying above upper A with grave","brief":"mod above upper A with grave","sbrief":"mod above upper A with grave"}}},{"category":"Lu","key":"00C1","mappings":{"default":{"default":"latin capital letter a with acute","alternative":"latin capital letter a acute","short":"cap a acute"},"mathspeak":{"default":"modifying above upper A with acute","brief":"mod above upper A with acute","sbrief":"mod above upper A with acute"}}},{"category":"Lu","key":"00C2","mappings":{"default":{"default":"latin capital letter a with circumflex","alternative":"latin capital letter a hat","short":"cap a hat"},"mathspeak":{"default":"modifying above upper A with caret","brief":"mod above upper A with caret","sbrief":"mod above upper A with caret"}}},{"category":"Lu","key":"00C3","mappings":{"default":{"default":"latin capital letter a with tilde","alternative":"latin capital letter a tilde","short":"cap a tilde"},"mathspeak":{"default":"upper A overtilde","brief":"upper A overtilde","sbrief":"upper A overtilde"}}},{"category":"Lu","key":"00C4","mappings":{"default":{"default":"latin capital letter a with diaeresis","alternative":"latin capital letter a double overdot","short":"cap a double overdot"},"mathspeak":{"default":"modifying above upper A with double dot","brief":"mod above upper A with double dot","sbrief":"mod above upper A with double dot"}}},{"category":"Lu","key":"00C5","mappings":{"default":{"default":"latin capital letter a with ring above","alternative":"latin capital letter a ring","short":"cap a ring"},"mathspeak":{"default":"modifying above upper A with ring","brief":"mod above upper A with ring","sbrief":"mod above upper A with ring"}}},{"category":"Lu","key":"00C7","mappings":{"default":{"default":"latin capital letter c cedilla","alternative":"latin capital letter c cedilla","short":"cap c cedilla"},"mathspeak":{"default":"modifying above upper C with cedilla","brief":"mod above upper C with cedilla","sbrief":"mod above upper C with cedilla"}}},{"category":"Lu","key":"00C8","mappings":{"default":{"default":"latin capital letter e with grave","alternative":"latin capital letter e grave","short":"cap e grave"},"mathspeak":{"default":"modifying above upper E with grave","brief":"mod above upper E with grave","sbrief":"mod above upper E with grave"}}},{"category":"Lu","key":"00C9","mappings":{"default":{"default":"latin capital letter e with acute","alternative":"latin capital letter e acute","short":"cap e acute"},"mathspeak":{"default":"modifying above upper E with acute","brief":"mod above upper E with acute","sbrief":"mod above upper E with acute"}}},{"category":"Lu","key":"00CA","mappings":{"default":{"default":"latin capital letter e with circumflex","alternative":"latin capital letter e hat","short":"cap e hat"},"mathspeak":{"default":"modifying above upper E with caret","brief":"mod above upper E with caret","sbrief":"mod above upper E with caret"}}},{"category":"Lu","key":"00CB","mappings":{"default":{"default":"latin capital letter e with diaeresis","alternative":"latin capital letter e double overdot","short":"cap e double overdot"},"mathspeak":{"default":"modifying above upper E with double dot","brief":"mod above upper E with double dot","sbrief":"mod above upper E with double dot"}}},{"category":"Lu","key":"00CC","mappings":{"default":{"default":"latin capital letter i with grave","alternative":"latin capital letter i grave","short":"cap i grave"},"mathspeak":{"default":"modifying above upper I with grave","brief":"mod above upper I with grave","sbrief":"mod above upper I with grave"}}},{"category":"Lu","key":"00CD","mappings":{"default":{"default":"latin capital letter i with acute","alternative":"latin capital letter i acute","short":"cap i acute"},"mathspeak":{"default":"modifying above upper I with acute","brief":"mod above upper I with acute","sbrief":"mod above upper I with acute"}}},{"category":"Lu","key":"00CE","mappings":{"default":{"default":"latin capital letter i with circumflex","alternative":"latin capital letter i hat","short":"cap i hat"},"mathspeak":{"default":"modifying above upper I with caret","brief":"mod above upper I with caret","sbrief":"mod above upper I with caret"}}},{"category":"Lu","key":"00CF","mappings":{"default":{"default":"latin capital letter i with diaeresis","alternative":"latin capital letter i double overdot","short":"cap i double overdot"},"mathspeak":{"default":"modifying above upper I with double dot","brief":"mod above upper I with double dot","sbrief":"mod above upper I with double dot"}}},{"category":"Lu","key":"00D1","mappings":{"default":{"default":"latin capital letter n tilde","alternative":"latin capital letter n tilde","short":"cap n tilde"},"mathspeak":{"default":"upper N overtilde","brief":"upper N overtilde","sbrief":"upper N overtilde"}}},{"category":"Lu","key":"00D2","mappings":{"default":{"default":"latin capital letter o with grave","alternative":"latin capital letter o grave","short":"cap o grave"},"mathspeak":{"default":"modifying above upper O with grave","brief":"mod above upper O with grave","sbrief":"mod above upper O with grave"}}},{"category":"Lu","key":"00D3","mappings":{"default":{"default":"latin capital letter o with acute","alternative":"latin capital letter o acute","short":"cap o acute"},"mathspeak":{"default":"modifying above upper O with acute","brief":"mod above upper O with acute","sbrief":"mod above upper O with acute"}}},{"category":"Lu","key":"00D4","mappings":{"default":{"default":"latin capital letter o with circumflex","alternative":"latin capital letter o hat","short":"cap o hat"},"mathspeak":{"default":"modifying above upper O with caret","brief":"mod above upper O with caret","sbrief":"mod above upper O with caret"}}},{"category":"Lu","key":"00D5","mappings":{"default":{"default":"latin capital letter o with tilde","alternative":"latin capital letter o tilde","short":"cap o tilde"},"mathspeak":{"default":"upper O overtilde","brief":"upper O overtilde","sbrief":"upper O overtilde"}}},{"category":"Lu","key":"00D6","mappings":{"default":{"default":"latin capital letter o with diaeresis","alternative":"latin capital letter o double overdot","short":"cap o double overdot"},"mathspeak":{"default":"modifying above upper O with double dot","brief":"mod above upper O with double dot","sbrief":"mod above upper O with double dot"}}},{"category":"Lu","key":"00D9","mappings":{"default":{"default":"latin capital letter u with grave","alternative":"latin capital letter u grave","short":"cap u grave"},"mathspeak":{"default":"modifying above upper U with grave","brief":"mod above upper U with grave","sbrief":"mod above upper U with grave"}}},{"category":"Lu","key":"00DA","mappings":{"default":{"default":"latin capital letter u with acute","alternative":"latin capital letter u acute","short":"cap u acute"},"mathspeak":{"default":"modifying above upper U with acute","brief":"mod above upper U with acute","sbrief":"mod above upper U with acute"}}},{"category":"Lu","key":"00DB","mappings":{"default":{"default":"latin capital letter u with circumflex","alternative":"latin capital letter u hat","short":"cap u hat"},"mathspeak":{"default":"modifying above upper U with caret","brief":"mod above upper U with caret","sbrief":"mod above upper U with caret"}}},{"category":"Lu","key":"00DC","mappings":{"default":{"default":"latin capital letter u with diaeresis","alternative":"latin capital letter u double overdot","short":"cap u double overdot"},"mathspeak":{"default":"modifying above upper U with double dot","brief":"mod above upper U with double dot","sbrief":"mod above upper U with double dot"}}},{"category":"Lu","key":"00DD","mappings":{"default":{"default":"latin capital letter y with acute","alternative":"latin capital letter y acute","short":"cap y acute"},"mathspeak":{"default":"modifying above upper Y with acute","brief":"mod above upper Y with acute","sbrief":"mod above upper Y with acute"}}},{"category":"Lu","key":"0100","mappings":{"default":{"default":"latin capital letter a macron","alternative":"latin capital letter a overbar","short":"cap a overbar"},"mathspeak":{"default":"upper A overbar","brief":"upper A overbar","sbrief":"upper A overbar"}}},{"category":"Lu","key":"0102","mappings":{"default":{"default":"latin capital letter a with breve","alternative":"latin capital letter a breve","short":"cap a breve"},"mathspeak":{"default":"modifying above upper A with breve","brief":"mod above upper A with breve","sbrief":"mod above upper A with breve"}}},{"category":"Lu","key":"0104","mappings":{"default":{"default":"latin capital letter a with ogonek","alternative":"latin capital letter a ogonek","short":"cap a ogonek"},"mathspeak":{"default":"modifying above upper A with ogonek","brief":"mod above upper A with ogonek","sbrief":"mod above upper A with ogonek"}}},{"category":"Lu","key":"0106","mappings":{"default":{"default":"latin capital letter c with acute","alternative":"latin capital letter c acute","short":"cap c acute"},"mathspeak":{"default":"modifying above upper C with acute","brief":"mod above upper C with acute","sbrief":"mod above upper C with acute"}}},{"category":"Lu","key":"0108","mappings":{"default":{"default":"latin capital letter c with circumflex","alternative":"latin capital letter c hat","short":"cap c hat"},"mathspeak":{"default":"modifying above upper C with caret","brief":"mod above upper C with caret","sbrief":"mod above upper C with caret"}}},{"category":"Lu","key":"010A","mappings":{"default":{"default":"latin capital letter c with dot above","alternative":"latin capital letter c overdot","short":"cap c overdot"},"mathspeak":{"default":"modifying above upper C with dot","brief":"mod above upper C with dot","sbrief":"mod above upper C with dot"}}},{"category":"Lu","key":"010C","mappings":{"default":{"default":"latin capital letter c with caron","alternative":"latin capital letter c hacek","short":"cap c caron"},"mathspeak":{"default":"modifying above upper C with caron","brief":"mod above upper C with caron","sbrief":"mod above upper C with caron"}}},{"category":"Lu","key":"010E","mappings":{"default":{"default":"latin capital letter d with caron","alternative":"latin capital letter d hacek","short":"cap d caron"},"mathspeak":{"default":"modifying above upper D with caron","brief":"mod above upper D with caron","sbrief":"mod above upper D with caron"}}},{"category":"Lu","key":"0112","mappings":{"default":{"default":"latin capital letter e with macron","alternative":"latin capital letter e overbar","short":"cap e overbar"},"mathspeak":{"default":"upper E overbar","brief":"upper E overbar","sbrief":"upper E overbar"}}},{"category":"Lu","key":"0114","mappings":{"default":{"default":"latin capital letter e with breve","alternative":"latin capital letter e breve","short":"cap e breve"},"mathspeak":{"default":"modifying above upper E with breve","brief":"mod above upper E with breve","sbrief":"mod above upper E with breve"}}},{"category":"Lu","key":"0116","mappings":{"default":{"default":"latin capital letter e with dot above","alternative":"latin capital letter e overdot","short":"cap e overdot"},"mathspeak":{"default":"modifying above upper E with dot","brief":"mod above upper E with dot","sbrief":"mod above upper E with dot"}}},{"category":"Lu","key":"0118","mappings":{"default":{"default":"latin capital letter e with ogonek","alternative":"latin capital letter e ogonek","short":"cap e ogonek"},"mathspeak":{"default":"modifying above upper E with ogonek","brief":"mod above upper E with ogonek","sbrief":"mod above upper E with ogonek"}}},{"category":"Lu","key":"011A","mappings":{"default":{"default":"latin capital letter e with caron","alternative":"latin capital letter e hacek","short":"cap e caron"},"mathspeak":{"default":"modifying above upper E with caron","brief":"mod above upper E with caron","sbrief":"mod above upper E with caron"}}},{"category":"Lu","key":"011C","mappings":{"default":{"default":"latin capital letter g with circumflex","alternative":"latin capital letter g hat","short":"cap g hat"},"mathspeak":{"default":"modifying above upper G with caret","brief":"mod above upper G with caret","sbrief":"mod above upper G with caret"}}},{"category":"Lu","key":"011E","mappings":{"default":{"default":"latin capital letter g with breve","alternative":"latin capital letter g breve","short":"cap g breve"},"mathspeak":{"default":"modifying above upper G with breve","brief":"mod above upper G with breve","sbrief":"mod above upper G with breve"}}},{"category":"Lu","key":"0120","mappings":{"default":{"default":"latin capital letter g with dot above","alternative":"latin capital letter g overdot","short":"cap g overdot"},"mathspeak":{"default":"modifying above upper G with dot","brief":"mod above upper G with dot","sbrief":"mod above upper G with dot"}}},{"category":"Lu","key":"0122","mappings":{"default":{"default":"latin capital letter g with cedilla","alternative":"latin capital letter g cedilla","short":"cap g cedilla"},"mathspeak":{"default":"modifying above upper G with cedilla","brief":"mod above upper G with cedilla","sbrief":"mod above upper G with cedilla"}}},{"category":"Lu","key":"0124","mappings":{"default":{"default":"latin capital letter h with circumflex","alternative":"latin capital letter h hat","short":"cap h hat"},"mathspeak":{"default":"modifying above upper H with caret","brief":"mod above upper H with caret","sbrief":"mod above upper H with caret"}}},{"category":"Lu","key":"0128","mappings":{"default":{"default":"latin capital letter i with tilde","alternative":"latin capital letter i tilde","short":"cap i tilde"},"mathspeak":{"default":"upper I overtilde","brief":"upper I overtilde","sbrief":"upper I overtilde"}}},{"category":"Lu","key":"012A","mappings":{"default":{"default":"latin capital letter i with macron","alternative":"latin capital letter i overbar","short":"cap i overbar"},"mathspeak":{"default":"upper I overbar","brief":"upper I overbar","sbrief":"upper I overbar"}}},{"category":"Lu","key":"012C","mappings":{"default":{"default":"latin capital letter i with breve","alternative":"latin capital letter i breve","short":"cap i breve"},"mathspeak":{"default":"modifying above upper I with breve","brief":"mod above upper I with breve","sbrief":"mod above upper I with breve"}}},{"category":"Lu","key":"012E","mappings":{"default":{"default":"latin capital letter i with ogonek","alternative":"latin capital letter i ogonek","short":"cap i ogonek"},"mathspeak":{"default":"modifying above upper I with ogonek","brief":"mod above upper I with ogonek","sbrief":"mod above upper I with ogonek"}}},{"category":"Lu","key":"0130","mappings":{"default":{"default":"latin capital letter i with dot above","alternative":"latin capital letter i overdot","short":"cap i overdot"},"mathspeak":{"default":"modifying above upper I with dot","brief":"mod above upper I with dot","sbrief":"mod above upper I with dot"}}},{"category":"Lu","key":"0134","mappings":{"default":{"default":"latin capital letter j circumflex","alternative":"latin capital letter j hat","short":"cap j hat"},"mathspeak":{"default":"modifying above upper J with caret","brief":"mod above upper J with caret","sbrief":"mod above upper J with caret"}}},{"category":"Lu","key":"0136","mappings":{"default":{"default":"latin capital letter k with cedilla","alternative":"latin capital letter k cedilla","short":"cap k cedilla"},"mathspeak":{"default":"modifying above upper K with cedilla","brief":"mod above upper K with cedilla","sbrief":"mod above upper K with cedilla"}}},{"category":"Lu","key":"0139","mappings":{"default":{"default":"latin capital letter l with acute","alternative":"latin capital letter l acute","short":"cap l acute"},"mathspeak":{"default":"modifying above upper L with acute","brief":"mod above upper L with acute","sbrief":"mod above upper L with acute"}}},{"category":"Lu","key":"013B","mappings":{"default":{"default":"latin capital letter l with cedilla","alternative":"latin capital letter l cedilla","short":"cap l cedilla"},"mathspeak":{"default":"modifying above upper L with cedilla","brief":"mod above upper L with cedilla","sbrief":"mod above upper L with cedilla"}}},{"category":"Lu","key":"013D","mappings":{"default":{"default":"latin capital letter l with caron","alternative":"latin capital letter l hacek","short":"cap l caron"},"mathspeak":{"default":"modifying above upper L with caron","brief":"mod above upper L with caron","sbrief":"mod above upper L with caron"}}},{"category":"Lu","key":"013F","mappings":{"default":{"default":"latin capital letter l with middle dot","alternative":"latin capital letter l middle dot","short":"cap l middle dot"},"mathspeak":{"default":"modifying above upper L with middle dot","brief":"mod above upper L with middle dot","sbrief":"mod above upper L with middle dot"}}},{"category":"Lu","key":"0143","mappings":{"default":{"default":"latin capital letter n with acute","alternative":"latin capital letter n acute","short":"cap n acute"},"mathspeak":{"default":"modifying above upper N with acute","brief":"mod above upper N with acute","sbrief":"mod above upper N with acute"}}},{"category":"Lu","key":"0145","mappings":{"default":{"default":"latin capital letter n with cedilla","alternative":"latin capital letter n cedilla","short":"cap n cedilla"},"mathspeak":{"default":"modifying above upper N with cedilla","brief":"mod above upper N with cedilla","sbrief":"mod above upper N with cedilla"}}},{"category":"Lu","key":"0147","mappings":{"default":{"default":"latin capital letter n with caron","alternative":"latin capital letter n hacek","short":"cap n caron"},"mathspeak":{"default":"modifying above upper N with caron","brief":"mod above upper N with caron","sbrief":"mod above upper N with caron"}}},{"category":"Lu","key":"014C","mappings":{"default":{"default":"latin capital letter o macron","alternative":"latin capital letter o overbar","short":"cap o overbar"},"mathspeak":{"default":"upper O overbar","brief":"upper O overbar","sbrief":"upper O overbar"}}},{"category":"Lu","key":"014E","mappings":{"default":{"default":"latin capital letter o with breve","alternative":"latin capital letter o breve","short":"cap o breve"},"mathspeak":{"default":"modifying above upper O with breve","brief":"mod above upper O with breve","sbrief":"mod above upper O with breve"}}},{"category":"Lu","key":"0150","mappings":{"default":{"default":"latin capital letter o with double acute","alternative":"latin capital letter o double acute","short":"cap o double acute"},"mathspeak":{"default":"modifying above upper O with double acute","brief":"mod above upper O with double acute","sbrief":"mod above upper O with double acute"}}},{"category":"Lu","key":"0154","mappings":{"default":{"default":"latin capital letter r acute","alternative":"latin capital letter r acute","short":"cap r acute"},"mathspeak":{"default":"modifying above upper R with acute","brief":"mod above upper R with acute","sbrief":"mod above upper R with acute"}}},{"category":"Lu","key":"0156","mappings":{"default":{"default":"latin capital letter r with cedilla","alternative":"latin capital letter r cedilla","short":"cap r cedilla"},"mathspeak":{"default":"modifying above upper R with cedilla","brief":"mod above upper R with cedilla","sbrief":"mod above upper R with cedilla"}}},{"category":"Lu","key":"0158","mappings":{"default":{"default":"latin capital letter r with caron","alternative":"latin capital letter r hacek","short":"cap r caron"},"mathspeak":{"default":"modifying above upper R with caron","brief":"mod above upper R with caron","sbrief":"mod above upper R with caron"}}},{"category":"Lu","key":"015A","mappings":{"default":{"default":"latin capital letter s with acute","alternative":"latin capital letter s acute","short":"cap s acute"},"mathspeak":{"default":"modifying above upper S with acute","brief":"mod above upper S with acute","sbrief":"mod above upper S with acute"}}},{"category":"Lu","key":"015C","mappings":{"default":{"default":"latin capital letter s with circumflex","alternative":"latin capital letter s hat","short":"cap s hat"},"mathspeak":{"default":"modifying above upper S with caret","brief":"mod above upper S with caret","sbrief":"mod above upper S with caret"}}},{"category":"Lu","key":"015E","mappings":{"default":{"default":"latin capital letter s with cedilla","alternative":"latin capital letter s cedilla","short":"cap s cedilla"},"mathspeak":{"default":"modifying above upper S with cedilla","brief":"mod above upper S with cedilla","sbrief":"mod above upper S with cedilla"}}},{"category":"Lu","key":"0160","mappings":{"default":{"default":"latin capital letter s with caron","alternative":"latin capital letter s hacek","short":"cap s caron"},"mathspeak":{"default":"modifying above upper S with caron","brief":"mod above upper S with caron","sbrief":"mod above upper S with caron"}}},{"category":"Lu","key":"0162","mappings":{"default":{"default":"latin capital letter t with cedilla","alternative":"latin capital letter t cedilla","short":"cap t cedilla"},"mathspeak":{"default":"modifying above upper T with cedilla","brief":"mod above upper T with cedilla","sbrief":"mod above upper T with cedilla"}}},{"category":"Lu","key":"0164","mappings":{"default":{"default":"latin capital letter t with caron","alternative":"latin capital letter t hacek","short":"cap t caron"},"mathspeak":{"default":"modifying above upper T with caron","brief":"mod above upper T with caron","sbrief":"mod above upper T with caron"}}},{"category":"Lu","key":"0168","mappings":{"default":{"default":"latin capital letter u with tilde","alternative":"latin capital letter u tilde","short":"cap u tilde"},"mathspeak":{"default":"upper U overtilde","brief":"upper U overtilde","sbrief":"upper U overtilde"}}},{"category":"Lu","key":"016A","mappings":{"default":{"default":"latin capital letter u with macron","alternative":"latin capital letter u overbar","short":"cap u overbar"},"mathspeak":{"default":"upper U overbar","brief":"upper U overbar","sbrief":"upper U overbar"}}},{"category":"Lu","key":"016C","mappings":{"default":{"default":"latin capital letter u with breve","alternative":"latin capital letter u breve","short":"cap u breve"},"mathspeak":{"default":"modifying above upper U with breve","brief":"mod above upper U with breve","sbrief":"mod above upper U with breve"}}},{"category":"Lu","key":"016E","mappings":{"default":{"default":"latin capital letter u with ring above","alternative":"latin capital letter u ring","short":"cap u ring"},"mathspeak":{"default":"modifying above upper U with ring","brief":"mod above upper U with ring","sbrief":"mod above upper U with ring"}}},{"category":"Lu","key":"0170","mappings":{"default":{"default":"latin capital letter u with double acute","alternative":"latin capital letter u double acute","short":"cap u double acute"},"mathspeak":{"default":"modifying above upper U with double acute","brief":"mod above upper U with double acute","sbrief":"mod above upper U with double acute"}}},{"category":"Lu","key":"0172","mappings":{"default":{"default":"latin capital letter u with ogonek","alternative":"latin capital letter u ogonek","short":"cap u ogonek"},"mathspeak":{"default":"modifying above upper U with ogonek","brief":"mod above upper U with ogonek","sbrief":"mod above upper U with ogonek"}}},{"category":"Lu","key":"0174","mappings":{"default":{"default":"latin capital letter w with circumflex","alternative":"latin capital letter w hat","short":"cap w hat"},"mathspeak":{"default":"modifying above upper W with caret","brief":"mod above upper W with caret","sbrief":"mod above upper W with caret"}}},{"category":"Lu","key":"0176","mappings":{"default":{"default":"latin capital letter y with circumflex","alternative":"latin capital letter y hat","short":"cap y hat"},"mathspeak":{"default":"modifying above upper Y with caret","brief":"mod above upper Y with caret","sbrief":"mod above upper Y with caret"}}},{"category":"Lu","key":"0178","mappings":{"default":{"default":"latin capital letter y with diaeresis","alternative":"latin capital letter y double overdot","short":"cap y double overdot"},"mathspeak":{"default":"modifying above upper Y with double dot","brief":"mod above upper Y with double dot","sbrief":"mod above upper Y with double dot"}}},{"category":"Lu","key":"0179","mappings":{"default":{"default":"latin capital letter z with acute","alternative":"latin capital letter z acute","short":"cap z acute"},"mathspeak":{"default":"modifying above upper Z with acute","brief":"mod above upper Z with acute","sbrief":"mod above upper Z with acute"}}},{"category":"Lu","key":"017B","mappings":{"default":{"default":"latin capital letter z with dot above","alternative":"latin capital letter z overdot","short":"cap z overdot"},"mathspeak":{"default":"modifying above upper Z with dot","brief":"mod above upper Z with dot","sbrief":"mod above upper Z with dot"}}},{"category":"Lu","key":"017D","mappings":{"default":{"default":"latin capital letter z with caron","alternative":"latin capital letter z hacek","short":"cap z caron"},"mathspeak":{"default":"modifying above upper Z with caron","brief":"mod above upper Z with caron","sbrief":"mod above upper Z with caron"}}},{"category":"Lu","key":"01CD","mappings":{"default":{"default":"latin capital letter a with caron","alternative":"latin capital letter a hacek","short":"cap a caron"},"mathspeak":{"default":"modifying above upper A with caron","brief":"mod above upper A with caron","sbrief":"mod above upper A with caron"}}},{"category":"Lu","key":"01CF","mappings":{"default":{"default":"latin capital letter i with caron","alternative":"latin capital letter i hacek","short":"cap i caron"},"mathspeak":{"default":"modifying above upper I with caron","brief":"mod above upper I with caron","sbrief":"mod above upper I with caron"}}},{"category":"Lu","key":"01D1","mappings":{"default":{"default":"latin capital letter o with caron","alternative":"latin capital letter o hacek","short":"cap o caron"},"mathspeak":{"default":"modifying above upper O with caron","brief":"mod above upper O with caron","sbrief":"mod above upper O with caron"}}},{"category":"Lu","key":"01D3","mappings":{"default":{"default":"latin capital letter u with caron","alternative":"latin capital letter u hacek","short":"cap u caron"},"mathspeak":{"default":"modifying above upper U with caron","brief":"mod above upper U with caron","sbrief":"mod above upper U with caron"}}},{"category":"Lu","key":"01E6","mappings":{"default":{"default":"latin capital letter g with caron","alternative":"latin capital letter g hacek","short":"cap g caron"},"mathspeak":{"default":"modifying above upper G with caron","brief":"mod above upper G with caron","sbrief":"mod above upper G with caron"}}},{"category":"Lu","key":"01E8","mappings":{"default":{"default":"latin capital letter k with caron","alternative":"latin capital letter k hacek","short":"cap k caron"},"mathspeak":{"default":"modifying above upper K with caron","brief":"mod above upper K with caron","sbrief":"mod above upper K with caron"}}},{"category":"Lu","key":"01EA","mappings":{"default":{"default":"latin capital letter o with ogonek","alternative":"latin capital letter o ogonek","short":"cap o ogonek"},"mathspeak":{"default":"modifying above upper O with ogonek","brief":"mod above upper O with ogonek","sbrief":"mod above upper O with ogonek"}}},{"category":"Lu","key":"01F4","mappings":{"default":{"default":"latin capital letter g with acute","alternative":"latin capital letter g acute","short":"cap g acute"},"mathspeak":{"default":"modifying above upper G with acute","brief":"mod above upper G with acute","sbrief":"mod above upper G with acute"}}},{"category":"Lu","key":"01F8","mappings":{"default":{"default":"latin capital letter n with grave","alternative":"latin capital letter n grave","short":"cap n grave"},"mathspeak":{"default":"modifying above upper N with grave","brief":"mod above upper N with grave","sbrief":"mod above upper N with grave"}}},{"category":"Lu","key":"0200","mappings":{"default":{"default":"latin capital letter a with double grave","alternative":"latin capital letter a double grave","short":"cap a double grave"},"mathspeak":{"default":"modifying above upper A with double grave","brief":"mod above upper A with double grave","sbrief":"mod above upper A with double grave"}}},{"category":"Lu","key":"0202","mappings":{"default":{"default":"latin capital letter a with inverted breve","alternative":"latin capital letter a inverted breve","short":"cap a inverted breve"},"mathspeak":{"default":"modifying above upper A with inverted breve","brief":"mod above upper A with inverted breve","sbrief":"mod above upper A with inverted breve"}}},{"category":"Lu","key":"0204","mappings":{"default":{"default":"latin capital letter e with double grave","alternative":"latin capital letter e double grave","short":"cap e double grave"},"mathspeak":{"default":"modifying above upper E with double grave","brief":"mod above upper E with double grave","sbrief":"mod above upper E with double grave"}}},{"category":"Lu","key":"0206","mappings":{"default":{"default":"latin capital letter e with inverted breve","alternative":"latin capital letter e inverted breve","short":"cap e inverted breve"},"mathspeak":{"default":"modifying above upper E with inverted breve","brief":"mod above upper E with inverted breve","sbrief":"mod above upper E with inverted breve"}}},{"category":"Lu","key":"0208","mappings":{"default":{"default":"latin capital letter i with double grave","alternative":"latin capital letter i double grave","short":"cap i double grave"},"mathspeak":{"default":"modifying above upper I with double grave","brief":"mod above upper I with double grave","sbrief":"mod above upper I with double grave"}}},{"category":"Lu","key":"020A","mappings":{"default":{"default":"latin capital letter i with inverted breve","alternative":"latin capital letter i inverted breve","short":"cap i inverted breve"},"mathspeak":{"default":"modifying above upper I with inverted breve","brief":"mod above upper I with inverted breve","sbrief":"mod above upper I with inverted breve"}}},{"category":"Lu","key":"020C","mappings":{"default":{"default":"latin capital letter o with double grave","alternative":"latin capital letter o double grave","short":"cap o double grave"},"mathspeak":{"default":"modifying above upper O with double grave","brief":"mod above upper O with double grave","sbrief":"mod above upper O with double grave"}}},{"category":"Lu","key":"020E","mappings":{"default":{"default":"latin capital letter o with inverted breve","alternative":"latin capital letter o inverted breve","short":"cap o inverted breve"},"mathspeak":{"default":"modifying above upper O with inverted breve","brief":"mod above upper O with inverted breve","sbrief":"mod above upper O with inverted breve"}}},{"category":"Lu","key":"0210","mappings":{"default":{"default":"latin capital letter r with double grave","alternative":"latin capital letter r double grave","short":"cap r double grave"},"mathspeak":{"default":"modifying above upper R with double grave","brief":"mod above upper R with double grave","sbrief":"mod above upper R with double grave"}}},{"category":"Lu","key":"0212","mappings":{"default":{"default":"latin capital letter r with inverted breve","alternative":"latin capital letter r inverted breve","short":"cap r inverted breve"},"mathspeak":{"default":"modifying above upper R with inverted breve","brief":"mod above upper R with inverted breve","sbrief":"mod above upper R with inverted breve"}}},{"category":"Lu","key":"0214","mappings":{"default":{"default":"latin capital letter u with double grave","alternative":"latin capital letter u double grave","short":"cap u double grave"},"mathspeak":{"default":"modifying above upper U with double grave","brief":"mod above upper U with double grave","sbrief":"mod above upper U with double grave"}}},{"category":"Lu","key":"0216","mappings":{"default":{"default":"latin capital letter u with inverted breve","alternative":"latin capital letter u inverted breve","short":"cap u inverted breve"},"mathspeak":{"default":"modifying above upper U with inverted breve","brief":"mod above upper U with inverted breve","sbrief":"mod above upper U with inverted breve"}}},{"category":"Lu","key":"0218","mappings":{"default":{"default":"latin capital letter s with comma below","alternative":"latin capital letter s comma below","short":"cap s comma below"},"mathspeak":{"default":"modifying below upper S with comma below","brief":"mod below upper S with comma below","sbrief":"mod below upper S with comma below"}}},{"category":"Lu","key":"021A","mappings":{"default":{"default":"latin capital letter t with comma below","alternative":"latin capital letter t comma below","short":"cap t comma below"},"mathspeak":{"default":"modifying below upper T with comma below","brief":"mod below upper T with comma below","sbrief":"mod below upper T with comma below"}}},{"category":"Lu","key":"021E","mappings":{"default":{"default":"latin capital letter h caron","short":"cap h caron"},"mathspeak":{"default":"modifying above upper H with caron","brief":"mod above upper H with caron","sbrief":"mod above upper H with caron"}}},{"category":"Lu","key":"0226","mappings":{"default":{"default":"latin capital letter a with dot above","alternative":"latin capital letter a overdot","short":"cap a overdot"},"mathspeak":{"default":"modifying above upper A with dot","brief":"mod above upper A with dot","sbrief":"mod above upper A with dot"}}},{"category":"Lu","key":"0228","mappings":{"default":{"default":"latin capital letter e with cedilla","alternative":"latin capital letter e cedilla","short":"cap e cedilla"},"mathspeak":{"default":"modifying above upper E with cedilla","brief":"mod above upper E with cedilla","sbrief":"mod above upper E with cedilla"}}},{"category":"Lu","key":"022E","mappings":{"default":{"default":"latin capital letter o with dot above","alternative":"latin capital letter o overdot","short":"cap o overdot"},"mathspeak":{"default":"modifying above upper O with dot","brief":"mod above upper O with dot","sbrief":"mod above upper O with dot"}}},{"category":"Lu","key":"0232","mappings":{"default":{"default":"latin capital letter y with macron","alternative":"latin capital letter y overbar","short":"cap y overbar"},"mathspeak":{"default":"upper Y overbar","brief":"upper Y overbar","sbrief":"upper Y overbar"}}},{"category":"Lu","key":"1E00","mappings":{"default":{"default":"latin capital letter a with ring below","alternative":"latin capital letter a ring below","short":"cap a ring below"},"mathspeak":{"default":"modifying below upper A with ring below","brief":"mod below upper A with ring below","sbrief":"mod below upper A with ring below"}}},{"category":"Lu","key":"1E02","mappings":{"default":{"default":"latin capital letter b with dot above","alternative":"latin capital letter b overdot","short":"cap b overdot"},"mathspeak":{"default":"modifying above upper B with dot","brief":"mod above upper B with dot","sbrief":"mod above upper B with dot"}}},{"category":"Lu","key":"1E04","mappings":{"default":{"default":"latin capital letter b with dot below","alternative":"latin capital letter b underdot","short":"cap b underdot"},"mathspeak":{"default":"modifying below upper B with dot","brief":"mod below upper B with dot","sbrief":"mod below upper B with dot"}}},{"category":"Lu","key":"1E06","mappings":{"default":{"default":"latin capital letter b with line below","alternative":"latin capital letter b underbar","short":"cap b underbar"},"mathspeak":{"default":"upper B underbar","brief":"upper B underbar","sbrief":"upper B underbar"}}},{"category":"Lu","key":"1E0A","mappings":{"default":{"default":"latin capital letter d with dot above","alternative":"latin capital letter d overdot","short":"cap d overdot"},"mathspeak":{"default":"modifying above upper D with dot","brief":"mod above upper D with dot","sbrief":"mod above upper D with dot"}}},{"category":"Lu","key":"1E0C","mappings":{"default":{"default":"latin capital letter d with dot below","alternative":"latin capital letter d underdot","short":"cap d underdot"},"mathspeak":{"default":"modifying below upper D with dot","brief":"mod below upper D with dot","sbrief":"mod below upper D with dot"}}},{"category":"Lu","key":"1E0E","mappings":{"default":{"default":"latin capital letter d with line below","alternative":"latin capital letter d underbar","short":"cap d underbar"},"mathspeak":{"default":"upper D underbar","brief":"upper D underbar","sbrief":"upper D underbar"}}},{"category":"Lu","key":"1E10","mappings":{"default":{"default":"latin capital letter d with cedilla","alternative":"latin capital letter d cedilla","short":"cap d cedilla"},"mathspeak":{"default":"modifying above upper D with cedilla","brief":"mod above upper D with cedilla","sbrief":"mod above upper D with cedilla"}}},{"category":"Lu","key":"1E12","mappings":{"default":{"default":"latin capital letter d with circumflex below","alternative":"latin capital letter d underhat","short":"cap d underhat"},"mathspeak":{"default":"modifying below upper D with caret","brief":"mod below upper D with caret","sbrief":"mod below upper D with caret"}}},{"category":"Lu","key":"1E18","mappings":{"default":{"default":"latin capital letter e with circumflex below","alternative":"latin capital letter e underhat","short":"cap e underhat"},"mathspeak":{"default":"modifying below upper E with caret","brief":"mod below upper E with caret","sbrief":"mod below upper E with caret"}}},{"category":"Lu","key":"1E1A","mappings":{"default":{"default":"latin capital letter e with tilde below","alternative":"latin capital letter e tilde below","short":"cap e tilde below"},"mathspeak":{"default":"upper E undertilde","brief":"upper E undertilde","sbrief":"upper E undertilde"}}},{"category":"Lu","key":"1E1E","mappings":{"default":{"default":"latin capital letter f with dot above","alternative":"latin capital letter f overdot","short":"cap f overdot"},"mathspeak":{"default":"modifying above upper F with dot","brief":"mod above upper F with dot","sbrief":"mod above upper F with dot"}}},{"category":"Lu","key":"1E20","mappings":{"default":{"default":"latin capital letter g with macron","alternative":"latin capital letter g overbar","short":"cap g overbar"},"mathspeak":{"default":"upper G overbar","brief":"upper G overbar","sbrief":"upper G overbar"}}},{"category":"Lu","key":"1E22","mappings":{"default":{"default":"latin capital letter h with dot above","alternative":"latin capital letter h overdot","short":"cap h overdot"},"mathspeak":{"default":"modifying above upper H with dot","brief":"mod above upper H with dot","sbrief":"mod above upper H with dot"}}},{"category":"Lu","key":"1E24","mappings":{"default":{"default":"latin capital letter h with dot below","alternative":"latin capital letter h underdot","short":"cap h underdot"},"mathspeak":{"default":"modifying below upper H with dot","brief":"mod below upper H with dot","sbrief":"mod below upper H with dot"}}},{"category":"Lu","key":"1E26","mappings":{"default":{"default":"latin capital letter h with diaeresis","alternative":"latin capital letter h double overdot","short":"cap h double overdot"},"mathspeak":{"default":"modifying above upper H with double dot","brief":"mod above upper H with double dot","sbrief":"mod above upper H with double dot"}}},{"category":"Lu","key":"1E28","mappings":{"default":{"default":"latin capital letter h with cedilla","alternative":"latin capital letter h cedilla","short":"cap h cedilla"},"mathspeak":{"default":"modifying above upper H with cedilla","brief":"mod above upper H with cedilla","sbrief":"mod above upper H with cedilla"}}},{"category":"Lu","key":"1E2A","mappings":{"default":{"default":"latin capital letter h with breve below","alternative":"latin capital letter h breve below","short":"cap h breve below"},"mathspeak":{"default":"modifying below upper H with breve below","brief":"mod below upper H with breve below","sbrief":"mod below upper H with breve below"}}},{"category":"Lu","key":"1E2C","mappings":{"default":{"default":"latin capital letter i with tilde below","alternative":"latin capital letter i tilde below","short":"cap i tilde below"},"mathspeak":{"default":"upper I undertilde","brief":"upper I undertilde","sbrief":"upper I undertilde"}}},{"category":"Lu","key":"1E30","mappings":{"default":{"default":"latin capital letter k with acute","alternative":"latin capital letter k acute","short":"cap k acute"},"mathspeak":{"default":"modifying above upper K with acute","brief":"mod above upper K with acute","sbrief":"mod above upper K with acute"}}},{"category":"Lu","key":"1E32","mappings":{"default":{"default":"latin capital letter k with dot below","alternative":"latin capital letter k underdot","short":"cap k underdot"},"mathspeak":{"default":"modifying below upper K with dot","brief":"mod below upper K with dot","sbrief":"mod below upper K with dot"}}},{"category":"Lu","key":"1E34","mappings":{"default":{"default":"latin capital letter k with line below","alternative":"latin capital letter k underbar","short":"cap k underbar"},"mathspeak":{"default":"upper K underbar","brief":"upper K underbar","sbrief":"upper K underbar"}}},{"category":"Lu","key":"1E36","mappings":{"default":{"default":"latin capital letter l with dot below","alternative":"latin capital letter l underdot","short":"cap l underdot"},"mathspeak":{"default":"modifying below upper L with dot","brief":"mod below upper L with dot","sbrief":"mod below upper L with dot"}}},{"category":"Lu","key":"1E3A","mappings":{"default":{"default":"latin capital letter l with line below","alternative":"latin capital letter l underbar","short":"cap l underbar"},"mathspeak":{"default":"upper L underbar","brief":"upper L underbar","sbrief":"upper L underbar"}}},{"category":"Lu","key":"1E3C","mappings":{"default":{"default":"latin capital letter l with circumflex below","alternative":"latin capital letter l underhat","short":"cap l underhat"},"mathspeak":{"default":"modifying below upper L with caret","brief":"mod below upper L with caret","sbrief":"mod below upper L with caret"}}},{"category":"Lu","key":"1E3E","mappings":{"default":{"default":"latin capital letter m with acute","alternative":"latin capital letter m acute","short":"cap m acute"},"mathspeak":{"default":"modifying above upper M with acute","brief":"mod above upper M with acute","sbrief":"mod above upper M with acute"}}},{"category":"Lu","key":"1E40","mappings":{"default":{"default":"latin capital letter m with dot above","alternative":"latin capital letter m overdot","short":"cap m overdot"},"mathspeak":{"default":"modifying above upper M with dot","brief":"mod above upper M with dot","sbrief":"mod above upper M with dot"}}},{"category":"Lu","key":"1E42","mappings":{"default":{"default":"latin capital letter m with dot below","alternative":"latin capital letter m underdot","short":"cap m underdot"},"mathspeak":{"default":"modifying below upper M with dot","brief":"mod below upper M with dot","sbrief":"mod below upper M with dot"}}},{"category":"Lu","key":"1E44","mappings":{"default":{"default":"latin capital letter n with dot above","alternative":"latin capital letter n overdot","short":"cap n overdot"},"mathspeak":{"default":"modifying above upper N with dot","brief":"mod above upper N with dot","sbrief":"mod above upper N with dot"}}},{"category":"Lu","key":"1E46","mappings":{"default":{"default":"latin capital letter n with dot below","alternative":"latin capital letter n underdot","short":"cap n underdot"},"mathspeak":{"default":"modifying below upper N with dot","brief":"mod below upper N with dot","sbrief":"mod below upper N with dot"}}},{"category":"Lu","key":"1E48","mappings":{"default":{"default":"latin capital letter n with line below","alternative":"latin capital letter n underbar","short":"cap n underbar"},"mathspeak":{"default":"upper N underbar","brief":"upper N underbar","sbrief":"upper N underbar"}}},{"category":"Lu","key":"1E4A","mappings":{"default":{"default":"latin capital letter n with circumflex below","alternative":"latin capital letter n underhat","short":"cap n underhat"},"mathspeak":{"default":"modifying below upper N with caret","brief":"mod below upper N with caret","sbrief":"mod below upper N with caret"}}},{"category":"Lu","key":"1E54","mappings":{"default":{"default":"latin capital letter p with acute","alternative":"latin capital letter p acute","short":"cap p acute"},"mathspeak":{"default":"modifying above upper P with acute","brief":"mod above upper P with acute","sbrief":"mod above upper P with acute"}}},{"category":"Lu","key":"1E56","mappings":{"default":{"default":"latin capital letter p with dot above","alternative":"latin capital letter p overdot","short":"cap p overdot"},"mathspeak":{"default":"modifying above upper P with dot","brief":"mod above upper P with dot","sbrief":"mod above upper P with dot"}}},{"category":"Lu","key":"1E58","mappings":{"default":{"default":"latin capital letter r with dot above","alternative":"latin capital letter r overdot","short":"cap r overdot"},"mathspeak":{"default":"modifying above upper R with dot","brief":"mod above upper R with dot","sbrief":"mod above upper R with dot"}}},{"category":"Lu","key":"1E5A","mappings":{"default":{"default":"latin capital letter r with dot below","alternative":"latin capital letter r underdot","short":"cap r underdot"},"mathspeak":{"default":"modifying below upper R with dot","brief":"mod below upper R with dot","sbrief":"mod below upper R with dot"}}},{"category":"Lu","key":"1E5E","mappings":{"default":{"default":"latin capital letter r with line below","alternative":"latin capital letter r underbar","short":"cap r underbar"},"mathspeak":{"default":"upper R underbar","brief":"upper R underbar","sbrief":"upper R underbar"}}},{"category":"Lu","key":"1E60","mappings":{"default":{"default":"latin capital letter s with dot above","alternative":"latin capital letter s overdot","short":"cap s overdot"},"mathspeak":{"default":"modifying above upper S with dot","brief":"mod above upper S with dot","sbrief":"mod above upper S with dot"}}},{"category":"Lu","key":"1E62","mappings":{"default":{"default":"latin capital letter s with dot below","alternative":"latin capital letter s underdot","short":"cap s underdot"},"mathspeak":{"default":"modifying below upper S with dot","brief":"mod below upper S with dot","sbrief":"mod below upper S with dot"}}},{"category":"Lu","key":"1E6A","mappings":{"default":{"default":"latin capital letter t with dot above","alternative":"latin capital letter t overdot","short":"cap t overdot"},"mathspeak":{"default":"modifying above upper T with dot","brief":"mod above upper T with dot","sbrief":"mod above upper T with dot"}}},{"category":"Lu","key":"1E6C","mappings":{"default":{"default":"latin capital letter t with dot below","alternative":"latin capital letter t underdot","short":"cap t underdot"},"mathspeak":{"default":"modifying below upper T with dot","brief":"mod below upper T with dot","sbrief":"mod below upper T with dot"}}},{"category":"Lu","key":"1E6E","mappings":{"default":{"default":"latin capital letter t with line below","alternative":"latin capital letter t underbar","short":"cap t underbar"},"mathspeak":{"default":"upper T underbar","brief":"upper T underbar","sbrief":"upper T underbar"}}},{"category":"Lu","key":"1E70","mappings":{"default":{"default":"latin capital letter t with circumflex below","alternative":"latin capital letter t underhat","short":"cap t underhat"},"mathspeak":{"default":"modifying below upper T with caret","brief":"mod below upper T with caret","sbrief":"mod below upper T with caret"}}},{"category":"Lu","key":"1E72","mappings":{"default":{"default":"latin capital letter u with diaeresis below","alternative":"latin capital letter u double underdot","short":"cap u double underdot"},"mathspeak":{"default":"modifying below upper U with double dot","brief":"mod below upper U with double dot","sbrief":"mod below upper U with double dot"}}},{"category":"Lu","key":"1E74","mappings":{"default":{"default":"latin capital letter u with tilde below","alternative":"latin capital letter u tilde below","short":"cap u tilde below"},"mathspeak":{"default":"upper U undertilde","brief":"upper U undertilde","sbrief":"upper U undertilde"}}},{"category":"Lu","key":"1E76","mappings":{"default":{"default":"latin capital letter u with circumflex below","alternative":"latin capital letter u underhat","short":"cap u underhat"},"mathspeak":{"default":"modifying below upper U with caret","brief":"mod below upper U with caret","sbrief":"mod below upper U with caret"}}},{"category":"Lu","key":"1E7C","mappings":{"default":{"default":"latin capital letter v with tilde","alternative":"latin capital letter v tilde","short":"cap v tilde"},"mathspeak":{"default":"upper V overtilde","brief":"upper V overtilde","sbrief":"upper V overtilde"}}},{"category":"Lu","key":"1E7E","mappings":{"default":{"default":"latin capital letter v with dot below","alternative":"latin capital letter v underdot","short":"cap v underdot"},"mathspeak":{"default":"modifying below upper V with dot","brief":"mod below upper V with dot","sbrief":"mod below upper V with dot"}}},{"category":"Lu","key":"1E80","mappings":{"default":{"default":"latin capital letter w with grave","alternative":"latin capital letter w grave","short":"cap w grave"},"mathspeak":{"default":"modifying above upper W with grave","brief":"mod above upper W with grave","sbrief":"mod above upper W with grave"}}},{"category":"Lu","key":"1E82","mappings":{"default":{"default":"latin capital letter w with acute","alternative":"latin capital letter w acute","short":"cap w acute"},"mathspeak":{"default":"modifying above upper W with acute","brief":"mod above upper W with acute","sbrief":"mod above upper W with acute"}}},{"category":"Lu","key":"1E84","mappings":{"default":{"default":"latin capital letter w with diaeresis","alternative":"latin capital letter w double overdot","short":"cap w double overdot"},"mathspeak":{"default":"modifying above upper W with double dot","brief":"mod above upper W with double dot","sbrief":"mod above upper W with double dot"}}},{"category":"Lu","key":"1E86","mappings":{"default":{"default":"latin capital letter w with dot above","alternative":"latin capital letter w overdot","short":"cap w overdot"},"mathspeak":{"default":"modifying above upper W with dot","brief":"mod above upper W with dot","sbrief":"mod above upper W with dot"}}},{"category":"Lu","key":"1E88","mappings":{"default":{"default":"latin capital letter w with dot below","alternative":"latin capital letter w underdot","short":"cap w underdot"},"mathspeak":{"default":"modifying below upper W with dot","brief":"mod below upper W with dot","sbrief":"mod below upper W with dot"}}},{"category":"Lu","key":"1E8A","mappings":{"default":{"default":"latin capital letter x with dot above","alternative":"latin capital letter x overdot","short":"cap x overdot"},"mathspeak":{"default":"modifying above upper X with dot","brief":"mod above upper X with dot","sbrief":"mod above upper X with dot"}}},{"category":"Lu","key":"1E8C","mappings":{"default":{"default":"latin capital letter x with diaeresis","alternative":"latin capital letter x double overdot","short":"cap x double overdot"},"mathspeak":{"default":"modifying above upper X with double dot","brief":"mod above upper X with double dot","sbrief":"mod above upper X with double dot"}}},{"category":"Lu","key":"1E8E","mappings":{"default":{"default":"latin capital letter y with dot above","alternative":"latin capital letter y overdot","short":"cap y overdot"},"mathspeak":{"default":"modifying above upper Y with dot","brief":"mod above upper Y with dot","sbrief":"mod above upper Y with dot"}}},{"category":"Lu","key":"1E90","mappings":{"default":{"default":"latin capital letter z with circumflex","alternative":"latin capital letter z circumflex","short":"cap z circumflex"},"mathspeak":{"default":"modifying above upper Z with circumflex","brief":"mod above upper Z with circumflex","sbrief":"mod above upper Z with circumflex"}}},{"category":"Lu","key":"1E92","mappings":{"default":{"default":"latin capital letter z with dot below","alternative":"latin capital letter z underdot","short":"cap z underdot"},"mathspeak":{"default":"modifying below upper Z with dot","brief":"mod below upper Z with dot","sbrief":"mod below upper Z with dot"}}},{"category":"Lu","key":"1E94","mappings":{"default":{"default":"latin capital letter z with line below","alternative":"latin capital letter z underbar","short":"cap z underbar"},"mathspeak":{"default":"upper Z underbar","brief":"upper Z underbar","sbrief":"upper Z underbar"}}},{"category":"Lu","key":"1EA0","mappings":{"default":{"default":"latin capital letter with a dot below","alternative":"latin capital letter with a underdot","short":"cap a underdot"},"mathspeak":{"default":"modifying below upper A with dot","brief":"mod below upper A with dot","sbrief":"mod below upper A with dot"}}},{"category":"Lu","key":"1EA2","mappings":{"default":{"default":"latin capital letter a with hook above","alternative":"latin capital letter a hook","short":"cap a hook"},"mathspeak":{"default":"modifying above upper A with hook","brief":"mod above upper A with hook","sbrief":"mod above upper A with hook"}}},{"category":"Lu","key":"1EB8","mappings":{"default":{"default":"latin capital letter e with dot below","alternative":"latin capital letter e underdot","short":"cap e underdot"},"mathspeak":{"default":"modifying below upper E with dot","brief":"mod below upper E with dot","sbrief":"mod below upper E with dot"}}},{"category":"Lu","key":"1EBA","mappings":{"default":{"default":"latin capital letter e with hook above","alternative":"latin capital letter e hook","short":"cap e hook"},"mathspeak":{"default":"modifying above upper E with hook","brief":"mod above upper E with hook","sbrief":"mod above upper E with hook"}}},{"category":"Lu","key":"1EBC","mappings":{"default":{"default":"latin capital letter e with tilde","alternative":"latin capital letter e tilde","short":"cap e tilde"},"mathspeak":{"default":"upper E overtilde","brief":"upper E overtilde","sbrief":"upper E overtilde"}}},{"category":"Lu","key":"1EC8","mappings":{"default":{"default":"latin capital letter i with hook above","alternative":"latin capital letter i hook","short":"cap i hook"},"mathspeak":{"default":"modifying above upper I with hook","brief":"mod above upper I with hook","sbrief":"mod above upper I with hook"}}},{"category":"Lu","key":"1ECA","mappings":{"default":{"default":"latin capital letter i with dot below","alternative":"latin capital letter i underdot","short":"cap i underdot"},"mathspeak":{"default":"modifying below upper I with dot","brief":"mod below upper I with dot","sbrief":"mod below upper I with dot"}}},{"category":"Lu","key":"1ECC","mappings":{"default":{"default":"latin capital letter o with dot below","alternative":"latin capital letter o underdot","short":"cap o underdot"},"mathspeak":{"default":"modifying below upper O with dot","brief":"mod below upper O with dot","sbrief":"mod below upper O with dot"}}},{"category":"Lu","key":"1ECE","mappings":{"default":{"default":"latin capital letter o with hook above","alternative":"latin capital letter o hook","short":"cap o hook"},"mathspeak":{"default":"modifying above upper O with hook","brief":"mod above upper O with hook","sbrief":"mod above upper O with hook"}}},{"category":"Lu","key":"1EE4","mappings":{"default":{"default":"latin capital letter u with dot below","alternative":"latin capital letter u underdot","short":"cap u underdot"},"mathspeak":{"default":"modifying below upper U with dot","brief":"mod below upper U with dot","sbrief":"mod below upper U with dot"}}},{"category":"Lu","key":"1EE6","mappings":{"default":{"default":"latin capital letter u with hook above","alternative":"latin capital letter u hook","short":"cap u hook"},"mathspeak":{"default":"modifying above upper U with hook","brief":"mod above upper U with hook","sbrief":"mod above upper U with hook"}}},{"category":"Lu","key":"1EF2","mappings":{"default":{"default":"latin capital letter y with grave","alternative":"latin capital letter y grave","short":"cap y grave"},"mathspeak":{"default":"modifying above upper Y with grave","brief":"mod above upper Y with grave","sbrief":"mod above upper Y with grave"}}},{"category":"Lu","key":"1EF4","mappings":{"default":{"default":"latin capital letter y with dot below","alternative":"latin capital letter y underdot","short":"cap y underdot"},"mathspeak":{"default":"modifying below upper Y with dot","brief":"mod below upper Y with dot","sbrief":"mod below upper Y with dot"}}},{"category":"Lu","key":"1EF6","mappings":{"default":{"default":"latin capital letter y with hook above","alternative":"latin capital letter y hook","short":"cap y hook"},"mathspeak":{"default":"modifying above upper Y with hook","brief":"mod above upper Y with hook","sbrief":"mod above upper Y with hook"}}},{"category":"Lu","key":"1EF8","mappings":{"default":{"default":"latin capital letter y with tilde","alternative":"latin capital letter y tilde","short":"cap y tilde"},"mathspeak":{"default":"upper Y overtilde","brief":"upper Y overtilde","sbrief":"upper Y overtilde"}}}]
,
"en/math_angles.js": 
[{"locale":"en"},{"category":"Sm","mappings":{"default":{"default":"right angle with arc"}},"key":"22BE"},{"category":"Sm","mappings":{"default":{"default":"right angle with downwards zigzag arrow"}},"key":"237C"},{"category":"Sm","mappings":{"default":{"default":"three dimensional angle"}},"key":"27C0"},{"category":"Sm","mappings":{"default":{"default":"measured angle opening left"}},"key":"299B"},{"category":"Sm","mappings":{"default":{"default":"right angle variant with square"}},"key":"299C"},{"category":"Sm","mappings":{"default":{"default":"measured right angle with dot"}},"key":"299D"},{"category":"Sm","mappings":{"default":{"default":"angle with s inside"}},"key":"299E"},{"category":"Sm","mappings":{"default":{"default":"acute angle"}},"key":"299F"},{"category":"Sm","mappings":{"default":{"default":"spherical angle opening left"}},"key":"29A0"},{"category":"Sm","mappings":{"default":{"default":"spherical angle opening up"}},"key":"29A1"},{"category":"Sm","mappings":{"default":{"default":"turned angle"}},"key":"29A2"},{"category":"Sm","mappings":{"default":{"default":"reversed angle"}},"key":"29A3"},{"category":"Sm","mappings":{"default":{"default":"angle with underbar"}},"key":"29A4"},{"category":"Sm","mappings":{"default":{"default":"reversed angle with underbar"}},"key":"29A5"},{"category":"Sm","mappings":{"default":{"default":"oblique angle opening up"}},"key":"29A6"},{"category":"Sm","mappings":{"default":{"default":"oblique angle opening down"}},"key":"29A7"},{"category":"Sm","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing up and right"}},"key":"29A8"},{"category":"Sm","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing up and left"}},"key":"29A9"},{"category":"Sm","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing down and right"}},"key":"29AA"},{"category":"Sm","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing down and left"}},"key":"29AB"},{"category":"Sm","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing right and up"}},"key":"29AC"},{"category":"Sm","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing left and up"}},"key":"29AD"},{"category":"Sm","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing right and down"}},"key":"29AE"},{"category":"Sm","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing left and down"}},"key":"29AF"}]
,
"en/math_arrows.js": 
[{"locale":"en"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow","short":"left arrow"},"mathspeak":{"default":"left-arrow","sbrief":"L arrow"}},"key":"2190"},{"category":"Sm","mappings":{"default":{"default":"upwards arrow","short":"up arrow"},"mathspeak":{"default":"up-arrow","sbrief":"U arrow"}},"key":"2191"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow","short":"right arrow"},"mathspeak":{"default":"right-arrow","sbrief":"R arrow"}},"key":"2192"},{"category":"Sm","mappings":{"default":{"default":"downwards arrow","short":"down arrow"},"mathspeak":{"default":"down-arrow","sbrief":"D arrow"}},"key":"2193"},{"category":"Sm","mappings":{"default":{"default":"left right arrow"},"mathspeak":{"default":"left-right-arrow","sbrief":"L R arrow"}},"key":"2194"},{"category":"So","mappings":{"default":{"default":"up down arrow"},"mathspeak":{"default":"up down-arrow","sbrief":"U D arrow"}},"key":"2195"},{"category":"So","mappings":{"default":{"default":"north west arrow","short":"up left arrow"},"mathspeak":{"default":"up left-arrow","sbrief":"U L arrow"}},"key":"2196"},{"category":"So","mappings":{"default":{"default":"north east arrow","short":"up right arrow"},"mathspeak":{"default":"up right-arrow","sbrief":"U R arrow"}},"key":"2197"},{"category":"So","mappings":{"default":{"default":"south east arrow","short":"down right arrow"},"mathspeak":{"default":"down right-arrow","sbrief":"D R arrow"}},"key":"2198"},{"category":"So","mappings":{"default":{"default":"south west arrow","short":"down left arrow"},"mathspeak":{"default":"down left-arrow","sbrief":"D L arrow"}},"key":"2199"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow with stroke","short":"left arrow with stroke"},"mathspeak":{"default":"left-arrow with stroke","sbrief":"L arrow with stroke"}},"key":"219A"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow with stroke","short":"right arrow with stroke"},"mathspeak":{"default":"right-arrow with stroke","sbrief":"R arrow with stroke"}},"key":"219B"},{"category":"So","mappings":{"default":{"default":"leftwards wave arrow","short":"left wave arrow"},"mathspeak":{"sbrief":"L wave arrow"}},"key":"219C"},{"category":"So","mappings":{"default":{"default":"rightwards wave arrow","short":"right wave arrow"},"mathspeak":{"sbrief":"R wave arrow"}},"key":"219D"},{"category":"So","mappings":{"default":{"default":"leftwards two headed arrow","alternative":"left two headed arrow","short":"two headed left arrow"},"mathspeak":{"default":"two headed left-arrow","sbrief":"two headed L arrow"}},"key":"219E"},{"category":"So","mappings":{"default":{"default":"upwards two headed arrow","alternative":"up two headed arrow","short":"two headed up arrow"},"mathspeak":{"default":"two headed up-arrow","sbrief":"two headed U arrow"}},"key":"219F"},{"category":"Sm","mappings":{"default":{"default":"rightwards two headed arrow","alternative":"right two headed arrow","short":"two headed right arrow"},"mathspeak":{"default":"two headed right-arrow","sbrief":"two headed R arrow"}},"key":"21A0"},{"category":"So","mappings":{"default":{"default":"downwards two headed arrow","alternative":"down two headed arrow","short":"two headed down arrow"},"mathspeak":{"default":"two headed down-arrow","sbrief":"two headed D arrow"}},"key":"21A1"},{"category":"So","mappings":{"default":{"default":"leftwards arrow with tail","short":"left arrow with tail"},"mathspeak":{"default":"left-arrow with tail","sbrief":"L arrow with tail"}},"key":"21A2"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow with tail","short":"right arrow with tail"},"mathspeak":{"default":"right-arrow with tail","sbrief":"R arrow with tail"}},"key":"21A3"},{"category":"So","mappings":{"default":{"default":"leftwards arrow from bar","short":"left arrow from bar"},"mathspeak":{"default":"left-arrow from bar","sbrief":"L arrow from bar"}},"key":"21A4"},{"category":"So","mappings":{"default":{"default":"upwards arrow from bar","short":"up arrow from bar"},"mathspeak":{"default":"up-arrow from bar","sbrief":"U arrow from bar"}},"key":"21A5"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow from bar","short":"right arrow from bar"},"mathspeak":{"default":"right-arrow from bar","sbrief":"R arrow from bar"}},"key":"21A6"},{"category":"So","mappings":{"default":{"default":"downwards arrow from bar","short":"down arrow from bar"},"mathspeak":{"default":"down-arrow from bar","sbrief":"D arrow from bar"}},"key":"21A7"},{"category":"So","mappings":{"default":{"default":"up down arrow with base"},"mathspeak":{"default":"up down-arrow with base","sbrief":"U D arrow with base"}},"key":"21A8"},{"category":"So","mappings":{"default":{"default":"leftwards arrow with hook","short":"left arrow with hook"},"mathspeak":{"default":"left-arrow with hook","sbrief":"L arrow with hook"}},"key":"21A9"},{"category":"So","mappings":{"default":{"default":"rightwards arrow with hook","short":"right arrow with hook"},"mathspeak":{"default":"right-arrow with hook","sbrief":"R arrow with hook"}},"key":"21AA"},{"category":"So","mappings":{"default":{"default":"leftwards arrow with loop","short":"left arrow with loop"},"mathspeak":{"default":"left-arrow with loop","sbrief":"L arrow with loop"}},"key":"21AB"},{"category":"So","mappings":{"default":{"default":"rightwards arrow with loop","short":"right arrow with loop"},"mathspeak":{"default":"right-arrow with loop","sbrief":"R arrow with loop"}},"key":"21AC"},{"category":"So","mappings":{"default":{"default":"left right wave arrow"},"mathspeak":{"sbrief":"L R wave arrow"}},"key":"21AD"},{"category":"Sm","mappings":{"default":{"default":"left right arrow with stroke"},"mathspeak":{"default":"left-right-arrow with stroke","sbrief":"L R arrow with stroke"}},"key":"21AE"},{"category":"So","mappings":{"default":{"default":"downwards zigzag arrow","short":"down zigzag arrow"},"mathspeak":{"sbrief":"d zigzag arrow"}},"key":"21AF"},{"category":"So","mappings":{"default":{"default":"upwards arrow with tip leftwards","short":"up arrow with tip left"},"mathspeak":{"default":"up-arrow with tip left","sbrief":"U arrow with tip left"}},"key":"21B0"},{"category":"So","mappings":{"default":{"default":"upwards arrow with tip rightwards","short":"up arrow with tip right"},"mathspeak":{"default":"up-arrow with tip right","sbrief":"U arrow with tip right"}},"key":"21B1"},{"category":"So","mappings":{"default":{"default":"downwards arrow with tip leftwards","short":"down arrow with tip left"},"mathspeak":{"default":"down-arrow with tip left","sbrief":"D arrow with tip left"}},"key":"21B2"},{"category":"So","mappings":{"default":{"default":"downwards arrow with tip rightwards","short":"down arrow with tip right"},"mathspeak":{"default":"down-arrow with tip right","sbrief":"D arrow with tip right"}},"key":"21B3"},{"category":"So","mappings":{"default":{"default":"rightwards arrow with corner downwards","short":"right arrow with corner down"},"mathspeak":{"default":"right-arrow with corner down","sbrief":"R arrow with corner down"}},"key":"21B4"},{"category":"So","mappings":{"default":{"default":"downwards arrow with corner leftwards","short":"down arrow with corner left"},"mathspeak":{"default":"down-arrow with corner left","sbrief":"D arrow with corner left"}},"key":"21B5"},{"category":"So","mappings":{"default":{"default":"anticlockwise top semicircle arrow"}},"key":"21B6"},{"category":"So","mappings":{"default":{"default":"clockwise top semicircle arrow"}},"key":"21B7"},{"category":"So","mappings":{"default":{"default":"north west arrow to long bar","short":"up left arrow to long bar"},"mathspeak":{"default":"up left-arrow to long bar","sbrief":"U L arrow to long bar"}},"key":"21B8"},{"category":"So","mappings":{"default":{"default":"leftwards arrow to bar over rightwards arrow to bar","short":"left arrow to bar over right arrow to bar"},"mathspeak":{"default":"left-arrow to bar over right-arrow to bar","sbrief":"L arrow to bar over R arrow to bar"}},"key":"21B9"},{"category":"So","mappings":{"default":{"default":"anticlockwise open circle arrow"}},"key":"21BA"},{"category":"So","mappings":{"default":{"default":"clockwise open circle arrow"}},"key":"21BB"},{"category":"So","mappings":{"default":{"default":"rightwards arrow over leftwards arrow","short":"right arrow over left arrow"},"mathspeak":{"default":"right-arrow over left-arrow","sbrief":"R arrow over L arrow"}},"key":"21C4"},{"category":"So","mappings":{"default":{"default":"upwards arrow leftwards of downwards arrow","short":"up arrow left of down arrow"},"mathspeak":{"default":"up-arrow left of down-arrow","sbrief":"U arrow L of D arrow"}},"key":"21C5"},{"category":"So","mappings":{"default":{"default":"leftwards arrow over rightwards arrow","short":"left arrow over right arrow"},"mathspeak":{"default":"left-arrow over right-arrow","sbrief":"L arrow over R arrow"}},"key":"21C6"},{"category":"So","mappings":{"default":{"default":"leftwards paired arrows","short":"left paired arrows"},"mathspeak":{"sbrief":"L paired arrows"}},"key":"21C7"},{"category":"So","mappings":{"default":{"default":"upwards paired arrows","short":"up paired arrows"},"mathspeak":{"sbrief":"U paired arrows"}},"key":"21C8"},{"category":"So","mappings":{"default":{"default":"rightwards paired arrows","short":"right paired arrows"},"mathspeak":{"sbrief":"R paired arrows"}},"key":"21C9"},{"category":"So","mappings":{"default":{"default":"downwards paired arrows","short":"down paired arrows"},"mathspeak":{"sbrief":"D paired arrows"}},"key":"21CA"},{"category":"So","mappings":{"default":{"default":"leftwards double arrow with stroke","short":"left double arrow with stroke"},"mathspeak":{"sbrief":"L double arrow with stroke"}},"key":"21CD"},{"category":"Sm","mappings":{"default":{"default":"left right double arrow with stroke"},"mathspeak":{"sbrief":"L R double arrow with stroke"}},"key":"21CE"},{"category":"Sm","mappings":{"default":{"default":"rightwards double arrow with stroke","short":"right double arrow with stroke"},"mathspeak":{"sbrief":"R double arrow with stroke"}},"key":"21CF"},{"category":"So","mappings":{"default":{"default":"leftwards double arrow","short":"left double arrow"},"mathspeak":{"sbrief":"L double arrow"}},"key":"21D0"},{"category":"So","mappings":{"default":{"default":"upwards double arrow","short":"up double arrow"},"mathspeak":{"sbrief":"U double arrow"}},"key":"21D1"},{"category":"Sm","mappings":{"default":{"default":"rightwards double arrow","short":"right double arrow"},"mathspeak":{"sbrief":"R double arrow"}},"key":"21D2"},{"category":"So","mappings":{"default":{"default":"downwards double arrow","short":"down double arrow"},"mathspeak":{"sbrief":"d double arrow"}},"key":"21D3"},{"category":"Sm","mappings":{"default":{"default":"left right double arrow"},"mathspeak":{"sbrief":"L R double arrow"}},"key":"21D4"},{"category":"So","mappings":{"default":{"default":"up down double arrow"},"mathspeak":{"sbrief":"U d double arrow"}},"key":"21D5"},{"category":"So","mappings":{"default":{"default":"north west double arrow","short":"up left double arrow"},"mathspeak":{"sbrief":"U L double arrow"}},"key":"21D6"},{"category":"So","mappings":{"default":{"default":"north east double arrow","short":"up right double arrow"},"mathspeak":{"sbrief":"U R double arrow"}},"key":"21D7"},{"category":"So","mappings":{"default":{"default":"south east double arrow","short":"down right double arrow"},"mathspeak":{"sbrief":"d R double arrow"}},"key":"21D8"},{"category":"So","mappings":{"default":{"default":"south west double arrow","short":"down left double arrow"},"mathspeak":{"sbrief":"d L double arrow"}},"key":"21D9"},{"category":"So","mappings":{"default":{"default":"leftwards triple arrow","short":"left triple arrow"},"mathspeak":{"sbrief":"L triple arrow"}},"key":"21DA"},{"category":"So","mappings":{"default":{"default":"rightwards triple arrow","short":"right triple arrow"},"mathspeak":{"sbrief":"r triple arrow"}},"key":"21DB"},{"category":"So","mappings":{"default":{"default":"leftwards squiggle arrow","short":"left squiggle arrow"},"mathspeak":{"sbrief":"L squiggle arrow"}},"key":"21DC"},{"category":"So","mappings":{"default":{"default":"rightwards squiggle arrow","short":"right squiggle arrow"},"mathspeak":{"sbrief":"r squiggle arrow"}},"key":"21DD"},{"category":"So","mappings":{"default":{"default":"upwards arrow with double stroke","short":"up arrow with double stroke"},"mathspeak":{"default":"up-arrow with double stroke","sbrief":"U arrow with double stroke"}},"key":"21DE"},{"category":"So","mappings":{"default":{"default":"downwards arrow with double stroke","short":"down arrow with double stroke"},"mathspeak":{"default":"down-arrow with double stroke","sbrief":"D arrow with double stroke"}},"key":"21DF"},{"category":"So","mappings":{"default":{"default":"leftwards dasheD arrow","short":"left dasheD arrow"},"mathspeak":{"sbrief":"L dasheD arrow"}},"key":"21E0"},{"category":"So","mappings":{"default":{"default":"upwards dasheD arrow","short":"up dasheD arrow"},"mathspeak":{"sbrief":"U dasheD arrow"}},"key":"21E1"},{"category":"So","mappings":{"default":{"default":"rightwards dasheD arrow","short":"right dasheD arrow"},"mathspeak":{"sbrief":"r dasheD arrow"}},"key":"21E2"},{"category":"So","mappings":{"default":{"default":"downwards dasheD arrow","short":"down dasheD arrow"},"mathspeak":{"sbrief":"d dasheD arrow"}},"key":"21E3"},{"category":"So","mappings":{"default":{"default":"leftwards arrow to bar","short":"left arrow to bar"},"mathspeak":{"default":"left-arrow to bar","sbrief":"L arrow to bar"}},"key":"21E4"},{"category":"So","mappings":{"default":{"default":"rightwards arrow to bar","short":"right arrow to bar"},"mathspeak":{"default":"right-arrow to bar","sbrief":"R arrow to bar"}},"key":"21E5"},{"category":"So","mappings":{"default":{"default":"leftwards white arrow","short":"white left arrow"},"mathspeak":{"default":"white left-arrow","sbrief":"white L arrow"}},"key":"21E6"},{"category":"So","mappings":{"default":{"default":"upwards white arrow","short":"white up arrow"},"mathspeak":{"default":"white up-arrow","sbrief":"white U arrow"}},"key":"21E7"},{"category":"So","mappings":{"default":{"default":"rightwards white arrow","short":"white right arrow"},"mathspeak":{"default":"white right-arrow","sbrief":"white R arrow"}},"key":"21E8"},{"category":"So","mappings":{"default":{"default":"downwards white arrow","short":"white down arrow"},"mathspeak":{"default":"white down-arrow","sbrief":"white D arrow"}},"key":"21E9"},{"category":"So","mappings":{"default":{"default":"upwards white arrow from bar","short":"white up arrow from bar"},"mathspeak":{"default":"white up-arrow from bar","sbrief":"white U arrow from bar"}},"key":"21EA"},{"category":"So","mappings":{"default":{"default":"upwards white arrow on pedestal","alternative":"up white arrow on pedestal","short":"white up arrow on pedestal"},"mathspeak":{"default":"white up-arrow on pedestal","sbrief":"white U arrow on pedestal"}},"key":"21EB"},{"category":"So","mappings":{"default":{"default":"upwards white arrow on pedestal with horizontal bar","alternative":"up white arrow on pedestal with horizontal bar","short":"white up arrow on pedestal with horizontal bar"},"mathspeak":{"default":"white up-arrow on pedestal with horizontal bar","sbrief":"white U arrow on pedestal with horizontal bar"}},"key":"21EC"},{"category":"So","mappings":{"default":{"default":"upwards white arrow on pedestal with vertical bar","alternative":"up white arrow on pedestal with vertical bar","short":"white up arrow on pedestal with vertical bar"},"mathspeak":{"default":"white up-arrow on pedestal with vertical bar","sbrief":"white U arrow on pedestal with vertical bar"}},"key":"21ED"},{"category":"So","mappings":{"default":{"default":"upwards white double arrow","alternative":"up white double arrow","short":"white double up arrow"},"mathspeak":{"default":"white double up-arrow","sbrief":"white double U arrow"}},"key":"21EE"},{"category":"So","mappings":{"default":{"default":"upwards white double arrow on pedestal","alternative":"up white double arrow on pedestal","short":"white double up arrow on pedestal"},"mathspeak":{"default":"white double up-arrow on pedestal","sbrief":"white double U arrow on pedestal"}},"key":"21EF"},{"category":"So","mappings":{"default":{"default":"rightwards white arrow from wall","alternative":"right white arrow from wall","short":"white right arrow from wall"},"mathspeak":{"default":"white right-arrow from wall","sbrief":"white R arrow from wall"}},"key":"21F0"},{"category":"So","mappings":{"default":{"default":"north west arrow to corner"}},"key":"21F1"},{"category":"So","mappings":{"default":{"default":"south east arrow to corner"}},"key":"21F2"},{"category":"So","mappings":{"default":{"default":"up down white arrow"},"mathspeak":{"sbrief":"U d white arrow"}},"key":"21F3"},{"category":"Sm","mappings":{"default":{"default":"right arrow with small circle"},"mathspeak":{"default":"right-arrow with small circle","sbrief":"R arrow with small circle"}},"key":"21F4"},{"category":"Sm","mappings":{"default":{"default":"down arrow leftwards of upwards arrow","short":"down arrow left of up arrow"},"mathspeak":{"default":"down-arrow left of up-arrow","sbrief":"D arrow l of U arrow"}},"key":"21F5"},{"category":"Sm","mappings":{"default":{"default":"three rightwards arrows","short":"three right arrows"},"mathspeak":{"default":"three right-arrows","sbrief":"three R arrows"}},"key":"21F6"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow with vertical stroke","short":"left arrow with vertical stroke"},"mathspeak":{"default":"left-arrow with vertical stroke","sbrief":"L arrow with vertical stroke"}},"key":"21F7"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow with vertical stroke","short":"right arrow with vertical stroke"},"mathspeak":{"default":"right-arrow with vertical stroke","sbrief":"R arrow with vertical stroke"}},"key":"21F8"},{"category":"Sm","mappings":{"default":{"default":"left right arrow with vertical stroke"},"mathspeak":{"default":"left-right-arrow with vertical stroke","sbrief":"L R arrow with vertical stroke"}},"key":"21F9"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow with double vertical stroke","short":"left arrow with double vertical stroke"},"mathspeak":{"default":"left-arrow with double vertical stroke","sbrief":"L arrow with double vertical stroke"}},"key":"21FA"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow with double vertical stroke","short":"right arrow with double vertical stroke"},"mathspeak":{"default":"right-arrow with double vertical stroke","sbrief":"R arrow with double vertical stroke"}},"key":"21FB"},{"category":"Sm","mappings":{"default":{"default":"left right arrow with double vertical stroke"},"mathspeak":{"default":"left-right-arrow with double vertical stroke","sbrief":"L R arrow with double vertical stroke"}},"key":"21FC"},{"category":"Sm","mappings":{"default":{"default":"leftwards open headed arrow","short":"left open headed arrow"},"mathspeak":{"sbrief":"l open headed arrow"}},"key":"21FD"},{"category":"Sm","mappings":{"default":{"default":"rightwards open headed arrow","short":"right open headed arrow"},"mathspeak":{"sbrief":"r open headed arrow"}},"key":"21FE"},{"category":"Sm","mappings":{"default":{"default":"left right open headed arrow"},"mathspeak":{"sbrief":"L R open headed arrow"}},"key":"21FF"},{"category":"So","mappings":{"default":{"default":"electric arrow"}},"key":"2301"},{"category":"So","mappings":{"default":{"default":"up arrowhead"},"mathspeak":{"default":"up-arrowhead","sbrief":"U arrowhead"}},"key":"2303"},{"category":"So","mappings":{"default":{"default":"down arrowhead"},"mathspeak":{"default":"down-arrowhead","sbrief":"D arrowhead"}},"key":"2304"},{"category":"So","mappings":{"default":{"default":"up arrowhead between two horizontal bars","alternative":"enter key"},"mathspeak":{"default":"up-arrowhead between two horizontal bars","sbrief":"U arrowhead between two horizontal bars"}},"key":"2324"},{"category":"So","mappings":{"default":{"default":"broken circle with northwest arrow"}},"key":"238B"},{"category":"So","mappings":{"default":{"default":"heavy wide headed rightwards arrow","short":"heavy wide headed right arrow"},"mathspeak":{"default":"heavy wide headed right-arrow","sbrief":"heavy wide headed R arrow"}},"key":"2794"},{"category":"So","mappings":{"default":{"default":"heavy south east arrow","short":"heavy down right arrow"},"mathspeak":{"default":"heavy down right-arrow","sbrief":"heavy d R arrow"}},"key":"2798"},{"category":"So","mappings":{"default":{"default":"heavy rightwards arrow","short":"heavy right arrow"},"mathspeak":{"default":"heavy right-arrow","sbrief":"heavy R arrow"}},"key":"2799"},{"category":"So","mappings":{"default":{"default":"heavy north east arrow","short":"heavy up right arrow"},"mathspeak":{"default":"heavy up right-arrow","sbrief":"heavy U R arrow"}},"key":"279A"},{"category":"So","mappings":{"default":{"default":"drafting point rightwards arrow","short":"drafting point right arrow"},"mathspeak":{"default":"drafting point right-arrow","sbrief":"drafting point R arrow"}},"key":"279B"},{"category":"So","mappings":{"default":{"default":"heavy round tipped rightwards arrow","short":"heavy round tipped right arrow"},"mathspeak":{"default":"heavy round tipped right-arrow","sbrief":"heavy round tipped R arrow"}},"key":"279C"},{"category":"So","mappings":{"default":{"default":"triangle headed rightwards arrow","short":"triangle headed right arrow"},"mathspeak":{"default":"triangle headed right-arrow","sbrief":"triangle headed R arrow"}},"key":"279D"},{"category":"So","mappings":{"default":{"default":"heavy triangle headed rightwards arrow","short":"heavy triangle headed right arrow"},"mathspeak":{"default":"heavy triangle headed right-arrow","sbrief":"heavy triangle headed R arrow"}},"key":"279E"},{"category":"So","mappings":{"default":{"default":"dashed triangle headed rightwards arrow","short":"dashed triangle headed right arrow"},"mathspeak":{"default":"dashed triangle headed right-arrow","sbrief":"dashed triangle headed R arrow"}},"key":"279F"},{"category":"So","mappings":{"default":{"default":"heavy dashed triangle headed rightwards arrow","short":"heavy dashed triangle headed right arrow"},"mathspeak":{"default":"heavy dashed triangle headed right-arrow","sbrief":"heavy dashed triangle headed R arrow"}},"key":"27A0"},{"category":"So","mappings":{"default":{"default":"black rightwards arrow","short":"black right arrow"},"mathspeak":{"default":"black right-arrow","sbrief":"black R arrow"}},"key":"27A1"},{"category":"So","mappings":{"default":{"default":"three d top lighted rightwards arrowhead","short":"three d top lighted right arrowhead"},"mathspeak":{"default":"three d top lighted right-arrowhead","sbrief":"three d top lighted R arrowhead"}},"key":"27A2"},{"category":"So","mappings":{"default":{"default":"three d bottom lighted rightwards arrowhead","short":"three d bottom lighted right arrowhead"},"mathspeak":{"default":"three d bottom lighted right-arrowhead","sbrief":"three d bottom lighted R arrowhead"}},"key":"27A3"},{"category":"So","mappings":{"default":{"default":"black rightwards arrowhead","short":"black right arrowhead"},"mathspeak":{"default":"black right-arrowhead","sbrief":"black R arrowhead"}},"key":"27A4"},{"category":"So","mappings":{"default":{"default":"heavy black curved downwards and rightwards arrow","short":"heavy black curved down and right arrow"},"mathspeak":{"default":"heavy black curved down and right-arrow","sbrief":"heavy black curved d and R arrow"}},"key":"27A5"},{"category":"So","mappings":{"default":{"default":"heavy black curved upwards and rightwards arrow","short":"heavy black curved up and right arrow"},"mathspeak":{"default":"heavy black curved up and right-arrow","sbrief":"heavy black curved U and R arrow"}},"key":"27A6"},{"category":"So","mappings":{"default":{"default":"squat black rightwards arrow","short":"squat black right arrow"},"mathspeak":{"default":"squat black right-arrow","sbrief":"squat black R arrow"}},"key":"27A7"},{"category":"So","mappings":{"default":{"default":"heavy concave pointed black rightwards arrow","short":"heavy concave pointed black right arrow"},"mathspeak":{"default":"heavy concave pointed black right-arrow","sbrief":"heavy concave pointed black R arrow"}},"key":"27A8"},{"category":"So","mappings":{"default":{"default":"right shaded white rightwards arrow","short":"right shaded white right arrow"},"mathspeak":{"default":"right shaded white right-arrow","sbrief":"right shaded white R arrow"}},"key":"27A9"},{"category":"So","mappings":{"default":{"default":"left shaded white rightwards arrow","short":"left shaded white right arrow"},"mathspeak":{"default":"left shaded white right-arrow","sbrief":"left shaded white R arrow"}},"key":"27AA"},{"category":"So","mappings":{"default":{"default":"back tilted shadowed white rightwards arrow","short":"back tilted shadowed white right arrow"},"mathspeak":{"default":"back tilted shadowed white right-arrow","sbrief":"back tilted shadowed white R arrow"}},"key":"27AB"},{"category":"So","mappings":{"default":{"default":"front tilted shadowed white rightwards arrow","short":"front tilted shadowed white right arrow"},"mathspeak":{"default":"front tilted shadowed white right-arrow","sbrief":"front tilted shadowed white R arrow"}},"key":"27AC"},{"category":"So","mappings":{"default":{"default":"heavy lower right shadowed white rightwards arrow","short":"heavy lower right shadowed white right arrow"},"mathspeak":{"default":"heavy lower right shadowed white right-arrow","sbrief":"heavy lower right shadowed white R arrow"}},"key":"27AD"},{"category":"So","mappings":{"default":{"default":"heavy upper right shadowed white rightwards arrow","short":"heavy upper right shadowed white right arrow"},"mathspeak":{"default":"heavy upper right shadowed white right-arrow","sbrief":"heavy upper right shadowed white R arrow"}},"key":"27AE"},{"category":"So","mappings":{"default":{"default":"notched lower right shadowed white rightwards arrow","short":"notched lower right shadowed white right arrow"},"mathspeak":{"default":"notched lower right shadowed white right-arrow","sbrief":"notched lower right shadowed white R arrow"}},"key":"27AF"},{"category":"So","mappings":{"default":{"default":"notched upper right shadowed white rightwards arrow","short":"notched upper right shadowed white right arrow"},"mathspeak":{"default":"notched upper right shadowed white right-arrow","sbrief":"notched upper right shadowed white R arrow"}},"key":"27B1"},{"category":"So","mappings":{"default":{"default":"circled heavy white rightwards arrow","short":"circled heavy white right arrow"},"mathspeak":{"default":"circled heavy white right-arrow","sbrief":"circled heavy white R arrow"}},"key":"27B2"},{"category":"So","mappings":{"default":{"default":"white feathered rightwards arrow","short":"white feathered right arrow"},"mathspeak":{"default":"white feathered right-arrow","sbrief":"white feathered R arrow"}},"key":"27B3"},{"category":"So","mappings":{"default":{"default":"black feathered south east arrow","short":"black feathered down right arrow"},"mathspeak":{"default":"black feathered down right-arrow","sbrief":"black feathered d R arrow"}},"key":"27B4"},{"category":"So","mappings":{"default":{"default":"black feathered rightwards arrow","short":"black feathered right arrow"},"mathspeak":{"default":"black feathered right-arrow","sbrief":"black feathered R arrow"}},"key":"27B5"},{"category":"So","mappings":{"default":{"default":"black feathered north east arrow","short":"black feathered up right arrow"},"mathspeak":{"default":"black feathered up right-arrow","sbrief":"black feathered U R arrow"}},"key":"27B6"},{"category":"So","mappings":{"default":{"default":"heavy black feathered south east arrow","short":"heavy black feathered down right arrow"},"mathspeak":{"default":"heavy black feathered down right-arrow","sbrief":"heavy black feathered d R arrow"}},"key":"27B7"},{"category":"So","mappings":{"default":{"default":"heavy black feathered rightwards arrow","short":"heavy black feathered right arrow"},"mathspeak":{"default":"heavy black feathered right-arrow","sbrief":"heavy black feathered R arrow"}},"key":"27B8"},{"category":"So","mappings":{"default":{"default":"heavy black feathered north east arrow","short":"heavy black feathered up right arrow"},"mathspeak":{"default":"heavy black feathered up right-arrow","sbrief":"heavy black feathered U R arrow"}},"key":"27B9"},{"category":"So","mappings":{"default":{"default":"teardrop barbed rightwards arrow","short":"teardrop barbed right arrow"},"mathspeak":{"default":"teardrop barbed right-arrow","sbrief":"teardrop barbed R arrow"}},"key":"27BA"},{"category":"So","mappings":{"default":{"default":"heavy teardrop shanked rightwards arrow","short":"heavy teardrop shanked right arrow"},"mathspeak":{"default":"heavy teardrop shanked right-arrow","sbrief":"heavy teardrop shanked R arrow"}},"key":"27BB"},{"category":"So","mappings":{"default":{"default":"wedge tailed rightwards arrow","short":"wedge tailed right arrow"},"mathspeak":{"default":"wedge tailed right-arrow","sbrief":"wedge tailed R arrow"}},"key":"27BC"},{"category":"So","mappings":{"default":{"default":"heavy wedge tailed rightwards arrow","short":"heavy wedge tailed right arrow"},"mathspeak":{"default":"heavy wedge tailed right-arrow","sbrief":"heavy wedge tailed R arrow"}},"key":"27BD"},{"category":"So","mappings":{"default":{"default":"open outlined rightwards arrow","short":"open outlined right arrow"},"mathspeak":{"default":"open outlined right-arrow","sbrief":"open outlined R arrow"}},"key":"27BE"},{"category":"Sm","mappings":{"default":{"default":"upwards quadruple arrow","short":"up quadruple arrow"},"mathspeak":{"sbrief":"U quadruple arrow"}},"key":"27F0"},{"category":"Sm","mappings":{"default":{"default":"downwards quadruple arrow","short":"down quadruple arrow"},"mathspeak":{"sbrief":"d quadrule arrow"}},"key":"27F1"},{"category":"Sm","mappings":{"default":{"default":"anticlockwise gapped circle arrow"}},"key":"27F2"},{"category":"Sm","mappings":{"default":{"default":"clockwise gapped circle arrow"}},"key":"27F3"},{"category":"Sm","mappings":{"default":{"default":"right arrow with circled plus"},"mathspeak":{"default":"right-arrow with circled plus","sbrief":"R arrow with circled plus"}},"key":"27F4"},{"category":"Sm","mappings":{"default":{"default":"long leftwards arrow","short":"long left arrow"},"mathspeak":{"default":"long left-arrow","sbrief":"long L arrow"}},"key":"27F5"},{"category":"Sm","mappings":{"default":{"default":"long rightwards arrow","short":"long right arrow"},"mathspeak":{"default":"long right-arrow","sbrief":"long R arrow"}},"key":"27F6"},{"category":"Sm","mappings":{"default":{"default":"long left right arrow"},"mathspeak":{"default":"long left-right-arrow","sbrief":"long L R arrow"}},"key":"27F7"},{"category":"Sm","mappings":{"default":{"default":"long leftwards double arrow","short":"long left double arrow"},"mathspeak":{"sbrief":"long l double arrow"}},"key":"27F8"},{"category":"Sm","mappings":{"default":{"default":"long rightwards double arrow","short":"long right double arrow"},"mathspeak":{"sbrief":"long R double arrow"}},"key":"27F9"},{"category":"Sm","mappings":{"default":{"default":"long left right double arrow"},"mathspeak":{"sbrief":"long L R double arrow"}},"key":"27FA"},{"category":"Sm","mappings":{"default":{"default":"long leftwards arrow from bar","short":"long left arrow from bar"},"mathspeak":{"default":"long left-arrow from bar","sbrief":"long L arrow from bar"}},"key":"27FB"},{"category":"Sm","mappings":{"default":{"default":"long rightwards arrow from bar","short":"long right arrow from bar"},"mathspeak":{"default":"long right-arrow from bar","sbrief":"long R arrow from bar"}},"key":"27FC"},{"category":"Sm","mappings":{"default":{"default":"long leftwards double arrow from bar","short":"long left double arrow from bar"},"mathspeak":{"sbrief":"long l double arrow from bar"}},"key":"27FD"},{"category":"Sm","mappings":{"default":{"default":"long rightwards double arrow from bar","short":"long right double arrow from bar"},"mathspeak":{"sbrief":"long R double arrow from bar"}},"key":"27FE"},{"category":"Sm","mappings":{"default":{"default":"long rightwards squiggle arrow","short":"long right squiggle arrow"},"mathspeak":{"sbrief":"long r squiggle arrow"}},"key":"27FF"},{"category":"Sm","mappings":{"default":{"default":"rightwards two headed arrow with vertical stroke","alternative":"right two headed arrow with vertical stroke","short":"two headed right arrow with vertical stroke"},"mathspeak":{"default":"two headed right-arrow with vertical stroke","sbrief":"two headed R arrow with vertical stroke"}},"key":"2900"},{"category":"Sm","mappings":{"default":{"default":"rightwards two headed arrow with double vertical stroke","alternative":"right two headed arrow with double vertical stroke","short":"two headed right arrow with double vertical stroke"},"mathspeak":{"default":"two headed right-arrow with double vertical stroke","sbrief":"two headed R arrow with double vertical stroke"}},"key":"2901"},{"category":"Sm","mappings":{"default":{"default":"leftwards double arrow with vertical stroke","alternative":"left double arrow with vertical stroke","short":"double left arrow with vertical stroke"},"mathspeak":{"default":"double left-arrow with vertical stroke","sbrief":"double L arrow with vertical stroke"}},"key":"2902"},{"category":"Sm","mappings":{"default":{"default":"rightwards double arrow with vertical stroke","alternative":"right double arrow with vertical stroke","short":"double right arrow with vertical stroke"},"mathspeak":{"default":"double right-arrow with vertical stroke","sbrief":"double R arrow with vertical stroke"}},"key":"2903"},{"category":"Sm","mappings":{"default":{"default":"left right double arrow with vertical stroke","short":"double left right arrow with vertical stroke"},"mathspeak":{"default":"double left-right-arrow with vertical stroke","sbrief":"double L R arrow with vertical stroke"}},"key":"2904"},{"category":"Sm","mappings":{"default":{"default":"rightwards two headed arrow from bar","alternative":"right two headed arrow from bar","short":"two headed right arrow from bar"},"mathspeak":{"default":"two headed right-arrow from bar","sbrief":"two headed R arrow from bar"}},"key":"2905"},{"category":"Sm","mappings":{"default":{"default":"leftwards double arrow from bar","alternative":"left double arrow from bar","short":"double left arrow from bar"},"mathspeak":{"default":"double left-arrow from bar","sbrief":"double L arrow from bar"}},"key":"2906"},{"category":"Sm","mappings":{"default":{"default":"rightwards double arrow from bar","alternative":"right double arrow from bar","short":"double right arrow from bar"},"mathspeak":{"default":"double right-arrow from bar","sbrief":"double R arrow from bar"}},"key":"2907"},{"category":"Sm","mappings":{"default":{"default":"downwards arrow with horizontal stroke","alternative":"down arrow with horizontal stroke","short":"arrow down with horizontal stroke"}},"key":"2908"},{"category":"Sm","mappings":{"default":{"default":"upwards arrow with horizontal stroke","short":"up arrow with horizontal stroke"},"mathspeak":{"default":"up-arrow with horizontal stroke","sbrief":"U arrow with horizontal stroke"}},"key":"2909"},{"category":"Sm","mappings":{"default":{"default":"upwards triple arrow","short":"up triple arrow"},"mathspeak":{"sbrief":"U triple arrow"}},"key":"290A"},{"category":"Sm","mappings":{"default":{"default":"downwards triple arrow","short":"down triple arrow"},"mathspeak":{"sbrief":"d triple arrow"}},"key":"290B"},{"category":"Sm","mappings":{"default":{"default":"leftwards double dash arrow","short":"left double dash arrow"},"mathspeak":{"sbrief":"l double dash arrow"}},"key":"290C"},{"category":"Sm","mappings":{"default":{"default":"rightwards double dash arrow","short":"right double dash arrow"},"mathspeak":{"sbrief":"R double dash arrow"}},"key":"290D"},{"category":"Sm","mappings":{"default":{"default":"leftwards triple dash arrow","short":"left triple dash arrow"},"mathspeak":{"sbrief":"l triple dash arrow"}},"key":"290E"},{"category":"Sm","mappings":{"default":{"default":"rightwards triple dash arrow","short":"right triple dash arrow"},"mathspeak":{"sbrief":"r triple dash arrow"}},"key":"290F"},{"category":"Sm","mappings":{"default":{"default":"rightwards two headed triple dash arrow","short":"right two headed triple dash arrow"},"mathspeak":{"sbrief":"r two headed triple dash arrow"}},"key":"2910"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow with dotted stem","short":"right arrow with dotted stem"},"mathspeak":{"default":"right-arrow with dotted stem","sbrief":"R arrow with dotted stem"}},"key":"2911"},{"category":"Sm","mappings":{"default":{"default":"upwards arrow to bar","short":"up arrow to bar"},"mathspeak":{"default":"up-arrow to bar","sbrief":"U arrow to bar"}},"key":"2912"},{"category":"Sm","mappings":{"default":{"default":"downwards arrow to bar","short":"down arrow to bar"},"mathspeak":{"default":"down-arrow to bar","sbrief":"D arrow to bar"}},"key":"2913"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow with tail with vertical stroke","short":"right arrow with tail with vertical stroke"},"mathspeak":{"default":"right-arrow with tail with vertical stroke","sbrief":"R arrow with tail with vertical stroke"}},"key":"2914"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow with tail with double vertical stroke","short":"right arrow with tail with double vertical stroke"},"mathspeak":{"default":"right-arrow with tail with double vertical stroke","sbrief":"R arrow with tail with double vertical stroke"}},"key":"2915"},{"category":"Sm","mappings":{"default":{"default":"rightwards two headed arrow with tail","short":"right two headed arrow with tail"},"mathspeak":{"sbrief":"r two headed arrow with tail"}},"key":"2916"},{"category":"Sm","mappings":{"default":{"default":"rightwards two headed arrow with tail with vertical stroke","short":"right two headed arrow with tail with vertical stroke"},"mathspeak":{"sbrief":"r two headed arrow with tail with vertical stroke"}},"key":"2917"},{"category":"Sm","mappings":{"default":{"default":"rightwards two headed arrow with tail with double vertical stroke","short":"right two headed arrow with tail with double vertical stroke"},"mathspeak":{"sbrief":"r two headed arrow with tail with double vertical stroke"}},"key":"2918"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow tail","short":"left arrow tail"},"mathspeak":{"default":"left-arrow tail","sbrief":"L arrow tail"}},"key":"2919"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow tail","short":"right arrow tail"},"mathspeak":{"default":"right-arrow tail","sbrief":"R arrow tail"}},"key":"291A"},{"category":"Sm","mappings":{"default":{"default":"leftwards double arrow tail","short":"left double arrow tail"},"mathspeak":{"sbrief":"l double arrow tail"}},"key":"291B"},{"category":"Sm","mappings":{"default":{"default":"rightwards double arrow tail","short":"right double arrow tail"},"mathspeak":{"sbrief":"R double arrow tail"}},"key":"291C"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow to black diamond","short":"left arrow to black diamond"},"mathspeak":{"default":"left-arrow to black diamond","sbrief":"L arrow to black diamond"}},"key":"291D"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow to black diamond","short":"right arrow to black diamond"},"mathspeak":{"default":"right-arrow to black diamond","sbrief":"R arrow to black diamond"}},"key":"291E"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow from bar to black diamond","short":"left arrow from bar to black diamond"},"mathspeak":{"default":"left-arrow from bar to black diamond","sbrief":"L arrow from bar to black diamond"}},"key":"291F"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow from bar to black diamond","short":"right arrow from bar to black diamond"},"mathspeak":{"default":"right-arrow from bar to black diamond","sbrief":"R arrow from bar to black diamond"}},"key":"2920"},{"category":"Sm","mappings":{"default":{"default":"north west and south east arrow"}},"key":"2921"},{"category":"Sm","mappings":{"default":{"default":"north east and south west arrow"}},"key":"2922"},{"category":"Sm","mappings":{"default":{"default":"north west arrow with hook"}},"key":"2923"},{"category":"Sm","mappings":{"default":{"default":"north east arrow with hook"}},"key":"2924"},{"category":"Sm","mappings":{"default":{"default":"south east arrow with hook"}},"key":"2925"},{"category":"Sm","mappings":{"default":{"default":"south west arrow with hook"}},"key":"2926"},{"category":"Sm","mappings":{"default":{"default":"north west arrow and north east arrow"}},"key":"2927"},{"category":"Sm","mappings":{"default":{"default":"north east arrow and south east arrow"}},"key":"2928"},{"category":"Sm","mappings":{"default":{"default":"south east arrow and south west arrow"}},"key":"2929"},{"category":"Sm","mappings":{"default":{"default":"south west arrow and north west arrow"}},"key":"292A"},{"category":"Sm","mappings":{"default":{"default":"south east arrow crossing north east arrow"}},"key":"292D"},{"category":"Sm","mappings":{"default":{"default":"north east arrow crossing south east arrow"}},"key":"292E"},{"category":"Sm","mappings":{"default":{"default":"falling diagonal crossing north east arrow"}},"key":"292F"},{"category":"Sm","mappings":{"default":{"default":"rising diagonal crossing south east arrow"}},"key":"2930"},{"category":"Sm","mappings":{"default":{"default":"north east arrow crossing north west arrow"}},"key":"2931"},{"category":"Sm","mappings":{"default":{"default":"north west arrow crossing north east arrow"}},"key":"2932"},{"category":"Sm","mappings":{"default":{"default":"wave arrow pointing directly right"}},"key":"2933"},{"category":"Sm","mappings":{"default":{"default":"arrow pointing rightwards then curving upwards","short":"arrow pointing right then curving up"}},"key":"2934"},{"category":"Sm","mappings":{"default":{"default":"arrow pointing rightwards then curving downwards","short":"arrow pointing right then curving down"}},"key":"2935"},{"category":"Sm","mappings":{"default":{"default":"arrow pointing downwards then curving leftwards","short":"arrow pointing down then curving left"}},"key":"2936"},{"category":"Sm","mappings":{"default":{"default":"arrow pointing downwards then curving rightwards","short":"arrow pointing down then curving right"}},"key":"2937"},{"category":"Sm","mappings":{"default":{"default":"right side arc clockwise arrow"},"mathspeak":{"sbrief":"r side arc clockwise arrow"}},"key":"2938"},{"category":"Sm","mappings":{"default":{"default":"left side arc anticlockwise arrow"},"mathspeak":{"sbrief":"l side arc anticlockwise arrow"}},"key":"2939"},{"category":"Sm","mappings":{"default":{"default":"top arc anticlockwise arrow"}},"key":"293A"},{"category":"Sm","mappings":{"default":{"default":"bottom arc anticlockwise arrow"}},"key":"293B"},{"category":"Sm","mappings":{"default":{"default":"top arc clockwise arrow with minus"}},"key":"293C"},{"category":"Sm","mappings":{"default":{"default":"top arc anticlockwise arrow with plus"}},"key":"293D"},{"category":"Sm","mappings":{"default":{"default":"lower right semicircular clockwise arrow","short":"down right semicircular clockwise arrow"},"mathspeak":{"sbrief":"d r semicircular clockwise arrow"}},"key":"293E"},{"category":"Sm","mappings":{"default":{"default":"lower left semicircular anticlockwise arrow","short":"down left semicircular anticlockwise arrow"},"mathspeak":{"sbrief":"d l semicircular anticlockwise arrow"}},"key":"293F"},{"category":"Sm","mappings":{"default":{"default":"anticlockwise closed circle arrow"}},"key":"2940"},{"category":"Sm","mappings":{"default":{"default":"clockwise closed circle arrow"}},"key":"2941"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow above short leftwards arrow","short":"right arrow above short left arrow"},"mathspeak":{"default":"right-arrow above short left-arrow","sbrief":"R arrow above short L arrow"}},"key":"2942"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow above short rightwards arrow","short":"left arrow above short right arrow"},"mathspeak":{"default":"left-arrow above short right-arrow","sbrief":"L arrow above short R arrow"}},"key":"2943"},{"category":"Sm","mappings":{"default":{"default":"short rightwards arrow above leftwards arrow","short":"short right arrow above left arrow"},"mathspeak":{"default":"short right-arrow above left-arrow","sbrief":"short R arrow above L arrow"}},"key":"2944"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow with plus below","short":"right arrow with plus below"},"mathspeak":{"default":"right-arrow with plus below","sbrief":"R arrow with plus below"}},"key":"2945"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow with plus below","short":"left arrow with plus below"},"mathspeak":{"default":"left-arrow with plus below","sbrief":"L arrow with plus below"}},"key":"2946"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow through x","short":"right arrow through x"},"mathspeak":{"default":"right-arrow through x","sbrief":"R arrow through x"}},"key":"2947"},{"category":"Sm","mappings":{"default":{"default":"left right arrow through small circle"},"mathspeak":{"default":"left-right-arrow through small circle","sbrief":"L R arrow through small circle"}},"key":"2948"},{"category":"Sm","mappings":{"default":{"default":"upwards two headed arrow from small circle","short":"up two headed arrow from small circle"},"mathspeak":{"sbrief":"U two headed arrow from small circle"}},"key":"2949"},{"category":"Sm","mappings":{"default":{"default":"right double arrow with rounded head"},"mathspeak":{"sbrief":"R double arrow with rounded head"}},"key":"2970"},{"category":"Sm","mappings":{"default":{"default":"equals sign above rightwards arrow","short":"equals sign above right arrow"},"mathspeak":{"default":"equals sign above right-arrow","sbrief":"equals sign above R arrow"}},"key":"2971"},{"category":"Sm","mappings":{"default":{"default":"tilde operator above rightwards arrow","short":"tilde operator above right arrow"},"mathspeak":{"default":"tilde operator above right-arrow","sbrief":"tilde operator above R arrow"}},"key":"2972"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow above tilde operator","short":"left arrow above tilde operator"},"mathspeak":{"default":"left-arrow above tilde operator","sbrief":"L arrow above tilde operator"}},"key":"2973"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow above tilde operator","short":"right arrow above tilde operator"},"mathspeak":{"default":"right-arrow above tilde operator","sbrief":"R arrow above tilde operator"}},"key":"2974"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow above almost equals","short":"right arrow above almost equals"},"mathspeak":{"default":"right-arrow above almost equals","sbrief":"R arrow above almost equals"}},"key":"2975"},{"category":"Sm","mappings":{"default":{"default":"less than above leftwards arrow","short":"less than above left arrow"},"mathspeak":{"default":"less than above left-arrow","sbrief":"less than above L arrow"}},"key":"2976"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow through less than","short":"left arrow through less than"},"mathspeak":{"default":"left-arrow through less than","sbrief":"L arrow through less than"}},"key":"2977"},{"category":"Sm","mappings":{"default":{"default":"greater than above rightwards arrow","short":"greater than above right arrow"},"mathspeak":{"default":"greater than above right-arrow","sbrief":"greater than above R arrow"}},"key":"2978"},{"category":"Sm","mappings":{"default":{"default":"subset above rightwards arrow","short":"subset above right arrow"},"mathspeak":{"default":"subset above right-arrow","sbrief":"subset above R arrow"}},"key":"2979"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow through subset","short":"left arrow through subset"},"mathspeak":{"default":"left-arrow through subset","sbrief":"L arrow through subset"}},"key":"297A"},{"category":"Sm","mappings":{"default":{"default":"superset above leftwards arrow","short":"superset above left arrow"},"mathspeak":{"default":"superset above left-arrow","sbrief":"suerset above L arrow"}},"key":"297B"},{"category":"Sm","mappings":{"default":{"default":"empty set with right arrow above"},"mathspeak":{"default":"empty set with right-arrow above","sbrief":"empty set with R arrow above"}},"key":"29B3"},{"category":"Sm","mappings":{"default":{"default":"empty set with left arrow above"},"mathspeak":{"default":"empty set with left-arrow above","sbrief":"empty set with L arrow above"}},"key":"29B4"},{"category":"Sm","mappings":{"default":{"default":"up arrow through circle"},"mathspeak":{"default":"up-arrow through circle","sbrief":"U arrow through circle"}},"key":"29BD"},{"category":"Sm","mappings":{"default":{"default":"black diamond with down arrow"},"mathspeak":{"default":"black diamond with down-arrow","sbrief":"black diamond with D arrow"}},"key":"29EA"},{"category":"Sm","mappings":{"default":{"default":"white circle with down arrow"},"mathspeak":{"default":"white circle with down-arrow","sbrief":"white circle with D arrow"}},"key":"29EC"},{"category":"Sm","mappings":{"default":{"default":"black circle with down arrow"},"mathspeak":{"default":"black circle with down-arrow","sbrief":"black circle with D arrow"}},"key":"29ED"},{"category":"Sm","mappings":{"default":{"default":"integral with leftwards arrow with hook","short":"integral with left arrow with hook"},"mathspeak":{"default":"integral with left-arrow with hook","sbrief":"integral with L arrow with hook"}},"key":"2A17"},{"category":"So","mappings":{"default":{"default":"north east white arrow"}},"key":"2B00"},{"category":"So","mappings":{"default":{"default":"north west white arrow"}},"key":"2B01"},{"category":"So","mappings":{"default":{"default":"south east white arrow"}},"key":"2B02"},{"category":"So","mappings":{"default":{"default":"south west white arrow"}},"key":"2B03"},{"category":"So","mappings":{"default":{"default":"left right white arrow"},"mathspeak":{"sbrief":"L R white arrow"}},"key":"2B04"},{"category":"So","mappings":{"default":{"default":"leftwards black arrow","short":"left black arrow"},"mathspeak":{"sbrief":"L black arrow"}},"key":"2B05"},{"category":"So","mappings":{"default":{"default":"upwards black arrow","short":"up black arrow"},"mathspeak":{"sbrief":"U black arrow"}},"key":"2B06"},{"category":"So","mappings":{"default":{"default":"downwards black arrow","short":"down black arrow"},"mathspeak":{"sbrief":"D black arrow"}},"key":"2B07"},{"category":"So","mappings":{"default":{"default":"north east black arrow"}},"key":"2B08"},{"category":"So","mappings":{"default":{"default":"north west black arrow"}},"key":"2B09"},{"category":"So","mappings":{"default":{"default":"south east black arrow"}},"key":"2B0A"},{"category":"So","mappings":{"default":{"default":"south west black arrow"}},"key":"2B0B"},{"category":"So","mappings":{"default":{"default":"left right black arrow"},"mathspeak":{"sbrief":"L R black arrow"}},"key":"2B0C"},{"category":"So","mappings":{"default":{"default":"up down black arrow"},"mathspeak":{"sbrief":"U D black arrow"}},"key":"2B0D"},{"category":"So","mappings":{"default":{"default":"rightwards arrow with tip downwards","short":"right arrow with tip down"},"mathspeak":{"default":"right-arrow with tip down","sbrief":"R arrow with tip down"}},"key":"2B0E"},{"category":"So","mappings":{"default":{"default":"rightwards arrow with tip upwards","short":"right arrow with tip up"},"mathspeak":{"default":"right-arrow with tip up","sbrief":"R arrow with tip up"}},"key":"2B0F"},{"category":"So","mappings":{"default":{"default":"leftwards arrow with tip downwards","short":"left arrow with tip down"},"mathspeak":{"default":"left-arrow with tip down","sbrief":"L arrow with tip down"}},"key":"2B10"},{"category":"So","mappings":{"default":{"default":"leftwards arrow with tip upwards","short":"left arrow with tip up"},"mathspeak":{"default":"left-arrow with tip up","sbrief":"L arrow with tip up"}},"key":"2B11"},{"category":"Sm","mappings":{"default":{"default":"left arrow with small circle"},"mathspeak":{"default":"left-arrow with small circle","sbrief":"L arrow with small circle"}},"key":"2B30"},{"category":"Sm","mappings":{"default":{"default":"three leftwards arrows","short":"three left arrows"},"mathspeak":{"default":"three left-arrows","sbrief":"three L arrows"}},"key":"2B31"},{"category":"Sm","mappings":{"default":{"default":"left arrow with circled plus"},"mathspeak":{"default":"left-arrow with circled plus","sbrief":"L arrow with circled plus"}},"key":"2B32"},{"category":"Sm","mappings":{"default":{"default":"long leftwards squiggle arrow","short":"long left squiggle arrow"},"mathspeak":{"sbrief":"long l squiggle arrow"}},"key":"2B33"},{"category":"Sm","mappings":{"default":{"default":"leftwards two headed arrow with vertical stroke","short":"left two headed arrow with vertical stroke"},"mathspeak":{"sbrief":"l two headed arrow with vertical stroke"}},"key":"2B34"},{"category":"Sm","mappings":{"default":{"default":"leftwards two headed arrow with double vertical stroke","short":"left two headed arrow with double vertical stroke"},"mathspeak":{"sbrief":"l two headed arrow with double vertical stroke"}},"key":"2B35"},{"category":"Sm","mappings":{"default":{"default":"leftwards two headed arrow from bar","short":"left two headed arrow from bar"},"mathspeak":{"sbrief":"l two headed arrow from bar"}},"key":"2B36"},{"category":"Sm","mappings":{"default":{"default":"leftwards two headed triple dash arrow","short":"left two headed triple dash arrow"},"mathspeak":{"sbrief":"l two headed triple dash arrow"}},"key":"2B37"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow with dotted stem","short":"left arrow with dotted stem"},"mathspeak":{"default":"left-arrow with dotted stem","sbrief":"L arrow with dotted stem"}},"key":"2B38"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow with tail with vertical stroke","short":"left arrow with tail with vertical stroke"},"mathspeak":{"default":"left-arrow with tail with vertical stroke","sbrief":"L arrow with tail with vertical stroke"}},"key":"2B39"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow with tail with double vertical stroke","short":"left arrow with tail with double vertical stroke"},"mathspeak":{"default":"left-arrow with tail with double vertical stroke","sbrief":"L arrow with tail with double vertical stroke"}},"key":"2B3A"},{"category":"Sm","mappings":{"default":{"default":"leftwards two headed arrow with tail","short":"left two headed arrow with tail"},"mathspeak":{"sbrief":"l two headed arrow with tail"}},"key":"2B3B"},{"category":"Sm","mappings":{"default":{"default":"leftwards two headed arrow with tail with vertical stroke","short":"left two headed arrow with tail with vertical stroke"},"mathspeak":{"sbrief":"l two headed arrow with tail with vertical stroke"}},"key":"2B3C"},{"category":"Sm","mappings":{"default":{"default":"leftwards two headed arrow with tail with double vertical stroke","short":"left two headed arrow with tail with double vertical stroke"},"mathspeak":{"sbrief":"l two headed arrow with tail with double vertical stroke"}},"key":"2B3D"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow through x","short":"left arrow through x"},"mathspeak":{"default":"left-arrow through x","sbrief":"L arrow through x"}},"key":"2B3E"},{"category":"Sm","mappings":{"default":{"default":"wave arrow pointing directly left"}},"key":"2B3F"},{"category":"Sm","mappings":{"default":{"default":"equals sign above leftwards arrow","short":"equals sign above left arrow"},"mathspeak":{"default":"equals sign above left-arrow","sbrief":"equals sign above L arrow"}},"key":"2B40"},{"category":"Sm","mappings":{"default":{"default":"reverse tilde operator above leftwards arrow","short":"reverse tilde operator above left arrow"},"mathspeak":{"default":"reverse tilde operator above left-arrow","sbrief":"reverse tilde operator above L arrow"}},"key":"2B41"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow above reverse almost equals","short":"left arrow above reverse almost equals"},"mathspeak":{"default":"left-arrow above reverse almost equals","sbrief":"L arrow above reverse almost equals"}},"key":"2B42"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow through greater than","short":"right arrow through greater than"},"mathspeak":{"default":"right-arrow through greater than","sbrief":"R arrow through greater than"}},"key":"2B43"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow through superset","short":"right arrow through superset"},"mathspeak":{"default":"right-arrow through superset","sbrief":"R arrow through superset"}},"key":"2B44"},{"category":"So","mappings":{"default":{"default":"leftwards quadruple arrow","short":"left quadruple arrow"},"mathspeak":{"sbrief":"l quadrule arrow"}},"key":"2B45"},{"category":"So","mappings":{"default":{"default":"rightwards quadruple arrow","short":"right quadruple arrow"},"mathspeak":{"sbrief":"r quadrule arrow"}},"key":"2B46"},{"category":"Sm","mappings":{"default":{"default":"reverse tilde operator above rightwards arrow","short":"reverse tilde operator above right arrow"},"mathspeak":{"default":"reverse tilde operator above right-arrow","sbrief":"reverse tilde operator above R arrow"}},"key":"2B47"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow above reverse almost equals","short":"right arrow above reverse almost equals"},"mathspeak":{"default":"right-arrow above reverse almost equals","sbrief":"R arrow above reverse almost equals"}},"key":"2B48"},{"category":"Sm","mappings":{"default":{"default":"tilde operator above leftwards arrow","short":"tilde operator above left arrow"},"mathspeak":{"default":"tilde operator above left-arrow","sbrief":"tilde operator above L arrow"}},"key":"2B49"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow above almost equals","short":"left arrow above almost equals"},"mathspeak":{"default":"left-arrow above almost equals","sbrief":"L arrow above almost equals"}},"key":"2B4A"},{"category":"Sm","mappings":{"default":{"default":"leftwards arrow above reverse tilde operator","short":"left arrow above reverse tilde operator"},"mathspeak":{"default":"left-arrow above reverse tilde operator","sbrief":"L arrow above reverse tilde operator"}},"key":"2B4B"},{"category":"Sm","mappings":{"default":{"default":"rightwards arrow above reverse tilde operator","short":"right arrow above reverse tilde operator"},"mathspeak":{"default":"right-arrow above reverse tilde operator","sbrief":"R arrow above reverse tilde operator"}},"key":"2B4C"},{"category":"Sm","mappings":{"default":{"default":"halfwidth leftwards arrow","short":"halfwidth left arrow"},"mathspeak":{"default":"halfwidth left-arrow","sbrief":"halfwidth L arrow"}},"key":"FFE9"},{"category":"Sm","mappings":{"default":{"default":"halfwidth upwards arrow","short":"halfwidth up arrow"},"mathspeak":{"default":"halfwidth up-arrow","sbrief":"halfwidth U arrow"}},"key":"FFEA"},{"category":"Sm","mappings":{"default":{"default":"halfwidth rightwards arrow","short":"halfwidth right arrow"},"mathspeak":{"default":"halfwidth right-arrow","sbrief":"halfwidth R arrow"}},"key":"FFEB"},{"category":"Sm","mappings":{"default":{"default":"halfwidth downwards arrow","short":"halfwidth down arrow"},"mathspeak":{"default":"halfwidth down-arrow","sbrief":"halfwidth D arrow"}},"key":"FFEC"}]
,
"en/math_characters.js": 
[{"locale":"en"},{"category":"Ll","mappings":{"default":{"default":"script small l","short":"script l"}},"key":"2113"},{"category":"Sm","mappings":{"default":{"default":"script capital p","alternative":"script p","short":"script cap p"},"mathspeak":{"default":"script upper P"}},"key":"2118"},{"category":"Ll","mappings":{"default":{"default":"double struck small pi","short":"double struck pi"}},"key":"213C"},{"category":"Ll","mappings":{"default":{"default":"double struck small gamma","short":"double struck gamma"}},"key":"213D"},{"category":"Lu","mappings":{"default":{"default":"double struck capital gamma","short":"double struck cap gamma"},"mathspeak":{"default":"double struck upper Gamma"}},"key":"213E"},{"category":"Lu","mappings":{"default":{"default":"double struck capital pi","short":"double struck cap pi"},"mathspeak":{"default":"double struck upper Pi"}},"key":"213F"},{"category":"Sm","mappings":{"default":{"default":"double struck n ary summation"}},"key":"2140"},{"category":"Lu","mappings":{"default":{"default":"double struck italic capital d","short":"double struck italic cap d"},"mathspeak":{"default":"double struck italic upper D"}},"key":"2145"},{"category":"Ll","mappings":{"default":{"default":"double struck italic small d","short":"double struck italic d"}},"key":"2146"},{"category":"Ll","mappings":{"default":{"default":"double struck italic small e","short":"double struck italic e"}},"key":"2147"},{"category":"Ll","mappings":{"default":{"default":"double struck italic small i","short":"double struck italic i"}},"key":"2148"},{"category":"Ll","mappings":{"default":{"default":"double struck italic small j","short":"double struck italic j"}},"key":"2149"},{"category":"Ll","mappings":{"default":{"default":"italic small dotless i","short":"italic dotless i"}},"key":"1D6A4"},{"category":"Ll","mappings":{"default":{"default":"italic small dotless j","short":"italic dotless j"}},"key":"1D6A5"}]
,
"en/math_delimiters.js": 
[{"locale":"en"},{"category":"Ps","mappings":{"default":{"default":"left parenthesis","alternative":"opening parenthesis"},"mathspeak":{"default":"left-parenthesis","brief":"left-p'ren","sbrief":"L p'ren"}},"key":"0028"},{"category":"Pe","mappings":{"default":{"default":"right parenthesis","alternative":"closing parenthesis"},"mathspeak":{"default":"right-parenthesis","brief":"right-p'ren","sbrief":"R p'ren"}},"key":"0029"},{"category":"Ps","mappings":{"default":{"default":"left square bracket","alternative":"opening square bracket"},"mathspeak":{"default":"left-bracket","brief":"left-brack","sbrief":"L brack"}},"key":"005B"},{"category":"Pe","mappings":{"default":{"default":"right square bracket","alternative":"closing square bracket"},"mathspeak":{"default":"right-bracket","brief":"right-brack","sbrief":"R brack"}},"key":"005D"},{"category":"Ps","mappings":{"default":{"default":"left curly bracket","alternative":"opening curly bracket"},"mathspeak":{"default":"left-brace","sbrief":"L brace"}},"key":"007B"},{"category":"Pe","mappings":{"default":{"default":"right curly bracket","alternative":"closing curly bracket"},"mathspeak":{"default":"right-brace","sbrief":"R brace"}},"key":"007D"},{"category":"Ps","mappings":{"default":{"default":"left square bracket with quill"},"mathspeak":{"default":"left-bracket with quill","brief":"left-brack with quill","sbrief":"L brack with quill"}},"key":"2045"},{"category":"Pe","mappings":{"default":{"default":"right square bracket with quill"},"mathspeak":{"default":"right-bracket with quill","brief":"right-brack with quill","sbrief":"R brack with quill"}},"key":"2046"},{"category":"Sm","mappings":{"default":{"default":"left ceiling"}},"key":"2308"},{"category":"Sm","mappings":{"default":{"default":"right ceiling"}},"key":"2309"},{"category":"Sm","mappings":{"default":{"default":"left floor"}},"key":"230A"},{"category":"Sm","mappings":{"default":{"default":"right floor"}},"key":"230B"},{"category":"So","mappings":{"default":{"default":"bottom right crop"}},"key":"230C"},{"category":"So","mappings":{"default":{"default":"bottom left crop"}},"key":"230D"},{"category":"So","mappings":{"default":{"default":"top right crop"}},"key":"230E"},{"category":"So","mappings":{"default":{"default":"top left crop"}},"key":"230F"},{"category":"So","mappings":{"default":{"default":"top left corner"}},"key":"231C"},{"category":"So","mappings":{"default":{"default":"top right corner"}},"key":"231D"},{"category":"So","mappings":{"default":{"default":"bottom left corner"}},"key":"231E"},{"category":"So","mappings":{"default":{"default":"bottom right corner"}},"key":"231F"},{"category":"Sm","mappings":{"default":{"default":"top half integral"}},"key":"2320"},{"category":"Sm","mappings":{"default":{"default":"bottom half integral"}},"key":"2321"},{"category":"Ps","mappings":{"default":{"default":"left pointing angle bracket","alternative":"bra"},"mathspeak":{"default":"left pointing angle"}},"key":"2329"},{"category":"Pe","mappings":{"default":{"default":"right pointing angle bracket","alternative":"ket"},"mathspeak":{"default":"right pointing angle"}},"key":"232A"},{"category":"Sm","mappings":{"default":{"default":"left parenthesis upper hook"},"mathspeak":{"default":"left-parenthesis upper hook","brief":"left-p'ren upper hook","sbrief":"L p'ren upper hook"}},"key":"239B"},{"category":"Sm","mappings":{"default":{"default":"left parenthesis extension"},"mathspeak":{"default":"left-parenthesis extension","brief":"left-p'ren extension","sbrief":"L p'ren extension"}},"key":"239C"},{"category":"Sm","mappings":{"default":{"default":"left parenthesis lower hook"},"mathspeak":{"default":"left-parenthesis lower hook","brief":"left-p'ren lower hook","sbrief":"L p'ren lower hook"}},"key":"239D"},{"category":"Sm","mappings":{"default":{"default":"right parenthesis upper hook"},"mathspeak":{"default":"right-parenthesis upper hook","brief":"right-p'ren upper hook","sbrief":"R p'ren upper hook"}},"key":"239E"},{"category":"Sm","mappings":{"default":{"default":"right parenthesis extension"},"mathspeak":{"default":"right-parenthesis extension","brief":"right-p'ren extension","sbrief":"R p'ren extension"}},"key":"239F"},{"category":"Sm","mappings":{"default":{"default":"right parenthesis lower hook"},"mathspeak":{"default":"right-parenthesis lower hook","brief":"right-p'ren lower hook","sbrief":"R p'ren lower hook"}},"key":"23A0"},{"category":"Sm","mappings":{"default":{"default":"left square bracket upper corner"},"mathspeak":{"default":"left-bracket upper corner","brief":"left-brack upper corner","sbrief":"L brack upper corner"}},"key":"23A1"},{"category":"Sm","mappings":{"default":{"default":"left square bracket extension"},"mathspeak":{"default":"left-bracket extension","brief":"left-brack extension","sbrief":"L brack extension"}},"key":"23A2"},{"category":"Sm","mappings":{"default":{"default":"left square bracket lower corner"},"mathspeak":{"default":"left-bracket lower corner","brief":"left-brack lower corner","sbrief":"L brack lower corner"}},"key":"23A3"},{"category":"Sm","mappings":{"default":{"default":"right square bracket upper corner"},"mathspeak":{"default":"right-bracket upper corner","brief":"right-brack upper corner","sbrief":"R brack upper corner"}},"key":"23A4"},{"category":"Sm","mappings":{"default":{"default":"right square bracket extension"},"mathspeak":{"default":"right-bracket extension","brief":"right-brack extension","sbrief":"R brack extension"}},"key":"23A5"},{"category":"Sm","mappings":{"default":{"default":"right square bracket lower corner"},"mathspeak":{"default":"right-bracket lower corner","brief":"right-brack lower corner","sbrief":"R brack lower corner"}},"key":"23A6"},{"category":"Sm","mappings":{"default":{"default":"left curly bracket upper hook"},"mathspeak":{"default":"left-brace upper hook","sbrief":"L brace upper hook"}},"key":"23A7"},{"category":"Sm","mappings":{"default":{"default":"left curly bracket middle piece"},"mathspeak":{"default":"left-brace middle piece","sbrief":"L brace middle piece"}},"key":"23A8"},{"category":"Sm","mappings":{"default":{"default":"left curly bracket lower hook"},"mathspeak":{"default":"left-brace lower hook","sbrief":"L brace lower hook"}},"key":"23A9"},{"category":"Sm","mappings":{"default":{"default":"curly bracket extension"},"mathspeak":{"default":"brace extension"}},"key":"23AA"},{"category":"Sm","mappings":{"default":{"default":"right curly bracket upper hook"},"mathspeak":{"default":"right-brace upper hook","sbrief":"R brace upper hook"}},"key":"23AB"},{"category":"Sm","mappings":{"default":{"default":"right curly bracket middle piece"},"mathspeak":{"default":"right-brace middle piece","sbrief":"R brace middle piece"}},"key":"23AC"},{"category":"Sm","mappings":{"default":{"default":"right curly bracket lower hook"},"mathspeak":{"default":"right-brace lower hook","sbrief":"R brace lower hook"}},"key":"23AD"},{"category":"Sm","mappings":{"default":{"default":"integral extension"}},"key":"23AE"},{"category":"Sm","mappings":{"default":{"default":"horizontal line extension"}},"key":"23AF"},{"category":"Sm","mappings":{"default":{"default":"upper left or lower right curly bracket section"},"mathspeak":{"default":"upper left or lower right-brace section"}},"key":"23B0"},{"category":"Sm","mappings":{"default":{"default":"upper right or lower left curly bracket section"},"mathspeak":{"default":"upper right or lower left-brace section"}},"key":"23B1"},{"category":"Sm","mappings":{"default":{"default":"summation top"}},"key":"23B2"},{"category":"Sm","mappings":{"default":{"default":"summation bottom"}},"key":"23B3"},{"category":"So","mappings":{"default":{"default":"top square bracket"},"mathspeak":{"default":"top-bracket","brief":"top-brack","sbrief":"T brack"}},"key":"23B4"},{"category":"So","mappings":{"default":{"default":"bottom square bracket"},"mathspeak":{"default":"bottom-bracket","brief":"bottom-brack","sbrief":"B brack"}},"key":"23B5"},{"category":"So","mappings":{"default":{"default":"bottom square bracket over top square bracket"},"mathspeak":{"default":"bottom-bracket over top-bracket","brief":"bottom-brack over top-brack","sbrief":"B brack over T brack"}},"key":"23B6"},{"category":"So","mappings":{"default":{"default":"radical symbol bottom"}},"key":"23B7"},{"category":"So","mappings":{"default":{"default":"left vertical box line"}},"key":"23B8"},{"category":"So","mappings":{"default":{"default":"right vertical box line"}},"key":"23B9"},{"category":"Sm","mappings":{"default":{"default":"top parenthesis"},"mathspeak":{"default":"top-parenthesis","brief":"top-p'ren","sbrief":"t p'ren"}},"key":"23DC"},{"category":"Sm","mappings":{"default":{"default":"bottom parenthesis"},"mathspeak":{"default":"bottom-parenthesis","brief":"bottom-p'ren","sbrief":"b p'ren"}},"key":"23DD"},{"category":"Sm","mappings":{"default":{"default":"top curly bracket"},"mathspeak":{"default":"top-brace","sbrief":"T brace"}},"key":"23DE"},{"category":"Sm","mappings":{"default":{"default":"bottom curly bracket"},"mathspeak":{"default":"bottom-brace","sbrief":"B brace"}},"key":"23DF"},{"category":"Sm","mappings":{"default":{"default":"top tortoise shell bracket"}},"key":"23E0"},{"category":"Sm","mappings":{"default":{"default":"bottom tortoise shell bracket"}},"key":"23E1"},{"category":"Ps","mappings":{"default":{"default":"medium left parenthesis ornament"},"mathspeak":{"default":"medium left-parenthesis ornament","brief":"medium left-p'ren ornament","sbrief":"medium L p'ren ornament"}},"key":"2768"},{"category":"Pe","mappings":{"default":{"default":"medium right parenthesis ornament"},"mathspeak":{"default":"medium right-parenthesis ornament","brief":"medium right-p'ren ornament","sbrief":"medium R p'ren ornament"}},"key":"2769"},{"category":"Ps","mappings":{"default":{"default":"medium flattened left parenthesis ornament"},"mathspeak":{"default":"medium flattened left-parenthesis ornament","brief":"medium flattened left-p'ren ornament","sbrief":"medium flattened L p'ren ornament"}},"key":"276A"},{"category":"Pe","mappings":{"default":{"default":"medium flattened right parenthesis ornament"},"mathspeak":{"default":"medium flattened right-parenthesis ornament","brief":"medium flattened right-p'ren ornament","sbrief":"medium flattened R p'ren ornament"}},"key":"276B"},{"category":"Ps","mappings":{"default":{"default":"medium left pointing angle bracket ornament"},"mathspeak":{"default":"medium left pointing angle ornament"}},"key":"276C"},{"category":"Pe","mappings":{"default":{"default":"medium right pointing angle bracket ornament"},"mathspeak":{"default":"medium right pointing angle ornament"}},"key":"276D"},{"category":"Ps","mappings":{"default":{"default":"heavy left pointing angle quotation mark ornament"}},"key":"276E"},{"category":"Pe","mappings":{"default":{"default":"heavy right pointing angle quotation mark ornament"}},"key":"276F"},{"category":"Ps","mappings":{"default":{"default":"heavy left pointing angle bracket ornament"},"mathspeak":{"default":"heavy left pointing angle ornament"}},"key":"2770"},{"category":"Pe","mappings":{"default":{"default":"heavy right pointing angle bracket ornament"},"mathspeak":{"default":"heavy right pointing angle ornament"}},"key":"2771"},{"category":"Ps","mappings":{"default":{"default":"light left tortoise shell bracket ornament"}},"key":"2772"},{"category":"Pe","mappings":{"default":{"default":"light right tortoise shell bracket ornament"}},"key":"2773"},{"category":"Ps","mappings":{"default":{"default":"medium left curly bracket ornament"},"mathspeak":{"default":"medium left-brace ornament","sbrief":"medium L brace ornament"}},"key":"2774"},{"category":"Pe","mappings":{"default":{"default":"medium right curly bracket ornament"},"mathspeak":{"default":"medium right-brace ornament","sbrief":"medium R brace ornament"}},"key":"2775"},{"category":"Ps","mappings":{"default":{"default":"left s shaped bag delimiter"}},"key":"27C5"},{"category":"Pe","mappings":{"default":{"default":"right s shaped bag delimiter"}},"key":"27C6"},{"category":"Ps","mappings":{"default":{"default":"mathematical left white square bracket"},"mathspeak":{"default":"mathematical left white bracket"}},"key":"27E6"},{"category":"Pe","mappings":{"default":{"default":"mathematical right white square bracket"},"mathspeak":{"default":"mathematical right white bracket"}},"key":"27E7"},{"category":"Ps","mappings":{"default":{"default":"mathematical left angle bracket"},"mathspeak":{"default":"mathematical left-angle","sbrief":"mathematical l angle"}},"key":"27E8"},{"category":"Pe","mappings":{"default":{"default":"mathematical right angle bracket"},"mathspeak":{"default":"mathematical right-angle","sbrief":"mathematical r angle"}},"key":"27E9"},{"category":"Ps","mappings":{"default":{"default":"mathematical left double angle bracket"},"mathspeak":{"default":"mathematical left double angle"}},"key":"27EA"},{"category":"Pe","mappings":{"default":{"default":"mathematical right double angle bracket"},"mathspeak":{"default":"mathematical right double angle"}},"key":"27EB"},{"category":"Ps","mappings":{"default":{"default":"mathematical left white tortoise shell bracket"}},"key":"27EC"},{"category":"Pe","mappings":{"default":{"default":"mathematical right white tortoise shell bracket"}},"key":"27ED"},{"category":"Ps","mappings":{"default":{"default":"mathematical left flattened parenthesis"},"mathspeak":{"default":"mathematical flattened left-parenthesis","brief":"mathematical flattened left-p'ren","sbrief":"mathematical flattened L p'ren"}},"key":"27EE"},{"category":"Pe","mappings":{"default":{"default":"mathematical right flattened parenthesis"},"mathspeak":{"default":"mathematical flattened right-parenthesis","brief":"mathematical flattened right-p'ren","sbrief":"mathematical flattened R p'ren"}},"key":"27EF"},{"category":"Ps","mappings":{"default":{"default":"left white curly bracket"},"mathspeak":{"default":"left white brace"}},"key":"2983"},{"category":"Pe","mappings":{"default":{"default":"right white curly bracket"},"mathspeak":{"default":"right white brace"}},"key":"2984"},{"category":"Ps","mappings":{"default":{"default":"left white parenthesis"},"mathspeak":{"default":"white left-parenthesis","brief":"white left-p'ren","sbrief":"white L p'ren"}},"key":"2985"},{"category":"Pe","mappings":{"default":{"default":"right white parenthesis"},"mathspeak":{"default":"white right-parenthesis","brief":"white right-p'ren","sbrief":"white R p'ren"}},"key":"2986"},{"category":"Ps","mappings":{"default":{"default":"z notation left image bracket"}},"key":"2987"},{"category":"Pe","mappings":{"default":{"default":"z notation right image bracket"}},"key":"2988"},{"category":"Ps","mappings":{"default":{"default":"z notation left binding bracket"}},"key":"2989"},{"category":"Pe","mappings":{"default":{"default":"z notation right binding bracket"}},"key":"298A"},{"category":"Ps","mappings":{"default":{"default":"left square bracket with underbar"},"mathspeak":{"default":"left-bracket with underbar","brief":"left-brack with underbar","sbrief":"L brack with underbar"}},"key":"298B"},{"category":"Pe","mappings":{"default":{"default":"right square bracket with underbar"},"mathspeak":{"default":"right-bracket with underbar","brief":"right-brack with underbar","sbrief":"R brack with underbar"}},"key":"298C"},{"category":"Ps","mappings":{"default":{"default":"left square bracket with tick in top corner"},"mathspeak":{"default":"left-bracket with tick in top corner","brief":"left-brack with tick in top corner","sbrief":"L brack with tick in top corner"}},"key":"298D"},{"category":"Pe","mappings":{"default":{"default":"right square bracket with tick in bottom corner"},"mathspeak":{"default":"right-bracket with tick in bottom corner","brief":"right-brack with tick in bottom corner","sbrief":"R brack with tick in bottom corner"}},"key":"298E"},{"category":"Ps","mappings":{"default":{"default":"left square bracket with tick in bottom corner"},"mathspeak":{"default":"left-bracket with tick in bottom corner","brief":"left-brack with tick in bottom corner","sbrief":"L brack with tick in bottom corner"}},"key":"298F"},{"category":"Pe","mappings":{"default":{"default":"right square bracket with tick in top corner"},"mathspeak":{"default":"right-bracket with tick in top corner","brief":"right-brack with tick in top corner","sbrief":"R brack with tick in top corner"}},"key":"2990"},{"category":"Ps","mappings":{"default":{"default":"left angle bracket with dot"},"mathspeak":{"default":"left-angle with dot","sbrief":"l angle with dot"}},"key":"2991"},{"category":"Pe","mappings":{"default":{"default":"right angle bracket with dot"},"mathspeak":{"default":"right-angle with dot","sbrief":"r angle with dot"}},"key":"2992"},{"category":"Ps","mappings":{"default":{"default":"left arc less than bracket"}},"key":"2993"},{"category":"Pe","mappings":{"default":{"default":"right arc greater than bracket"}},"key":"2994"},{"category":"Ps","mappings":{"default":{"default":"double left arc greater than bracket"}},"key":"2995"},{"category":"Pe","mappings":{"default":{"default":"double right arc less than bracket"}},"key":"2996"},{"category":"Ps","mappings":{"default":{"default":"left black tortoise shell bracket"}},"key":"2997"},{"category":"Pe","mappings":{"default":{"default":"right black tortoise shell bracket"}},"key":"2998"},{"category":"Ps","mappings":{"default":{"default":"left wiggly fence"}},"key":"29D8"},{"category":"Pe","mappings":{"default":{"default":"right wiggly fence"}},"key":"29D9"},{"category":"Ps","mappings":{"default":{"default":"left double wiggly fence"}},"key":"29DA"},{"category":"Pe","mappings":{"default":{"default":"right double wiggly fence"}},"key":"29DB"},{"category":"Ps","mappings":{"default":{"default":"left pointing curved angle bracket"},"mathspeak":{"default":"left pointing curved angle"}},"key":"29FC"},{"category":"Pe","mappings":{"default":{"default":"right pointing curved angle bracket"},"mathspeak":{"default":"right pointing curved angle"}},"key":"29FD"},{"category":"Ps","mappings":{"default":{"default":"top left half bracket"},"mathspeak":{"default":"top half left-bracket","brief":"top half left-brack","sbrief":"top half L brack"}},"key":"2E22"},{"category":"Pe","mappings":{"default":{"default":"top right half bracket"},"mathspeak":{"default":"top half right-bracket","brief":"top half right-brack","sbrief":"top half R brack"}},"key":"2E23"},{"category":"Ps","mappings":{"default":{"default":"bottom left half bracket"},"mathspeak":{"default":"bottom half left-bracket","brief":"bottom half left-brack","sbrief":"bottom half L brack"}},"key":"2E24"},{"category":"Pe","mappings":{"default":{"default":"bottom right half bracket"},"mathspeak":{"default":"bottom half right-bracket","brief":"bottom half right-brack","sbrief":"bottom half R brack"}},"key":"2E25"},{"category":"Ps","mappings":{"default":{"default":"left sideways U bracket"}},"key":"2E26"},{"category":"Pe","mappings":{"default":{"default":"right sideways U bracket"}},"key":"2E27"},{"category":"Ps","mappings":{"default":{"default":"left double parenthesis"},"mathspeak":{"default":"double left-parenthesis","brief":"double left-p'ren","sbrief":"double L p'ren"}},"key":"2E28"},{"category":"Pe","mappings":{"default":{"default":"right double parenthesis"},"mathspeak":{"default":"double right-parenthesis","brief":"double right-p'ren","sbrief":"double R p'ren"}},"key":"2E29"},{"category":"Ps","mappings":{"default":{"default":"left angle bracket","alternative":"opening angle bracket"},"mathspeak":{"default":"left-angle","sbrief":"l angle"}},"key":"3008"},{"category":"Pe","mappings":{"default":{"default":"right angle bracket","alternative":"closing angle bracket"},"mathspeak":{"default":"right-angle","sbrief":"r angle"}},"key":"3009"},{"category":"Ps","mappings":{"default":{"default":"left double angle bracket","alternative":"opening double angle bracket"},"mathspeak":{"default":"left double angle"}},"key":"300A"},{"category":"Pe","mappings":{"default":{"default":"right double angle bracket","alternative":"closing double angle bracket"},"mathspeak":{"default":"right double angle"}},"key":"300B"},{"category":"Ps","mappings":{"default":{"default":"left corner bracket","alternative":"opening corner bracket"}},"key":"300C"},{"category":"Pe","mappings":{"default":{"default":"right corner bracket","alternative":"closing corner bracket"}},"key":"300D"},{"category":"Ps","mappings":{"default":{"default":"left white corner bracket","alternative":"opening white corner bracket"}},"key":"300E"},{"category":"Pe","mappings":{"default":{"default":"right white corner bracket","alternative":"closing white corner bracket"}},"key":"300F"},{"category":"Ps","mappings":{"default":{"default":"left black lenticular bracket","alternative":"opening black lenticular bracket"}},"key":"3010"},{"category":"Pe","mappings":{"default":{"default":"right black lenticular bracket","alternative":"closing black lenticular bracket"}},"key":"3011"},{"category":"Ps","mappings":{"default":{"default":"left tortoise shell bracket","alternative":"opening tortoise shell bracket"}},"key":"3014"},{"category":"Pe","mappings":{"default":{"default":"right tortoise shell bracket","alternative":"closing tortoise shell bracket"}},"key":"3015"},{"category":"Ps","mappings":{"default":{"default":"left white lenticular bracket","alternative":"opening white lenticular bracket"}},"key":"3016"},{"category":"Pe","mappings":{"default":{"default":"right white lenticular bracket","alternative":"closing white lenticular bracket"}},"key":"3017"},{"category":"Ps","mappings":{"default":{"default":"left white tortoise shell bracket","alternative":"opening white tortoise shell bracket"}},"key":"3018"},{"category":"Pe","mappings":{"default":{"default":"right white tortoise shell bracket","alternative":"closing white tortoise shell bracket"}},"key":"3019"},{"category":"Ps","mappings":{"default":{"default":"left white square bracket","alternative":"opening white square bracket"},"mathspeak":{"default":"left white bracket"}},"key":"301A"},{"category":"Pe","mappings":{"default":{"default":"right white square bracket","alternative":"closing white square bracket"},"mathspeak":{"default":"right white bracket"}},"key":"301B"},{"category":"Ps","mappings":{"default":{"default":"reversed double prime quotation mark"}},"key":"301D"},{"category":"Pe","mappings":{"default":{"default":"double prime quotation mark"}},"key":"301E"},{"category":"Pe","mappings":{"default":{"default":"low double prime quotation mark"}},"key":"301F"},{"category":"Ps","mappings":{"default":{"default":"ornate left parenthesis"},"mathspeak":{"default":"ornate left-parenthesis","brief":"ornate left-p'ren","sbrief":"ornate L p'ren"}},"key":"FD3E"},{"category":"Pe","mappings":{"default":{"default":"ornate right parenthesis"},"mathspeak":{"default":"ornate right-parenthesis","brief":"ornate right-p'ren","sbrief":"ornate R p'ren"}},"key":"FD3F"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left white lenticular bracket"}},"key":"FE17"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right white lenticular brakcet"}},"key":"FE18"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left parenthesis","alternative":"glyph for vertical opening parenthesis"},"mathspeak":{"default":"presentation form for vertical left-parenthesis","brief":"presentation form for vertical left-p'ren","sbrief":"presentation form for vertical L p'ren"}},"key":"FE35"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right parenthesis","alternative":"glyph for vertical closing parenthesis"},"mathspeak":{"default":"presentation form for vertical right-parenthesis","brief":"presentation form for vertical right-p'ren","sbrief":"presentation form for vertical R p'ren"}},"key":"FE36"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left curly bracket","alternative":"glyph for vertical opening curly bracket"},"mathspeak":{"default":"presentation form for vertical left-brace","sbrief":"presentation form for vertical L brace"}},"key":"FE37"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right curly bracket","alternative":"glyph for vertical closing curly bracket"},"mathspeak":{"default":"presentation form for vertical right-brace","sbrief":"presentation form for vertical r brace"}},"key":"FE38"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left tortoise shell bracket","alternative":"glyph for vertical opening tortoise shell bracket"}},"key":"FE39"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right tortoise shell bracket","alternative":"glyph for vertical closing tortoise shell bracket"}},"key":"FE3A"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left black lenticular bracket","alternative":"glyph for vertical opening black lenticular bracket"}},"key":"FE3B"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right black lenticular bracket","alternative":"glyph for vertical closing black lenticular bracket"}},"key":"FE3C"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left double angle bracket","alternative":"glyph for vertical opening double angle bracket"},"mathspeak":{"default":"presentation form for vertical left double angle"}},"key":"FE3D"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right double angle bracket","alternative":"glyph for vertical closing double angle bracket"},"mathspeak":{"default":"presentation form for vertical right double angle"}},"key":"FE3E"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left angle bracket","alternative":"glyph for vertical opening angle bracket"},"mathspeak":{"default":"presentation form for vertical left-angle","sbrief":"presentation form for vertical l angle"}},"key":"FE3F"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right angle bracket","alternative":"glyph for vertical closing angle bracket"},"mathspeak":{"default":"presentation form for vertical right-angle","sbrief":"presentation form for vertical r angle"}},"key":"FE40"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left corner bracket","alternative":"glyph for vertical opening corner bracket"}},"key":"FE41"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right corner bracket","alternative":"glyph for vertical closing corner bracket"}},"key":"FE42"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left white corner bracket","alternative":"glyph for vertical opening white corner bracket"}},"key":"FE43"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right white corner bracket","alternative":"glyph for vertical closing white corner bracket"}},"key":"FE44"},{"category":"Ps","mappings":{"default":{"default":"presentation form for vertical left square bracket"},"mathspeak":{"default":"presentation form for vertical left-bracket","brief":"presentation form for vertical left-brack","sbrief":"presentation form for vertical L brack"}},"key":"FE47"},{"category":"Pe","mappings":{"default":{"default":"presentation form for vertical right square bracket"},"mathspeak":{"default":"presentation form for vertical right-bracket","brief":"presentation form for vertical right-brack","sbrief":"presentation form for vertical r brack"}},"key":"FE48"},{"category":"Ps","mappings":{"default":{"default":"small left parenthesis","alternative":"small opening parenthesis"},"mathspeak":{"default":"small left-parenthesis","brief":"small left-p'ren","sbrief":"small L p'ren"}},"key":"FE59"},{"category":"Pe","mappings":{"default":{"default":"small right parenthesis","alternative":"small closing parenthesis"},"mathspeak":{"default":"small right-parenthesis","brief":"small right-p'ren","sbrief":"small R p'ren"}},"key":"FE5A"},{"category":"Ps","mappings":{"default":{"default":"small left curly bracket","alternative":"small opening curly bracket"},"mathspeak":{"default":"small left-brace","sbrief":"small L brace"}},"key":"FE5B"},{"category":"Pe","mappings":{"default":{"default":"small right curly bracket","alternative":"small closing curly bracket"},"mathspeak":{"default":"small right-brace","sbrief":"small r brace"}},"key":"FE5C"},{"category":"Ps","mappings":{"default":{"default":"small left tortoise shell bracket","alternative":"small opening tortoise shell bracket"}},"key":"FE5D"},{"category":"Pe","mappings":{"default":{"default":"small right tortoise shell bracket","alternative":"small closing tortoise shell bracket"}},"key":"FE5E"},{"category":"Ps","mappings":{"default":{"default":"fullwidth left parenthesis","alternative":"fullwidth opening parenthesis"},"mathspeak":{"default":"fullwidth left-parenthesis","brief":"fullwidth left-p'ren","sbrief":"fullwidth L p'ren"}},"key":"FF08"},{"category":"Pe","mappings":{"default":{"default":"fullwidth right parenthesis","alternative":"fullwidth closing parenthesis"},"mathspeak":{"default":"fullwidth right-parenthesis","brief":"fullwidth right-p'ren","sbrief":"fullwidth R p'ren"}},"key":"FF09"},{"category":"Ps","mappings":{"default":{"default":"fullwidth left square bracket","alternative":"fullwidth opening square bracket"},"mathspeak":{"default":"fullwidth left-bracket","brief":"fullwidth left-brack","sbrief":"fullwidth L brack"}},"key":"FF3B"},{"category":"Pe","mappings":{"default":{"default":"fullwidth right square bracket","alternative":"fullwidth closing square bracket"},"mathspeak":{"default":"fullwidth right-bracket","brief":"fullwidth right-brack","sbrief":"fullwidth r brack"}},"key":"FF3D"},{"category":"Ps","mappings":{"default":{"default":"fullwidth left curly bracket","alternative":"fullwidth opening curly bracket"},"mathspeak":{"default":"fullwidth left-brace","sbrief":"fullwidth L brace"}},"key":"FF5B"},{"category":"Pe","mappings":{"default":{"default":"fullwidth right curly bracket","alternative":"fullwidth closing curly bracket"},"mathspeak":{"default":"fullwidth right-brace","sbrief":"fullwidth r brace"}},"key":"FF5D"},{"category":"Ps","mappings":{"default":{"default":"fullwidth white left parenthesis"},"mathspeak":{"default":"fullwidth white left-parenthesis","brief":"fullwidth white left-p'ren","sbrief":"fullwidth white L p'ren"}},"key":"FF5F"},{"category":"Pe","mappings":{"default":{"default":"fullwidth white right parenthesis"},"mathspeak":{"default":"fullwidth white right-parenthesis","brief":"fullwidth white right-p'ren","sbrief":"fullwidth white R p'ren"}},"key":"FF60"},{"category":"Ps","mappings":{"default":{"default":"halfwidth left corner bracket","alternative":"halfwidth opening corner bracket"}},"key":"FF62"},{"category":"Pe","mappings":{"default":{"default":"halfwidth right corner bracket","alternative":"halfwidth closing corner bracket"}},"key":"FF63"}]
,
"en/math_digits.js": 
[{"locale":"en"},{"category":"Nd","mappings":{"default":{"default":"digit zero","short":"zero"},"mathspeak":{"default":"0"}},"key":"0030"},{"category":"Nd","mappings":{"default":{"default":"digit one","short":"one"},"mathspeak":{"default":"1"}},"key":"0031"},{"category":"Nd","mappings":{"default":{"default":"digit two","short":"two"},"mathspeak":{"default":"2"}},"key":"0032"},{"category":"Nd","mappings":{"default":{"default":"digit three","short":"three"},"mathspeak":{"default":"3"}},"key":"0033"},{"category":"Nd","mappings":{"default":{"default":"digit four","short":"four"},"mathspeak":{"default":"4"}},"key":"0034"},{"category":"Nd","mappings":{"default":{"default":"digit five","short":"five"},"mathspeak":{"default":"5"}},"key":"0035"},{"category":"Nd","mappings":{"default":{"default":"digit six","short":"six"},"mathspeak":{"default":"6"}},"key":"0036"},{"category":"Nd","mappings":{"default":{"default":"digit seven","short":"seven"},"mathspeak":{"default":"7"}},"key":"0037"},{"category":"Nd","mappings":{"default":{"default":"digit eight","short":"eight"},"mathspeak":{"default":"8"}},"key":"0038"},{"category":"Nd","mappings":{"default":{"default":"digit nine","short":"nine"},"mathspeak":{"default":"9"}},"key":"0039"},{"category":"No","mappings":{"default":{"default":"superscript digit two","alternative":"superscript two","short":"square"},"mathspeak":{"default":"9"}},"key":"00B2"},{"category":"No","mappings":{"default":{"default":"superscript digit three","alternative":"superscript three","short":"cube"}},"key":"00B3"},{"category":"No","mappings":{"default":{"default":"superscript digit one","alternative":"superscript one","short":"super one"}},"key":"00B9"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one quarter","alternative":"fraction one quarter","short":"one quarter"}},"key":"00BC"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one half","alternative":"fraction one half","short":"one half"}},"key":"00BD"},{"category":"No","mappings":{"default":{"default":"vulgar fraction three quarters","alternative":"fraction three quarters","short":"three quarters"}},"key":"00BE"},{"category":"No","mappings":{"default":{"default":"superscript zero","short":"super zero"}},"key":"2070"},{"category":"No","mappings":{"default":{"default":"superscript digit four","alternative":"superscript four","short":"super four"}},"key":"2074"},{"category":"No","mappings":{"default":{"default":"superscript digit five","alternative":"superscript five","short":"super five"}},"key":"2075"},{"category":"No","mappings":{"default":{"default":"superscript digit six","alternative":"superscript six","short":"super six"}},"key":"2076"},{"category":"No","mappings":{"default":{"default":"superscript digit seven","alternative":"superscript seven","short":"super seven"}},"key":"2077"},{"category":"No","mappings":{"default":{"default":"superscript digit eight","alternative":"superscript eight","short":"super eight"}},"key":"2078"},{"category":"No","mappings":{"default":{"default":"superscript digit nine","alternative":"superscript nine","short":"super nine"}},"key":"2079"},{"category":"No","mappings":{"default":{"default":"subscript digit zero","alternative":"subscript zero","short":"sub zero"}},"key":"2080"},{"category":"No","mappings":{"default":{"default":"subscript digit one","alternative":"subscript one","short":"sub one"}},"key":"2081"},{"category":"No","mappings":{"default":{"default":"subscript digit two","alternative":"subscript two","short":"sub two"}},"key":"2082"},{"category":"No","mappings":{"default":{"default":"subscript digit three","alternative":"subscript three","short":"sub three"}},"key":"2083"},{"category":"No","mappings":{"default":{"default":"subscript digit four","alternative":"subscript four","short":"sub four"}},"key":"2084"},{"category":"No","mappings":{"default":{"default":"subscript digit five","alternative":"subscript five","short":"sub five"}},"key":"2085"},{"category":"No","mappings":{"default":{"default":"subscript digit six","alternative":"subscript six","short":"sub six"}},"key":"2086"},{"category":"No","mappings":{"default":{"default":"subscript digit seven","alternative":"subscript seven","short":"sub seven"}},"key":"2087"},{"category":"No","mappings":{"default":{"default":"subscript digit eight","alternative":"subscript eight","short":"sub eight"}},"key":"2088"},{"category":"No","mappings":{"default":{"default":"subscript digit nine","alternative":"subscript nine","short":"sub nine"}},"key":"2089"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one seventh","short":"one seventh"}},"key":"2150"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one ninth","short":"one ninth"}},"key":"2151"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one tenth","short":"one tenth"}},"key":"2152"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one third","alternative":"fraction one third","short":"one third"}},"key":"2153"},{"category":"No","mappings":{"default":{"default":"vulgar fraction two thirds","alternative":"fraction two thirds","short":"two thirds"}},"key":"2154"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one fifth","alternative":"fraction one fifth","short":"one fifth"}},"key":"2155"},{"category":"No","mappings":{"default":{"default":"vulgar fraction two fifths","alternative":"fraction two fifths","short":"two fifths"}},"key":"2156"},{"category":"No","mappings":{"default":{"default":"vulgar fraction three fifths","alternative":"fraction three fifths","short":"three fifths"}},"key":"2157"},{"category":"No","mappings":{"default":{"default":"vulgar fraction four fifths","alternative":"fraction four fifths","short":"four fifths"}},"key":"2158"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one sixth","alternative":"fraction one sixth","short":"one sixth"}},"key":"2159"},{"category":"No","mappings":{"default":{"default":"vulgar fraction five sixths","alternative":"fraction five sixths","short":"five sixths"}},"key":"215A"},{"category":"No","mappings":{"default":{"default":"vulgar fraction one eighth","alternative":"fraction one eighth","short":"one eighth"}},"key":"215B"},{"category":"No","mappings":{"default":{"default":"vulgar fraction three eighths","alternative":"fraction three eighths","short":"three eighths"}},"key":"215C"},{"category":"No","mappings":{"default":{"default":"vulgar fraction five eighths","alternative":"fraction five eighths","short":"five eighths"}},"key":"215D"},{"category":"No","mappings":{"default":{"default":"vulgar fraction seven eighths","alternative":"fraction seven eighths","short":"seven eighths"}},"key":"215E"},{"category":"No","mappings":{"default":{"default":"fraction numerator one","short":"numerator one"}},"key":"215F"},{"category":"No","mappings":{"default":{"default":"vulgar fraction zero thirds","short":"zero thirds"}},"key":"2189"},{"category":"No","mappings":{"default":{"default":"circled digit one","short":"circled one"},"mathspeak":{"default":"circled 1"}},"key":"2460"},{"category":"No","mappings":{"default":{"default":"circled digit two","short":"circled two"},"mathspeak":{"default":"circled 2"}},"key":"2461"},{"category":"No","mappings":{"default":{"default":"circled digit three","short":"circled three"},"mathspeak":{"default":"circled 3"}},"key":"2462"},{"category":"No","mappings":{"default":{"default":"circled digit four","short":"circled four"},"mathspeak":{"default":"circled 4"}},"key":"2463"},{"category":"No","mappings":{"default":{"default":"circled digit five","short":"circled five"},"mathspeak":{"default":"circled 5"}},"key":"2464"},{"category":"No","mappings":{"default":{"default":"circled digit six","short":"circled six"},"mathspeak":{"default":"circled 6"}},"key":"2465"},{"category":"No","mappings":{"default":{"default":"circled digit seven","short":"circled seven"},"mathspeak":{"default":"circled 7"}},"key":"2466"},{"category":"No","mappings":{"default":{"default":"circled digit eight","short":"circled eight"},"mathspeak":{"default":"circled 8"}},"key":"2467"},{"category":"No","mappings":{"default":{"default":"circled digit nine","short":"circled nine"},"mathspeak":{"default":"circled 9"}},"key":"2468"},{"category":"No","mappings":{"default":{"default":"circled number ten","short":"circled ten"},"mathspeak":{"default":"circled 10"}},"key":"2469"},{"category":"No","mappings":{"default":{"default":"circled number eleven","short":"circled eleven"},"mathspeak":{"default":"circled 11"}},"key":"246A"},{"category":"No","mappings":{"default":{"default":"circled number twelve","short":"circled twelve"},"mathspeak":{"default":"circled 12"}},"key":"246B"},{"category":"No","mappings":{"default":{"default":"circled number thirteen","short":"circled thirteen"},"mathspeak":{"default":"circled 13"}},"key":"246C"},{"category":"No","mappings":{"default":{"default":"circled number fourteen","short":"circled fourteen"},"mathspeak":{"default":"circled 14"}},"key":"246D"},{"category":"No","mappings":{"default":{"default":"circled number fifteen","short":"circled fifteen"},"mathspeak":{"default":"circled 15"}},"key":"246E"},{"category":"No","mappings":{"default":{"default":"circled number sixteen","short":"circled sixteen"},"mathspeak":{"default":"circled 16"}},"key":"246F"},{"category":"No","mappings":{"default":{"default":"circled number seventeen","short":"circled seventeen"},"mathspeak":{"default":"circled 17"}},"key":"2470"},{"category":"No","mappings":{"default":{"default":"circled number eighteen","short":"circled eighteen"},"mathspeak":{"default":"circled 18"}},"key":"2471"},{"category":"No","mappings":{"default":{"default":"circled number nineteen","short":"circled nineteen"},"mathspeak":{"default":"circled 19"}},"key":"2472"},{"category":"No","mappings":{"default":{"default":"circled number twenty","short":"circled twenty"},"mathspeak":{"default":"circled 20"}},"key":"2473"},{"category":"No","mappings":{"default":{"default":"parenthesized digit one","short":"parenthesized one"},"mathspeak":{"default":"parenthesized 1"}},"key":"2474"},{"category":"No","mappings":{"default":{"default":"parenthesized digit two","short":"parenthesized two"},"mathspeak":{"default":"parenthesized 2"}},"key":"2475"},{"category":"No","mappings":{"default":{"default":"parenthesized digit three","short":"parenthesized three"},"mathspeak":{"default":"parenthesized 3"}},"key":"2476"},{"category":"No","mappings":{"default":{"default":"parenthesized digit four","short":"parenthesized four"},"mathspeak":{"default":"parenthesized 4"}},"key":"2477"},{"category":"No","mappings":{"default":{"default":"parenthesized digit five","short":"parenthesized five"},"mathspeak":{"default":"parenthesized 5"}},"key":"2478"},{"category":"No","mappings":{"default":{"default":"parenthesized digit six","short":"parenthesized six"},"mathspeak":{"default":"parenthesized 6"}},"key":"2479"},{"category":"No","mappings":{"default":{"default":"parenthesized digit seven","short":"parenthesized seven"},"mathspeak":{"default":"parenthesized 7"}},"key":"247A"},{"category":"No","mappings":{"default":{"default":"parenthesized digit eight","short":"parenthesized eight"},"mathspeak":{"default":"parenthesized 8"}},"key":"247B"},{"category":"No","mappings":{"default":{"default":"parenthesized digit nine","short":"parenthesized nine"},"mathspeak":{"default":"parenthesized 9"}},"key":"247C"},{"category":"No","mappings":{"default":{"default":"parenthesized number ten","short":"parenthesized ten"},"mathspeak":{"default":"parenthesized 10"}},"key":"247D"},{"category":"No","mappings":{"default":{"default":"parenthesized number eleven","short":"parenthesized eleven"},"mathspeak":{"default":"parenthesized 11"}},"key":"247E"},{"category":"No","mappings":{"default":{"default":"parenthesized number twelve","short":"parenthesized twelve"},"mathspeak":{"default":"parenthesized 12"}},"key":"247F"},{"category":"No","mappings":{"default":{"default":"parenthesized number thirteen","short":"parenthesized thirteen"},"mathspeak":{"default":"parenthesized 13"}},"key":"2480"},{"category":"No","mappings":{"default":{"default":"parenthesized number fourteen","short":"parenthesized fourteen"},"mathspeak":{"default":"parenthesized 14"}},"key":"2481"},{"category":"No","mappings":{"default":{"default":"parenthesized number fifteen","short":"parenthesized fifteen"},"mathspeak":{"default":"parenthesized 15"}},"key":"2482"},{"category":"No","mappings":{"default":{"default":"parenthesized number sixteen","short":"parenthesized sixteen"},"mathspeak":{"default":"parenthesized 16"}},"key":"2483"},{"category":"No","mappings":{"default":{"default":"parenthesized number seventeen","short":"parenthesized seventeen"},"mathspeak":{"default":"parenthesized 17"}},"key":"2484"},{"category":"No","mappings":{"default":{"default":"parenthesized number eighteen","short":"parenthesized eighteen"},"mathspeak":{"default":"parenthesized 18"}},"key":"2485"},{"category":"No","mappings":{"default":{"default":"parenthesized number nineteen","short":"parenthesized nineteen"},"mathspeak":{"default":"parenthesized 19"}},"key":"2486"},{"category":"No","mappings":{"default":{"default":"parenthesized number twenty","short":"parenthesized twenty"},"mathspeak":{"default":"parenthesized 20"}},"key":"2487"},{"category":"No","mappings":{"default":{"default":"digit one full stop","alternative":"digit one period","short":"one period"},"mathspeak":{"default":"1 period"}},"key":"2488"},{"category":"No","mappings":{"default":{"default":"digit two full stop","alternative":"digit two period","short":"two period"},"mathspeak":{"default":"2 period"}},"key":"2489"},{"category":"No","mappings":{"default":{"default":"digit three full stop","alternative":"digit three period","short":"three period"},"mathspeak":{"default":"3 period"}},"key":"248A"},{"category":"No","mappings":{"default":{"default":"digit four full stop","alternative":"digit four period","short":"four period"},"mathspeak":{"default":"4 period"}},"key":"248B"},{"category":"No","mappings":{"default":{"default":"digit five full stop","alternative":"digit five period","short":"five period"},"mathspeak":{"default":"5 period"}},"key":"248C"},{"category":"No","mappings":{"default":{"default":"digit six full stop","alternative":"digit six period","short":"six period"},"mathspeak":{"default":"6 period"}},"key":"248D"},{"category":"No","mappings":{"default":{"default":"digit seven full stop","alternative":"digit seven period","short":"seven period"},"mathspeak":{"default":"7 period"}},"key":"248E"},{"category":"No","mappings":{"default":{"default":"digit eight full stop","alternative":"digit eight period","short":"eight period"},"mathspeak":{"default":"8 period"}},"key":"248F"},{"category":"No","mappings":{"default":{"default":"digit nine full stop","alternative":"digit nine period","short":"nine period"},"mathspeak":{"default":"9 period"}},"key":"2490"},{"category":"No","mappings":{"default":{"default":"number ten full stop","alternative":"number ten period","short":"ten period"},"mathspeak":{"default":"10 period"}},"key":"2491"},{"category":"No","mappings":{"default":{"default":"number eleven full stop","alternative":"number eleven period","short":"eleven period"},"mathspeak":{"default":"11 period"}},"key":"2492"},{"category":"No","mappings":{"default":{"default":"number twelve full stop","alternative":"number twelve period","short":"twelve period"},"mathspeak":{"default":"12 period"}},"key":"2493"},{"category":"No","mappings":{"default":{"default":"number thirteen full stop","alternative":"number thirteen period","short":"thirteen period"},"mathspeak":{"default":"13 period"}},"key":"2494"},{"category":"No","mappings":{"default":{"default":"number fourteen full stop","alternative":"number fourteen period","short":"fourteen period"},"mathspeak":{"default":"14 period"}},"key":"2495"},{"category":"No","mappings":{"default":{"default":"number fifteen full stop","alternative":"number fifteen period","short":"fifteen period"},"mathspeak":{"default":"15 period"}},"key":"2496"},{"category":"No","mappings":{"default":{"default":"number sixteen full stop","alternative":"number sixteen period","short":"sixteen period"},"mathspeak":{"default":"16 period"}},"key":"2497"},{"category":"No","mappings":{"default":{"default":"number seventeen full stop","alternative":"number seventeen period","short":"seventeen period"},"mathspeak":{"default":"17 period"}},"key":"2498"},{"category":"No","mappings":{"default":{"default":"number eighteen full stop","alternative":"number eighteen period","short":"eighteen period"},"mathspeak":{"default":"18 period"}},"key":"2499"},{"category":"No","mappings":{"default":{"default":"number nineteen full stop","alternative":"number nineteen period","short":"nineteen period"},"mathspeak":{"default":"19 period"}},"key":"249A"},{"category":"No","mappings":{"default":{"default":"number twenty full stop","alternative":"number twenty period","short":"twenty period"},"mathspeak":{"default":"20 period"}},"key":"249B"},{"category":"No","mappings":{"default":{"default":"circled digit zero","short":"circled zero"},"mathspeak":{"default":"circled 0"}},"key":"24EA"},{"category":"No","mappings":{"default":{"default":"negative circled number eleven","short":"negative circled eleven"},"mathspeak":{"default":"negative circled 11"}},"key":"24EB"},{"category":"No","mappings":{"default":{"default":"negative circled number twelve","short":"negative circled twelve"},"mathspeak":{"default":"negative circled 12"}},"key":"24EC"},{"category":"No","mappings":{"default":{"default":"negative circled number thirteen","short":"negative circled thirteen"},"mathspeak":{"default":"negative circled 13"}},"key":"24ED"},{"category":"No","mappings":{"default":{"default":"negative circled number fourteen","short":"negative circled fourteen"},"mathspeak":{"default":"negative circled 14"}},"key":"24EE"},{"category":"No","mappings":{"default":{"default":"negative circled number fifteen","short":"negative circled fifteen"},"mathspeak":{"default":"negative circled 15"}},"key":"24EF"},{"category":"No","mappings":{"default":{"default":"negative circled number sixteen","short":"negative circled sixteen"},"mathspeak":{"default":"negative circled 16"}},"key":"24F0"},{"category":"No","mappings":{"default":{"default":"negative circled number seventeen","short":"negative circled seventeen"},"mathspeak":{"default":"negative circled 17"}},"key":"24F1"},{"category":"No","mappings":{"default":{"default":"negative circled number eighteen","short":"negative circled eighteen"},"mathspeak":{"default":"negative circled 18"}},"key":"24F2"},{"category":"No","mappings":{"default":{"default":"negative circled number nineteen","short":"negative circled nineteen"},"mathspeak":{"default":"negative circled 19"}},"key":"24F3"},{"category":"No","mappings":{"default":{"default":"negative circled number twenty","short":"negative circled twenty"},"mathspeak":{"default":"negative circled 20"}},"key":"24F4"},{"category":"No","mappings":{"default":{"default":"double circled digit one","short":"double circled one"},"mathspeak":{"default":"double circled 1"}},"key":"24F5"},{"category":"No","mappings":{"default":{"default":"double circled digit two","short":"double circled two"},"mathspeak":{"default":"double circled 2"}},"key":"24F6"},{"category":"No","mappings":{"default":{"default":"double circled digit three","short":"double circled three"},"mathspeak":{"default":"double circled 3"}},"key":"24F7"},{"category":"No","mappings":{"default":{"default":"double circled digit four","short":"double circled four"},"mathspeak":{"default":"double circled 4"}},"key":"24F8"},{"category":"No","mappings":{"default":{"default":"double circled digit five","short":"double circled five"},"mathspeak":{"default":"double circled 5"}},"key":"24F9"},{"category":"No","mappings":{"default":{"default":"double circled digit six","short":"double circled six"},"mathspeak":{"default":"double circled 6"}},"key":"24FA"},{"category":"No","mappings":{"default":{"default":"double circled digit seven","short":"double circled seven"},"mathspeak":{"default":"double circled 7"}},"key":"24FB"},{"category":"No","mappings":{"default":{"default":"double circled digit eight","short":"double circled eight"},"mathspeak":{"default":"double circled 8"}},"key":"24FC"},{"category":"No","mappings":{"default":{"default":"double circled digit nine","short":"double circled nine"},"mathspeak":{"default":"double circled 9"}},"key":"24FD"},{"category":"No","mappings":{"default":{"default":"double circled number ten","short":"double circled ten"},"mathspeak":{"default":"double circled 10"}},"key":"24FE"},{"category":"No","mappings":{"default":{"default":"negative circled digit zero","short":"negative circled zero"},"mathspeak":{"default":"negative circled 0"}},"key":"24FF"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit one","alternative":"inverse circled digit one","short":"inverse circled one"},"mathspeak":{"default":"inverse circled 1"}},"key":"2776"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit two","alternative":"inverse circled digit two","short":"inverse circled two"},"mathspeak":{"default":"inverse circled 2"}},"key":"2777"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit three","alternative":"inverse circled digit three","short":"inverse circled three"},"mathspeak":{"default":"inverse circled 3"}},"key":"2778"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit four","alternative":"inverse circled digit four","short":"inverse circled four"},"mathspeak":{"default":"inverse circled 4"}},"key":"2779"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit five","alternative":"inverse circled digit five","short":"inverse circled five"},"mathspeak":{"default":"inverse circled 5"}},"key":"277A"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit six","alternative":"inverse circled digit six","short":"inverse circled six"},"mathspeak":{"default":"inverse circled 6"}},"key":"277B"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit seven","alternative":"inverse circled digit seven","short":"inverse circled seven"},"mathspeak":{"default":"inverse circled 7"}},"key":"277C"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit eight","alternative":"inverse circled digit eight","short":"inverse circled eight"},"mathspeak":{"default":"inverse circled 8"}},"key":"277D"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled digit nine","alternative":"inverse circled digit nine","short":"inverse circled nine"},"mathspeak":{"default":"inverse circled 9"}},"key":"277E"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled number ten","alternative":"inverse circled number ten","short":"inverse circled ten"},"mathspeak":{"default":"inverse circled 10"}},"key":"277F"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit one","alternative":"circled sans serif digit one","short":"circled one"}},"key":"2780"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit two","alternative":"circled sans serif digit two","short":"circled two"}},"key":"2781"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit three","alternative":"circled sans serif digit three","short":"circled three"}},"key":"2782"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit four","alternative":"circled sans serif digit four","short":"circled four"}},"key":"2783"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit five","alternative":"circled sans serif digit five","short":"circled five"}},"key":"2784"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit six","alternative":"circled sans serif digit six","short":"circled six"}},"key":"2785"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit seven","alternative":"circled sans serif digit seven","short":"circled seven"}},"key":"2786"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit eight","alternative":"circled sans serif digit eight","short":"circled eight"}},"key":"2787"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif digit nine","alternative":"circled sans serif digit nine","short":"circled nine"}},"key":"2788"},{"category":"No","mappings":{"default":{"default":"dingbat circled sans serif number ten","alternative":"circled sans serif number ten","short":"circled ten"}},"key":"2789"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit one","alternative":"inverse circled sans serif digit one","short":"inverse circled one"},"mathspeak":{"default":"inverse circled 1"}},"key":"278A"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit two","alternative":"inverse circled sans serif digit two","short":"inverse circled two"},"mathspeak":{"default":"inverse circled 2"}},"key":"278B"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit three","alternative":"inverse circled sans serif digit three","short":"inverse circled three"},"mathspeak":{"default":"inverse circled 3"}},"key":"278C"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit four","alternative":"inverse circled sans serif digit four","short":"inverse circled four"},"mathspeak":{"default":"inverse circled 4"}},"key":"278D"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit five","alternative":"inverse circled sans serif digit five","short":"inverse circled five"},"mathspeak":{"default":"inverse circled 5"}},"key":"278E"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit six","alternative":"inverse circled sans serif digit six","short":"inverse circled six"},"mathspeak":{"default":"inverse circled 6"}},"key":"278F"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit seven","alternative":"inverse circled sans serif digit seven","short":"inverse circled seven"},"mathspeak":{"default":"inverse circled 7"}},"key":"2790"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit eight","alternative":"inverse circled sans serif digit eight","short":"inverse circled eight"},"mathspeak":{"default":"inverse circled 8"}},"key":"2791"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif digit nine","alternative":"inverse circled sans serif digit nine","short":"inverse circled nine"},"mathspeak":{"default":"inverse circled 9"}},"key":"2792"},{"category":"No","mappings":{"default":{"default":"dingbat negative circled sans serif number ten","alternative":"inverse circled sans serif number ten","short":"inverse circled ten"},"mathspeak":{"default":"inverse circled 10"}},"key":"2793"},{"category":"No","mappings":{"default":{"default":"circled number ten on black square","short":"circled ten on black square"}},"key":"3248"},{"category":"No","mappings":{"default":{"default":"circled number twenty on black square","short":"circled twenty on black square"}},"key":"3249"},{"category":"No","mappings":{"default":{"default":"circled number thirty on black square","short":"circled thirty on black square"}},"key":"324A"},{"category":"No","mappings":{"default":{"default":"circled number forty on black square","short":"circled forty on black square"}},"key":"324B"},{"category":"No","mappings":{"default":{"default":"circled number fifty on black square","short":"circled fifty on black square"}},"key":"324C"},{"category":"No","mappings":{"default":{"default":"circled number sixty on black square","short":"circled sixty on black square"}},"key":"324D"},{"category":"No","mappings":{"default":{"default":"circled number seventy on black square","short":"circled seventy on black square"}},"key":"324E"},{"category":"No","mappings":{"default":{"default":"circled number eighty on black square","short":"circled eighty on black square"}},"key":"324F"},{"category":"No","mappings":{"default":{"default":"circled number twenty one","short":"circled twenty one"}},"key":"3251"},{"category":"No","mappings":{"default":{"default":"circled number twenty two","short":"circled twenty two"}},"key":"3252"},{"category":"No","mappings":{"default":{"default":"circled number twenty three","short":"circled twenty three"}},"key":"3253"},{"category":"No","mappings":{"default":{"default":"circled number twenty four","short":"circled twenty four"}},"key":"3254"},{"category":"No","mappings":{"default":{"default":"circled number twenty five","short":"circled twenty five"}},"key":"3255"},{"category":"No","mappings":{"default":{"default":"circled number twenty six","short":"circled twenty six"}},"key":"3256"},{"category":"No","mappings":{"default":{"default":"circled number twenty seven","short":"circled twenty seven"}},"key":"3257"},{"category":"No","mappings":{"default":{"default":"circled number twenty eight","short":"circled twenty eight"}},"key":"3258"},{"category":"No","mappings":{"default":{"default":"circled number twenty nine","short":"circled twenty nine"}},"key":"3259"},{"category":"No","mappings":{"default":{"default":"circled number thirty","short":"circled thirty"}},"key":"325A"},{"category":"No","mappings":{"default":{"default":"circled number thirty one","short":"circled thirty one"}},"key":"325B"},{"category":"No","mappings":{"default":{"default":"circled number thirty two","short":"circled thirty two"}},"key":"325C"},{"category":"No","mappings":{"default":{"default":"circled number thirty three","short":"circled thirty three"}},"key":"325D"},{"category":"No","mappings":{"default":{"default":"circled number thirty four","short":"circled thirty four"}},"key":"325E"},{"category":"No","mappings":{"default":{"default":"circled number thirty five","short":"circled thirty five"}},"key":"325F"},{"category":"No","mappings":{"default":{"default":"circled number thirty six","short":"circled thirty six"}},"key":"32B1"},{"category":"No","mappings":{"default":{"default":"circled number thirty seven","short":"circled thirty seven"}},"key":"32B2"},{"category":"No","mappings":{"default":{"default":"circled number thirty eight","short":"circled thirty eight"}},"key":"32B3"},{"category":"No","mappings":{"default":{"default":"circled number thirty nine","short":"circled thirty nine"}},"key":"32B4"},{"category":"No","mappings":{"default":{"default":"circled number forty","short":"circled forty"}},"key":"32B5"},{"category":"No","mappings":{"default":{"default":"circled number forty one","short":"circled forty one"}},"key":"32B6"},{"category":"No","mappings":{"default":{"default":"circled number forty two","short":"circled forty two"}},"key":"32B7"},{"category":"No","mappings":{"default":{"default":"circled number forty three","short":"circled forty three"}},"key":"32B8"},{"category":"No","mappings":{"default":{"default":"circled number forty four","short":"circled forty four"}},"key":"32B9"},{"category":"No","mappings":{"default":{"default":"circled number forty five","short":"circled forty five"}},"key":"32BA"},{"category":"No","mappings":{"default":{"default":"circled number forty six","short":"circled forty six"}},"key":"32BB"},{"category":"No","mappings":{"default":{"default":"circled number forty seven","short":"circled forty seven"}},"key":"32BC"},{"category":"No","mappings":{"default":{"default":"circled number forty eight","short":"circled forty eight"}},"key":"32BD"},{"category":"No","mappings":{"default":{"default":"circled number forty nine","short":"circled forty nine"}},"key":"32BE"},{"category":"No","mappings":{"default":{"default":"circled number fifty","short":"circled fifty"}},"key":"32BF"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit zero","short":"zero"},"mathspeak":{"default":"0"}},"key":"FF10"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit one","short":"one"},"mathspeak":{"default":"1"}},"key":"FF11"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit two","short":"two"},"mathspeak":{"default":"2"}},"key":"FF12"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit three","short":"three"},"mathspeak":{"default":"3"}},"key":"FF13"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit four","short":"four"},"mathspeak":{"default":"4"}},"key":"FF14"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit five","short":"five"},"mathspeak":{"default":"5"}},"key":"FF15"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit six","short":"six"},"mathspeak":{"default":"6"}},"key":"FF16"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit seven","short":"seven"},"mathspeak":{"default":"7"}},"key":"FF17"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit eight","short":"eight"},"mathspeak":{"default":"8"}},"key":"FF18"},{"category":"Nd","mappings":{"default":{"default":"fullwidth digit nine","short":"nine"},"mathspeak":{"default":"9"}},"key":"FF19"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit zero","alternative":"bold digit zero","short":"bold zero"},"mathspeak":{"default":"bold 0"}},"key":"1D7CE"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit one","alternative":"bold digit one","short":"bold one"},"mathspeak":{"default":"bold 1"}},"key":"1D7CF"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit two","alternative":"bold digit two","short":"bold two"},"mathspeak":{"default":"bold 2"}},"key":"1D7D0"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit three","alternative":"bold digit three","short":"bold three"},"mathspeak":{"default":"bold 3"}},"key":"1D7D1"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit four","alternative":"bold digit four","short":"bold four"},"mathspeak":{"default":"bold 4"}},"key":"1D7D2"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit five","alternative":"bold digit five","short":"bold five"},"mathspeak":{"default":"bold 5"}},"key":"1D7D3"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit six","alternative":"bold digit six","short":"bold six"},"mathspeak":{"default":"bold 6"}},"key":"1D7D4"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit seven","alternative":"bold digit seven","short":"bold seven"},"mathspeak":{"default":"bold 7"}},"key":"1D7D5"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit eight","alternative":"bold digit eight","short":"bold eight"},"mathspeak":{"default":"bold 8"}},"key":"1D7D6"},{"category":"Nd","mappings":{"default":{"default":"mathematical bold digit nine","alternative":"bold digit nine","short":"bold nine"},"mathspeak":{"default":"bold 9"}},"key":"1D7D7"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit zero","alternative":"double struck zero","short":"blackboard zero"},"mathspeak":{"default":"blackboard 0"}},"key":"1D7D8"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit one","alternative":"double struck one","short":"blackboard one"},"mathspeak":{"default":"blackboard 1"}},"key":"1D7D9"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit two","alternative":"double struck two","short":"blackboard two"},"mathspeak":{"default":"blackboard 2"}},"key":"1D7DA"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit three","alternative":"double struck three","short":"blackboard three"},"mathspeak":{"default":"blackboard 3"}},"key":"1D7DB"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit four","alternative":"double struck four","short":"blackboard four"},"mathspeak":{"default":"blackboard 4"}},"key":"1D7DC"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit five","alternative":"double struck five","short":"blackboard five"},"mathspeak":{"default":"blackboard 5"}},"key":"1D7DD"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit six","alternative":"double struck six","short":"blackboard six"},"mathspeak":{"default":"blackboard 6"}},"key":"1D7DE"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit seven","alternative":"double struck seven","short":"blackboard seven"},"mathspeak":{"default":"blackboard 7"}},"key":"1D7DF"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit eight","alternative":"double struck eight","short":"blackboard eight"},"mathspeak":{"default":"blackboard 8"}},"key":"1D7E0"},{"category":"Nd","mappings":{"default":{"default":"mathematical double struck digit nine","alternative":"double struck nine","short":"blackboard nine"},"mathspeak":{"default":"blackboard 9"}},"key":"1D7E1"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit zero","alternative":"sans serif digit zero","short":"sans serif zero"},"mathspeak":{"default":"sans serif 0"}},"key":"1D7E2"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit one","alternative":"sans serif digit one","short":"sans serif one"},"mathspeak":{"default":"sans serif 1"}},"key":"1D7E3"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit two","alternative":"sans serif digit two","short":"sans serif two"},"mathspeak":{"default":"sans serif 2"}},"key":"1D7E4"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit three","alternative":"sans serif digit three","short":"sans serif three"},"mathspeak":{"default":"sans serif 3"}},"key":"1D7E5"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit four","alternative":"sans serif digit four","short":"sans serif four"},"mathspeak":{"default":"sans serif 4"}},"key":"1D7E6"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit five","alternative":"sans serif digit five","short":"sans serif five"},"mathspeak":{"default":"sans serif 5"}},"key":"1D7E7"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit six","alternative":"sans serif digit six","short":"sans serif six"},"mathspeak":{"default":"sans serif 6"}},"key":"1D7E8"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit seven","alternative":"sans serif digit seven","short":"sans serif seven"},"mathspeak":{"default":"sans serif 7"}},"key":"1D7E9"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit eight","alternative":"sans serif digit eight","short":"sans serif eight"},"mathspeak":{"default":"sans serif 8"}},"key":"1D7EA"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif digit nine","alternative":"sans serif digit nine","short":"sans serif nine"},"mathspeak":{"default":"sans serif 9"}},"key":"1D7EB"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit zero","alternative":"sans serif bold digit zero","short":"sans serif bold zero"},"mathspeak":{"default":"sans serif bold 0"}},"key":"1D7EC"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit one","alternative":"sans serif bold digit one","short":"sans serif bold one"},"mathspeak":{"default":"sans serif bold 1"}},"key":"1D7ED"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit two","alternative":"sans serif bold digit two","short":"sans serif bold two"},"mathspeak":{"default":"sans serif bold 2"}},"key":"1D7EE"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit three","alternative":"sans serif bold digit three","short":"sans serif bold three"},"mathspeak":{"default":"sans serif bold 3"}},"key":"1D7EF"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit four","alternative":"sans serif bold digit four","short":"sans serif bold four"},"mathspeak":{"default":"sans serif bold 4"}},"key":"1D7F0"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit five","alternative":"sans serif bold digit five","short":"sans serif bold five"},"mathspeak":{"default":"sans serif bold 5"}},"key":"1D7F1"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit six","alternative":"sans serif bold digit six","short":"sans serif bold six"},"mathspeak":{"default":"sans serif bold 6"}},"key":"1D7F2"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit seven","alternative":"sans serif bold digit seven","short":"sans serif bold seven"},"mathspeak":{"default":"sans serif bold 7"}},"key":"1D7F3"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit eight","alternative":"sans serif bold digit eight","short":"sans serif bold eight"},"mathspeak":{"default":"sans serif bold 8"}},"key":"1D7F4"},{"category":"Nd","mappings":{"default":{"default":"mathematical sans serif bold digit nine","alternative":"sans serif bold digit nine","short":"sans serif bold nine"},"mathspeak":{"default":"sans serif bold 9"}},"key":"1D7F5"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit zero","alternative":"monospace zero","short":"thin zero"},"mathspeak":{"default":"monospace 0"}},"key":"1D7F6"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit one","alternative":"monospace one","short":"thin one"},"mathspeak":{"default":"monospace 1"}},"key":"1D7F7"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit two","alternative":"monospace two","short":"thin two"},"mathspeak":{"default":"monospace 2"}},"key":"1D7F8"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit three","alternative":"monospace three","short":"thin three"},"mathspeak":{"default":"monospace 3"}},"key":"1D7F9"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit four","alternative":"monospace four","short":"thin four"},"mathspeak":{"default":"monospace 4"}},"key":"1D7FA"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit five","alternative":"monospace five","short":"thin five"},"mathspeak":{"default":"monospace 5"}},"key":"1D7FB"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit six","alternative":"monospace six","short":"thin six"},"mathspeak":{"default":"monospace 6"}},"key":"1D7FC"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit seven","alternative":"monospace seven","short":"thin seven"},"mathspeak":{"default":"monospace 7"}},"key":"1D7FD"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit eight","alternative":"monospace eight","short":"thin eight"},"mathspeak":{"default":"monospace 8"}},"key":"1D7FE"},{"category":"Nd","mappings":{"default":{"default":"mathematical monospace digit nine","alternative":"monospace nine","short":"thin nine"},"mathspeak":{"default":"monospace 9"}},"key":"1D7FF"},{"category":"No","mappings":{"default":{"default":"digit zero full stop","short":"zero period"},"mathspeak":{"default":"0 period"}},"key":"1F100"},{"category":"No","mappings":{"default":{"default":"digit zero comma","short":"zero comma"},"mathspeak":{"default":"0 comma"}},"key":"1F101"},{"category":"No","mappings":{"default":{"default":"digit one comma","short":"one comma"},"mathspeak":{"default":"1 comma"}},"key":"1F102"},{"category":"No","mappings":{"default":{"default":"digit two comma","short":"two comma"},"mathspeak":{"default":"2 comma"}},"key":"1F103"},{"category":"No","mappings":{"default":{"default":"digit three comma","short":"three comma"},"mathspeak":{"default":"3 comma"}},"key":"1F104"},{"category":"No","mappings":{"default":{"default":"digit four comma","short":"four comma"},"mathspeak":{"default":"4 comma"}},"key":"1F105"},{"category":"No","mappings":{"default":{"default":"digit five comma","short":"five comma"},"mathspeak":{"default":"5 comma"}},"key":"1F106"},{"category":"No","mappings":{"default":{"default":"digit six comma","short":"six comma"},"mathspeak":{"default":"6 comma"}},"key":"1F107"},{"category":"No","mappings":{"default":{"default":"digit seven comma","short":"seven comma"},"mathspeak":{"default":"7 comma"}},"key":"1F108"},{"category":"No","mappings":{"default":{"default":"digit eight comma","short":"eight comma"},"mathspeak":{"default":"8 comma"}},"key":"1F109"},{"category":"No","mappings":{"default":{"default":"digit nine comma","short":"nine comma"},"mathspeak":{"default":"9 comma"}},"key":"1F10A"}]
,
"en/math_geometry.js": 
[{"locale":"en"},{"category":"So","mappings":{"default":{"default":"box drawings light horizontal","alternative":"forms light horizontal"}},"key":"2500"},{"category":"So","mappings":{"default":{"default":"box drawings heavy horizontal","alternative":"forms heavy horizontal"}},"key":"2501"},{"category":"So","mappings":{"default":{"default":"box drawings light vertical","alternative":"forms light vertical"}},"key":"2502"},{"category":"So","mappings":{"default":{"default":"box drawings heavy vertical","alternative":"forms heavy vertical"}},"key":"2503"},{"category":"So","mappings":{"default":{"default":"box drawings light triple dash horizontal","alternative":"forms light triple dash horizontal"}},"key":"2504"},{"category":"So","mappings":{"default":{"default":"box drawings heavy triple dash horizontal","alternative":"forms heavy triple dash horizontal"}},"key":"2505"},{"category":"So","mappings":{"default":{"default":"box drawings light triple dash vertical","alternative":"forms light triple dash vertical"}},"key":"2506"},{"category":"So","mappings":{"default":{"default":"box drawings heavy triple dash vertical","alternative":"forms heavy triple dash vertical"}},"key":"2507"},{"category":"So","mappings":{"default":{"default":"box drawings light quadruple dash horizontal","alternative":"forms light quadruple dash horizontal"}},"key":"2508"},{"category":"So","mappings":{"default":{"default":"box drawings heavy quadruple dash horizontal","alternative":"forms heavy quadruple dash horizontal"}},"key":"2509"},{"category":"So","mappings":{"default":{"default":"box drawings light quadruple dash vertical","alternative":"forms light quadruple dash vertical"}},"key":"250A"},{"category":"So","mappings":{"default":{"default":"box drawings heavy quadruple dash vertical","alternative":"forms heavy quadruple dash vertical"}},"key":"250B"},{"category":"So","mappings":{"default":{"default":"box drawings light down and right","alternative":"forms light down and right"}},"key":"250C"},{"category":"So","mappings":{"default":{"default":"box drawings down light and right heavy","alternative":"forms down light and right heavy"}},"key":"250D"},{"category":"So","mappings":{"default":{"default":"box drawings down heavy and right light","alternative":"forms down heavy and right light"}},"key":"250E"},{"category":"So","mappings":{"default":{"default":"box drawings heavy down and right","alternative":"forms heavy down and right"}},"key":"250F"},{"category":"So","mappings":{"default":{"default":"box drawings light down and left","alternative":"forms light down and left"}},"key":"2510"},{"category":"So","mappings":{"default":{"default":"box drawings down light and left heavy","alternative":"forms down light and left heavy"}},"key":"2511"},{"category":"So","mappings":{"default":{"default":"box drawings down heavy and left light","alternative":"forms down heavy and left light"}},"key":"2512"},{"category":"So","mappings":{"default":{"default":"box drawings heavy down and left","alternative":"forms heavy down and left"}},"key":"2513"},{"category":"So","mappings":{"default":{"default":"box drawings light up and right","alternative":"forms light up and right"}},"key":"2514"},{"category":"So","mappings":{"default":{"default":"box drawings up light and right heavy","alternative":"forms up light and right heavy"}},"key":"2515"},{"category":"So","mappings":{"default":{"default":"box drawings up heavy and right light","alternative":"forms up heavy and right light"}},"key":"2516"},{"category":"So","mappings":{"default":{"default":"box drawings heavy up and right","alternative":"forms heavy up and right"}},"key":"2517"},{"category":"So","mappings":{"default":{"default":"box drawings light up and left","alternative":"forms light up and left"}},"key":"2518"},{"category":"So","mappings":{"default":{"default":"box drawings up light and left heavy","alternative":"forms up light and left heavy"}},"key":"2519"},{"category":"So","mappings":{"default":{"default":"box drawings up heavy and left light","alternative":"forms up heavy and left light"}},"key":"251A"},{"category":"So","mappings":{"default":{"default":"box drawings heavy up and left","alternative":"forms heavy up and left"}},"key":"251B"},{"category":"So","mappings":{"default":{"default":"box drawings light vertical and right","alternative":"forms light vertical and right"}},"key":"251C"},{"category":"So","mappings":{"default":{"default":"box drawings vertical light and right heavy","alternative":"forms vertical light and right heavy"}},"key":"251D"},{"category":"So","mappings":{"default":{"default":"box drawings up heavy and right down light","alternative":"forms up heavy and right down light"}},"key":"251E"},{"category":"So","mappings":{"default":{"default":"box drawings down heavy and right up light","alternative":"forms down heavy and right up light"}},"key":"251F"},{"category":"So","mappings":{"default":{"default":"box drawings vertical heavy and right light","alternative":"forms vertical heavy and right light"}},"key":"2520"},{"category":"So","mappings":{"default":{"default":"box drawings down light and right up heavy","alternative":"forms down light and right up heavy"}},"key":"2521"},{"category":"So","mappings":{"default":{"default":"box drawings up light and right down heavy","alternative":"forms up light and right down heavy"}},"key":"2522"},{"category":"So","mappings":{"default":{"default":"box drawings heavy vertical and right","alternative":"forms heavy vertical and right"}},"key":"2523"},{"category":"So","mappings":{"default":{"default":"box drawings light vertical and left","alternative":"forms light vertical and left"}},"key":"2524"},{"category":"So","mappings":{"default":{"default":"box drawings vertical light and left heavy","alternative":"forms vertical light and left heavy"}},"key":"2525"},{"category":"So","mappings":{"default":{"default":"box drawings up heavy and left down light","alternative":"forms up heavy and left down light"}},"key":"2526"},{"category":"So","mappings":{"default":{"default":"box drawings down heavy and left up light","alternative":"forms down heavy and left up light"}},"key":"2527"},{"category":"So","mappings":{"default":{"default":"box drawings vertical heavy and left light","alternative":"forms vertical heavy and left light"}},"key":"2528"},{"category":"So","mappings":{"default":{"default":"box drawings down light and left up heavy","alternative":"forms down light and left up heavy"}},"key":"2529"},{"category":"So","mappings":{"default":{"default":"box drawings up light and left down heavy","alternative":"forms up light and left down heavy"}},"key":"252A"},{"category":"So","mappings":{"default":{"default":"box drawings heavy vertical and left","alternative":"forms heavy vertical and left"}},"key":"252B"},{"category":"So","mappings":{"default":{"default":"box drawings light down and horizontal","alternative":"forms light down and horizontal"}},"key":"252C"},{"category":"So","mappings":{"default":{"default":"box drawings left heavy and right down light","alternative":"forms left heavy and right down light"}},"key":"252D"},{"category":"So","mappings":{"default":{"default":"box drawings right heavy and left down light","alternative":"forms right heavy and left down light"}},"key":"252E"},{"category":"So","mappings":{"default":{"default":"box drawings down light and horizontal heavy","alternative":"forms down light and horizontal heavy"}},"key":"252F"},{"category":"So","mappings":{"default":{"default":"box drawings down heavy and horizontal light","alternative":"forms down heavy and horizontal light"}},"key":"2530"},{"category":"So","mappings":{"default":{"default":"box drawings right light and left down heavy","alternative":"forms right light and left down heavy"}},"key":"2531"},{"category":"So","mappings":{"default":{"default":"box drawings left light and right down heavy","alternative":"forms left light and right down heavy"}},"key":"2532"},{"category":"So","mappings":{"default":{"default":"box drawings heavy down and horizontal","alternative":"forms heavy down and horizontal"}},"key":"2533"},{"category":"So","mappings":{"default":{"default":"box drawings light up and horizontal","alternative":"forms light up and horizontal"}},"key":"2534"},{"category":"So","mappings":{"default":{"default":"box drawings left heavy and right up light","alternative":"forms left heavy and right up light"}},"key":"2535"},{"category":"So","mappings":{"default":{"default":"box drawings right heavy and left up light","alternative":"forms right heavy and left up light"}},"key":"2536"},{"category":"So","mappings":{"default":{"default":"box drawings up light and horizontal heavy","alternative":"forms up light and horizontal heavy"}},"key":"2537"},{"category":"So","mappings":{"default":{"default":"box drawings up heavy and horizontal light","alternative":"forms up heavy and horizontal light"}},"key":"2538"},{"category":"So","mappings":{"default":{"default":"box drawings right light and left up heavy","alternative":"forms right light and left up heavy"}},"key":"2539"},{"category":"So","mappings":{"default":{"default":"box drawings left light and right up heavy","alternative":"forms left light and right up heavy"}},"key":"253A"},{"category":"So","mappings":{"default":{"default":"box drawings heavy up and horizontal","alternative":"forms heavy up and horizontal"}},"key":"253B"},{"category":"So","mappings":{"default":{"default":"box drawings light vertical and horizontal","alternative":"forms light vertical and horizontal"}},"key":"253C"},{"category":"So","mappings":{"default":{"default":"box drawings left heavy and right vertical light","alternative":"forms left heavy and right vertical light"}},"key":"253D"},{"category":"So","mappings":{"default":{"default":"box drawings right heavy and left vertical light","alternative":"forms right heavy and left vertical light"}},"key":"253E"},{"category":"So","mappings":{"default":{"default":"box drawings vertical light and horizontal heavy","alternative":"forms vertical light and horizontal heavy"}},"key":"253F"},{"category":"So","mappings":{"default":{"default":"box drawings up heavy and down horizontal light","alternative":"forms up heavy and down horizontal light"}},"key":"2540"},{"category":"So","mappings":{"default":{"default":"box drawings down heavy and up horizontal light","alternative":"forms down heavy and up horizontal light"}},"key":"2541"},{"category":"So","mappings":{"default":{"default":"box drawings vertical heavy and horizontal light","alternative":"forms vertical heavy and horizontal light"}},"key":"2542"},{"category":"So","mappings":{"default":{"default":"box drawings left up heavy and right down light","alternative":"forms left up heavy and right down light"}},"key":"2543"},{"category":"So","mappings":{"default":{"default":"box drawings right up heavy and left down light","alternative":"forms right up heavy and left down light"}},"key":"2544"},{"category":"So","mappings":{"default":{"default":"box drawings left down heavy and right up light","alternative":"forms left down heavy and right up light"}},"key":"2545"},{"category":"So","mappings":{"default":{"default":"box drawings right down heavy and left up light","alternative":"forms right down heavy and left up light"}},"key":"2546"},{"category":"So","mappings":{"default":{"default":"box drawings down light and up horizontal heavy","alternative":"forms down light and up horizontal heavy"}},"key":"2547"},{"category":"So","mappings":{"default":{"default":"box drawings up light and down horizontal heavy","alternative":"forms up light and down horizontal heavy"}},"key":"2548"},{"category":"So","mappings":{"default":{"default":"box drawings right light and left vertical heavy","alternative":"forms right light and left vertical heavy"}},"key":"2549"},{"category":"So","mappings":{"default":{"default":"box drawings left light and right vertical heavy","alternative":"forms left light and right vertical heavy"}},"key":"254A"},{"category":"So","mappings":{"default":{"default":"box drawings heavy vertical and horizontal","alternative":"forms heavy vertical and horizontal"}},"key":"254B"},{"category":"So","mappings":{"default":{"default":"box drawings light double dash horizontal","alternative":"forms light double dash horizontal"}},"key":"254C"},{"category":"So","mappings":{"default":{"default":"box drawings heavy double dash horizontal","alternative":"forms heavy double dash horizontal"}},"key":"254D"},{"category":"So","mappings":{"default":{"default":"box drawings light double dash vertical","alternative":"forms light double dash vertical"}},"key":"254E"},{"category":"So","mappings":{"default":{"default":"box drawings heavy double dash vertical","alternative":"forms heavy double dash vertical"}},"key":"254F"},{"category":"So","mappings":{"default":{"default":"box drawings double horizontal","alternative":"forms double horizontal"}},"key":"2550"},{"category":"So","mappings":{"default":{"default":"box drawings double vertical","alternative":"forms double vertical"}},"key":"2551"},{"category":"So","mappings":{"default":{"default":"box drawings down single and right double","alternative":"forms down single and right double"}},"key":"2552"},{"category":"So","mappings":{"default":{"default":"box drawings down double and right single","alternative":"forms down double and right single"}},"key":"2553"},{"category":"So","mappings":{"default":{"default":"box drawings double down and right","alternative":"forms double down and right"}},"key":"2554"},{"category":"So","mappings":{"default":{"default":"box drawings down single and left double","alternative":"forms down single and left double"}},"key":"2555"},{"category":"So","mappings":{"default":{"default":"box drawings down double and left single","alternative":"forms down double and left single"}},"key":"2556"},{"category":"So","mappings":{"default":{"default":"box drawings double down and left","alternative":"forms double down and left"}},"key":"2557"},{"category":"So","mappings":{"default":{"default":"box drawings up single and right double","alternative":"forms up single and right double"}},"key":"2558"},{"category":"So","mappings":{"default":{"default":"box drawings up double and right single","alternative":"forms up double and right single"}},"key":"2559"},{"category":"So","mappings":{"default":{"default":"box drawings double up and right","alternative":"forms double up and right"}},"key":"255A"},{"category":"So","mappings":{"default":{"default":"box drawings up single and left double","alternative":"forms up single and left double"}},"key":"255B"},{"category":"So","mappings":{"default":{"default":"box drawings up double and left single","alternative":"forms up double and left single"}},"key":"255C"},{"category":"So","mappings":{"default":{"default":"box drawings double up and left","alternative":"forms double up and left"}},"key":"255D"},{"category":"So","mappings":{"default":{"default":"box drawings vertical single and right double","alternative":"forms vertical single and right double"}},"key":"255E"},{"category":"So","mappings":{"default":{"default":"box drawings vertical double and right single","alternative":"forms vertical double and right single"}},"key":"255F"},{"category":"So","mappings":{"default":{"default":"box drawings double vertical and right","alternative":"forms double vertical and right"}},"key":"2560"},{"category":"So","mappings":{"default":{"default":"box drawings vertical single and left double","alternative":"forms vertical single and left double"}},"key":"2561"},{"category":"So","mappings":{"default":{"default":"box drawings vertical double and left single","alternative":"forms vertical double and left single"}},"key":"2562"},{"category":"So","mappings":{"default":{"default":"box drawings double vertical and left","alternative":"forms double vertical and left"}},"key":"2563"},{"category":"So","mappings":{"default":{"default":"box drawings down single and horizontal double","alternative":"forms down single and horizontal double"}},"key":"2564"},{"category":"So","mappings":{"default":{"default":"box drawings down double and horizontal single","alternative":"forms down double and horizontal single"}},"key":"2565"},{"category":"So","mappings":{"default":{"default":"box drawings double down and horizontal","alternative":"forms double down and horizontal"}},"key":"2566"},{"category":"So","mappings":{"default":{"default":"box drawings up single and horizontal double","alternative":"forms up single and horizontal double"}},"key":"2567"},{"category":"So","mappings":{"default":{"default":"box drawings up double and horizontal single","alternative":"forms up double and horizontal single"}},"key":"2568"},{"category":"So","mappings":{"default":{"default":"box drawings double up and horizontal","alternative":"forms double up and horizontal"}},"key":"2569"},{"category":"So","mappings":{"default":{"default":"box drawings vertical single and horizontal double","alternative":"forms vertical single and horizontal double"}},"key":"256A"},{"category":"So","mappings":{"default":{"default":"box drawings vertical double and horizontal single","alternative":"forms vertical double and horizontal single"}},"key":"256B"},{"category":"So","mappings":{"default":{"default":"box drawings double vertical and horizontal","alternative":"forms double vertical and horizontal"}},"key":"256C"},{"category":"So","mappings":{"default":{"default":"box drawings light arc down and right","alternative":"forms light arc down and right"}},"key":"256D"},{"category":"So","mappings":{"default":{"default":"box drawings light arc down and left","alternative":"forms light arc down and left"}},"key":"256E"},{"category":"So","mappings":{"default":{"default":"box drawings light arc up and left","alternative":"forms light arc up and left"}},"key":"256F"},{"category":"So","mappings":{"default":{"default":"box drawings light arc up and right","alternative":"forms light arc up and right"}},"key":"2570"},{"category":"So","mappings":{"default":{"default":"box drawings light diagonal upper right to lower left","alternative":"forms light diagonal upper right to lower left"}},"key":"2571"},{"category":"So","mappings":{"default":{"default":"box drawings light diagonal upper left to lower right","alternative":"forms light diagonal upper left to lower right"}},"key":"2572"},{"category":"So","mappings":{"default":{"default":"box drawings light diagonal cross","alternative":"forms light diagonal cross"}},"key":"2573"},{"category":"So","mappings":{"default":{"default":"box drawings light left","alternative":"forms light left"}},"key":"2574"},{"category":"So","mappings":{"default":{"default":"box drawings light up","alternative":"forms light up"}},"key":"2575"},{"category":"So","mappings":{"default":{"default":"box drawings light right","alternative":"forms light right"}},"key":"2576"},{"category":"So","mappings":{"default":{"default":"box drawings light down","alternative":"forms light down"}},"key":"2577"},{"category":"So","mappings":{"default":{"default":"box drawings heavy left","alternative":"forms heavy left"}},"key":"2578"},{"category":"So","mappings":{"default":{"default":"box drawings heavy up","alternative":"forms heavy up"}},"key":"2579"},{"category":"So","mappings":{"default":{"default":"box drawings heavy right","alternative":"forms heavy right"}},"key":"257A"},{"category":"So","mappings":{"default":{"default":"box drawings heavy down","alternative":"forms heavy down"}},"key":"257B"},{"category":"So","mappings":{"default":{"default":"box drawings light left and heavy right","alternative":"forms light left and heavy right"}},"key":"257C"},{"category":"So","mappings":{"default":{"default":"box drawings light up and heavy down","alternative":"forms light up and heavy down"}},"key":"257D"},{"category":"So","mappings":{"default":{"default":"box drawings heavy left and light right","alternative":"forms heavy left and light right"}},"key":"257E"},{"category":"So","mappings":{"default":{"default":"box drawings heavy up and light down","alternative":"forms heavy up and light down"}},"key":"257F"},{"category":"So","mappings":{"default":{"default":"upper half block"}},"key":"2580"},{"category":"So","mappings":{"default":{"default":"lower one eighth block"}},"key":"2581"},{"category":"So","mappings":{"default":{"default":"lower one quarter block"}},"key":"2582"},{"category":"So","mappings":{"default":{"default":"lower three eighths block"}},"key":"2583"},{"category":"So","mappings":{"default":{"default":"lower half block"}},"key":"2584"},{"category":"So","mappings":{"default":{"default":"lower five eighths block"}},"key":"2585"},{"category":"So","mappings":{"default":{"default":"lower three quarters block","alternative":"lower three quarter block"}},"key":"2586"},{"category":"So","mappings":{"default":{"default":"lower seven eighths block"}},"key":"2587"},{"category":"So","mappings":{"default":{"default":"full block"}},"key":"2588"},{"category":"So","mappings":{"default":{"default":"left seven eighths block"}},"key":"2589"},{"category":"So","mappings":{"default":{"default":"left three quarters block","alternative":"left three quarter block"}},"key":"258A"},{"category":"So","mappings":{"default":{"default":"left five eighths block"}},"key":"258B"},{"category":"So","mappings":{"default":{"default":"left half block"}},"key":"258C"},{"category":"So","mappings":{"default":{"default":"left three eighths block"}},"key":"258D"},{"category":"So","mappings":{"default":{"default":"left one quarter block"}},"key":"258E"},{"category":"So","mappings":{"default":{"default":"left one eighth block"}},"key":"258F"},{"category":"So","mappings":{"default":{"default":"right half block"}},"key":"2590"},{"category":"So","mappings":{"default":{"default":"light shade"}},"key":"2591"},{"category":"So","mappings":{"default":{"default":"medium shade"}},"key":"2592"},{"category":"So","mappings":{"default":{"default":"dark shade"}},"key":"2593"},{"category":"So","mappings":{"default":{"default":"upper one eighth block"}},"key":"2594"},{"category":"So","mappings":{"default":{"default":"right one eighth block"}},"key":"2595"},{"category":"So","mappings":{"default":{"default":"quadrant lower left"}},"key":"2596"},{"category":"So","mappings":{"default":{"default":"quadrant lower right"}},"key":"2597"},{"category":"So","mappings":{"default":{"default":"quadrant upper left"}},"key":"2598"},{"category":"So","mappings":{"default":{"default":"quadrant upper left and lower left and lower right"}},"key":"2599"},{"category":"So","mappings":{"default":{"default":"quadrant upper left and lower right"}},"key":"259A"},{"category":"So","mappings":{"default":{"default":"quadrant upper left and upper right and lower left"}},"key":"259B"},{"category":"So","mappings":{"default":{"default":"quadrant upper left and upper right and lower right"}},"key":"259C"},{"category":"So","mappings":{"default":{"default":"quadrant upper right"}},"key":"259D"},{"category":"So","mappings":{"default":{"default":"quadrant upper right and lower left"}},"key":"259E"},{"category":"So","mappings":{"default":{"default":"quadrant upper right and lower left and lower right"}},"key":"259F"},{"category":"So","mappings":{"default":{"default":"black square"}},"key":"25A0"},{"category":"So","mappings":{"default":{"default":"white square"}},"key":"25A1"},{"category":"So","mappings":{"default":{"default":"white square with rounded corners"}},"key":"25A2"},{"category":"So","mappings":{"default":{"default":"white square containing black small square"}},"key":"25A3"},{"category":"So","mappings":{"default":{"default":"square with horizontal fill"}},"key":"25A4"},{"category":"So","mappings":{"default":{"default":"square with vertical fill"}},"key":"25A5"},{"category":"So","mappings":{"default":{"default":"square with orthogonal crosshatch fill"}},"key":"25A6"},{"category":"So","mappings":{"default":{"default":"square with upper left to lower right fill"}},"key":"25A7"},{"category":"So","mappings":{"default":{"default":"square with upper right to lower left fill"}},"key":"25A8"},{"category":"So","mappings":{"default":{"default":"square with diagonal crosshatch fill"}},"key":"25A9"},{"category":"So","mappings":{"default":{"default":"black small square"}},"key":"25AA"},{"category":"So","mappings":{"default":{"default":"white small square"}},"key":"25AB"},{"category":"So","mappings":{"default":{"default":"black rectangle"}},"key":"25AC"},{"category":"So","mappings":{"default":{"default":"white rectangle"}},"key":"25AD"},{"category":"So","mappings":{"default":{"default":"black vertical rectangle"}},"key":"25AE"},{"category":"So","mappings":{"default":{"default":"white vertical rectangle"}},"key":"25AF"},{"category":"So","mappings":{"default":{"default":"black parallelogram"}},"key":"25B0"},{"category":"So","mappings":{"default":{"default":"white parallelogram"}},"key":"25B1"},{"category":"So","mappings":{"default":{"default":"black up pointing triangle","alternative":"black up pointing triangle"}},"key":"25B2"},{"category":"So","mappings":{"default":{"default":"white up pointing triangle","alternative":"white up pointing triangle"}},"key":"25B3"},{"category":"So","mappings":{"default":{"default":"black up pointing small triangle","alternative":"black up pointing small triangle"}},"key":"25B4"},{"category":"So","mappings":{"default":{"default":"white up pointing small triangle","alternative":"white up pointing small triangle"}},"key":"25B5"},{"category":"So","mappings":{"default":{"default":"black right pointing triangle","alternative":"black right pointing triangle"}},"key":"25B6"},{"category":"Sm","mappings":{"default":{"default":"white right pointing triangle","alternative":"white right pointing triangle"}},"key":"25B7"},{"category":"So","mappings":{"default":{"default":"black right pointing small triangle","alternative":"black right pointing small triangle"}},"key":"25B8"},{"category":"So","mappings":{"default":{"default":"white right pointing small triangle","alternative":"white right pointing small triangle"}},"key":"25B9"},{"category":"So","mappings":{"default":{"default":"black right pointing pointer","alternative":"black right pointing pointer"}},"key":"25BA"},{"category":"So","mappings":{"default":{"default":"white right pointing pointer","alternative":"white right pointing pointer"}},"key":"25BB"},{"category":"So","mappings":{"default":{"default":"black down pointing triangle","alternative":"black down pointing triangle"}},"key":"25BC"},{"category":"So","mappings":{"default":{"default":"white down pointing triangle","alternative":"white down pointing triangle"}},"key":"25BD"},{"category":"So","mappings":{"default":{"default":"black down pointing small triangle","alternative":"black down pointing small triangle"}},"key":"25BE"},{"category":"So","mappings":{"default":{"default":"white down pointing small triangle","alternative":"white down pointing small triangle"}},"key":"25BF"},{"category":"So","mappings":{"default":{"default":"black left pointing triangle","alternative":"black left pointing triangle"}},"key":"25C0"},{"category":"Sm","mappings":{"default":{"default":"white left pointing triangle","alternative":"white left pointing triangle"}},"key":"25C1"},{"category":"So","mappings":{"default":{"default":"black left pointing small triangle","alternative":"black left pointing small triangle"}},"key":"25C2"},{"category":"So","mappings":{"default":{"default":"white left pointing small triangle","alternative":"white left pointing small triangle"}},"key":"25C3"},{"category":"So","mappings":{"default":{"default":"black left pointing pointer","alternative":"black left pointing pointer"}},"key":"25C4"},{"category":"So","mappings":{"default":{"default":"white left pointing pointer","alternative":"white left pointing pointer"}},"key":"25C5"},{"category":"So","mappings":{"default":{"default":"black diamond"}},"key":"25C6"},{"category":"So","mappings":{"default":{"default":"white diamond"}},"key":"25C7"},{"category":"So","mappings":{"default":{"default":"white diamond containing black small diamond"}},"key":"25C8"},{"category":"So","mappings":{"default":{"default":"fisheye"}},"key":"25C9"},{"category":"So","mappings":{"default":{"default":"lozenge"}},"key":"25CA"},{"category":"So","mappings":{"default":{"default":"white circle"}},"key":"25CB"},{"category":"So","mappings":{"default":{"default":"dotted circle"}},"key":"25CC"},{"category":"So","mappings":{"default":{"default":"circle with vertical fill"}},"key":"25CD"},{"category":"So","mappings":{"default":{"default":"bullseye"}},"key":"25CE"},{"category":"So","mappings":{"default":{"default":"black circle"}},"key":"25CF"},{"category":"So","mappings":{"default":{"default":"circle with left half black"}},"key":"25D0"},{"category":"So","mappings":{"default":{"default":"circle with right half black"}},"key":"25D1"},{"category":"So","mappings":{"default":{"default":"circle with lower half black"}},"key":"25D2"},{"category":"So","mappings":{"default":{"default":"circle with upper half black"}},"key":"25D3"},{"category":"So","mappings":{"default":{"default":"circle with upper right quadrant black"}},"key":"25D4"},{"category":"So","mappings":{"default":{"default":"circle with all but upper left quadrant black"}},"key":"25D5"},{"category":"So","mappings":{"default":{"default":"left half black circle"}},"key":"25D6"},{"category":"So","mappings":{"default":{"default":"right half black circle"}},"key":"25D7"},{"category":"So","mappings":{"default":{"default":"inverse bullet"}},"key":"25D8"},{"category":"So","mappings":{"default":{"default":"inverse white circle"}},"key":"25D9"},{"category":"So","mappings":{"default":{"default":"upper half inverse white circle"}},"key":"25DA"},{"category":"So","mappings":{"default":{"default":"lower half inverse white circle"}},"key":"25DB"},{"category":"So","mappings":{"default":{"default":"upper left quadrant circular arc"}},"key":"25DC"},{"category":"So","mappings":{"default":{"default":"upper right quadrant circular arc"}},"key":"25DD"},{"category":"So","mappings":{"default":{"default":"lower right quadrant circular arc"}},"key":"25DE"},{"category":"So","mappings":{"default":{"default":"lower left quadrant circular arc"}},"key":"25DF"},{"category":"So","mappings":{"default":{"default":"upper half circle"}},"key":"25E0"},{"category":"So","mappings":{"default":{"default":"lower half circle"}},"key":"25E1"},{"category":"So","mappings":{"default":{"default":"black lower right triangle"}},"key":"25E2"},{"category":"So","mappings":{"default":{"default":"black lower left triangle"}},"key":"25E3"},{"category":"So","mappings":{"default":{"default":"black upper left triangle"}},"key":"25E4"},{"category":"So","mappings":{"default":{"default":"black upper right triangle"}},"key":"25E5"},{"category":"So","mappings":{"default":{"default":"white bullet"}},"key":"25E6"},{"category":"So","mappings":{"default":{"default":"square with left half black"}},"key":"25E7"},{"category":"So","mappings":{"default":{"default":"square with right half black"}},"key":"25E8"},{"category":"So","mappings":{"default":{"default":"square with upper left diagonal half black"}},"key":"25E9"},{"category":"So","mappings":{"default":{"default":"square with lower right diagonal half black"}},"key":"25EA"},{"category":"So","mappings":{"default":{"default":"white square with vertical bisecting line"}},"key":"25EB"},{"category":"So","mappings":{"default":{"default":"white up pointing triangle with dot","alternative":"white up pointing triangle with dot"}},"key":"25EC"},{"category":"So","mappings":{"default":{"default":"up pointing triangle with left half black","alternative":"up pointing triangle with left half black"}},"key":"25ED"},{"category":"So","mappings":{"default":{"default":"up pointing triangle with right half black","alternative":"up pointing triangle with right half black"}},"key":"25EE"},{"category":"So","mappings":{"default":{"default":"large circle"}},"key":"25EF"},{"category":"So","mappings":{"default":{"default":"white square with upper left quadrant"}},"key":"25F0"},{"category":"So","mappings":{"default":{"default":"white square with lower left quadrant"}},"key":"25F1"},{"category":"So","mappings":{"default":{"default":"white square with lower right quadrant"}},"key":"25F2"},{"category":"So","mappings":{"default":{"default":"white square with upper right quadrant"}},"key":"25F3"},{"category":"So","mappings":{"default":{"default":"white circle with upper left quadrant"}},"key":"25F4"},{"category":"So","mappings":{"default":{"default":"white circle with lower left quadrant"}},"key":"25F5"},{"category":"So","mappings":{"default":{"default":"white circle with lower right quadrant"}},"key":"25F6"},{"category":"So","mappings":{"default":{"default":"white circle with upper right quadrant"}},"key":"25F7"},{"category":"Sm","mappings":{"default":{"default":"upper left triangle"}},"key":"25F8"},{"category":"Sm","mappings":{"default":{"default":"upper right triangle"}},"key":"25F9"},{"category":"Sm","mappings":{"default":{"default":"lower left triangle"}},"key":"25FA"},{"category":"Sm","mappings":{"default":{"default":"white medium square"}},"key":"25FB"},{"category":"Sm","mappings":{"default":{"default":"black medium square"}},"key":"25FC"},{"category":"Sm","mappings":{"default":{"default":"white medium small square"}},"key":"25FD"},{"category":"Sm","mappings":{"default":{"default":"black medium small square"}},"key":"25FE"},{"category":"Sm","mappings":{"default":{"default":"lower right triangle"}},"key":"25FF"},{"category":"So","mappings":{"default":{"default":"square with top half black"}},"key":"2B12"},{"category":"So","mappings":{"default":{"default":"square with bottom half black"}},"key":"2B13"},{"category":"So","mappings":{"default":{"default":"square with upper right diagonal half black"}},"key":"2B14"},{"category":"So","mappings":{"default":{"default":"square with lower left diagonal half black"}},"key":"2B15"},{"category":"So","mappings":{"default":{"default":"diamond with left half black"}},"key":"2B16"},{"category":"So","mappings":{"default":{"default":"diamond with right half black"}},"key":"2B17"},{"category":"So","mappings":{"default":{"default":"diamond with top half black"}},"key":"2B18"},{"category":"So","mappings":{"default":{"default":"diamond with bottom half black"}},"key":"2B19"},{"category":"So","mappings":{"default":{"default":"dotted square"}},"key":"2B1A"},{"category":"So","mappings":{"default":{"default":"black large square"}},"key":"2B1B"},{"category":"So","mappings":{"default":{"default":"white large square"}},"key":"2B1C"},{"category":"So","mappings":{"default":{"default":"black very small square"}},"key":"2B1D"},{"category":"So","mappings":{"default":{"default":"white very small square"}},"key":"2B1E"},{"category":"So","mappings":{"default":{"default":"black pentagon"}},"key":"2B1F"},{"category":"So","mappings":{"default":{"default":"white pentagon"}},"key":"2B20"},{"category":"So","mappings":{"default":{"default":"white hexagon"}},"key":"2B21"},{"category":"So","mappings":{"default":{"default":"black hexagon"}},"key":"2B22"},{"category":"So","mappings":{"default":{"default":"horizontal black hexagon"}},"key":"2B23"},{"category":"So","mappings":{"default":{"default":"black large circle"}},"key":"2B24"},{"category":"So","mappings":{"default":{"default":"black medium diamond"}},"key":"2B25"},{"category":"So","mappings":{"default":{"default":"white medium diamond"}},"key":"2B26"},{"category":"So","mappings":{"default":{"default":"black medium lozenge"}},"key":"2B27"},{"category":"So","mappings":{"default":{"default":"white medium lozenge"}},"key":"2B28"},{"category":"So","mappings":{"default":{"default":"black small diamond"}},"key":"2B29"},{"category":"So","mappings":{"default":{"default":"black small lozenge"}},"key":"2B2A"},{"category":"So","mappings":{"default":{"default":"white small lozenge"}},"key":"2B2B"},{"category":"So","mappings":{"default":{"default":"black horizontal ellipse"}},"key":"2B2C"},{"category":"So","mappings":{"default":{"default":"white horizontal ellipse"}},"key":"2B2D"},{"category":"So","mappings":{"default":{"default":"black vertical ellipse"}},"key":"2B2E"},{"category":"So","mappings":{"default":{"default":"white vertical ellipse"}},"key":"2B2F"},{"category":"So","mappings":{"default":{"default":"white medium star"}},"key":"2B50"},{"category":"So","mappings":{"default":{"default":"black small star"}},"key":"2B51"},{"category":"So","mappings":{"default":{"default":"white small star"}},"key":"2B52"},{"category":"So","mappings":{"default":{"default":"black right pointing pentagon"}},"key":"2B53"},{"category":"So","mappings":{"default":{"default":"white right pointing pentagon"}},"key":"2B54"},{"category":"So","mappings":{"default":{"default":"heavy large circle"}},"key":"2B55"},{"category":"So","mappings":{"default":{"default":"heavy oval with oval inside"}},"key":"2B56"},{"category":"So","mappings":{"default":{"default":"heavy circle with circle inside"}},"key":"2B57"},{"category":"So","mappings":{"default":{"default":"heavy circle"}},"key":"2B58"},{"category":"So","mappings":{"default":{"default":"heavy circled saltire"}},"key":"2B59"}]
,
"en/math_harpoons.js": 
[{"locale":"en"},{"category":"So","mappings":{"default":{"default":"leftwards harpoon with barb upwards","short":"left harpoon with barb up"}},"key":"21BC"},{"category":"So","mappings":{"default":{"default":"leftwards harpoon with barb downwards","short":"left harpoon with barb down"}},"key":"21BD"},{"category":"So","mappings":{"default":{"default":"upwards harpoon with barb rightwards","short":"up harpoon with barb right"}},"key":"21BE"},{"category":"So","mappings":{"default":{"default":"upwards harpoon with barb leftwards","short":"up harpoon with barb left"}},"key":"21BF"},{"category":"So","mappings":{"default":{"default":"rightwards harpoon with barb upwards","short":"right harpoon with barb up"}},"key":"21C0"},{"category":"So","mappings":{"default":{"default":"rightwards harpoon with barb downwards","short":"right harpoon with barb down"}},"key":"21C1"},{"category":"So","mappings":{"default":{"default":"downwards harpoon with barb rightwards","short":"down harpoon with barb right"}},"key":"21C2"},{"category":"So","mappings":{"default":{"default":"downwards harpoon with barb leftwards","short":"down harpoon with barb left"}},"key":"21C3"},{"category":"So","mappings":{"default":{"default":"leftwards harpoon over rightwards harpoon","short":"left harpoon over right harpoon"}},"key":"21CB"},{"category":"So","mappings":{"default":{"default":"rightwards harpoon over leftwards harpoon","short":"right harpoon over left harpoon"}},"key":"21CC"},{"category":"Sm","mappings":{"default":{"default":"left barb up right barb down harpoon"}},"key":"294A"},{"category":"Sm","mappings":{"default":{"default":"left barb down right barb up harpoon"}},"key":"294B"},{"category":"Sm","mappings":{"default":{"default":"up barb right down barb left harpoon"}},"key":"294C"},{"category":"Sm","mappings":{"default":{"default":"up barb left down barb right harpoon"}},"key":"294D"},{"category":"Sm","mappings":{"default":{"default":"left barb up right barb up harpoon"}},"key":"294E"},{"category":"Sm","mappings":{"default":{"default":"up barb right down barb right harpoon"}},"key":"294F"},{"category":"Sm","mappings":{"default":{"default":"left barb down right barb down harpoon"}},"key":"2950"},{"category":"Sm","mappings":{"default":{"default":"up barb left down barb left harpoon"}},"key":"2951"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb up to bar","short":"left harpoon with barb up to bar"}},"key":"2952"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb up to bar","short":"right harpoon with barb up to bar"}},"key":"2953"},{"category":"Sm","mappings":{"default":{"default":"upwards harpoon with barb right to bar","short":"up harpoon with barb right to bar"}},"key":"2954"},{"category":"Sm","mappings":{"default":{"default":"downwards harpoon with barb right to bar","short":"down harpoon with barb right to bar"}},"key":"2955"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb down to bar","short":"left harpoon with barb down to bar"}},"key":"2956"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb down to bar","short":"right harpoon with barb down to bar"}},"key":"2957"},{"category":"Sm","mappings":{"default":{"default":"upwards harpoon with barb left to bar","short":"up harpoon with barb left to bar"}},"key":"2958"},{"category":"Sm","mappings":{"default":{"default":"downwards harpoon with barb left to bar","short":"down harpoon with barb left to bar"}},"key":"2959"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb up from bar","short":"left harpoon with barb up from bar"}},"key":"295A"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb up from bar","short":"right harpoon with barb up from bar"}},"key":"295B"},{"category":"Sm","mappings":{"default":{"default":"upwards harpoon with barb right from bar","short":"up harpoon with barb right from bar"}},"key":"295C"},{"category":"Sm","mappings":{"default":{"default":"downwards harpoon with barb right from bar","short":"down harpoon with barb right from bar"}},"key":"295D"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb down from bar","short":"left harpoon with barb down from bar"}},"key":"295E"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb down from bar","short":"right harpoon with barb down from bar"}},"key":"295F"},{"category":"Sm","mappings":{"default":{"default":"upwards harpoon with barb left from bar","short":"up harpoon with barb left from bar"}},"key":"2960"},{"category":"Sm","mappings":{"default":{"default":"downwards harpoon with barb left from bar","short":"down harpoon with barb left from bar"}},"key":"2961"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb up above leftwards harpoon with barb down","short":"left harpoon with barb up above left harpoon with barb down"}},"key":"2962"},{"category":"Sm","mappings":{"default":{"default":"upwards harpoon with barb left beside upwards harpoon with barb right","short":"up harpoon with barb left beside up harpoon with barb right"}},"key":"2963"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb up above rightwards harpoon with barb down","short":"right harpoon with barb up above right harpoon with barb down"}},"key":"2964"},{"category":"Sm","mappings":{"default":{"default":"downwards harpoon with barb left beside downwards harpoon with barb right","short":"down harpoon with barb left beside down harpoon with barb right"}},"key":"2965"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb up above rightwards harpoon with barb up","short":"left harpoon with barb up above right harpoon with barb up"}},"key":"2966"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb down above rightwards harpoon with barb down","short":"left harpoon with barb down above right harpoon with barb down"}},"key":"2967"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb up above leftwards harpoon with barb up","short":"right harpoon with barb up above left harpoon with barb up"}},"key":"2968"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb down above leftwards harpoon with barb down","short":"right harpoon with barb down above left harpoon with barb down"}},"key":"2969"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb up above long dash","short":"left harpoon with barb up above long dash"}},"key":"296A"},{"category":"Sm","mappings":{"default":{"default":"leftwards harpoon with barb down below long dash","short":"left harpoon with barb down below long dash"}},"key":"296B"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb up above long dash","short":"right harpoon with barb up above long dash"}},"key":"296C"},{"category":"Sm","mappings":{"default":{"default":"rightwards harpoon with barb down below long dash","short":"right harpoon with barb down below long dash"}},"key":"296D"},{"category":"Sm","mappings":{"default":{"default":"upwards harpoon with barb left beside downwards harpoon with barb right","short":"up harpoon with barb left beside down harpoon with barb right"}},"key":"296E"},{"category":"Sm","mappings":{"default":{"default":"downwards harpoon with barb left beside upwards harpoon with barb right","short":"down harpoon with barb left beside up harpoon with barb right"}},"key":"296F"},{"category":"Sm","mappings":{"default":{"default":"left fish tail"}},"key":"297C"},{"category":"Sm","mappings":{"default":{"default":"right fish tail"}},"key":"297D"},{"category":"Sm","mappings":{"default":{"default":"up fish tail"}},"key":"297E"},{"category":"Sm","mappings":{"default":{"default":"down fish tail"}},"key":"297F"}]
,
"en/math_non_characters.js": 
[{"locale":"en"},{"category":"Ll","mappings":{"default":{"default":"mathematical italic small h over two time greek letter pi","alternative":"italic small h over two pi","short":"italic h over two pi"},"physics":{"default":"planck constant over two pi","alternative":"planck constant over 2 pi"}},"key":"210F"},{"category":"So","mappings":{"default":{"default":"l b bar symbol","short":"l b bar"}},"key":"2114"},{"category":"So","mappings":{"default":{"default":"numero sign","alternative":"numero","short":"numero"}},"key":"2116"},{"category":"So","mappings":{"default":{"default":"sound recording copyright"}},"key":"2117"},{"category":"So","mappings":{"default":{"default":"prescription take"}},"key":"211E"},{"category":"So","mappings":{"default":{"default":"response"}},"key":"211F"},{"category":"So","mappings":{"default":{"default":"service mark"}},"key":"2120"},{"category":"So","mappings":{"default":{"default":"telephone sign","alternative":"t e l symbol"}},"key":"2121"},{"category":"So","mappings":{"default":{"default":"trade mark sign","alternative":"trademark","short":"trade mark"}},"key":"2122"},{"category":"So","mappings":{"default":{"default":"versicle"}},"key":"2123"},{"category":"So","mappings":{"default":{"default":"ounce sign","alternative":"ounce","short":"ounce"}},"key":"2125"},{"category":"Lu","mappings":{"default":{"default":"ohm sign","alternative":"ohm","short":"ohm"}},"key":"2126"},{"category":"So","mappings":{"default":{"default":"inverted ohm sign","alternative":"mho","short":"inverted ohm"}},"key":"2127"},{"category":"Lu","mappings":{"default":{"default":"kelvin sign","alternative":"degrees kelvin","short":"kelvin"}},"key":"212A"},{"category":"Lu","mappings":{"default":{"default":"angstrom sign","alternative":"angstrom unit","short":"angstrom"}},"key":"212B"},{"category":"So","mappings":{"default":{"default":"estimated symbol","short":"estimated"}},"key":"212E"},{"category":"Lu","mappings":{"default":{"default":"turned capital f","alternative":"turned f","short":"turned cap f"},"mathspeak":{"default":"turned upper F"}},"key":"2132"},{"category":"Ll","mappings":{"default":{"default":"information source"}},"key":"2139"},{"category":"So","mappings":{"default":{"default":"rotated capital q","short":"rotated cap q"},"mathspeak":{"default":"rotated upper Q"}},"key":"213A"},{"category":"So","mappings":{"default":{"default":"facsimile sign"}},"key":"213B"},{"category":"Sm","mappings":{"default":{"default":"turned sans serif capital g","short":"turned sans serif cap g"},"mathspeak":{"default":"turned sans serif upper G"}},"key":"2141"},{"category":"Sm","mappings":{"default":{"default":"turned sans serif capital l","short":"turned sans serif cap l"},"mathspeak":{"default":"turned sans serif upper L"}},"key":"2142"},{"category":"Sm","mappings":{"default":{"default":"reversed sans serif capital l","short":"reversed sans serif cap l"},"mathspeak":{"default":"reversed sans serif upper L"}},"key":"2143"},{"category":"Sm","mappings":{"default":{"default":"turned sans serif capital y","short":"turned sans serif cap y"},"mathspeak":{"default":"turned sans serif upper Y"}},"key":"2144"}]
,
"en/math_symbols.js": 
[{"locale":"en"},{"category":"Po","mappings":{"default":{"default":"factorial operator","alternative":"exclamation mark","short":"factorial"},"mathspeak":{"default":"exclamation-mark"}},"key":"0021"},{"category":"Po","mappings":{"default":{"default":"quotation mark"},"mathspeak":{"default":"quotation-mark"}},"key":"0022"},{"category":"Po","mappings":{"default":{"default":"number sign","alternative":"hash","short":"number"},"mathspeak":{"default":"number-sign","brief":"num-sign","sbrief":"num-sign"}},"key":"0023"},{"category":"Sc","mappings":{"default":{"default":"dollar sign","short":"dollar"},"mathspeak":{"default":"dollar-sign"}},"key":"0024"},{"category":"Po","mappings":{"default":{"default":"percent sign","short":"percent"},"mathspeak":{"default":"percent-sign"}},"key":"0025"},{"category":"Po","mappings":{"default":{"default":"ampersand"}},"key":"0026"},{"category":"Po","mappings":{"default":{"default":"apostrophe","alternative":"apostrophe quote"},"mathspeak":{"default":"prime"}},"key":"0027"},{"category":"Po","mappings":{"default":{"default":"asterisk"}},"key":"002A"},{"category":"Sm","mappings":{"default":{"default":"plus sign","short":"plus"}},"key":"002B"},{"category":"Po","mappings":{"default":{"default":"comma"}},"key":"002C"},{"category":"Pd","mappings":{"default":{"default":"hyphen minus","short":"minus"},"mathspeak":{"default":"hyphen"}},"key":"002D"},{"category":"Po","mappings":{"default":{"default":"full stop","alternative":"period"},"mathspeak":{"default":"period"}},"key":"002E"},{"category":"Po","mappings":{"default":{"default":"solidus","alternative":"slash"},"mathspeak":{"default":"slash"},"emacspeak":{"default":"slash"}},"key":"002F"},{"category":"Po","mappings":{"default":{"default":"colon"}},"key":"003A"},{"category":"Po","mappings":{"default":{"default":"semicolon"}},"key":"003B"},{"category":"Sm","mappings":{"default":{"default":"less than sign","short":"less than"},"mathspeak":{"default":"less-than"}},"key":"003C"},{"category":"Sm","mappings":{"default":{"default":"equals sign","short":"equals"}},"key":"003D"},{"category":"Sm","mappings":{"default":{"default":"greater than sign","short":"greater than"},"mathspeak":{"default":"greater-than"}},"key":"003E"},{"category":"Po","mappings":{"default":{"default":"question mark"},"mathspeak":{"default":"question-mark"}},"key":"003F"},{"category":"Po","mappings":{"default":{"default":"commercial at","short":"at"},"mathspeak":{"default":"commercial-at"}},"key":"0040"},{"category":"Po","mappings":{"default":{"default":"reverse solidus","alternative":"backslash"},"mathspeak":{"default":"reverse-solidus"}},"key":"005C"},{"category":"Sk","mappings":{"default":{"default":"circumflex accent","alternative":"spacing circumflex","short":"hat"},"mathspeak":{"default":"caret"}},"key":"005E"},{"category":"Pc","mappings":{"default":{"default":"low line","alternative":"spacing underscore"},"mathspeak":{"default":"bar"}},"key":"005F"},{"category":"Sk","mappings":{"default":{"default":"grave accent","alternative":"spacing grave","short":"grave"},"mathspeak":{"default":"grave"}},"key":"0060"},{"category":"Sm","mappings":{"default":{"default":"vertical line","alternative":"vertical bar"},"mathspeak":{"default":"vertical-bar"}},"key":"007C"},{"category":"Sm","mappings":{"default":{"default":"tilde"}},"key":"007E"},{"category":"Po","mappings":{"default":{"default":"inverted exclamation mark"},"mathspeak":{"default":"inverted-exclamation-mark"}},"key":"00A1"},{"category":"Sc","mappings":{"default":{"default":"cent sign","short":"cent"},"mathspeak":{"default":"cent-sign"}},"key":"00A2"},{"category":"Sc","mappings":{"default":{"default":"pound sign","short":"pound"},"mathspeak":{"default":"pound-sign"}},"key":"00A3"},{"category":"Sc","mappings":{"default":{"default":"currency sign","short":"currency"},"mathspeak":{"default":"currency-sign"}},"key":"00A4"},{"category":"Sc","mappings":{"default":{"default":"yen sign","short":"yen"},"mathspeak":{"default":"yen-sign"}},"key":"00A5"},{"category":"So","mappings":{"default":{"default":"broken bar","alternative":"broken vertical bar"},"mathspeak":{"default":"broken-vertical-bar"}},"key":"00A6"},{"category":"Po","mappings":{"default":{"default":"section sign","short":"section"},"mathspeak":{"default":"section-sign"}},"key":"00A7"},{"category":"Sk","mappings":{"default":{"default":"diaeresis","alternative":"spacing diaeresis","short":"double dot"},"mathspeak":{"default":"two-dots"}},"key":"00A8"},{"category":"So","mappings":{"default":{"default":"copyright sign","short":"copyright"},"mathspeak":{"default":"copyright-sign"}},"key":"00A9"},{"category":"Lo","mappings":{"default":{"default":"feminine ordinal indicator"},"mathspeak":{"default":"feminine-ordinal-indicator"}},"key":"00AA"},{"category":"Pi","mappings":{"default":{"default":"left pointing double angle quotation mark","alternative":"left pointing guillemet"},"mathspeak":{"default":"left-pointing-guillemet"}},"key":"00AB"},{"category":"Sm","mappings":{"default":{"default":"not sign","short":"not"},"mathspeak":{"default":"not-sign"}},"key":"00AC"},{"category":"So","mappings":{"default":{"default":"registered sign","alternative":"registered trade mark sign","short":"registered"},"mathspeak":{"default":"registered-trade-mark-sign"}},"key":"00AE"},{"category":"Sk","mappings":{"default":{"default":"macron","alternative":"spacing macron"},"mathspeak":{"default":"bar"}},"key":"00AF"},{"category":"So","mappings":{"default":{"default":"degree sign","short":"degree"},"mathspeak":{"default":"degree"}},"key":"00B0"},{"category":"Sm","mappings":{"default":{"default":"plus minus sign","alternative":"plus or minus sign","short":"plus minus"},"mathspeak":{"default":"plus-or-minus"}},"key":"00B1"},{"category":"Sk","mappings":{"default":{"default":"acute accent","alternative":"spacing acute","short":"acute"},"mathspeak":{"default":"acute"}},"key":"00B4"},{"category":"Ll","mappings":{"default":{"default":"micro sign","short":"micro"},"mathspeak":{"default":"micro-sign"}},"key":"00B5"},{"category":"Po","mappings":{"default":{"default":"pilcrow sign","alternative":"paragraph sign","short":"pilcrow"},"mathspeak":{"default":"paragraph-sign"}},"key":"00B6"},{"category":"Po","mappings":{"default":{"default":"middle dot"},"mathspeak":{"default":"dot"}},"key":"00B7"},{"category":"Sk","mappings":{"default":{"default":"cedilla","alternative":"spacing cedilla"},"mathspeak":{"default":"cedilla"}},"key":"00B8"},{"category":"Lo","mappings":{"default":{"default":"masculine ordinal indicator"},"mathspeak":{"default":"masculine-ordinal-indicator"}},"key":"00BA"},{"category":"Pf","mappings":{"default":{"default":"right pointing double angle quotation mark","alternative":"right pointing guillemet"},"mathspeak":{"default":"right-pointing-guillemet"}},"key":"00BB"},{"category":"Po","mappings":{"default":{"default":"inverted question mark"},"mathspeak":{"default":"inverted-question-mark"}},"key":"00BF"},{"category":"Sm","mappings":{"default":{"default":"multiplication sign","short":"multiplication"},"mathspeak":{"default":"times"}},"key":"00D7"},{"category":"Sm","mappings":{"default":{"default":"division sign","short":"division"},"mathspeak":{"default":"division-sign"}},"key":"00F7"},{"category":"Sk","mappings":{"default":{"default":"breve","alternative":"spacing breve"},"mathspeak":{"default":"breve"}},"key":"02D8"},{"category":"Sk","mappings":{"default":{"default":"dot above","alternative":"spacing dot above"},"mathspeak":{"default":"dot"}},"key":"02D9"},{"category":"Sk","mappings":{"default":{"default":"ring above","alternative":"spacing ring above"},"mathspeak":{"default":"ring-above"}},"key":"02DA"},{"category":"Sk","mappings":{"default":{"default":"ogonek","alternative":"spacing ogonek"},"mathspeak":{"default":"ogonek"}},"key":"02DB"},{"category":"Sk","mappings":{"default":{"default":"small tilde","alternative":"spacing tilde"},"mathspeak":{"default":"tilde"}},"key":"02DC"},{"category":"Sk","mappings":{"default":{"default":"double acute accent","alternative":"spacing double acute"},"mathspeak":{"default":"double-acute"}},"key":"02DD"},{"category":"Pd","mappings":{"default":{"default":"hyphen"}},"key":"2010"},{"category":"Pd","mappings":{"default":{"default":"non breaking hyphen"},"mathspeak":{"default":"non-breaking-hyphen"}},"key":"2011"},{"category":"Pd","mappings":{"default":{"default":"figure dash"},"mathspeak":{"default":"figure-dash"}},"key":"2012"},{"category":"Pd","mappings":{"default":{"default":"en dash"},"mathspeak":{"default":"en-dash"}},"key":"2013"},{"category":"Pd","mappings":{"default":{"default":"em dash"},"mathspeak":{"default":"em-dash"}},"key":"2014"},{"category":"Pd","mappings":{"default":{"default":"horizontal bar","alternative":"quotation dash"},"mathspeak":{"default":"quotation-dash"}},"key":"2015"},{"category":"Po","mappings":{"default":{"default":"double vertical line","alternative":"double vertical bar"},"mathspeak":{"default":"double-vertical-bar"}},"key":"2016"},{"category":"Po","mappings":{"default":{"default":"double low line","alternative":"spacing double underscore"},"mathspeak":{"default":"double-underscore"}},"key":"2017"},{"category":"Pi","mappings":{"default":{"default":"left single quotation mark","alternative":"single turned comma quotation mark"},"mathspeak":{"default":"single-turned-comma-quotation-mark"}},"key":"2018"},{"category":"Pf","mappings":{"default":{"default":"right single quotation mark","alternative":"single comma quotation mark"},"mathspeak":{"default":"single-comma-quotation-mark"}},"key":"2019"},{"category":"Ps","mappings":{"default":{"default":"single low 9 quotation mark","alternative":"low single comma quotation mark"},"mathspeak":{"default":"low-single-comma-quotation-mark"}},"key":"201A"},{"category":"Pi","mappings":{"default":{"default":"single high reversed 9 quotation mark","alternative":"single reversed comma quotation mark"},"mathspeak":{"default":"single-reversed-comma-quotation-mark"}},"key":"201B"},{"category":"Pi","mappings":{"default":{"default":"left double quotation mark","alternative":"double turned comma quotation mark"},"mathspeak":{"default":"double-turned-comma-quotation-mark"}},"key":"201C"},{"category":"Pf","mappings":{"default":{"default":"right double quotation mark","alternative":"double comma quotation mark"},"mathspeak":{"default":"double-comma-quotation-mark"}},"key":"201D"},{"category":"Ps","mappings":{"default":{"default":"double low 9 quotation mark","alternative":"low double comma quotation mark"},"mathspeak":{"default":"low-double-comma-quotation-mark"}},"key":"201E"},{"category":"Pi","mappings":{"default":{"default":"double high reversed 9 quotation mark","alternative":"double reversed comma quotation mark"},"mathspeak":{"default":"double-reversed-comma-quotation-mark"}},"key":"201F"},{"category":"Po","mappings":{"default":{"default":"dagger"}},"key":"2020"},{"category":"Po","mappings":{"default":{"default":"double dagger"},"mathspeak":{"default":"double-dagger"}},"key":"2021"},{"category":"Po","mappings":{"default":{"default":"bullet"}},"key":"2022"},{"category":"Po","mappings":{"default":{"default":"triangular bullet"},"mathspeak":{"default":"triangular-bullet"}},"key":"2023"},{"category":"Po","mappings":{"default":{"default":"one dot leader"},"mathspeak":{"default":"one-dot-leader"}},"key":"2024"},{"category":"Po","mappings":{"default":{"default":"two dot leader"},"mathspeak":{"default":"two-dot-leader"}},"key":"2025"},{"category":"Po","mappings":{"default":{"default":"horizontal ellipsis"},"mathspeak":{"default":"ellipsis"}},"key":"2026"},{"category":"Po","mappings":{"default":{"default":"hyphenation point"},"mathspeak":{"default":"hyphenation-point"}},"key":"2027"},{"category":"Po","mappings":{"default":{"default":"per mille sign","short":"per mille"},"mathspeak":{"default":"per-mille"}},"key":"2030"},{"category":"Po","mappings":{"default":{"default":"per ten thousand sign","short":"per ten thousand"},"mathspeak":{"default":"per-ten-thousand"}},"key":"2031"},{"category":"Po","mappings":{"default":{"default":"prime"}},"key":"2032"},{"category":"Po","mappings":{"default":{"default":"double prime"},"mathspeak":{"default":"double-prime"}},"key":"2033"},{"category":"Po","mappings":{"default":{"default":"triple prime"},"mathspeak":{"default":"triple-prime"}},"key":"2034"},{"category":"Po","mappings":{"default":{"default":"reversed prime"},"mathspeak":{"default":"reversed-prime"}},"key":"2035"},{"category":"Po","mappings":{"default":{"default":"reversed double prime"},"mathspeak":{"default":"reversed-double-prime"}},"key":"2036"},{"category":"Po","mappings":{"default":{"default":"reversed triple prime"},"mathspeak":{"default":"reversed-triple-prime"}},"key":"2037"},{"category":"Po","mappings":{"default":{"default":"caret"}},"key":"2038"},{"category":"Pi","mappings":{"default":{"default":"single left pointing angle quotation mark","alternative":"left pointing single guillemet"},"mathspeak":{"default":"left-pointing-single-guillemet"}},"key":"2039"},{"category":"Pf","mappings":{"default":{"default":"single right pointing angle quotation mark","alternative":"right pointing single guillemet"},"mathspeak":{"default":"right-pointing-single-guillemet"}},"key":"203A"},{"category":"Po","mappings":{"default":{"default":"reference mark"},"mathspeak":{"default":"reference-mark"}},"key":"203B"},{"category":"Po","mappings":{"default":{"default":"double exclamation mark"},"mathspeak":{"default":"double-exclamation-mark"}},"key":"203C"},{"category":"Po","mappings":{"default":{"default":"interrobang"}},"key":"203D"},{"category":"Po","mappings":{"default":{"default":"overline","alternative":"spacing overscore"},"mathspeak":{"default":"bar"}},"key":"203E"},{"category":"Pc","mappings":{"default":{"default":"undertie"}},"key":"203F"},{"category":"Pc","mappings":{"default":{"default":"character tie"},"mathspeak":{"default":"character-tie"}},"key":"2040"},{"category":"Po","mappings":{"default":{"default":"caret insertion point"},"mathspeak":{"default":"caret-insertion-point"}},"key":"2041"},{"category":"Po","mappings":{"default":{"default":"asterism"}},"key":"2042"},{"category":"Po","mappings":{"default":{"default":"hyphen bullet"},"mathspeak":{"default":"hyphen-bullet"}},"key":"2043"},{"category":"Sm","mappings":{"default":{"default":"fraction slash"},"mathspeak":{"default":"fraction-slash"}},"key":"2044"},{"category":"Po","mappings":{"default":{"default":"double question mark"},"mathspeak":{"default":"double-question-mark"}},"key":"2047"},{"category":"Po","mappings":{"default":{"default":"question exclamation mark"},"mathspeak":{"default":"question-exclamation-mark"}},"key":"2048"},{"category":"Po","mappings":{"default":{"default":"exclamation question mark"},"mathspeak":{"default":"exclamation-question-mark"}},"key":"2049"},{"category":"Po","mappings":{"default":{"default":"reversed pilcrow sign","short":"reversed pilcrow"},"mathspeak":{"default":"reversed-pilcrow"}},"key":"204B"},{"category":"Po","mappings":{"default":{"default":"black leftwards bullet"},"mathspeak":{"default":"black-leftwards-bullet"}},"key":"204C"},{"category":"Po","mappings":{"default":{"default":"black rightwards bullet"},"mathspeak":{"default":"black-rightwards-bullet"}},"key":"204D"},{"category":"Po","mappings":{"default":{"default":"low asterisk"},"mathspeak":{"default":"low-asterisk"}},"key":"204E"},{"category":"Po","mappings":{"default":{"default":"reversed semicolon"},"mathspeak":{"default":"reversed-semicolon"}},"key":"204F"},{"category":"Po","mappings":{"default":{"default":"close up"},"mathspeak":{"default":"close-up"}},"key":"2050"},{"category":"Po","mappings":{"default":{"default":"two asterisks aligned vertically"},"mathspeak":{"default":"two-asterisks-aligned-vertically"}},"key":"2051"},{"category":"Sm","mappings":{"default":{"default":"commercial minus sign","short":"commercial minus"},"mathspeak":{"default":"commercial-minus"}},"key":"2052"},{"category":"Po","mappings":{"default":{"default":"swung dash"},"mathspeak":{"default":"swung-dash"}},"key":"2053"},{"category":"Pc","mappings":{"default":{"default":"inverted undertie"},"mathspeak":{"default":"inverted-undertie"}},"key":"2054"},{"category":"Po","mappings":{"default":{"default":"flower punctuation mark"},"mathspeak":{"default":"flower-punctuation-mark"}},"key":"2055"},{"category":"Po","mappings":{"default":{"default":"three dot punctuation"},"mathspeak":{"default":"three-dot-punctuation"}},"key":"2056"},{"category":"Po","mappings":{"default":{"default":"quadruple prime"},"mathspeak":{"default":"quadruple-prime"}},"key":"2057"},{"category":"Po","mappings":{"default":{"default":"four dot punctuation"},"mathspeak":{"default":"four-dot-punctuation"}},"key":"2058"},{"category":"Po","mappings":{"default":{"default":"five dot punctuation"},"mathspeak":{"default":"five-dot-punctuation"}},"key":"2059"},{"category":"Po","mappings":{"default":{"default":"two dot punctuation"},"mathspeak":{"default":"two-dot-punctuation"}},"key":"205A"},{"category":"Po","mappings":{"default":{"default":"four dot mark"},"mathspeak":{"default":"four-dot-mark"}},"key":"205B"},{"category":"Po","mappings":{"default":{"default":"dotted cross"},"mathspeak":{"default":"dotted-cross"}},"key":"205C"},{"category":"Po","mappings":{"default":{"default":"tricolon"}},"key":"205D"},{"category":"Po","mappings":{"default":{"default":"vertical four dots"},"mathspeak":{"default":"vertical-four-dots"}},"key":"205E"},{"category":"Sm","mappings":{"default":{"default":"superscript plus sign","short":"superscript plus"},"mathspeak":{"default":"superscript-plus"}},"key":"207A"},{"category":"Sm","mappings":{"default":{"default":"superscript minus","alternative":"superscript hyphen minus"},"mathspeak":{"default":"superscript-hyphen-minus"}},"key":"207B"},{"category":"Sm","mappings":{"default":{"default":"superscript equals sign","short":"superscript equals"},"mathspeak":{"default":"superscript-equals"}},"key":"207C"},{"category":"Ps","mappings":{"default":{"default":"superscript left parenthesis","alternative":"superscript opening parenthesis"},"mathspeak":{"default":"superscript-opening-parenthesis"}},"key":"207D"},{"category":"Pe","mappings":{"default":{"default":"superscript right parenthesis","alternative":"superscript closing parenthesis"},"mathspeak":{"default":"superscript-closing-parenthesis"}},"key":"207E"},{"category":"Sm","mappings":{"default":{"default":"subscript plus sign","short":"subscript plus"},"mathspeak":{"default":"subscript-plus"}},"key":"208A"},{"category":"Sm","mappings":{"default":{"default":"subscript minus","alternative":"subscript hyphen minus"},"mathspeak":{"default":"subscript-hyphen-minus"}},"key":"208B"},{"category":"Sm","mappings":{"default":{"default":"subscript equals sign","short":"subscript equals"},"mathspeak":{"default":"subscript-equals"}},"key":"208C"},{"category":"Ps","mappings":{"default":{"default":"subscript left parenthesis","alternative":"subscript opening parenthesis"},"mathspeak":{"default":"subscript-opening-parenthesis"}},"key":"208D"},{"category":"Pe","mappings":{"default":{"default":"subscript right parenthesis","alternative":"subscript closing parenthesis"},"mathspeak":{"default":"subscript-closing-parenthesis"}},"key":"208E"},{"category":"So","mappings":{"default":{"default":"property line"},"mathspeak":{"default":"property-line"}},"key":"214A"},{"category":"Sm","mappings":{"default":{"default":"turned ampersand"},"mathspeak":{"default":"turned-ampersand"}},"key":"214B"},{"category":"So","mappings":{"default":{"default":"per sign","short":"per"},"mathspeak":{"default":"per-sign"}},"key":"214C"},{"category":"So","mappings":{"default":{"default":"aktieselskab"}},"key":"214D"},{"category":"Ll","mappings":{"default":{"default":"turned small f"},"mathspeak":{"default":"turned-small-f"}},"key":"214E"},{"category":"Sm","mappings":{"default":{"default":"for all"},"mathspeak":{"default":"for-all"}},"key":"2200"},{"category":"Sm","mappings":{"default":{"default":"complement"}},"key":"2201"},{"category":"Sm","mappings":{"default":{"default":"partial differential"},"mathspeak":{"default":"partial-differential"}},"key":"2202"},{"category":"Sm","mappings":{"default":{"default":"there exists"},"mathspeak":{"default":"there-exists"}},"key":"2203"},{"category":"Sm","mappings":{"default":{"default":"there does not exist"},"mathspeak":{"default":"there-does-not-exist"}},"key":"2204"},{"category":"Sm","mappings":{"default":{"default":"empty set"},"mathspeak":{"default":"empty-set"}},"key":"2205"},{"category":"Sm","mappings":{"default":{"default":"increment"}},"key":"2206"},{"category":"Sm","mappings":{"default":{"default":"nabla"}},"key":"2207"},{"category":"Sm","mappings":{"default":{"default":"element of"},"mathspeak":{"default":"element-of"}},"key":"2208"},{"category":"Sm","mappings":{"default":{"default":"not an element of"},"mathspeak":{"default":"not-an-element-of"}},"key":"2209"},{"category":"Sm","mappings":{"default":{"default":"small element of"},"mathspeak":{"default":"small-element-of"}},"key":"220A"},{"category":"Sm","mappings":{"default":{"default":"contains as member"},"mathspeak":{"default":"contains-as-member"}},"key":"220B"},{"category":"Sm","mappings":{"default":{"default":"does not contain as member"},"mathspeak":{"default":"does-not-contain-as-member"}},"key":"220C"},{"category":"Sm","mappings":{"default":{"default":"small contains as member"},"mathspeak":{"default":"small-contains-as-member"}},"key":"220D"},{"category":"Sm","mappings":{"default":{"default":"end of proof"},"mathspeak":{"default":"end-of-proof"}},"key":"220E"},{"category":"Sm","mappings":{"default":{"default":"n ary product"},"mathspeak":{"default":"product"}},"key":"220F"},{"category":"Sm","mappings":{"default":{"default":"n ary coproduct"},"mathspeak":{"default":"coproduct"}},"key":"2210"},{"category":"Sm","mappings":{"default":{"default":"n ary summation"},"mathspeak":{"default":"sigma-summation"}},"key":"2211"},{"category":"Sm","mappings":{"default":{"default":"minus sign","short":"minus"}},"key":"2212"},{"category":"Sm","mappings":{"default":{"default":"minus or plus sign","short":"minus or plus"},"mathspeak":{"default":"minus-or-plus"}},"key":"2213"},{"category":"Sm","mappings":{"default":{"default":"dot plus"},"mathspeak":{"default":"dot-plus"}},"key":"2214"},{"category":"Sm","mappings":{"default":{"default":"division slash"},"mathspeak":{"default":"division-slash"}},"key":"2215"},{"category":"Sm","mappings":{"default":{"default":"set minus"},"mathspeak":{"default":"set-minus"}},"key":"2216"},{"category":"Sm","mappings":{"default":{"default":"asterisk operator"},"mathspeak":{"default":"asterisk"}},"key":"2217"},{"category":"Sm","mappings":{"default":{"default":"ring operator"},"mathspeak":{"default":"ring"}},"key":"2218"},{"category":"Sm","mappings":{"default":{"default":"bullet operator"},"mathspeak":{"default":"bullet"}},"key":"2219"},{"category":"Sm","mappings":{"default":{"default":"square root"},"mathspeak":{"default":"square-root"}},"key":"221A"},{"category":"Sm","mappings":{"default":{"default":"cube root"},"mathspeak":{"default":"cube-root"}},"key":"221B"},{"category":"Sm","mappings":{"default":{"default":"fourth root"},"mathspeak":{"default":"fourth-root"}},"key":"221C"},{"category":"Sm","mappings":{"default":{"default":"proportional to"},"mathspeak":{"default":"proportional-to"}},"key":"221D"},{"category":"Sm","mappings":{"default":{"default":"infinity"}},"key":"221E"},{"category":"Sm","mappings":{"default":{"default":"right angle"},"mathspeak":{"default":"right-angle"}},"key":"221F"},{"category":"Sm","mappings":{"default":{"default":"angle"}},"key":"2220"},{"category":"Sm","mappings":{"default":{"default":"measured angle"},"mathspeak":{"default":"measured-angle"}},"key":"2221"},{"category":"Sm","mappings":{"default":{"default":"spherical angle"},"mathspeak":{"default":"spherical-angle"}},"key":"2222"},{"category":"Sm","mappings":{"default":{"default":"divides","short":"bar"}},"key":"2223"},{"category":"Sm","mappings":{"default":{"default":"does not divide"},"mathspeak":{"default":"does-not-divide"}},"key":"2224"},{"category":"Sm","mappings":{"default":{"default":"parallel to"},"mathspeak":{"default":"parallel-to"}},"key":"2225"},{"category":"Sm","mappings":{"default":{"default":"not parallel to"},"mathspeak":{"default":"not-parallel-to"}},"key":"2226"},{"category":"Sm","mappings":{"default":{"default":"logical and"},"mathspeak":{"default":"logical-and"}},"key":"2227"},{"category":"Sm","mappings":{"default":{"default":"logical or"},"mathspeak":{"default":"logical-or"}},"key":"2228"},{"category":"Sm","mappings":{"default":{"default":"intersection"}},"key":"2229"},{"category":"Sm","mappings":{"default":{"default":"union"}},"key":"222A"},{"category":"Sm","mappings":{"default":{"default":"integral"}},"key":"222B"},{"category":"Sm","mappings":{"default":{"default":"double integral"},"mathspeak":{"default":"double-integral"}},"key":"222C"},{"category":"Sm","mappings":{"default":{"default":"triple integral"},"mathspeak":{"default":"triple-integral"}},"key":"222D"},{"category":"Sm","mappings":{"default":{"default":"contour integral"},"mathspeak":{"default":"contour-integral"}},"key":"222E"},{"category":"Sm","mappings":{"default":{"default":"surface integral"},"mathspeak":{"default":"surface-integral"}},"key":"222F"},{"category":"Sm","mappings":{"default":{"default":"volume integral"},"mathspeak":{"default":"volume-integral"}},"key":"2230"},{"category":"Sm","mappings":{"default":{"default":"clockwise integral"},"mathspeak":{"default":"clockwise-integral"}},"key":"2231"},{"category":"Sm","mappings":{"default":{"default":"clockwise contour integral"},"mathspeak":{"default":"clockwise-contour-integral"}},"key":"2232"},{"category":"Sm","mappings":{"default":{"default":"anticlockwise contour integral"},"mathspeak":{"default":"anticlockwise-contour-integral"}},"key":"2233"},{"category":"Sm","mappings":{"default":{"default":"therefore"}},"key":"2234"},{"category":"Sm","mappings":{"default":{"default":"because"}},"key":"2235"},{"category":"Sm","mappings":{"default":{"default":"ratio"}},"key":"2236"},{"category":"Sm","mappings":{"default":{"default":"proportion"}},"key":"2237"},{"category":"Sm","mappings":{"default":{"default":"dot minus"},"mathspeak":{"default":"dot-minus"}},"key":"2238"},{"category":"Sm","mappings":{"default":{"default":"excess"}},"key":"2239"},{"category":"Sm","mappings":{"default":{"default":"geometric proportion"},"mathspeak":{"default":"geometric-proportion"}},"key":"223A"},{"category":"Sm","mappings":{"default":{"default":"homothetic"}},"key":"223B"},{"category":"Sm","mappings":{"default":{"default":"tilde operator"},"mathspeak":{"default":"tilde"}},"key":"223C"},{"category":"Sm","mappings":{"default":{"default":"reversed tilde"},"mathspeak":{"default":"reversed-tilde"}},"key":"223D"},{"category":"Sm","mappings":{"default":{"default":"inverted lazy s"},"mathspeak":{"default":"inverted-lazy-s"}},"key":"223E"},{"category":"Sm","mappings":{"default":{"default":"sine wave"},"mathspeak":{"default":"sine-wave"}},"key":"223F"},{"category":"Sm","mappings":{"default":{"default":"wreath product"},"mathspeak":{"default":"wreath-product"}},"key":"2240"},{"category":"Sm","mappings":{"default":{"default":"not tilde"},"mathspeak":{"default":"not-tilde"}},"key":"2241"},{"category":"Sm","mappings":{"default":{"default":"minus tilde"},"mathspeak":{"default":"minus-tilde"}},"key":"2242"},{"category":"Sm","mappings":{"default":{"default":"asymptotically equals"},"mathspeak":{"default":"asymptotically-equals"}},"key":"2243"},{"category":"Sm","mappings":{"default":{"default":"not asymptotically equals"},"mathspeak":{"default":"not-asymptotically-equals"}},"key":"2244"},{"category":"Sm","mappings":{"default":{"default":"approximately equals"},"mathspeak":{"default":"approximately-equals"}},"key":"2245"},{"category":"Sm","mappings":{"default":{"default":"approximately but not actually equals"},"mathspeak":{"default":"approximately-but-not-actually-equals"}},"key":"2246"},{"category":"Sm","mappings":{"default":{"default":"neither approximately nor actually equals"},"mathspeak":{"default":"neither-approximately-nor-actually-equals"}},"key":"2247"},{"category":"Sm","mappings":{"default":{"default":"almost equals"},"mathspeak":{"default":"almost-equals"}},"key":"2248"},{"category":"Sm","mappings":{"default":{"default":"not almost equals"},"mathspeak":{"default":"not-almost-equals"}},"key":"2249"},{"category":"Sm","mappings":{"default":{"default":"almost equal or equals"},"mathspeak":{"default":"almost-equal-or-equal-to"}},"key":"224A"},{"category":"Sm","mappings":{"default":{"default":"triple tilde"},"mathspeak":{"default":"triple-tilde"}},"key":"224B"},{"category":"Sm","mappings":{"default":{"default":"all equals"},"mathspeak":{"default":"all-equals"}},"key":"224C"},{"category":"Sm","mappings":{"default":{"default":"equivalent to"},"mathspeak":{"default":"equivalent-to"}},"key":"224D"},{"category":"Sm","mappings":{"default":{"default":"geometrically equivalent to"},"mathspeak":{"default":"geometrically-equivalent-to"}},"key":"224E"},{"category":"Sm","mappings":{"default":{"default":"difference between"},"mathspeak":{"default":"difference-between"}},"key":"224F"},{"category":"Sm","mappings":{"default":{"default":"approaches the limit"},"mathspeak":{"default":"approaches-the-limit"}},"key":"2250"},{"category":"Sm","mappings":{"default":{"default":"geometrically equals"},"mathspeak":{"default":"geometrically-equals"}},"key":"2251"},{"category":"Sm","mappings":{"default":{"default":"approximately equals or the image of"},"mathspeak":{"default":"approximately-equals-or-the-image-of"}},"key":"2252"},{"category":"Sm","mappings":{"default":{"default":"image of or approximately equals"},"mathspeak":{"default":"image-of-or-approximately-equals"}},"key":"2253"},{"category":"Sm","mappings":{"default":{"default":"colon equals","alternative":"colon equal"},"mathspeak":{"default":"colon-equal"}},"key":"2254"},{"category":"Sm","mappings":{"default":{"default":"equals colon","alternative":"equal colon"},"mathspeak":{"default":"equal-colon"}},"key":"2255"},{"category":"Sm","mappings":{"default":{"default":"ring in equals"},"mathspeak":{"default":"ring-in-equals"}},"key":"2256"},{"category":"Sm","mappings":{"default":{"default":"ring equals"},"mathspeak":{"default":"ring-equals"}},"key":"2257"},{"category":"Sm","mappings":{"default":{"default":"corresponds to"},"mathspeak":{"default":"corresponds-to"}},"key":"2258"},{"category":"Sm","mappings":{"default":{"default":"estimates"}},"key":"2259"},{"category":"Sm","mappings":{"default":{"default":"equiangular to"},"mathspeak":{"default":"equiangular-to"}},"key":"225A"},{"category":"Sm","mappings":{"default":{"default":"star equals"},"mathspeak":{"default":"star-equals"}},"key":"225B"},{"category":"Sm","mappings":{"default":{"default":"delta equals"},"mathspeak":{"default":"delta-equals"}},"key":"225C"},{"category":"Sm","mappings":{"default":{"default":"equals by definition"},"mathspeak":{"default":"equals-by-definition"}},"key":"225D"},{"category":"Sm","mappings":{"default":{"default":"measured by"},"mathspeak":{"default":"measured-by"}},"key":"225E"},{"category":"Sm","mappings":{"default":{"default":"questioned equals"},"mathspeak":{"default":"questioned-equals"}},"key":"225F"},{"category":"Sm","mappings":{"default":{"default":"not equals"},"mathspeak":{"default":"not-equals"}},"key":"2260"},{"category":"Sm","mappings":{"default":{"default":"identical to"},"mathspeak":{"default":"identical-to"}},"key":"2261"},{"category":"Sm","mappings":{"default":{"default":"not identical to"},"mathspeak":{"default":"not-identical-to"}},"key":"2262"},{"category":"Sm","mappings":{"default":{"default":"strictly equivalent to"},"mathspeak":{"default":"strictly-equivalent-to"}},"key":"2263"},{"category":"Sm","mappings":{"default":{"default":"less than or equals","alternative":"less than or equals"},"mathspeak":{"default":"less-than-or-equal-to"}},"key":"2264"},{"category":"Sm","mappings":{"default":{"default":"greater than or equals","alternative":"greater than or equals"},"mathspeak":{"default":"greater-than-or-equal-to"}},"key":"2265"},{"category":"Sm","mappings":{"default":{"default":"less than over equals","alternative":"less than over equals"},"mathspeak":{"default":"less-than-over-equals"}},"key":"2266"},{"category":"Sm","mappings":{"default":{"default":"greater than over equals","alternative":"greater than over equals"},"mathspeak":{"default":"greater-than-over-equals"}},"key":"2267"},{"category":"Sm","mappings":{"default":{"default":"less than but not equals","alternative":"less than but not equals"},"mathspeak":{"default":"less-than-but-not-equals"}},"key":"2268"},{"category":"Sm","mappings":{"default":{"default":"greater than but not equals","alternative":"greater than but not equals"},"mathspeak":{"default":"greater-than-but-not-equals"}},"key":"2269"},{"category":"Sm","mappings":{"default":{"default":"much less than","alternative":"much less than"},"mathspeak":{"default":"much-less-than"}},"key":"226A"},{"category":"Sm","mappings":{"default":{"default":"much greater than","alternative":"much greater than"},"mathspeak":{"default":"much-greater-than"}},"key":"226B"},{"category":"Sm","mappings":{"default":{"default":"between"}},"key":"226C"},{"category":"Sm","mappings":{"default":{"default":"not equivalent to"},"mathspeak":{"default":"not-equivalent-to"}},"key":"226D"},{"category":"Sm","mappings":{"default":{"default":"not less than","alternative":"not less than"},"mathspeak":{"default":"not-less-than"}},"key":"226E"},{"category":"Sm","mappings":{"default":{"default":"not greater than","alternative":"not greater than"},"mathspeak":{"default":"not-greater-than"}},"key":"226F"},{"category":"Sm","mappings":{"default":{"default":"neither less than nor equals","alternative":"neither less than nor equals"},"mathspeak":{"default":"neither-less-than-nor-equal-to"}},"key":"2270"},{"category":"Sm","mappings":{"default":{"default":"neither greater than nor equals","alternative":"neither greater than nor equals"},"mathspeak":{"default":"neither-greater-than-nor-equal-to"}},"key":"2271"},{"category":"Sm","mappings":{"default":{"default":"less than or equivalent to","alternative":"less than or equivalent to"},"mathspeak":{"default":"less-than-or-equivalent-to"}},"key":"2272"},{"category":"Sm","mappings":{"default":{"default":"greater than or equivalent to","alternative":"greater than or equivalent to"},"mathspeak":{"default":"greater-than-or-equivalent-to"}},"key":"2273"},{"category":"Sm","mappings":{"default":{"default":"neither less than nor equivalent to","alternative":"neither less than nor equivalent to"},"mathspeak":{"default":"neither-less-than-nor-equivalent-to"}},"key":"2274"},{"category":"Sm","mappings":{"default":{"default":"neither greater than nor equivalent to","alternative":"neither greater than nor equivalent to"},"mathspeak":{"default":"neither-greater-than-nor-equivalent-to"}},"key":"2275"},{"category":"Sm","mappings":{"default":{"default":"less than or greater than","alternative":"less than or greater than"},"mathspeak":{"default":"less-than-or-greater-than"}},"key":"2276"},{"category":"Sm","mappings":{"default":{"default":"greater than or less than","alternative":"greater than or less than"},"mathspeak":{"default":"greater-than-or-less-than"}},"key":"2277"},{"category":"Sm","mappings":{"default":{"default":"neither less than nor greater than","alternative":"neither less than nor greater than"},"mathspeak":{"default":"neither-less-than-nor-greater-than"}},"key":"2278"},{"category":"Sm","mappings":{"default":{"default":"neither greater than nor less than","alternative":"neither greater than nor less than"},"mathspeak":{"default":"neither-greater-than-nor-less-than"}},"key":"2279"},{"category":"Sm","mappings":{"default":{"default":"precedes"}},"key":"227A"},{"category":"Sm","mappings":{"default":{"default":"succeeds"}},"key":"227B"},{"category":"Sm","mappings":{"default":{"default":"precedes or equals"},"mathspeak":{"default":"precedes-or-equal-to"}},"key":"227C"},{"category":"Sm","mappings":{"default":{"default":"succeeds or equals"},"mathspeak":{"default":"succeeds-or-equal-to"}},"key":"227D"},{"category":"Sm","mappings":{"default":{"default":"precedes or equivalent to"},"mathspeak":{"default":"precedes-or-equivalent-to"}},"key":"227E"},{"category":"Sm","mappings":{"default":{"default":"succeeds or equivalent to"},"mathspeak":{"default":"succeeds-or-equivalent-to"}},"key":"227F"},{"category":"Sm","mappings":{"default":{"default":"does not precede"},"mathspeak":{"default":"does-not-precede"}},"key":"2280"},{"category":"Sm","mappings":{"default":{"default":"does not succeed"},"mathspeak":{"default":"does-not-succeed"}},"key":"2281"},{"category":"Sm","mappings":{"default":{"default":"subset of"},"mathspeak":{"default":"subset-of"}},"key":"2282"},{"category":"Sm","mappings":{"default":{"default":"superset of"},"mathspeak":{"default":"superset-of"}},"key":"2283"},{"category":"Sm","mappings":{"default":{"default":"not a subset of"},"mathspeak":{"default":"not-a-subset-of"}},"key":"2284"},{"category":"Sm","mappings":{"default":{"default":"not a superset of"},"mathspeak":{"default":"not-a-superset-of"}},"key":"2285"},{"category":"Sm","mappings":{"default":{"default":"subset of or equals"},"mathspeak":{"default":"subset-of-or-equal-to"}},"key":"2286"},{"category":"Sm","mappings":{"default":{"default":"superset of or equals"},"mathspeak":{"default":"superset-of-or-equal-to"}},"key":"2287"},{"category":"Sm","mappings":{"default":{"default":"neither a subset of nor equals"},"mathspeak":{"default":"neither-a-subset-of-nor-equal-to"}},"key":"2288"},{"category":"Sm","mappings":{"default":{"default":"neither a superset of nor equals"},"mathspeak":{"default":"neither-a-superset-of-nor-equal-to"}},"key":"2289"},{"category":"Sm","mappings":{"default":{"default":"subset of with not equals","alternative":"subset of or not equals","short":"subset of or not equals"},"mathspeak":{"default":"subset-of-or-not-equals"}},"key":"228A"},{"category":"Sm","mappings":{"default":{"default":"superset of with not equals","alternative":"superset of or not equals","short":"superset of or not equals"},"mathspeak":{"default":"superset-of-or-not-equals"}},"key":"228B"},{"category":"Sm","mappings":{"default":{"default":"multiset"}},"key":"228C"},{"category":"Sm","mappings":{"default":{"default":"multiset multiplication"},"mathspeak":{"default":"multiset-multiplication"}},"key":"228D"},{"category":"Sm","mappings":{"default":{"default":"multiset union"},"mathspeak":{"default":"multiset-union"}},"key":"228E"},{"category":"Sm","mappings":{"default":{"default":"square image of"},"mathspeak":{"default":"square-image-of"}},"key":"228F"},{"category":"Sm","mappings":{"default":{"default":"square original of"},"mathspeak":{"default":"square-original-of"}},"key":"2290"},{"category":"Sm","mappings":{"default":{"default":"square image of or equals"},"mathspeak":{"default":"square-image-of-or-equal-to"}},"key":"2291"},{"category":"Sm","mappings":{"default":{"default":"square original of or equals"},"mathspeak":{"default":"square-original-of-or-equal-to"}},"key":"2292"},{"category":"Sm","mappings":{"default":{"default":"square cap"},"mathspeak":{"default":"square-cap"}},"key":"2293"},{"category":"Sm","mappings":{"default":{"default":"square cup"},"mathspeak":{"default":"square-cup"}},"key":"2294"},{"category":"Sm","mappings":{"default":{"default":"circled plus"},"mathspeak":{"default":"circled-plus"}},"key":"2295"},{"category":"Sm","mappings":{"default":{"default":"circled minus"},"mathspeak":{"default":"circled-minus"}},"key":"2296"},{"category":"Sm","mappings":{"default":{"default":"circled times"},"mathspeak":{"default":"circled-times"}},"key":"2297"},{"category":"Sm","mappings":{"default":{"default":"circled division slash"},"mathspeak":{"default":"circled-division-slash"}},"key":"2298"},{"category":"Sm","mappings":{"default":{"default":"circled dot operator"},"mathspeak":{"default":"circled-dot"}},"key":"2299"},{"category":"Sm","mappings":{"default":{"default":"circled ring operator"},"mathspeak":{"default":"circled-ring"}},"key":"229A"},{"category":"Sm","mappings":{"default":{"default":"circled asterisk operator"},"mathspeak":{"default":"circled-asterisk"}},"key":"229B"},{"category":"Sm","mappings":{"default":{"default":"circled equals"},"mathspeak":{"default":"circled-equals"}},"key":"229C"},{"category":"Sm","mappings":{"default":{"default":"circled dash"},"mathspeak":{"default":"circled-dash"}},"key":"229D"},{"category":"Sm","mappings":{"default":{"default":"squared plus"},"mathspeak":{"default":"squared-plus"}},"key":"229E"},{"category":"Sm","mappings":{"default":{"default":"squared minus"},"mathspeak":{"default":"squared-minus"}},"key":"229F"},{"category":"Sm","mappings":{"default":{"default":"squared times"},"mathspeak":{"default":"squared-times"}},"key":"22A0"},{"category":"Sm","mappings":{"default":{"default":"squared dot operator"},"mathspeak":{"default":"squared-dot"}},"key":"22A1"},{"category":"Sm","mappings":{"default":{"default":"right tack"},"mathspeak":{"default":"right-tack"}},"key":"22A2"},{"category":"Sm","mappings":{"default":{"default":"left tack"},"mathspeak":{"default":"left-tack"}},"key":"22A3"},{"category":"Sm","mappings":{"default":{"default":"down tack"},"mathspeak":{"default":"down-tack"}},"key":"22A4"},{"category":"Sm","mappings":{"default":{"default":"up tack"},"mathspeak":{"default":"up-tack"}},"key":"22A5"},{"category":"Sm","mappings":{"default":{"default":"assertion"}},"key":"22A6"},{"category":"Sm","mappings":{"default":{"default":"models"}},"key":"22A7"},{"category":"Sm","mappings":{"default":{"default":"true"}},"key":"22A8"},{"category":"Sm","mappings":{"default":{"default":"forces"}},"key":"22A9"},{"category":"Sm","mappings":{"default":{"default":"triple vertical bar right turnstile"},"mathspeak":{"default":"triple-vertical-bar-right-turnstile"}},"key":"22AA"},{"category":"Sm","mappings":{"default":{"default":"double vertical bar double right turnstile"},"mathspeak":{"default":"double-vertical-bar-double-right-turnstile"}},"key":"22AB"},{"category":"Sm","mappings":{"default":{"default":"does not prove"},"mathspeak":{"default":"does-not-prove"}},"key":"22AC"},{"category":"Sm","mappings":{"default":{"default":"not true"},"mathspeak":{"default":"not-true"}},"key":"22AD"},{"category":"Sm","mappings":{"default":{"default":"does not force"},"mathspeak":{"default":"does-not-force"}},"key":"22AE"},{"category":"Sm","mappings":{"default":{"default":"negated double vertical bar double right turnstile"},"mathspeak":{"default":"negated-double-vertical-bar-double-right-turnstile"}},"key":"22AF"},{"category":"Sm","mappings":{"default":{"default":"precedes under relation"},"mathspeak":{"default":"precedes-under-relation"}},"key":"22B0"},{"category":"Sm","mappings":{"default":{"default":"succeeds under relation"},"mathspeak":{"default":"succeeds-under-relation"}},"key":"22B1"},{"category":"Sm","mappings":{"default":{"default":"normal subgroup of"},"mathspeak":{"default":"normal-subgroup-of"}},"key":"22B2"},{"category":"Sm","mappings":{"default":{"default":"contains as normal subgroup"},"mathspeak":{"default":"contains-as-normal-subgroup"}},"key":"22B3"},{"category":"Sm","mappings":{"default":{"default":"normal subgroup of or equals"},"mathspeak":{"default":"normal-subgroup-of-or-equal-to"}},"key":"22B4"},{"category":"Sm","mappings":{"default":{"default":"contains as normal subgroup or equals"},"mathspeak":{"default":"contains-as-normal-subgroup-or-equal-to"}},"key":"22B5"},{"category":"Sm","mappings":{"default":{"default":"original of"},"mathspeak":{"default":"original-of"}},"key":"22B6"},{"category":"Sm","mappings":{"default":{"default":"image of"},"mathspeak":{"default":"image-of"}},"key":"22B7"},{"category":"Sm","mappings":{"default":{"default":"multimap"}},"key":"22B8"},{"category":"Sm","mappings":{"default":{"default":"hermitian conjugate matrix"},"mathspeak":{"default":"hermitian-conjugate-matrix"}},"key":"22B9"},{"category":"Sm","mappings":{"default":{"default":"intercalate"}},"key":"22BA"},{"category":"Sm","mappings":{"default":{"default":"xor"}},"key":"22BB"},{"category":"Sm","mappings":{"default":{"default":"nand"}},"key":"22BC"},{"category":"Sm","mappings":{"default":{"default":"nor"}},"key":"22BD"},{"category":"Sm","mappings":{"default":{"default":"right triangle"},"mathspeak":{"default":"right-triangle"}},"key":"22BF"},{"category":"Sm","mappings":{"default":{"default":"n ary logical and"},"mathspeak":{"default":"logical-and"}},"key":"22C0"},{"category":"Sm","mappings":{"default":{"default":"n ary logical or"},"mathspeak":{"default":"logical-or"}},"key":"22C1"},{"category":"Sm","mappings":{"default":{"default":"n ary intersection"},"mathspeak":{"default":"intersection"}},"key":"22C2"},{"category":"Sm","mappings":{"default":{"default":"n ary union"},"mathspeak":{"default":"union"}},"key":"22C3"},{"category":"Sm","mappings":{"default":{"default":"diamond operator"},"mathspeak":{"default":"diamond"}},"key":"22C4"},{"category":"Sm","mappings":{"default":{"default":"dot operator"},"mathspeak":{"default":"dot"}},"key":"22C5"},{"category":"Sm","mappings":{"default":{"default":"star operator"},"mathspeak":{"default":"star"}},"key":"22C6"},{"category":"Sm","mappings":{"default":{"default":"division times"},"mathspeak":{"default":"division-times"}},"key":"22C7"},{"category":"Sm","mappings":{"default":{"default":"bowtie"}},"key":"22C8"},{"category":"Sm","mappings":{"default":{"default":"left normal factor semidirect product"},"mathspeak":{"default":"left-normal-factor-semidirect-product"}},"key":"22C9"},{"category":"Sm","mappings":{"default":{"default":"right normal factor semidirect product"},"mathspeak":{"default":"right-normal-factor-semidirect-product"}},"key":"22CA"},{"category":"Sm","mappings":{"default":{"default":"left semidirect product"},"mathspeak":{"default":"left-semidirect-product"}},"key":"22CB"},{"category":"Sm","mappings":{"default":{"default":"right semidirect product"},"mathspeak":{"default":"right-semidirect-product"}},"key":"22CC"},{"category":"Sm","mappings":{"default":{"default":"reversed tilde equals"},"mathspeak":{"default":"reversed-tilde-equals"}},"key":"22CD"},{"category":"Sm","mappings":{"default":{"default":"curly logical or"},"mathspeak":{"default":"curly-logical-or"}},"key":"22CE"},{"category":"Sm","mappings":{"default":{"default":"curly logical and"},"mathspeak":{"default":"curly-logical-and"}},"key":"22CF"},{"category":"Sm","mappings":{"default":{"default":"double subset"},"mathspeak":{"default":"double-subset"}},"key":"22D0"},{"category":"Sm","mappings":{"default":{"default":"double superset"},"mathspeak":{"default":"double-superset"}},"key":"22D1"},{"category":"Sm","mappings":{"default":{"default":"double intersection"},"mathspeak":{"default":"double-intersection"}},"key":"22D2"},{"category":"Sm","mappings":{"default":{"default":"double union"},"mathspeak":{"default":"double-union"}},"key":"22D3"},{"category":"Sm","mappings":{"default":{"default":"pitchfork"}},"key":"22D4"},{"category":"Sm","mappings":{"default":{"default":"equal and parallel to"},"mathspeak":{"default":"equal-and-parallel-to"}},"key":"22D5"},{"category":"Sm","mappings":{"default":{"default":"less than with dot","alternative":"less than with dot","short":"less than dot"},"mathspeak":{"default":"less-than-dot"}},"key":"22D6"},{"category":"Sm","mappings":{"default":{"default":"greater than with dot","alternative":"greater than with dot","short":"greater than dot"},"mathspeak":{"default":"greater-than-dot"}},"key":"22D7"},{"category":"Sm","mappings":{"default":{"default":"very much less than","alternative":"very much less than"},"mathspeak":{"default":"very-much-less-than"}},"key":"22D8"},{"category":"Sm","mappings":{"default":{"default":"very much greater than","alternative":"very much greater than"},"mathspeak":{"default":"very-much-greater-than"}},"key":"22D9"},{"category":"Sm","mappings":{"default":{"default":"less than equals or greater than","alternative":"less than equals or greater than"},"mathspeak":{"default":"less-than-equals-or-greater-than"}},"key":"22DA"},{"category":"Sm","mappings":{"default":{"default":"greater than equals or less than","alternative":"greater than equals or less than"},"mathspeak":{"default":"greater-than-equals-or-less-than"}},"key":"22DB"},{"category":"Sm","mappings":{"default":{"default":"equals or less than","alternative":"equals or less than"},"mathspeak":{"default":"equals-or-less-than"}},"key":"22DC"},{"category":"Sm","mappings":{"default":{"default":"equals or greater than","alternative":"equals or greater than"},"mathspeak":{"default":"equals-or-greater-than"}},"key":"22DD"},{"category":"Sm","mappings":{"default":{"default":"equals or precedes"},"mathspeak":{"default":"equals-or-precedes"}},"key":"22DE"},{"category":"Sm","mappings":{"default":{"default":"equals or succeeds"},"mathspeak":{"default":"equals-or-succeeds"}},"key":"22DF"},{"category":"Sm","mappings":{"default":{"default":"does not precede or equal"},"mathspeak":{"default":"does-not-precede-or-equal"}},"key":"22E0"},{"category":"Sm","mappings":{"default":{"default":"does not succeed or equal"},"mathspeak":{"default":"does-not-succeed-or-equal"}},"key":"22E1"},{"category":"Sm","mappings":{"default":{"default":"not square image of or equals"},"mathspeak":{"default":"not-square-image-of-or-equal-to"}},"key":"22E2"},{"category":"Sm","mappings":{"default":{"default":"not square original of or equals"},"mathspeak":{"default":"not-square-original-of-or-equal-to"}},"key":"22E3"},{"category":"Sm","mappings":{"default":{"default":"square image of or not equals"},"mathspeak":{"default":"square-image-of-or-not-equals"}},"key":"22E4"},{"category":"Sm","mappings":{"default":{"default":"square original of or not equals"},"mathspeak":{"default":"square-original-of-or-not-equals"}},"key":"22E5"},{"category":"Sm","mappings":{"default":{"default":"less than but not equivalent to","alternative":"less than but not equivalent to"},"mathspeak":{"default":"less-than-but-not-equivalent-to"}},"key":"22E6"},{"category":"Sm","mappings":{"default":{"default":"greater than but not equivalent to","alternative":"greater than but not equivalent to"},"mathspeak":{"default":"greater-than-but-not-equivalent-to"}},"key":"22E7"},{"category":"Sm","mappings":{"default":{"default":"precedes but not equivalent to"},"mathspeak":{"default":"precedes-but-not-equivalent-to"}},"key":"22E8"},{"category":"Sm","mappings":{"default":{"default":"succeeds but not equivalent to"},"mathspeak":{"default":"succeeds-but-not-equivalent-to"}},"key":"22E9"},{"category":"Sm","mappings":{"default":{"default":"not normal subgroup of"},"mathspeak":{"default":"not-normal-subgroup-of"}},"key":"22EA"},{"category":"Sm","mappings":{"default":{"default":"does not contain as normal subgroup"},"mathspeak":{"default":"does-not-contain-as-normal-subgroup"}},"key":"22EB"},{"category":"Sm","mappings":{"default":{"default":"not normal subgroup of or equals"},"mathspeak":{"default":"not-normal-subgroup-of-or-equal-to"}},"key":"22EC"},{"category":"Sm","mappings":{"default":{"default":"does not contain as normal subgroup or equal"},"mathspeak":{"default":"does-not-contain-as-normal-subgroup-or-equal"}},"key":"22ED"},{"category":"Sm","mappings":{"default":{"default":"vertical ellipsis"},"mathspeak":{"default":"vertical-ellipsis"}},"key":"22EE"},{"category":"Sm","mappings":{"default":{"default":"midline horizontal ellipsis"},"mathspeak":{"default":"midline-horizontal-ellipsis"}},"key":"22EF"},{"category":"Sm","mappings":{"default":{"default":"up right diagonal ellipsis"},"mathspeak":{"default":"up-right-diagonal-ellipsis"}},"key":"22F0"},{"category":"Sm","mappings":{"default":{"default":"down right diagonal ellipsis"},"mathspeak":{"default":"down-right-diagonal-ellipsis"}},"key":"22F1"},{"category":"Sm","mappings":{"default":{"default":"element of with long horizontal stroke"},"mathspeak":{"default":"element-of-with-long-horizontal-stroke"}},"key":"22F2"},{"category":"Sm","mappings":{"default":{"default":"element of with vertical bar at end of horizontal stroke"},"mathspeak":{"default":"element-of-with-vertical-bar-at-end-of-horizontal-stroke"}},"key":"22F3"},{"category":"Sm","mappings":{"default":{"default":"small element of with vertical bar at end of horizontal stroke"},"mathspeak":{"default":"small-element-of-with-vertical-bar-at-end-of-horizontal-stroke"}},"key":"22F4"},{"category":"Sm","mappings":{"default":{"default":"element of with dot above"},"mathspeak":{"default":"element-of-with-dot-above"}},"key":"22F5"},{"category":"Sm","mappings":{"default":{"default":"element of with overbar"},"mathspeak":{"default":"element-of-with-overbar"}},"key":"22F6"},{"category":"Sm","mappings":{"default":{"default":"small element of with overbar"},"mathspeak":{"default":"small-element-of-with-overbar"}},"key":"22F7"},{"category":"Sm","mappings":{"default":{"default":"element of with underbar"},"mathspeak":{"default":"element-of-with-underbar"}},"key":"22F8"},{"category":"Sm","mappings":{"default":{"default":"element of with two horizontal strokes"},"mathspeak":{"default":"element-of-with-two-horizontal-strokes"}},"key":"22F9"},{"category":"Sm","mappings":{"default":{"default":"contains with long horizontal stroke"},"mathspeak":{"default":"contains-with-long-horizontal-stroke"}},"key":"22FA"},{"category":"Sm","mappings":{"default":{"default":"contains with vertical bar at end of horizontal stroke"},"mathspeak":{"default":"contains-with-vertical-bar-at-end-of-horizontal-stroke"}},"key":"22FB"},{"category":"Sm","mappings":{"default":{"default":"small contains with vertical bar at end of horizontal stroke"},"mathspeak":{"default":"small-contains-with-vertical-bar-at-end-of-horizontal-stroke"}},"key":"22FC"},{"category":"Sm","mappings":{"default":{"default":"contains with overbar"},"mathspeak":{"default":"contains-with-overbar"}},"key":"22FD"},{"category":"Sm","mappings":{"default":{"default":"small contains with overbar"},"mathspeak":{"default":"small-contains-with-overbar"}},"key":"22FE"},{"category":"Sm","mappings":{"default":{"default":"z notation bag membership"},"mathspeak":{"default":"z-notation-bag-membership"}},"key":"22FF"},{"category":"So","mappings":{"default":{"default":"diameter sign","short":"diameter"},"mathspeak":{"default":"diameter-sign"}},"key":"2300"},{"category":"So","mappings":{"default":{"default":"house"}},"key":"2302"},{"category":"So","mappings":{"default":{"default":"projective"}},"key":"2305"},{"category":"So","mappings":{"default":{"default":"perspective"}},"key":"2306"},{"category":"So","mappings":{"default":{"default":"wavy line"},"mathspeak":{"default":"wavy-line"}},"key":"2307"},{"category":"So","mappings":{"default":{"default":"reversed not sign","short":"reversed not"},"mathspeak":{"default":"reversed-not"}},"key":"2310"},{"category":"So","mappings":{"default":{"default":"square lozenge"},"mathspeak":{"default":"square-lozenge"}},"key":"2311"},{"category":"So","mappings":{"default":{"default":"arc"}},"key":"2312"},{"category":"So","mappings":{"default":{"default":"segment"}},"key":"2313"},{"category":"So","mappings":{"default":{"default":"sector"}},"key":"2314"},{"category":"So","mappings":{"default":{"default":"heavy plus sign","alternative":"heavy plus","short":"bold plus"},"mathspeak":{"default":"bold-plus"}},"key":"2795"},{"category":"So","mappings":{"default":{"default":"heavy minus sign","alternative":"heavy minus","short":"bold minus"},"mathspeak":{"default":"bold-minus"}},"key":"2796"},{"category":"So","mappings":{"default":{"default":"heavy division sign","alternative":"heavy division","short":"bold division"},"mathspeak":{"default":"bold-division"}},"key":"2797"},{"category":"So","mappings":{"default":{"default":"curly loop"},"mathspeak":{"default":"curly-loop"}},"key":"27B0"},{"category":"So","mappings":{"default":{"default":"double curly loop"},"mathspeak":{"default":"double-curly-loop"}},"key":"27BF"},{"category":"Sm","mappings":{"default":{"default":"white triangle containing small white triangle"},"mathspeak":{"default":"white-triangle-containing-small-white-triangle"}},"key":"27C1"},{"category":"Sm","mappings":{"default":{"default":"perpendicular"}},"key":"27C2"},{"category":"Sm","mappings":{"default":{"default":"open subset"},"mathspeak":{"default":"open-subset"}},"key":"27C3"},{"category":"Sm","mappings":{"default":{"default":"open superset"},"mathspeak":{"default":"open-superset"}},"key":"27C4"},{"category":"Sm","mappings":{"default":{"default":"or with dot inside"},"mathspeak":{"default":"or-with-dot-inside"}},"key":"27C7"},{"category":"Sm","mappings":{"default":{"default":"reverse solidus preceding subset"},"mathspeak":{"default":"reverse-solidus-preceding-subset"}},"key":"27C8"},{"category":"Sm","mappings":{"default":{"default":"superset preceding solidus"},"mathspeak":{"default":"superset-preceding-solidus"}},"key":"27C9"},{"category":"Sm","mappings":{"default":{"default":"vertical bar with horizontal stroke"},"mathspeak":{"default":"vertical-bar-with-horizontal-stroke"}},"key":"27CA"},{"category":"Sm","mappings":{"default":{"default":"mathematical rising diagonal"},"mathspeak":{"default":"mathematical-rising-diagonal"}},"key":"27CB"},{"category":"Sm","mappings":{"default":{"default":"long division"},"mathspeak":{"default":"long-division"}},"key":"27CC"},{"category":"Sm","mappings":{"default":{"default":"mathematical falling diagonal"},"mathspeak":{"default":"mathematical-falling-diagonal"}},"key":"27CD"},{"category":"Sm","mappings":{"default":{"default":"squared logical and"},"mathspeak":{"default":"squared-logical-and"}},"key":"27CE"},{"category":"Sm","mappings":{"default":{"default":"squared logical or"},"mathspeak":{"default":"squared-logical-or"}},"key":"27CF"},{"category":"Sm","mappings":{"default":{"default":"white diamond with centered dot"},"mathspeak":{"default":"white-diamond-with-centered-dot"}},"key":"27D0"},{"category":"Sm","mappings":{"default":{"default":"and with dot"},"mathspeak":{"default":"and-with-dot"}},"key":"27D1"},{"category":"Sm","mappings":{"default":{"default":"element of opening upwards"},"mathspeak":{"default":"element-of-opening-upwards"}},"key":"27D2"},{"category":"Sm","mappings":{"default":{"default":"lower right corner with dot"},"mathspeak":{"default":"lower-right-corner-with-dot"}},"key":"27D3"},{"category":"Sm","mappings":{"default":{"default":"upper left corner with dot"},"mathspeak":{"default":"upper-left-corner-with-dot"}},"key":"27D4"},{"category":"Sm","mappings":{"default":{"default":"left outer join"},"mathspeak":{"default":"left-outer-join"}},"key":"27D5"},{"category":"Sm","mappings":{"default":{"default":"right outer join"},"mathspeak":{"default":"right-outer-join"}},"key":"27D6"},{"category":"Sm","mappings":{"default":{"default":"full outer join"},"mathspeak":{"default":"full-outer-join"}},"key":"27D7"},{"category":"Sm","mappings":{"default":{"default":"large up tack"},"mathspeak":{"default":"large-up-tack"}},"key":"27D8"},{"category":"Sm","mappings":{"default":{"default":"large down tack"},"mathspeak":{"default":"large-down-tack"}},"key":"27D9"},{"category":"Sm","mappings":{"default":{"default":"left and right double turnstile"},"mathspeak":{"default":"left-and-right-double-turnstile"}},"key":"27DA"},{"category":"Sm","mappings":{"default":{"default":"left and right tack"},"mathspeak":{"default":"left-and-right-tack"}},"key":"27DB"},{"category":"Sm","mappings":{"default":{"default":"left multimap"},"mathspeak":{"default":"left-multimap"}},"key":"27DC"},{"category":"Sm","mappings":{"default":{"default":"long right tack"},"mathspeak":{"default":"long-right-tack"}},"key":"27DD"},{"category":"Sm","mappings":{"default":{"default":"long left tack"},"mathspeak":{"default":"long-left-tack"}},"key":"27DE"},{"category":"Sm","mappings":{"default":{"default":"up tack with circle above"},"mathspeak":{"default":"up-tack-with-circle-above"}},"key":"27DF"},{"category":"Sm","mappings":{"default":{"default":"lozenge divided by horizontal rule"},"mathspeak":{"default":"lozenge-divided-by-horizontal-rule"}},"key":"27E0"},{"category":"Sm","mappings":{"default":{"default":"white concave sided diamond"},"mathspeak":{"default":"white-concave-sided-diamond"}},"key":"27E1"},{"category":"Sm","mappings":{"default":{"default":"white concave sided diamond with leftwards tick"},"mathspeak":{"default":"white-concave-sided-diamond-with-leftwards-tick"}},"key":"27E2"},{"category":"Sm","mappings":{"default":{"default":"white concave sided diamond with rightwards tick"},"mathspeak":{"default":"white-concave-sided-diamond-with-rightwards-tick"}},"key":"27E3"},{"category":"Sm","mappings":{"default":{"default":"white square with leftwards tick"},"mathspeak":{"default":"white-square-with-leftwards-tick"}},"key":"27E4"},{"category":"Sm","mappings":{"default":{"default":"white square with rightwards tick"},"mathspeak":{"default":"white-square-with-rightwards-tick"}},"key":"27E5"},{"category":"Sm","mappings":{"default":{"default":"rising diagonal crossing falling diagonal"},"mathspeak":{"default":"rising-diagonal-crossing-falling-diagonal"}},"key":"292B"},{"category":"Sm","mappings":{"default":{"default":"falling diagonal crossing rising diagonal"},"mathspeak":{"default":"falling-diagonal-crossing-rising-diagonal"}},"key":"292C"},{"category":"Sm","mappings":{"default":{"default":"triple vertical bar delimiter"},"mathspeak":{"default":"triple-vertical-bar-delimiter"}},"key":"2980"},{"category":"Sm","mappings":{"default":{"default":"z notation spot"},"mathspeak":{"default":"z-notation-spot"}},"key":"2981"},{"category":"Sm","mappings":{"default":{"default":"z notation type colon"},"mathspeak":{"default":"z-notation-type-colon"}},"key":"2982"},{"category":"Sm","mappings":{"default":{"default":"dotted fence"},"mathspeak":{"default":"dotted-fence"}},"key":"2999"},{"category":"Sm","mappings":{"default":{"default":"vertical zigzag line"},"mathspeak":{"default":"vertical-zigzag-line"}},"key":"299A"},{"category":"Sm","mappings":{"default":{"default":"reversed empty set"},"mathspeak":{"default":"reversed-empty-set"}},"key":"29B0"},{"category":"Sm","mappings":{"default":{"default":"empty set with overbar"},"mathspeak":{"default":"empty-set-with-overbar"}},"key":"29B1"},{"category":"Sm","mappings":{"default":{"default":"empty set with small circle above"},"mathspeak":{"default":"empty-set-with-small-circle-above"}},"key":"29B2"},{"category":"Sm","mappings":{"default":{"default":"circle with horizontal bar"},"mathspeak":{"default":"circle-with-horizontal-bar"}},"key":"29B5"},{"category":"Sm","mappings":{"default":{"default":"circled vertical bar"},"mathspeak":{"default":"circled-vertical-bar"}},"key":"29B6"},{"category":"Sm","mappings":{"default":{"default":"circled parallel"},"mathspeak":{"default":"circled-parallel"}},"key":"29B7"},{"category":"Sm","mappings":{"default":{"default":"circled reverse solidus"},"mathspeak":{"default":"circled-reverse-solidus"}},"key":"29B8"},{"category":"Sm","mappings":{"default":{"default":"circled perpendicular"},"mathspeak":{"default":"circled-perpendicular"}},"key":"29B9"},{"category":"Sm","mappings":{"default":{"default":"circle divided by horizontal bar and top half divided by vertical bar"},"mathspeak":{"default":"circle-divided-by-horizontal-bar-and-top-half-divided-by-vertical-bar"}},"key":"29BA"},{"category":"Sm","mappings":{"default":{"default":"circle with superimposed x"},"mathspeak":{"default":"circle-with-superimposed-x"}},"key":"29BB"},{"category":"Sm","mappings":{"default":{"default":"circled anticlockwise rotated division sign","short":"circled anticlockwise rotated division"},"mathspeak":{"default":"circled-anticlockwise-rotated-division"}},"key":"29BC"},{"category":"Sm","mappings":{"default":{"default":"circled white bullet"},"mathspeak":{"default":"circled-white-bullet"}},"key":"29BE"},{"category":"Sm","mappings":{"default":{"default":"circled bullet"},"mathspeak":{"default":"circled-bullet"}},"key":"29BF"},{"category":"Sm","mappings":{"default":{"default":"circled less than"},"mathspeak":{"default":"circled-less-than"}},"key":"29C0"},{"category":"Sm","mappings":{"default":{"default":"circled greater than"},"mathspeak":{"default":"circled-greater-than"}},"key":"29C1"},{"category":"Sm","mappings":{"default":{"default":"circle with small circle to the right"},"mathspeak":{"default":"circle-with-small-circle-to-the-right"}},"key":"29C2"},{"category":"Sm","mappings":{"default":{"default":"circle with two horizontal strokes to the right"},"mathspeak":{"default":"circle-with-two-horizontal-strokes-to-the-right"}},"key":"29C3"},{"category":"Sm","mappings":{"default":{"default":"squared rising diagonal slash"},"mathspeak":{"default":"squared-rising-diagonal-slash"}},"key":"29C4"},{"category":"Sm","mappings":{"default":{"default":"squared falling diagonal slash"},"mathspeak":{"default":"squared-falling-diagonal-slash"}},"key":"29C5"},{"category":"Sm","mappings":{"default":{"default":"squared asterisk"},"mathspeak":{"default":"squared-asterisk"}},"key":"29C6"},{"category":"Sm","mappings":{"default":{"default":"squared small circle"},"mathspeak":{"default":"squared-small-circle"}},"key":"29C7"},{"category":"Sm","mappings":{"default":{"default":"squared square"},"mathspeak":{"default":"squared-square"}},"key":"29C8"},{"category":"Sm","mappings":{"default":{"default":"two joined squares"},"mathspeak":{"default":"two-joined-squares"}},"key":"29C9"},{"category":"Sm","mappings":{"default":{"default":"triangle with dot above"},"mathspeak":{"default":"triangle-with-dot-above"}},"key":"29CA"},{"category":"Sm","mappings":{"default":{"default":"triangle with underbar"},"mathspeak":{"default":"triangle-with-underbar"}},"key":"29CB"},{"category":"Sm","mappings":{"default":{"default":"s in triangle"},"mathspeak":{"default":"s-in-triangle"}},"key":"29CC"},{"category":"Sm","mappings":{"default":{"default":"triangle with serifs at bottom"},"mathspeak":{"default":"triangle-with-serifs-at-bottom"}},"key":"29CD"},{"category":"Sm","mappings":{"default":{"default":"right triangle above left triangle"},"mathspeak":{"default":"right-triangle-above-left-triangle"}},"key":"29CE"},{"category":"Sm","mappings":{"default":{"default":"left triangle beside vertical bar"},"mathspeak":{"default":"left-triangle-beside-vertical-bar"}},"key":"29CF"},{"category":"Sm","mappings":{"default":{"default":"vertical bar beside right triangle"},"mathspeak":{"default":"vertical-bar-beside-right-triangle"}},"key":"29D0"},{"category":"Sm","mappings":{"default":{"default":"bowtie with left half black"},"mathspeak":{"default":"bowtie-with-left-half-black"}},"key":"29D1"},{"category":"Sm","mappings":{"default":{"default":"bowtie with right half black"},"mathspeak":{"default":"bowtie-with-right-half-black"}},"key":"29D2"},{"category":"Sm","mappings":{"default":{"default":"black bowtie"},"mathspeak":{"default":"black-bowtie"}},"key":"29D3"},{"category":"Sm","mappings":{"default":{"default":"times with left half black"},"mathspeak":{"default":"times-with-left-half-black"}},"key":"29D4"},{"category":"Sm","mappings":{"default":{"default":"times with right half black"},"mathspeak":{"default":"times-with-right-half-black"}},"key":"29D5"},{"category":"Sm","mappings":{"default":{"default":"white hourglass"},"mathspeak":{"default":"white-hourglass"}},"key":"29D6"},{"category":"Sm","mappings":{"default":{"default":"black hourglass"},"mathspeak":{"default":"black-hourglass"}},"key":"29D7"},{"category":"Sm","mappings":{"default":{"default":"incomplete infinity"},"mathspeak":{"default":"incomplete-infinity"}},"key":"29DC"},{"category":"Sm","mappings":{"default":{"default":"tie over infinity"},"mathspeak":{"default":"tie-over-infinity"}},"key":"29DD"},{"category":"Sm","mappings":{"default":{"default":"infinity negated with vertical bar"},"mathspeak":{"default":"infinity-negated-with-vertical-bar"}},"key":"29DE"},{"category":"Sm","mappings":{"default":{"default":"double ended multimap"},"mathspeak":{"default":"double-ended-multimap"}},"key":"29DF"},{"category":"Sm","mappings":{"default":{"default":"square with contoured outline"},"mathspeak":{"default":"square-with-contoured-outline"}},"key":"29E0"},{"category":"Sm","mappings":{"default":{"default":"increases as"},"mathspeak":{"default":"increases-as"}},"key":"29E1"},{"category":"Sm","mappings":{"default":{"default":"shuffle product"},"mathspeak":{"default":"shuffle-product"}},"key":"29E2"},{"category":"Sm","mappings":{"default":{"default":"equals sign and slanted parallel"},"mathspeak":{"default":"equals-and-slanted-parallel"}},"key":"29E3"},{"category":"Sm","mappings":{"default":{"default":"equals sign and slanted parallel with tilde above"},"mathspeak":{"default":"equals-and-slanted-parallel-with-tilde-above"}},"key":"29E4"},{"category":"Sm","mappings":{"default":{"default":"identical to and slanted parallel"},"mathspeak":{"default":"identical-to-and-slanted-parallel"}},"key":"29E5"},{"category":"Sm","mappings":{"default":{"default":"gleich stark"},"mathspeak":{"default":"gleich-stark"}},"key":"29E6"},{"category":"Sm","mappings":{"default":{"default":"thermodynamic"}},"key":"29E7"},{"category":"Sm","mappings":{"default":{"default":"down pointing triangle with left half black"},"mathspeak":{"default":"down-pointing-triangle-with-left-half-black"}},"key":"29E8"},{"category":"Sm","mappings":{"default":{"default":"down pointing triangle with right half black"},"mathspeak":{"default":"down-pointing-triangle-with-right-half-black"}},"key":"29E9"},{"category":"Sm","mappings":{"default":{"default":"black lozenge"},"mathspeak":{"default":"black-lozenge"}},"key":"29EB"},{"category":"Sm","mappings":{"default":{"default":"error barred white square"},"mathspeak":{"default":"error-barred-white-square"}},"key":"29EE"},{"category":"Sm","mappings":{"default":{"default":"error barred black square"},"mathspeak":{"default":"error-barred-black-square"}},"key":"29EF"},{"category":"Sm","mappings":{"default":{"default":"error barred white diamond"},"mathspeak":{"default":"error-barred-white-diamond"}},"key":"29F0"},{"category":"Sm","mappings":{"default":{"default":"error barred black diamond"},"mathspeak":{"default":"error-barred-black-diamond"}},"key":"29F1"},{"category":"Sm","mappings":{"default":{"default":"error barred white circle"},"mathspeak":{"default":"error-barred-white-circle"}},"key":"29F2"},{"category":"Sm","mappings":{"default":{"default":"error barred black circle"},"mathspeak":{"default":"error-barred-black-circle"}},"key":"29F3"},{"category":"Sm","mappings":{"default":{"default":"rule delayed"},"mathspeak":{"default":"rule-delayed"}},"key":"29F4"},{"category":"Sm","mappings":{"default":{"default":"reverse solidus operator"},"mathspeak":{"default":"reverse-solidus"}},"key":"29F5"},{"category":"Sm","mappings":{"default":{"default":"solidus with overbar"},"mathspeak":{"default":"solidus-with-overbar"}},"key":"29F6"},{"category":"Sm","mappings":{"default":{"default":"reverse solidus with horizontal stroke"},"mathspeak":{"default":"reverse-solidus-with-horizontal-stroke"}},"key":"29F7"},{"category":"Sm","mappings":{"default":{"default":"big solidus"},"mathspeak":{"default":"solidus"}},"key":"29F8"},{"category":"Sm","mappings":{"default":{"default":"big reverse solidus"},"mathspeak":{"default":"reverse-solidus"}},"key":"29F9"},{"category":"Sm","mappings":{"default":{"default":"double plus"},"mathspeak":{"default":"double-plus"}},"key":"29FA"},{"category":"Sm","mappings":{"default":{"default":"triple plus"},"mathspeak":{"default":"triple-plus"}},"key":"29FB"},{"category":"Sm","mappings":{"default":{"default":"tiny"}},"key":"29FE"},{"category":"Sm","mappings":{"default":{"default":"miny"}},"key":"29FF"},{"category":"Sm","mappings":{"default":{"default":"n ary circled dot operator"},"mathspeak":{"default":"circled-dot"}},"key":"2A00"},{"category":"Sm","mappings":{"default":{"default":"n ary circled plus operator"},"mathspeak":{"default":"circled-plus"}},"key":"2A01"},{"category":"Sm","mappings":{"default":{"default":"n ary circled times operator"},"mathspeak":{"default":"circled-times"}},"key":"2A02"},{"category":"Sm","mappings":{"default":{"default":"n ary union operator with dot"},"mathspeak":{"default":"union-with-dot"}},"key":"2A03"},{"category":"Sm","mappings":{"default":{"default":"n ary union operator with plus"},"mathspeak":{"default":"union-with-plus"}},"key":"2A04"},{"category":"Sm","mappings":{"default":{"default":"n ary square intersection operator"},"mathspeak":{"default":"square-intersection"}},"key":"2A05"},{"category":"Sm","mappings":{"default":{"default":"n ary square union operator"},"mathspeak":{"default":"square-union"}},"key":"2A06"},{"category":"Sm","mappings":{"default":{"default":"two logical and operator"},"mathspeak":{"default":"two-logical-and"}},"key":"2A07"},{"category":"Sm","mappings":{"default":{"default":"two logical or operator"},"mathspeak":{"default":"two-logical-or"}},"key":"2A08"},{"category":"Sm","mappings":{"default":{"default":"n ary times operator"},"mathspeak":{"default":"times"}},"key":"2A09"},{"category":"Sm","mappings":{"default":{"default":"modulo two sum"},"mathspeak":{"default":"modulo-two-sum"}},"key":"2A0A"},{"category":"Sm","mappings":{"default":{"default":"summation with integral"},"mathspeak":{"default":"summation-with-integral"}},"key":"2A0B"},{"category":"Sm","mappings":{"default":{"default":"quadruple integral operator"},"mathspeak":{"default":"quadruple-integral"}},"key":"2A0C"},{"category":"Sm","mappings":{"default":{"default":"finite part integral"},"mathspeak":{"default":"finite-part-integral"}},"key":"2A0D"},{"category":"Sm","mappings":{"default":{"default":"integral with double stroke"},"mathspeak":{"default":"integral-with-double-stroke"}},"key":"2A0E"},{"category":"Sm","mappings":{"default":{"default":"integral average with slash"},"mathspeak":{"default":"integral-average-with-slash"}},"key":"2A0F"},{"category":"Sm","mappings":{"default":{"default":"circulation function"},"mathspeak":{"default":"circulation-function"}},"key":"2A10"},{"category":"Sm","mappings":{"default":{"default":"anticlockwise integration"},"mathspeak":{"default":"anticlockwise-integration"}},"key":"2A11"},{"category":"Sm","mappings":{"default":{"default":"line integration with rectangular path around pole"},"mathspeak":{"default":"line-integration-with-rectangular-path-around-pole"}},"key":"2A12"},{"category":"Sm","mappings":{"default":{"default":"line integration with semicircular path around pole"},"mathspeak":{"default":"line-integration-with-semicircular-path-around-pole"}},"key":"2A13"},{"category":"Sm","mappings":{"default":{"default":"line integration not including the pole"},"mathspeak":{"default":"line-integration-not-including-the-pole"}},"key":"2A14"},{"category":"Sm","mappings":{"default":{"default":"integral around a point operator"},"mathspeak":{"default":"integral-around-a-point"}},"key":"2A15"},{"category":"Sm","mappings":{"default":{"default":"quaternion integral operator"},"mathspeak":{"default":"quaternion-integral"}},"key":"2A16"},{"category":"Sm","mappings":{"default":{"default":"integral with times sign","short":"integral with times"},"mathspeak":{"default":"integral-with-times"}},"key":"2A18"},{"category":"Sm","mappings":{"default":{"default":"integral with intersection"},"mathspeak":{"default":"integral-with-intersection"}},"key":"2A19"},{"category":"Sm","mappings":{"default":{"default":"integral with union"},"mathspeak":{"default":"integral-with-union"}},"key":"2A1A"},{"category":"Sm","mappings":{"default":{"default":"integral with overbar"},"mathspeak":{"default":"integral-with-overbar"}},"key":"2A1B"},{"category":"Sm","mappings":{"default":{"default":"integral with underbar"},"mathspeak":{"default":"integral-with-underbar"}},"key":"2A1C"},{"category":"Sm","mappings":{"default":{"default":"join"}},"key":"2A1D"},{"category":"Sm","mappings":{"default":{"default":"large left triangle operator"},"mathspeak":{"default":"large-left-triangle"}},"key":"2A1E"},{"category":"Sm","mappings":{"default":{"default":"z notation schema composition"},"mathspeak":{"default":"z-notation-schema-composition"}},"key":"2A1F"},{"category":"Sm","mappings":{"default":{"default":"z notation schema piping"},"mathspeak":{"default":"z-notation-schema-piping"}},"key":"2A20"},{"category":"Sm","mappings":{"default":{"default":"z notation schema projection"},"mathspeak":{"default":"z-notation-schema-projection"}},"key":"2A21"},{"category":"Sm","mappings":{"default":{"default":"plus sign with small circle above","short":"plus with circle above"},"mathspeak":{"default":"plus-with-circle-above"}},"key":"2A22"},{"category":"Sm","mappings":{"default":{"default":"plus sign with circumflex accent above","short":"plus hat"},"mathspeak":{"default":"plus-hat"}},"key":"2A23"},{"category":"Sm","mappings":{"default":{"default":"plus sign with tilde above","short":"plus tilde"},"mathspeak":{"default":"plus-tilde"}},"key":"2A24"},{"category":"Sm","mappings":{"default":{"default":"plus sign with dot below","short":"plus underdot"},"mathspeak":{"default":"plus-underdot"}},"key":"2A25"},{"category":"Sm","mappings":{"default":{"default":"plus sign with tilde below"},"mathspeak":{"default":"plus-sign-with-tilde-below"}},"key":"2A26"},{"category":"Sm","mappings":{"default":{"default":"plus sign with subscript two"},"mathspeak":{"default":"plus-sign-with-subscript-two"}},"key":"2A27"},{"category":"Sm","mappings":{"default":{"default":"plus sign with black triangle"},"mathspeak":{"default":"plus-sign-with-black-triangle"}},"key":"2A28"},{"category":"Sm","mappings":{"default":{"default":"minus sign with comma above"},"mathspeak":{"default":"minus-sign-with-comma-above"}},"key":"2A29"},{"category":"Sm","mappings":{"default":{"default":"minus sign with dot below"},"mathspeak":{"default":"minus-sign-with-dot-below"}},"key":"2A2A"},{"category":"Sm","mappings":{"default":{"default":"minus sign with falling dots"},"mathspeak":{"default":"minus-sign-with-falling-dots"}},"key":"2A2B"},{"category":"Sm","mappings":{"default":{"default":"minus sign with rising dots"},"mathspeak":{"default":"minus-sign-with-rising-dots"}},"key":"2A2C"},{"category":"Sm","mappings":{"default":{"default":"plus sign in left half circle"},"mathspeak":{"default":"plus-sign-in-left-half-circle"}},"key":"2A2D"},{"category":"Sm","mappings":{"default":{"default":"plus sign in right half circle"},"mathspeak":{"default":"plus-sign-in-right-half-circle"}},"key":"2A2E"},{"category":"Sm","mappings":{"default":{"default":"vector or cross product"},"mathspeak":{"default":"vector-or-cross-product"}},"key":"2A2F"},{"category":"Sm","mappings":{"default":{"default":"multiplication sign with dot above"},"mathspeak":{"default":"multiplication-sign-with-dot-above"}},"key":"2A30"},{"category":"Sm","mappings":{"default":{"default":"multiplication sign with underbar"},"mathspeak":{"default":"multiplication-sign-with-underbar"}},"key":"2A31"},{"category":"Sm","mappings":{"default":{"default":"semidirect product with bottom closed"},"mathspeak":{"default":"semidirect-product-with-bottom-closed"}},"key":"2A32"},{"category":"Sm","mappings":{"default":{"default":"smash product"},"mathspeak":{"default":"smash-product"}},"key":"2A33"},{"category":"Sm","mappings":{"default":{"default":"multiplication sign in left half circle"},"mathspeak":{"default":"multiplication-sign-in-left-half-circle"}},"key":"2A34"},{"category":"Sm","mappings":{"default":{"default":"multiplication sign in right half circle"},"mathspeak":{"default":"multiplication-sign-in-right-half-circle"}},"key":"2A35"},{"category":"Sm","mappings":{"default":{"default":"circled multiplication sign with circumflex accent"},"mathspeak":{"default":"circled-multiplication-sign-with-circumflex-accent"}},"key":"2A36"},{"category":"Sm","mappings":{"default":{"default":"multiplication sign in double circle"},"mathspeak":{"default":"multiplication-sign-in-double-circle"}},"key":"2A37"},{"category":"Sm","mappings":{"default":{"default":"circled division sign","short":"circled division"},"mathspeak":{"default":"circled-division"}},"key":"2A38"},{"category":"Sm","mappings":{"default":{"default":"plus sign in triangle"},"mathspeak":{"default":"plus-sign-in-triangle"}},"key":"2A39"},{"category":"Sm","mappings":{"default":{"default":"minus sign in triangle"},"mathspeak":{"default":"minus-sign-in-triangle"}},"key":"2A3A"},{"category":"Sm","mappings":{"default":{"default":"multiplication sign in triangle"},"mathspeak":{"default":"multiplication-sign-in-triangle"}},"key":"2A3B"},{"category":"Sm","mappings":{"default":{"default":"interior product"},"mathspeak":{"default":"interior-product"}},"key":"2A3C"},{"category":"Sm","mappings":{"default":{"default":"righthand interior product"},"mathspeak":{"default":"righthand-interior-product"}},"key":"2A3D"},{"category":"Sm","mappings":{"default":{"default":"z notation relational composition"},"mathspeak":{"default":"z-notation-relational-composition"}},"key":"2A3E"},{"category":"Sm","mappings":{"default":{"default":"amalgamation or coproduct"},"mathspeak":{"default":"amalgamation-or-coproduct"}},"key":"2A3F"},{"category":"Sm","mappings":{"default":{"default":"intersection with dot"},"mathspeak":{"default":"intersection-with-dot"}},"key":"2A40"},{"category":"Sm","mappings":{"default":{"default":"union with minus sign","short":"union with minus"},"mathspeak":{"default":"union-with-minus"}},"key":"2A41"},{"category":"Sm","mappings":{"default":{"default":"union with overbar"},"mathspeak":{"default":"union-with-overbar"}},"key":"2A42"},{"category":"Sm","mappings":{"default":{"default":"intersection with overbar"},"mathspeak":{"default":"intersection-with-overbar"}},"key":"2A43"},{"category":"Sm","mappings":{"default":{"default":"intersection with logical and"},"mathspeak":{"default":"intersection-with-logical-and"}},"key":"2A44"},{"category":"Sm","mappings":{"default":{"default":"union with logical or"},"mathspeak":{"default":"union-with-logical-or"}},"key":"2A45"},{"category":"Sm","mappings":{"default":{"default":"union above intersection"},"mathspeak":{"default":"union-above-intersection"}},"key":"2A46"},{"category":"Sm","mappings":{"default":{"default":"intersection above union"},"mathspeak":{"default":"intersection-above-union"}},"key":"2A47"},{"category":"Sm","mappings":{"default":{"default":"union above bar above intersection"},"mathspeak":{"default":"union-above-bar-above-intersection"}},"key":"2A48"},{"category":"Sm","mappings":{"default":{"default":"intersection above bar above union"},"mathspeak":{"default":"intersection-above-bar-above-union"}},"key":"2A49"},{"category":"Sm","mappings":{"default":{"default":"union beside and joined with union"},"mathspeak":{"default":"union-beside-and-joined-with-union"}},"key":"2A4A"},{"category":"Sm","mappings":{"default":{"default":"intersection beside and joined with intersection"},"mathspeak":{"default":"intersection-beside-and-joined-with-intersection"}},"key":"2A4B"},{"category":"Sm","mappings":{"default":{"default":"closed union with serifs"},"mathspeak":{"default":"closed-union-with-serifs"}},"key":"2A4C"},{"category":"Sm","mappings":{"default":{"default":"closed intersection with serifs"},"mathspeak":{"default":"closed-intersection-with-serifs"}},"key":"2A4D"},{"category":"Sm","mappings":{"default":{"default":"double square intersection"},"mathspeak":{"default":"double-square-intersection"}},"key":"2A4E"},{"category":"Sm","mappings":{"default":{"default":"double square union"},"mathspeak":{"default":"double-square-union"}},"key":"2A4F"},{"category":"Sm","mappings":{"default":{"default":"closed union with serifs and smash product"},"mathspeak":{"default":"closed-union-with-serifs-and-smash-product"}},"key":"2A50"},{"category":"Sm","mappings":{"default":{"default":"logical and with dot above"},"mathspeak":{"default":"logical-and-with-dot-above"}},"key":"2A51"},{"category":"Sm","mappings":{"default":{"default":"logical or with dot above"},"mathspeak":{"default":"logical-or-with-dot-above"}},"key":"2A52"},{"category":"Sm","mappings":{"default":{"default":"double logical and"},"mathspeak":{"default":"double-logical-and"}},"key":"2A53"},{"category":"Sm","mappings":{"default":{"default":"double logical or"},"mathspeak":{"default":"double-logical-or"}},"key":"2A54"},{"category":"Sm","mappings":{"default":{"default":"two intersecting logical and"},"mathspeak":{"default":"two-intersecting-logical-and"}},"key":"2A55"},{"category":"Sm","mappings":{"default":{"default":"two intersecting logical or"},"mathspeak":{"default":"two-intersecting-logical-or"}},"key":"2A56"},{"category":"Sm","mappings":{"default":{"default":"sloping large or"},"mathspeak":{"default":"sloping-large-or"}},"key":"2A57"},{"category":"Sm","mappings":{"default":{"default":"sloping large and"},"mathspeak":{"default":"sloping-large-and"}},"key":"2A58"},{"category":"Sm","mappings":{"default":{"default":"logical or overlapping logical and"},"mathspeak":{"default":"logical-or-overlapping-logical-and"}},"key":"2A59"},{"category":"Sm","mappings":{"default":{"default":"logical and with middle stem"},"mathspeak":{"default":"logical-and-with-middle-stem"}},"key":"2A5A"},{"category":"Sm","mappings":{"default":{"default":"logical or with middle stem"},"mathspeak":{"default":"logical-or-with-middle-stem"}},"key":"2A5B"},{"category":"Sm","mappings":{"default":{"default":"logical and with horizontal dash"},"mathspeak":{"default":"logical-and-with-horizontal-dash"}},"key":"2A5C"},{"category":"Sm","mappings":{"default":{"default":"logical or with horizontal dash"},"mathspeak":{"default":"logical-or-with-horizontal-dash"}},"key":"2A5D"},{"category":"Sm","mappings":{"default":{"default":"logical and with double overbar"},"mathspeak":{"default":"logical-and-with-double-overbar"}},"key":"2A5E"},{"category":"Sm","mappings":{"default":{"default":"logical and with underbar"},"mathspeak":{"default":"logical-and-with-underbar"}},"key":"2A5F"},{"category":"Sm","mappings":{"default":{"default":"logical and with double underbar"},"mathspeak":{"default":"logical-and-with-double-underbar"}},"key":"2A60"},{"category":"Sm","mappings":{"default":{"default":"small vee with underbar"},"mathspeak":{"default":"small-vee-with-underbar"}},"key":"2A61"},{"category":"Sm","mappings":{"default":{"default":"logical or with double overbar"},"mathspeak":{"default":"logical-or-with-double-overbar"}},"key":"2A62"},{"category":"Sm","mappings":{"default":{"default":"logical or with double underbar"},"mathspeak":{"default":"logical-or-with-double-underbar"}},"key":"2A63"},{"category":"Sm","mappings":{"default":{"default":"z notation domain antirestriction"},"mathspeak":{"default":"z-notation-domain-antirestriction"}},"key":"2A64"},{"category":"Sm","mappings":{"default":{"default":"z notation range antirestriction"},"mathspeak":{"default":"z-notation-range-antirestriction"}},"key":"2A65"},{"category":"Sm","mappings":{"default":{"default":"equals sign with dot below"},"mathspeak":{"default":"equals-with-dot-below"}},"key":"2A66"},{"category":"Sm","mappings":{"default":{"default":"identical with dot above"},"mathspeak":{"default":"identical-with-dot-above"}},"key":"2A67"},{"category":"Sm","mappings":{"default":{"default":"triple horizontal bar with double vertical stroke"},"mathspeak":{"default":"triple-horizontal-bar-with-double-vertical-stroke"}},"key":"2A68"},{"category":"Sm","mappings":{"default":{"default":"triple horizontal bar with triple vertical stroke"},"mathspeak":{"default":"triple-horizontal-bar-with-triple-vertical-stroke"}},"key":"2A69"},{"category":"Sm","mappings":{"default":{"default":"tilde operator with dot above"},"mathspeak":{"default":"tilde-with-dot-above"}},"key":"2A6A"},{"category":"Sm","mappings":{"default":{"default":"tilde operator with rising dots"},"mathspeak":{"default":"tilde-with-rising-dots"}},"key":"2A6B"},{"category":"Sm","mappings":{"default":{"default":"similar minus similar"},"mathspeak":{"default":"similar-minus-similar"}},"key":"2A6C"},{"category":"Sm","mappings":{"default":{"default":"congruent with dot above"},"mathspeak":{"default":"congruent-with-dot-above"}},"key":"2A6D"},{"category":"Sm","mappings":{"default":{"default":"equals with asterisk"},"mathspeak":{"default":"equals-with-asterisk"}},"key":"2A6E"},{"category":"Sm","mappings":{"default":{"default":"almost equals with circumflex accent","short":"almost equal hat"},"mathspeak":{"default":"almost-equal-hat"}},"key":"2A6F"},{"category":"Sm","mappings":{"default":{"default":"approximately equal or equals"},"mathspeak":{"default":"approximately-equal-or-equal-to"}},"key":"2A70"},{"category":"Sm","mappings":{"default":{"default":"equals sign above plus sign","short":"equals above plus"},"mathspeak":{"default":"equals-above-plus"}},"key":"2A71"},{"category":"Sm","mappings":{"default":{"default":"plus sign above equals sign","short":"plus above equals"},"mathspeak":{"default":"plus-above-equals"}},"key":"2A72"},{"category":"Sm","mappings":{"default":{"default":"equals sign above tilde operator","short":"equals above tilde operator"},"mathspeak":{"default":"equals-above-tilde"}},"key":"2A73"},{"category":"Sm","mappings":{"default":{"default":"double colon equal"},"mathspeak":{"default":"double-colon-equal"}},"key":"2A74"},{"category":"Sm","mappings":{"default":{"default":"two consecutive equals signs","short":"two consecutive equals"},"mathspeak":{"default":"two-consecutive-equals"}},"key":"2A75"},{"category":"Sm","mappings":{"default":{"default":"three consecutive equals signs","short":"three consecutive equals"},"mathspeak":{"default":"three-consecutive-equals"}},"key":"2A76"},{"category":"Sm","mappings":{"default":{"default":"equals sign with two dots above and two dots below"},"mathspeak":{"default":"equals-with-two-dots-above-and-two-dots-below"}},"key":"2A77"},{"category":"Sm","mappings":{"default":{"default":"equivalent with four dots above"},"mathspeak":{"default":"equivalent-with-four-dots-above"}},"key":"2A78"},{"category":"Sm","mappings":{"default":{"default":"less than with circle inside"},"mathspeak":{"default":"less-than-with-circle-inside"}},"key":"2A79"},{"category":"Sm","mappings":{"default":{"default":"greater than with circle inside"},"mathspeak":{"default":"greater-than-with-circle-inside"}},"key":"2A7A"},{"category":"Sm","mappings":{"default":{"default":"less than with question mark above"},"mathspeak":{"default":"less-than-with-question-mark-above"}},"key":"2A7B"},{"category":"Sm","mappings":{"default":{"default":"greater than with question mark above"},"mathspeak":{"default":"greater-than-with-question-mark-above"}},"key":"2A7C"},{"category":"Sm","mappings":{"default":{"default":"less than or slanted equals"},"mathspeak":{"default":"less-than-or-slanted-equals"}},"key":"2A7D"},{"category":"Sm","mappings":{"default":{"default":"greater than or slanted equals"},"mathspeak":{"default":"greater-than-or-slanted-equals"}},"key":"2A7E"},{"category":"Sm","mappings":{"default":{"default":"less than or slanted equals with dot inside"},"mathspeak":{"default":"less-than-or-slanted-equals-with-dot-inside"}},"key":"2A7F"},{"category":"Sm","mappings":{"default":{"default":"greater than or slanted equals with dot inside"},"mathspeak":{"default":"greater-than-or-slanted-equals-with-dot-inside"}},"key":"2A80"},{"category":"Sm","mappings":{"default":{"default":"less than or slanted equals with dot above"},"mathspeak":{"default":"less-than-or-slanted-equals-with-dot-above"}},"key":"2A81"},{"category":"Sm","mappings":{"default":{"default":"greater than or slanted equals with dot above"},"mathspeak":{"default":"greater-than-or-slanted-equals-with-dot-above"}},"key":"2A82"},{"category":"Sm","mappings":{"default":{"default":"less than or slanted equals with dot above right"},"mathspeak":{"default":"less-than-or-slanted-equals-with-dot-above-right"}},"key":"2A83"},{"category":"Sm","mappings":{"default":{"default":"greater than or slanted equals with dot above left"},"mathspeak":{"default":"greater-than-or-slanted-equals-with-dot-above-left"}},"key":"2A84"},{"category":"Sm","mappings":{"default":{"default":"less than or approximate"},"mathspeak":{"default":"less-than-or-approximate"}},"key":"2A85"},{"category":"Sm","mappings":{"default":{"default":"greater than or approximate"},"mathspeak":{"default":"greater-than-or-approximate"}},"key":"2A86"},{"category":"Sm","mappings":{"default":{"default":"less than and single line not equals"},"mathspeak":{"default":"less-than-and-single-line-not-equals"}},"key":"2A87"},{"category":"Sm","mappings":{"default":{"default":"greater than and single line not equals"},"mathspeak":{"default":"greater-than-and-single-line-not-equals"}},"key":"2A88"},{"category":"Sm","mappings":{"default":{"default":"less than and not approximate"},"mathspeak":{"default":"less-than-and-not-approximate"}},"key":"2A89"},{"category":"Sm","mappings":{"default":{"default":"greater than and not approximate"},"mathspeak":{"default":"greater-than-and-not-approximate"}},"key":"2A8A"},{"category":"Sm","mappings":{"default":{"default":"less than above double line equal above greater than"},"mathspeak":{"default":"less-than-above-double-line-equal-above-greater-than"}},"key":"2A8B"},{"category":"Sm","mappings":{"default":{"default":"greater than above double line equal above less than"},"mathspeak":{"default":"greater-than-above-double-line-equal-above-less-than"}},"key":"2A8C"},{"category":"Sm","mappings":{"default":{"default":"less than above similar or equal"},"mathspeak":{"default":"less-than-above-similar-or-equal"}},"key":"2A8D"},{"category":"Sm","mappings":{"default":{"default":"greater than above similar or equal"},"mathspeak":{"default":"greater-than-above-similar-or-equal"}},"key":"2A8E"},{"category":"Sm","mappings":{"default":{"default":"less than above similar above greater than"},"mathspeak":{"default":"less-than-above-similar-above-greater-than"}},"key":"2A8F"},{"category":"Sm","mappings":{"default":{"default":"greater than above similar above less than"},"mathspeak":{"default":"greater-than-above-similar-above-less-than"}},"key":"2A90"},{"category":"Sm","mappings":{"default":{"default":"less than above greater than above double line equal"},"mathspeak":{"default":"less-than-above-greater-than-above-double-line-equal"}},"key":"2A91"},{"category":"Sm","mappings":{"default":{"default":"greater than above less than above double line equal"},"mathspeak":{"default":"greater-than-above-less-than-above-double-line-equal"}},"key":"2A92"},{"category":"Sm","mappings":{"default":{"default":"less than above slanted equal above greater than above slanted equal"},"mathspeak":{"default":"less-than-above-slanted-equal-above-greater-than-above-slanted-equal"}},"key":"2A93"},{"category":"Sm","mappings":{"default":{"default":"greater than above slanted equal above less than above slanted equal"},"mathspeak":{"default":"greater-than-above-slanted-equal-above-less-than-above-slanted-equal"}},"key":"2A94"},{"category":"Sm","mappings":{"default":{"default":"slanted equals or less than"},"mathspeak":{"default":"slanted-equals-or-less-than"}},"key":"2A95"},{"category":"Sm","mappings":{"default":{"default":"slanted equals or greater than"},"mathspeak":{"default":"slanted-equals-or-greater-than"}},"key":"2A96"},{"category":"Sm","mappings":{"default":{"default":"slanted equals or less than with dot inside"},"mathspeak":{"default":"slanted-equals-or-less-than-with-dot-inside"}},"key":"2A97"},{"category":"Sm","mappings":{"default":{"default":"slanted equals or greater than with dot inside"},"mathspeak":{"default":"slanted-equals-or-greater-than-with-dot-inside"}},"key":"2A98"},{"category":"Sm","mappings":{"default":{"default":"double line equals or less than"},"mathspeak":{"default":"double-line-equals-or-less-than"}},"key":"2A99"},{"category":"Sm","mappings":{"default":{"default":"double line equals or greater than"},"mathspeak":{"default":"double-line-equals-or-greater-than"}},"key":"2A9A"},{"category":"Sm","mappings":{"default":{"default":"double line slanted equals or less than"},"mathspeak":{"default":"double-line-slanted-equals-or-less-than"}},"key":"2A9B"},{"category":"Sm","mappings":{"default":{"default":"double line slanted equals or greater than"},"mathspeak":{"default":"double-line-slanted-equals-or-greater-than"}},"key":"2A9C"},{"category":"Sm","mappings":{"default":{"default":"similar or less than"},"mathspeak":{"default":"similar-or-less-than"}},"key":"2A9D"},{"category":"Sm","mappings":{"default":{"default":"similar or greater than"},"mathspeak":{"default":"similar-or-greater-than"}},"key":"2A9E"},{"category":"Sm","mappings":{"default":{"default":"similar above less than above equals sign"},"mathspeak":{"default":"similar-above-less-than-above-equals"}},"key":"2A9F"},{"category":"Sm","mappings":{"default":{"default":"similar above greater than above equals sign"},"mathspeak":{"default":"similar-above-greater-than-above-equals"}},"key":"2AA0"},{"category":"Sm","mappings":{"default":{"default":"double nested less than"},"mathspeak":{"default":"double-nested-less-than"}},"key":"2AA1"},{"category":"Sm","mappings":{"default":{"default":"double nested greater than"},"mathspeak":{"default":"double-nested-greater-than"}},"key":"2AA2"},{"category":"Sm","mappings":{"default":{"default":"double nested less than with underbar"},"mathspeak":{"default":"double-nested-less-than-with-underbar"}},"key":"2AA3"},{"category":"Sm","mappings":{"default":{"default":"greater than overlapping less than"},"mathspeak":{"default":"greater-than-overlapping-less-than"}},"key":"2AA4"},{"category":"Sm","mappings":{"default":{"default":"greater than beside less than"},"mathspeak":{"default":"greater-than-beside-less-than"}},"key":"2AA5"},{"category":"Sm","mappings":{"default":{"default":"less than closed by curve"},"mathspeak":{"default":"less-than-closed-by-curve"}},"key":"2AA6"},{"category":"Sm","mappings":{"default":{"default":"greater than closed by curve"},"mathspeak":{"default":"greater-than-closed-by-curve"}},"key":"2AA7"},{"category":"Sm","mappings":{"default":{"default":"less than closed by curve above slanted equal"},"mathspeak":{"default":"less-than-closed-by-curve-above-slanted-equal"}},"key":"2AA8"},{"category":"Sm","mappings":{"default":{"default":"greater than closed by curve above slanted equal"},"mathspeak":{"default":"greater-than-closed-by-curve-above-slanted-equal"}},"key":"2AA9"},{"category":"Sm","mappings":{"default":{"default":"smaller than"},"mathspeak":{"default":"smaller-than"}},"key":"2AAA"},{"category":"Sm","mappings":{"default":{"default":"larger than"},"mathspeak":{"default":"larger-than"}},"key":"2AAB"},{"category":"Sm","mappings":{"default":{"default":"smaller than or equals"},"mathspeak":{"default":"smaller-than-or-equal-to"}},"key":"2AAC"},{"category":"Sm","mappings":{"default":{"default":"larger than or equals"},"mathspeak":{"default":"larger-than-or-equal-to"}},"key":"2AAD"},{"category":"Sm","mappings":{"default":{"default":"equals sign with bumpy above"},"mathspeak":{"default":"equals-with-bumpy-above"}},"key":"2AAE"},{"category":"Sm","mappings":{"default":{"default":"precedes above single line equals sign"},"mathspeak":{"default":"precedes-above-single-line-equals"}},"key":"2AAF"},{"category":"Sm","mappings":{"default":{"default":"succeeds above single line equals sign"},"mathspeak":{"default":"succeeds-above-single-line-equals"}},"key":"2AB0"},{"category":"Sm","mappings":{"default":{"default":"precedes above single line not equals"},"mathspeak":{"default":"precedes-above-single-line-not-equals"}},"key":"2AB1"},{"category":"Sm","mappings":{"default":{"default":"succeeds above single line not equals"},"mathspeak":{"default":"succeeds-above-single-line-not-equals"}},"key":"2AB2"},{"category":"Sm","mappings":{"default":{"default":"precedes above equals sign"},"mathspeak":{"default":"precedes-above-equals"}},"key":"2AB3"},{"category":"Sm","mappings":{"default":{"default":"succeeds above equals sign"},"mathspeak":{"default":"succeeds-above-equals"}},"key":"2AB4"},{"category":"Sm","mappings":{"default":{"default":"precedes above not equals"},"mathspeak":{"default":"precedes-above-not-equals"}},"key":"2AB5"},{"category":"Sm","mappings":{"default":{"default":"succeeds above not equals"},"mathspeak":{"default":"succeeds-above-not-equals"}},"key":"2AB6"},{"category":"Sm","mappings":{"default":{"default":"precedes above almost equals"},"mathspeak":{"default":"precedes-above-almost-equals"}},"key":"2AB7"},{"category":"Sm","mappings":{"default":{"default":"succeeds above almost equals"},"mathspeak":{"default":"succeeds-above-almost-equals"}},"key":"2AB8"},{"category":"Sm","mappings":{"default":{"default":"precedes above not almost equals"},"mathspeak":{"default":"precedes-above-not-almost-equals"}},"key":"2AB9"},{"category":"Sm","mappings":{"default":{"default":"succeeds above not almost equals"},"mathspeak":{"default":"succeeds-above-not-almost-equals"}},"key":"2ABA"},{"category":"Sm","mappings":{"default":{"default":"double precedes"},"mathspeak":{"default":"double-precedes"}},"key":"2ABB"},{"category":"Sm","mappings":{"default":{"default":"double succeeds"},"mathspeak":{"default":"double-succeeds"}},"key":"2ABC"},{"category":"Sm","mappings":{"default":{"default":"subset with dot"},"mathspeak":{"default":"subset-with-dot"}},"key":"2ABD"},{"category":"Sm","mappings":{"default":{"default":"superset with dot"},"mathspeak":{"default":"superset-with-dot"}},"key":"2ABE"},{"category":"Sm","mappings":{"default":{"default":"subset with plus sign below"},"mathspeak":{"default":"subset-with-plus-sign-below"}},"key":"2ABF"},{"category":"Sm","mappings":{"default":{"default":"superset with plus sign below"},"mathspeak":{"default":"superset-with-plus-sign-below"}},"key":"2AC0"},{"category":"Sm","mappings":{"default":{"default":"subset with multiplication sign below"},"mathspeak":{"default":"subset-with-multiplication-sign-below"}},"key":"2AC1"},{"category":"Sm","mappings":{"default":{"default":"superset with multiplication sign below"},"mathspeak":{"default":"superset-with-multiplication-sign-below"}},"key":"2AC2"},{"category":"Sm","mappings":{"default":{"default":"subset of or equals with dot above"},"mathspeak":{"default":"subset-of-or-equal-to-with-dot-above"}},"key":"2AC3"},{"category":"Sm","mappings":{"default":{"default":"superset of or equals with dot above"},"mathspeak":{"default":"superset-of-or-equal-to-with-dot-above"}},"key":"2AC4"},{"category":"Sm","mappings":{"default":{"default":"subset of above equals sign"},"mathspeak":{"default":"subset-of-above-equals"}},"key":"2AC5"},{"category":"Sm","mappings":{"default":{"default":"superset of above equals sign"},"mathspeak":{"default":"superset-of-above-equals"}},"key":"2AC6"},{"category":"Sm","mappings":{"default":{"default":"subset of above tilde operator"},"mathspeak":{"default":"subset-of-above-tilde"}},"key":"2AC7"},{"category":"Sm","mappings":{"default":{"default":"superset of above tilde operator"},"mathspeak":{"default":"superset-of-above-tilde"}},"key":"2AC8"},{"category":"Sm","mappings":{"default":{"default":"subset of above almost equals"},"mathspeak":{"default":"subset-of-above-almost-equals"}},"key":"2AC9"},{"category":"Sm","mappings":{"default":{"default":"superset of above almost equals"},"mathspeak":{"default":"superset-of-above-almost-equals"}},"key":"2ACA"},{"category":"Sm","mappings":{"default":{"default":"subset of above not equals"},"mathspeak":{"default":"subset-of-above-not-equals"}},"key":"2ACB"},{"category":"Sm","mappings":{"default":{"default":"superset of above not equals"},"mathspeak":{"default":"superset-of-above-not-equals"}},"key":"2ACC"},{"category":"Sm","mappings":{"default":{"default":"square left open box operator"},"mathspeak":{"default":"square-left-open-box"}},"key":"2ACD"},{"category":"Sm","mappings":{"default":{"default":"square right open box operator"},"mathspeak":{"default":"square-right-open-box"}},"key":"2ACE"},{"category":"Sm","mappings":{"default":{"default":"closed subset"},"mathspeak":{"default":"closed-subset"}},"key":"2ACF"},{"category":"Sm","mappings":{"default":{"default":"closed superset"},"mathspeak":{"default":"closed-superset"}},"key":"2AD0"},{"category":"Sm","mappings":{"default":{"default":"closed subset or equals"},"mathspeak":{"default":"closed-subset-or-equal-to"}},"key":"2AD1"},{"category":"Sm","mappings":{"default":{"default":"closed superset or equals"},"mathspeak":{"default":"closed-superset-or-equal-to"}},"key":"2AD2"},{"category":"Sm","mappings":{"default":{"default":"subset above superset"},"mathspeak":{"default":"subset-above-superset"}},"key":"2AD3"},{"category":"Sm","mappings":{"default":{"default":"superset above subset"},"mathspeak":{"default":"superset-above-subset"}},"key":"2AD4"},{"category":"Sm","mappings":{"default":{"default":"subset above subset"},"mathspeak":{"default":"subset-above-subset"}},"key":"2AD5"},{"category":"Sm","mappings":{"default":{"default":"superset above superset"},"mathspeak":{"default":"superset-above-superset"}},"key":"2AD6"},{"category":"Sm","mappings":{"default":{"default":"superset beside subset"},"mathspeak":{"default":"superset-beside-subset"}},"key":"2AD7"},{"category":"Sm","mappings":{"default":{"default":"superset beside and joined by dash with subset"},"mathspeak":{"default":"superset-beside-and-joined-by-dash-with-subset"}},"key":"2AD8"},{"category":"Sm","mappings":{"default":{"default":"element of opening downwards"},"mathspeak":{"default":"element-of-opening-downwards"}},"key":"2AD9"},{"category":"Sm","mappings":{"default":{"default":"pitchfork with tee top"},"mathspeak":{"default":"pitchfork-with-tee-top"}},"key":"2ADA"},{"category":"Sm","mappings":{"default":{"default":"transversal intersection"},"mathspeak":{"default":"transversal-intersection"}},"key":"2ADB"},{"category":"Sm","mappings":{"default":{"default":"forking"}},"key":"2ADC"},{"category":"Sm","mappings":{"default":{"default":"nonforking"}},"key":"2ADD"},{"category":"Sm","mappings":{"default":{"default":"short left tack"},"mathspeak":{"default":"short-left-tack"}},"key":"2ADE"},{"category":"Sm","mappings":{"default":{"default":"short down tack"},"mathspeak":{"default":"short-down-tack"}},"key":"2ADF"},{"category":"Sm","mappings":{"default":{"default":"short up tack"},"mathspeak":{"default":"short-up-tack"}},"key":"2AE0"},{"category":"Sm","mappings":{"default":{"default":"perpendicular with s"},"mathspeak":{"default":"perpendicular-with-s"}},"key":"2AE1"},{"category":"Sm","mappings":{"default":{"default":"vertical bar triple right turnstile"},"mathspeak":{"default":"vertical-bar-triple-right-turnstile"}},"key":"2AE2"},{"category":"Sm","mappings":{"default":{"default":"double vertical bar left turnstile"},"mathspeak":{"default":"double-vertical-bar-left-turnstile"}},"key":"2AE3"},{"category":"Sm","mappings":{"default":{"default":"vertical bar double left turnstile"},"mathspeak":{"default":"vertical-bar-double-left-turnstile"}},"key":"2AE4"},{"category":"Sm","mappings":{"default":{"default":"double vertical bar double left turnstile"},"mathspeak":{"default":"double-vertical-bar-double-left-turnstile"}},"key":"2AE5"},{"category":"Sm","mappings":{"default":{"default":"long dash from left member of double vertical"},"mathspeak":{"default":"long-dash-from-left-member-of-double-vertical"}},"key":"2AE6"},{"category":"Sm","mappings":{"default":{"default":"short down tack with overbar"},"mathspeak":{"default":"short-down-tack-with-overbar"}},"key":"2AE7"},{"category":"Sm","mappings":{"default":{"default":"short up tack with underbar"},"mathspeak":{"default":"short-up-tack-with-underbar"}},"key":"2AE8"},{"category":"Sm","mappings":{"default":{"default":"short up tack above short down tack"},"mathspeak":{"default":"short-up-tack-above-short-down-tack"}},"key":"2AE9"},{"category":"Sm","mappings":{"default":{"default":"double down tack"},"mathspeak":{"default":"double-down-tack"}},"key":"2AEA"},{"category":"Sm","mappings":{"default":{"default":"double up tack"},"mathspeak":{"default":"double-up-tack"}},"key":"2AEB"},{"category":"Sm","mappings":{"default":{"default":"double stroke not sign"},"mathspeak":{"default":"double-stroke-not-sign"}},"key":"2AEC"},{"category":"Sm","mappings":{"default":{"default":"reversed double stroke not sign"},"mathspeak":{"default":"reversed-double-stroke-not-sign"}},"key":"2AED"},{"category":"Sm","mappings":{"default":{"default":"does not divide with reversed negation slash"},"mathspeak":{"default":"does-not-divide-with-reversed-negation-slash"}},"key":"2AEE"},{"category":"Sm","mappings":{"default":{"default":"vertical line with circle above"},"mathspeak":{"default":"vertical-line-with-circle-above"}},"key":"2AEF"},{"category":"Sm","mappings":{"default":{"default":"vertical line with circle below"},"mathspeak":{"default":"vertical-line-with-circle-below"}},"key":"2AF0"},{"category":"Sm","mappings":{"default":{"default":"down tack with circle below"},"mathspeak":{"default":"down-tack-with-circle-below"}},"key":"2AF1"},{"category":"Sm","mappings":{"default":{"default":"parallel with horizontal stroke"},"mathspeak":{"default":"parallel-with-horizontal-stroke"}},"key":"2AF2"},{"category":"Sm","mappings":{"default":{"default":"parallel with tilde operator"},"mathspeak":{"default":"parallel-with-tilde"}},"key":"2AF3"},{"category":"Sm","mappings":{"default":{"default":"triple vertical bar binary relation"},"mathspeak":{"default":"triple-vertical-bar-binary-relation"}},"key":"2AF4"},{"category":"Sm","mappings":{"default":{"default":"triple vertical bar with horizontal stroke"},"mathspeak":{"default":"triple-vertical-bar-with-horizontal-stroke"}},"key":"2AF5"},{"category":"Sm","mappings":{"default":{"default":"triple colon operator"},"mathspeak":{"default":"triple-colon"}},"key":"2AF6"},{"category":"Sm","mappings":{"default":{"default":"triple nested less than"},"mathspeak":{"default":"triple-nested-less-than"}},"key":"2AF7"},{"category":"Sm","mappings":{"default":{"default":"triple nested greater than"},"mathspeak":{"default":"triple-nested-greater-than"}},"key":"2AF8"},{"category":"Sm","mappings":{"default":{"default":"double line slanted less than or equals"},"mathspeak":{"default":"double-line-slanted-less-than-or-equal-to"}},"key":"2AF9"},{"category":"Sm","mappings":{"default":{"default":"double line slanted greater than or equals"},"mathspeak":{"default":"double-line-slanted-greater-than-or-equal-to"}},"key":"2AFA"},{"category":"Sm","mappings":{"default":{"default":"triple solidus binary relation"},"mathspeak":{"default":"triple-solidus-binary-relation"}},"key":"2AFB"},{"category":"Sm","mappings":{"default":{"default":"large triple vertical bar operator"},"mathspeak":{"default":"large-triple-vertical-bar"}},"key":"2AFC"},{"category":"Sm","mappings":{"default":{"default":"double solidus operator"},"mathspeak":{"default":"double-solidus"}},"key":"2AFD"},{"category":"Sm","mappings":{"default":{"default":"white vertical bar"},"mathspeak":{"default":"white-vertical-bar"}},"key":"2AFE"},{"category":"Sm","mappings":{"default":{"default":"n ary white vertical bar"},"mathspeak":{"default":"white-vertical-bar"}},"key":"2AFF"},{"category":"Pd","mappings":{"default":{"default":"wave dash"},"mathspeak":{"default":"wave-dash"}},"key":"301C"},{"category":"Po","mappings":{"default":{"default":"presentation form for vertical comma"},"mathspeak":{"default":"presentation-form-for-vertical-comma"}},"key":"FE10"},{"category":"Po","mappings":{"default":{"default":"presentation form for vertical colon"},"mathspeak":{"default":"presentation-form-for-vertical-colon"}},"key":"FE13"},{"category":"Po","mappings":{"default":{"default":"presentation form for vertical semicolon"},"mathspeak":{"default":"presentation-form-for-vertical-semicolon"}},"key":"FE14"},{"category":"Po","mappings":{"default":{"default":"presentation form for vertical exclamation mark"},"mathspeak":{"default":"presentation-form-for-vertical-exclamation-mark"}},"key":"FE15"},{"category":"Po","mappings":{"default":{"default":"presentation form for vertical question mark"},"mathspeak":{"default":"presentation-form-for-vertical-question-mark"}},"key":"FE16"},{"category":"Po","mappings":{"default":{"default":"presentation form for vertical horizontal ellipsis"},"mathspeak":{"default":"presentation-form-for-vertical-horizontal-ellipsis"}},"key":"FE19"},{"category":"Po","mappings":{"default":{"default":"presentation form for vertical two dot leader","alternative":"glyph for vertical two dot leader"},"mathspeak":{"default":"glyph-for-vertical-two-dot-leader"}},"key":"FE30"},{"category":"Pd","mappings":{"default":{"default":"presentation form for vertical em dash","alternative":"glyph for vertical em dash"},"mathspeak":{"default":"glyph-for-vertical-em-dash"}},"key":"FE31"},{"category":"Pd","mappings":{"default":{"default":"presentation form for vertical en dash","alternative":"glyph for vertical en dash"},"mathspeak":{"default":"glyph-for-vertical-en-dash"}},"key":"FE32"},{"category":"Pc","mappings":{"default":{"default":"presentation form for vertical low line","alternative":"glyph for vertical spacing underscore"},"mathspeak":{"default":"glyph-for-vertical-underscore"}},"key":"FE33"},{"category":"Pc","mappings":{"default":{"default":"presentation form for vertical wavy low line","alternative":"glyph for vertical spacing wavy underscore"},"mathspeak":{"default":"glyph-for-vertical-wavy-underscore"}},"key":"FE34"},{"category":"Po","mappings":{"default":{"default":"sesame dot"},"mathspeak":{"default":"sesame-dot"}},"key":"FE45"},{"category":"Po","mappings":{"default":{"default":"white sesame dot"},"mathspeak":{"default":"white-sesame-dot"}},"key":"FE46"},{"category":"Po","mappings":{"default":{"default":"dashed overline","alternative":"spacing dashed overscore"},"mathspeak":{"default":"dashed-overscore"}},"key":"FE49"},{"category":"Po","mappings":{"default":{"default":"centerline overline","alternative":"spacing centerline overscore"},"mathspeak":{"default":"centerline-overscore"}},"key":"FE4A"},{"category":"Po","mappings":{"default":{"default":"wavy overline","alternative":"spacing wavy overscore"},"mathspeak":{"default":"wavy-overscore"}},"key":"FE4B"},{"category":"Po","mappings":{"default":{"default":"double wavy overline","alternative":"spacing double wavy overscore"},"mathspeak":{"default":"double-wavy-overscore"}},"key":"FE4C"},{"category":"Pc","mappings":{"default":{"default":"dashed low line","alternative":"spacing dashed underscore"},"mathspeak":{"default":"dashed-underscore"}},"key":"FE4D"},{"category":"Pc","mappings":{"default":{"default":"centerline low line","alternative":"spacing centerline underscore"},"mathspeak":{"default":"centerline-underscore"}},"key":"FE4E"},{"category":"Pc","mappings":{"default":{"default":"wavy low line","alternative":"spacing wavy underscore"},"mathspeak":{"default":"wavy-underscore"}},"key":"FE4F"},{"category":"Po","mappings":{"default":{"default":"small comma"},"mathspeak":{"default":"small-comma"}},"key":"FE50"},{"category":"Po","mappings":{"default":{"default":"small full stop","alternative":"small period"},"mathspeak":{"default":"small-period"}},"key":"FE52"},{"category":"Po","mappings":{"default":{"default":"small semicolon"},"mathspeak":{"default":"small-semicolon"}},"key":"FE54"},{"category":"Po","mappings":{"default":{"default":"small colon"},"mathspeak":{"default":"small-colon"}},"key":"FE55"},{"category":"Po","mappings":{"default":{"default":"small question mark"},"mathspeak":{"default":"small-question-mark"}},"key":"FE56"},{"category":"Po","mappings":{"default":{"default":"small exclamation mark"},"mathspeak":{"default":"small-exclamation-mark"}},"key":"FE57"},{"category":"Pd","mappings":{"default":{"default":"small em dash"},"mathspeak":{"default":"small-em-dash"}},"key":"FE58"},{"category":"Po","mappings":{"default":{"default":"small number sign"},"mathspeak":{"default":"small-number-sign"}},"key":"FE5F"},{"category":"Po","mappings":{"default":{"default":"small ampersand"},"mathspeak":{"default":"small-ampersand"}},"key":"FE60"},{"category":"Po","mappings":{"default":{"default":"small asterisk"},"mathspeak":{"default":"small-asterisk"}},"key":"FE61"},{"category":"Sm","mappings":{"default":{"default":"small plus sign"},"mathspeak":{"default":"small-plus-sign"}},"key":"FE62"},{"category":"Pd","mappings":{"default":{"default":"small hyphen minus"},"mathspeak":{"default":"small-hyphen-minus"}},"key":"FE63"},{"category":"Sm","mappings":{"default":{"default":"small less than sign"},"mathspeak":{"default":"small-less-than-sign"}},"key":"FE64"},{"category":"Sm","mappings":{"default":{"default":"small greater than sign"},"mathspeak":{"default":"small-greater-than-sign"}},"key":"FE65"},{"category":"Sm","mappings":{"default":{"default":"small equals sign"},"mathspeak":{"default":"small-equals"}},"key":"FE66"},{"category":"Po","mappings":{"default":{"default":"small reverse solidus","alternative":"small backslash"},"mathspeak":{"default":"small-backslash"}},"key":"FE68"},{"category":"Sc","mappings":{"default":{"default":"small dollar sign"},"mathspeak":{"default":"small-dollar-sign"}},"key":"FE69"},{"category":"Po","mappings":{"default":{"default":"small percent sign"},"mathspeak":{"default":"small-percent-sign"}},"key":"FE6A"},{"category":"Po","mappings":{"default":{"default":"small commercial at"},"mathspeak":{"default":"small-commercial-at"}},"key":"FE6B"},{"category":"Po","mappings":{"default":{"default":"fullwidth exclamation mark"},"mathspeak":{"default":"exclamation-mark"}},"key":"FF01"},{"category":"Po","mappings":{"default":{"default":"fullwidth quotation mark"},"mathspeak":{"default":"quotation-mark"}},"key":"FF02"},{"category":"Po","mappings":{"default":{"default":"fullwidth number sign"},"mathspeak":{"default":"number-sign"}},"key":"FF03"},{"category":"Sc","mappings":{"default":{"default":"fullwidth dollar sign"},"mathspeak":{"default":"dollar-sign"}},"key":"FF04"},{"category":"Po","mappings":{"default":{"default":"fullwidth percent sign"},"mathspeak":{"default":"percent-sign"}},"key":"FF05"},{"category":"Po","mappings":{"default":{"default":"fullwidth ampersand"},"mathspeak":{"default":"ampersand"}},"key":"FF06"},{"category":"Po","mappings":{"default":{"default":"fullwidth apostrophe"},"mathspeak":{"default":"apostrophe"}},"key":"FF07"},{"category":"Po","mappings":{"default":{"default":"fullwidth asterisk"},"mathspeak":{"default":"asterisk"}},"key":"FF0A"},{"category":"Sm","mappings":{"default":{"default":"fullwidth plus sign"},"mathspeak":{"default":"plus-sign"}},"key":"FF0B"},{"category":"Po","mappings":{"default":{"default":"fullwidth comma"},"mathspeak":{"default":"comma"}},"key":"FF0C"},{"category":"Pd","mappings":{"default":{"default":"fullwidth hyphen minus"},"mathspeak":{"default":"hyphen-minus"}},"key":"FF0D"},{"category":"Po","mappings":{"default":{"default":"fullwidth full stop","alternative":"fullwidth period"},"mathspeak":{"default":"period"}},"key":"FF0E"},{"category":"Po","mappings":{"default":{"default":"fullwidth solidus","alternative":"fullwidth slash"},"mathspeak":{"default":"slash"}},"key":"FF0F"},{"category":"Po","mappings":{"default":{"default":"fullwidth colon"},"mathspeak":{"default":"colon"}},"key":"FF1A"},{"category":"Po","mappings":{"default":{"default":"fullwidth semicolon"},"mathspeak":{"default":"semicolon"}},"key":"FF1B"},{"category":"Sm","mappings":{"default":{"default":"fullwidth less than sign"},"mathspeak":{"default":"less-than-sign"}},"key":"FF1C"},{"category":"Sm","mappings":{"default":{"default":"fullwidth equals sign"},"mathspeak":{"default":"equals"}},"key":"FF1D"},{"category":"Sm","mappings":{"default":{"default":"fullwidth greater than sign"},"mathspeak":{"default":"greater-than-sign"}},"key":"FF1E"},{"category":"Po","mappings":{"default":{"default":"fullwidth question mark"},"mathspeak":{"default":"question-mark"}},"key":"FF1F"},{"category":"Po","mappings":{"default":{"default":"fullwidth commercial at"},"mathspeak":{"default":"commercial-at"}},"key":"FF20"},{"category":"Po","mappings":{"default":{"default":"fullwidth reverse solidus","alternative":"fullwidth backslash"},"mathspeak":{"default":"backslash"}},"key":"FF3C"},{"category":"Sk","mappings":{"default":{"default":"fullwidth circumflex accent","alternative":"fullwidth spacing circumflex"},"mathspeak":{"default":"caret"}},"key":"FF3E"},{"category":"Pc","mappings":{"default":{"default":"fullwidth low line","alternative":"fullwidth spacing underscore"},"mathspeak":{"default":"bar"}},"key":"FF3F"},{"category":"Sk","mappings":{"default":{"default":"fullwidth grave accent","alternative":"fullwidth spacing grave"},"mathspeak":{"default":"grave"}},"key":"FF40"},{"category":"Sm","mappings":{"default":{"default":"fullwidth vertical line","alternative":"fullwidth vertical bar"},"mathspeak":{"default":"vertical-bar"}},"key":"FF5C"},{"category":"Sm","mappings":{"default":{"default":"fullwidth tilde","alternative":"fullwidth spacing tilde"},"mathspeak":{"default":"tilde"}},"key":"FF5E"},{"category":"Sc","mappings":{"default":{"default":"fullwidth cent sign"},"mathspeak":{"default":"cent-sign"}},"key":"FFE0"},{"category":"Sc","mappings":{"default":{"default":"fullwidth pound sign"},"mathspeak":{"default":"pound-sign"}},"key":"FFE1"},{"category":"Sm","mappings":{"default":{"default":"fullwidth not sign"},"mathspeak":{"default":"not-sign"}},"key":"FFE2"},{"category":"Sk","mappings":{"default":{"default":"fullwidth macron","alternative":"fullwidth spacing macron"},"mathspeak":{"default":"bar"}},"key":"FFE3"},{"category":"So","mappings":{"default":{"default":"fullwidth broken bar","alternative":"fullwidth broken vertical bar"},"mathspeak":{"default":"broken-vertical-bar"}},"key":"FFE4"},{"category":"Sc","mappings":{"default":{"default":"fullwidth yen sign"},"mathspeak":{"default":"yen-sign"}},"key":"FFE5"},{"category":"Sc","mappings":{"default":{"default":"fullwidth won sign"},"mathspeak":{"default":"won-sign"}},"key":"FFE6"},{"category":"So","mappings":{"default":{"default":"halfwidth forms light vertical"},"mathspeak":{"default":"halfwidth-forms-light-vertical"}},"key":"FFE8"},{"category":"So","mappings":{"default":{"default":"halfwidth black square"},"mathspeak":{"default":"halfwidth-black-square"}},"key":"FFED"},{"category":"So","mappings":{"default":{"default":"halfwidth white circle"},"mathspeak":{"default":"halfwidth-white-circle"}},"key":"FFEE"}]
,
"en/math_whitespace.js": 
[{"locale":"en"},{"category":"Zs","mappings":{"default":{"default":"space"}},"key":"0020"},{"category":"Zs","mappings":{"default":{"default":"no break space","alternative":"non breaking space"}},"key":"00A0"},{"category":"Cf","mappings":{"default":{"default":"soft hyphen"}},"key":"00AD"},{"category":"Zs","mappings":{"default":{"default":"en quad"}},"key":"2000"},{"category":"Zs","mappings":{"default":{"default":"em quad"}},"key":"2001"},{"category":"Zs","mappings":{"default":{"default":"en space"}},"key":"2002"},{"category":"Zs","mappings":{"default":{"default":"em space"}},"key":"2003"},{"category":"Zs","mappings":{"default":{"default":"three per em space"}},"key":"2004"},{"category":"Zs","mappings":{"default":{"default":"four per em space"}},"key":"2005"},{"category":"Zs","mappings":{"default":{"default":"six per em space"}},"key":"2006"},{"category":"Zs","mappings":{"default":{"default":"figure space"}},"key":"2007"},{"category":"Zs","mappings":{"default":{"default":"punctuation space"}},"key":"2008"},{"category":"Zs","mappings":{"default":{"default":"thin space"}},"key":"2009"},{"category":"Zs","mappings":{"default":{"default":"hair space"}},"key":"200A"},{"category":"Cf","mappings":{"default":{"default":"zero width space"}},"key":"200B"},{"category":"Cf","mappings":{"default":{"default":"zero width non joiner"}},"key":"200C"},{"category":"Cf","mappings":{"default":{"default":"zero width joiner"}},"key":"200D"},{"category":"Cf","mappings":{"default":{"default":"left to right mark"}},"key":"200E"},{"category":"Cf","mappings":{"default":{"default":"right to left mark"}},"key":"200F"},{"category":"Zl","mappings":{"default":{"default":"line separator"}},"key":"2028"},{"category":"Zp","mappings":{"default":{"default":"paragraph separator"}},"key":"2029"},{"category":"Cf","mappings":{"default":{"default":"left to right embedding"}},"key":"202A"},{"category":"Cf","mappings":{"default":{"default":"right to left embedding"}},"key":"202B"},{"category":"Cf","mappings":{"default":{"default":"pop directional formatting"}},"key":"202C"},{"category":"Cf","mappings":{"default":{"default":"left to right override"}},"key":"202D"},{"category":"Cf","mappings":{"default":{"default":"right to left override"}},"key":"202E"},{"category":"Zs","mappings":{"default":{"default":"narrow no break space"}},"key":"202F"},{"category":"Zs","mappings":{"default":{"default":"medium mathematical space"}},"key":"205F"},{"category":"Cf","mappings":{"default":{"default":"word joiner"}},"key":"2060"},{"category":"Cf","mappings":{"default":{"default":"function application","short":"of"}},"key":"2061"},{"category":"Cf","mappings":{"default":{"default":"invisible times","short":"times"}},"key":"2062"},{"category":"Cf","mappings":{"default":{"default":"invisible separator","short":"separator"}},"key":"2063"},{"category":"Cf","mappings":{"default":{"default":"invisible plus","short":"plus"}},"key":"2064"},{"category":"Cf","mappings":{"default":{"default":"inhibit symmetric swapping"}},"key":"206A"},{"category":"Cf","mappings":{"default":{"default":"activate symmetric swapping"}},"key":"206B"},{"category":"Cf","mappings":{"default":{"default":"national digit shapes"}},"key":"206E"},{"category":"Cf","mappings":{"default":{"default":"nominal digit shapes"}},"key":"206F"},{"category":"Cf","mappings":{"default":{"default":"zero width no break space","alternative":"byte order mark"}},"key":"FEFF"},{"category":"Cf","mappings":{"default":{"default":"interlinear annotation anchor"}},"key":"FFF9"},{"category":"Cf","mappings":{"default":{"default":"interlinear annotation separator"}},"key":"FFFA"},{"category":"Cf","mappings":{"default":{"default":"interlinear annotation terminator"}},"key":"FFFB"}]
,
"en/other_stars.js": 
[{"locale":"en"},{"category":"So","mappings":{"default":{"default":"decimal exponent symbol"}},"key":"23E8"},{"category":"So","mappings":{"default":{"default":"black star"}},"key":"2605"},{"category":"So","mappings":{"default":{"default":"white star"}},"key":"2606"},{"category":"So","mappings":{"default":{"default":"medium white circle","short":"white circle"}},"key":"26AA"},{"category":"So","mappings":{"default":{"default":"medium black circle","short":"black circle"}},"key":"26AB"},{"category":"So","mappings":{"default":{"default":"white heavy check mark","short":"white check"}},"key":"2705"},{"category":"So","mappings":{"default":{"default":"check mark","short":"check"}},"key":"2713"},{"category":"So","mappings":{"default":{"default":"heavy check mark","short":"heavy check"}},"key":"2714"},{"category":"So","mappings":{"default":{"default":"multiplication x"}},"key":"2715"},{"category":"So","mappings":{"default":{"default":"heavy multiplication x"}},"key":"2716"},{"category":"So","mappings":{"default":{"default":"ballot x"}},"key":"2717"},{"category":"So","mappings":{"default":{"default":"heavy ballot x"}},"key":"2718"},{"category":"So","mappings":{"default":{"default":"open center cross"}},"key":"271B"},{"category":"So","mappings":{"default":{"default":"heavy open center cross"}},"key":"271C"},{"category":"So","mappings":{"default":{"default":"maltese cross"}},"key":"2720"},{"category":"So","mappings":{"default":{"default":"star of david"}},"key":"2721"},{"category":"So","mappings":{"default":{"default":"four teardrop spoked asterisk"}},"key":"2722"},{"category":"So","mappings":{"default":{"default":"four balloon spoked asterisk"}},"key":"2723"},{"category":"So","mappings":{"default":{"default":"heavy four balloon spoked asterisk"}},"key":"2724"},{"category":"So","mappings":{"default":{"default":"four club spoked asterisk"}},"key":"2725"},{"category":"So","mappings":{"default":{"default":"black four pointed star"}},"key":"2726"},{"category":"So","mappings":{"default":{"default":"white four pointed star"}},"key":"2727"},{"category":"So","mappings":{"default":{"default":"sparkles"}},"key":"2728"},{"category":"So","mappings":{"default":{"default":"stress outlined white star"}},"key":"2729"},{"category":"So","mappings":{"default":{"default":"circled white star"}},"key":"272A"},{"category":"So","mappings":{"default":{"default":"open center black star"}},"key":"272B"},{"category":"So","mappings":{"default":{"default":"black center white star"}},"key":"272C"},{"category":"So","mappings":{"default":{"default":"outlined black star"}},"key":"272D"},{"category":"So","mappings":{"default":{"default":"heavy outlined black star"}},"key":"272E"},{"category":"So","mappings":{"default":{"default":"pinwheel star"}},"key":"272F"},{"category":"So","mappings":{"default":{"default":"shadowed white star"}},"key":"2730"},{"category":"So","mappings":{"default":{"default":"heavy asterisk"}},"key":"2731"},{"category":"So","mappings":{"default":{"default":"open center asterisk"}},"key":"2732"},{"category":"So","mappings":{"default":{"default":"eight spoked asterisk"}},"key":"2733"},{"category":"So","mappings":{"default":{"default":"eight pointed black star"}},"key":"2734"},{"category":"So","mappings":{"default":{"default":"eight pointed pinwheel star"}},"key":"2735"},{"category":"So","mappings":{"default":{"default":"six pointed black star"}},"key":"2736"},{"category":"So","mappings":{"default":{"default":"twelve pointed black star"}},"key":"2739"},{"category":"So","mappings":{"default":{"default":"sixteen pointed asterisk"}},"key":"273A"},{"category":"So","mappings":{"default":{"default":"teardrop spoked asterisk"}},"key":"273B"},{"category":"So","mappings":{"default":{"default":"open center teardrop spoked asterisk"}},"key":"273C"},{"category":"So","mappings":{"default":{"default":"heavy teardrop spoked asterisk"}},"key":"273D"},{"category":"So","mappings":{"default":{"default":"six petalled black and white florette"}},"key":"273E"},{"category":"So","mappings":{"default":{"default":"black florette"}},"key":"273F"},{"category":"So","mappings":{"default":{"default":"white florette"}},"key":"2740"},{"category":"So","mappings":{"default":{"default":"eight petalled outlined black florette"}},"key":"2741"},{"category":"So","mappings":{"default":{"default":"circled open center eight pointed star"}},"key":"2742"},{"category":"So","mappings":{"default":{"default":"heavy teardrop spoked pinwheel asterisk"}},"key":"2743"},{"category":"So","mappings":{"default":{"default":"snowflake"}},"key":"2744"},{"category":"So","mappings":{"default":{"default":"tight trifoliate snowflake"}},"key":"2745"},{"category":"So","mappings":{"default":{"default":"heavy chevron snowflake"}},"key":"2746"},{"category":"So","mappings":{"default":{"default":"sparkle"}},"key":"2747"},{"category":"So","mappings":{"default":{"default":"heavy sparkle"}},"key":"2748"},{"category":"So","mappings":{"default":{"default":"balloon spoked asterisk"}},"key":"2749"},{"category":"So","mappings":{"default":{"default":"eight teardrop spoked propeller asterisk"}},"key":"274A"},{"category":"So","mappings":{"default":{"default":"heavy eight teardrop spoked propeller asterisk"}},"key":"274B"},{"category":"So","mappings":{"default":{"default":"cross mark"}},"key":"274C"},{"category":"So","mappings":{"default":{"default":"shadowed white circle"}},"key":"274D"}]
,
"en/energy.js": 
[{"locale":"en"},{"category":"energy","mappings":{"default":{"default":"watts"}},"key":"W","names":["W","w"]},{"category":"energy","mappings":{"default":{"default":"kilowatts"}},"key":"kW","names":["kw","kW"]},{"category":"energy","mappings":{"default":{"default":"milliwatts"}},"key":"mW","names":["mw","mW"]},{"category":"energy","mappings":{"default":{"default":"kilowatt hours"}},"key":"kwh","names":["kwh","kWh"]},{"category":"energy","mappings":{"default":{"default":"joules"}},"key":"J","names":["J"]},{"category":"energy","mappings":{"default":{"default":"Newton"}},"key":"N","names":["N"]},{"category":"energy","mappings":{"default":{"default":"amperes"}},"key":"A","names":["A"]},{"category":"energy","mappings":{"default":{"default":"volts"}},"key":"V","names":["V"]},{"category":"energy","mappings":{"default":{"default":"microohm"}},"key":"µΩ","names":["µΩ"]},{"category":"energy","mappings":{"default":{"default":"milliohm"}},"key":"mΩ","names":["mΩ"]},{"category":"energy","mappings":{"default":{"default":"ohm"}},"key":"Ω","names":["Ω","Ohm"]},{"category":"energy","mappings":{"default":{"default":"kilohm"}},"key":"kΩ","names":["kΩ","KΩ"]},{"category":"energy","mappings":{"default":{"default":"ohm"}},"key":"Ω","names":["Ω"]},{"category":"energy","mappings":{"default":{"default":"megaohm"}},"key":"MΩ","names":["MΩ"]},{"category":"energy","mappings":{"default":{"default":"gigaohm"}},"key":"GΩ","names":["GΩ"]}]
,
"en/length.js": 
[{"locale":"en"},{"category":"Length","mappings":{"default":{"default":"millimeters"}},"key":"mm","names":["mm"]},{"category":"Length","mappings":{"default":{"default":"centimeters"}},"key":"cm","names":["cm"]},{"category":"Length","mappings":{"default":{"default":"meters"}},"key":"m","names":["m"]},{"category":"Length","mappings":{"default":{"default":"kilometers"}},"key":"km","names":["km"]},{"category":"Length","mappings":{"default":{"default":"feet"}},"key":"ft","names":["ft","ft."]},{"category":"Length","mappings":{"default":{"default":"inches"}},"key":"in","names":["in","in."]},{"category":"Length","mappings":{"default":{"default":"miles"}},"key":"mi","names":["mi","mi."]},{"category":"Length","mappings":{"default":{"default":"yards"}},"key":"yd","names":["yd","yd."]},{"category":"","mappings":{"default":{"default":"nautical miles"}},"key":"n.m.","names":["n.m."]}]
,
"en/memory.js": 
[{"locale":"en"},{"category":"","mappings":{"default":{"default":"bits"}},"key":"b","names":["b"]},{"category":"","mappings":{"default":{"default":"bytes"}},"key":"B","names":["B"]},{"category":"","mappings":{"default":{"default":"kilobytes"}},"key":"KB","names":["KB"]},{"category":"","mappings":{"default":{"default":"megabytes"}},"key":"MB","names":["MB"]},{"category":"","mappings":{"default":{"default":"gigabytes"}},"key":"GB","names":["GB"]},{"category":"","mappings":{"default":{"default":"terabytes"}},"key":"TB","names":["TB"]}]
,
"en/other.js": 
[{"locale":"en"},{"category":"","mappings":{"default":{"default":"dozen"}},"key":"doz","names":["doz","doz.","dz","dz."]},{"category":"","mappings":{"default":{"default":"square"}},"key":"sq","names":["sq","sq."]},{"category":"","mappings":{"default":{"default":"hectare"}},"key":"ha","names":["ha"]}]
,
"en/speed.js": 
[{"locale":"en"},{"category":"","mappings":{"default":{"default":"knot"}},"key":"kt","names":["kt","kt."]},{"category":"","mappings":{"default":{"default":"miles per hour"}},"key":"mph","names":["mph"]},{"category":"","mappings":{"default":{"default":"revolutions per minute"}},"key":"rpm","names":["rpm"]},{"category":"","mappings":{"default":{"default":"kilometers per hour"}},"key":"kmh","names":["kmh"]}]
,
"en/temperature.js": 
[{"locale":"en"},{"category":"","mappings":{"default":{"default":"Fahrenheit"}},"key":"F","names":["F","F.","°F"]},{"category":"","mappings":{"default":{"default":"Celsius","alternative":"Centigrade"}},"key":"C","names":["C","°C"]},{"category":"","mappings":{"default":{"default":"Kelvin"}},"key":"K","names":["K","°K"]}]
,
"en/time.js": 
[{"locale":"en"},{"category":"time","mappings":{"default":{"default":"nanoseconds"}},"key":"ns","names":["ns"]},{"category":"time","mappings":{"default":{"default":"microseconds"}},"key":"µs","names":["µs"]},{"category":"time","mappings":{"default":{"default":"milliseconds"}},"key":"ms","names":["ms"]},{"category":"time","mappings":{"default":{"default":"seconds"}},"key":"s","names":["s"]},{"category":"time","mappings":{"default":{"default":"minutes"}},"key":"min","names":["min"]},{"category":"time","mappings":{"default":{"default":"hours"}},"key":"h","names":["h","hr"]}]
,
"en/volume.js": 
[{"locale":"en"},{"category":"volume","mappings":{"default":{"default":"barrels"}},"key":"bbl","names":["bbl.","bbl"]},{"category":"volume","mappings":{"default":{"default":"cubics"}},"key":"cu","names":["cu","cu."]},{"category":"volume","mappings":{"default":{"default":"fluid ounces"}},"key":"fl. oz.","names":["fl. oz."]},{"category":"volume","mappings":{"default":{"default":"gallons"}},"key":"gal","names":["gal","gal."]},{"category":"volume","mappings":{"default":{"default":"pints"}},"key":"pt","names":["pt","pt."]},{"category":"volume","mappings":{"default":{"default":"quarts"}},"key":"qt","names":["qt","qt."]},{"category":"volume","mappings":{"default":{"default":"tablespoons"}},"key":"tbsp","names":["tbsp","tbsp."]},{"category":"volume","mappings":{"default":{"default":"teaspoons"}},"key":"tsp","names":["tsp","tsp."]},{"category":"volume","mappings":{"default":{"default":"cubic centimeters"}},"key":"cc","names":["cc"]},{"category":"volume","mappings":{"default":{"default":"kiloliters"}},"key":"kl","names":["kl"]},{"category":"volume","mappings":{"default":{"default":"liters"}},"key":"l","names":["l"]},{"category":"volume","mappings":{"default":{"default":"milliliters"}},"key":"ml","names":["ml"]}]
,
"en/weight.js": 
[{"locale":"en"},{"category":"","mappings":{"default":{"default":"pounds"}},"key":"lb","names":["lb","lb."]},{"category":"","mappings":{"default":{"default":"long tons"}},"key":"LT","names":["LT","L.T."]},{"category":"","mappings":{"default":{"default":"ounces"}},"key":"oz","names":["oz","oz."]},{"key":"µg","names":["µg","mcg"],"mappings":{"default":{"default":"micrograms"}}},{"category":"","mappings":{"default":{"default":"grams"}},"key":"gr","names":["g","gr"]},{"category":"","mappings":{"default":{"default":"kilograms"}},"key":"kg","names":["kg"]},{"category":"","mappings":{"default":{"default":"micrograms"}},"key":"mcg","names":["mg","µg"]},{"category":"","mappings":{"default":{"default":"milligrams"}},"key":"mg","names":["mg"]},{"category":"","mappings":{"default":{"default":"tons"}},"key":"t","names":["t","T"]}]
,
"es/algebra.js": 
[{"locale":"es"},{"key":"deg","names":["deg"],"mappings":{"default":{"default":"grados"}},"category":"Algebra"},{"key":"det","names":["det"],"mappings":{"default":{"default":"determinante"}},"category":"Algebra"},{"key":"dim","names":["dim"],"mappings":{"default":{"default":"dimensión"}},"category":"Algebra"},{"key":"hom","names":["hom","Hom"],"mappings":{"default":{"default":"homomorfismo"}},"category":"Algebra"},{"key":"ker","names":["ker"],"mappings":{"default":{"default":"kernel"}},"category":"Algebra"},{"key":"Tr","names":["Tr","tr"],"mappings":{"default":{"default":"traza"}},"category":"Algebra"}]
,
"es/elementary.js": 
[{"locale":"es"},{"key":"log","names":["log"],"mappings":{"default":{"default":"logaritmo"}},"category":"Logarithm"},{"key":"ln","names":["ln"],"mappings":{"default":{"default":"logaritmo neperiano"}},"category":"Logarithm"},{"key":"lg","names":["lg"],"mappings":{"default":{"default":"logaritmo base 10"}},"category":"Logarithm"},{"key":"exp","names":["exp","expt"],"mappings":{"default":{"default":"exponente"}},"category":"Elementary"},{"key":"gcd","names":["gcd"],"mappings":{"default":{"default":"MCD"}},"category":"Elementary"},{"key":"lcm","names":["lcm"],"mappings":{"default":{"default":"mcm"}},"category":"Elementary"},{"key":"arg","names":["arg"],"mappings":{"default":{"default":"argumento"}},"category":"Complex"},{"key":"im","names":["im"],"mappings":{"default":{"default":"parte imaginaria"}},"category":"Complex"},{"key":"re","names":["re"],"mappings":{"default":{"default":"residuo"}},"category":"Complex"},{"key":"inf","names":["inf"],"mappings":{"default":{"default":"extremo inferior"}},"category":"Limits"},{"key":"lim","names":["lim"],"mappings":{"default":{"default":"límite"}},"category":"Limits"},{"key":"max","names":["max"],"mappings":{"default":{"default":"máximo"}},"category":"Limits"},{"key":"min","names":["min"],"mappings":{"default":{"default":"mínimo"}},"category":"Limits"},{"key":"sup","names":["sup"],"mappings":{"default":{"default":"superior"}},"category":"Limits"},{"key":"lim inf","names":["lim inf","liminf"],"mappings":{"default":{"default":"límite inferior"}},"category":"Limits"},{"key":"lim sup","names":["lim sup","limsup"],"mappings":{"default":{"default":"límite superior"}},"category":"Limits"},{"key":"injlim","names":["injlim","inj lim"],"mappings":{"default":{"default":"límite directo"}},"category":"Limits"},{"key":"projlim","names":["projlim","proj lim"],"mappings":{"default":{"default":"límite inverso"}},"category":"Limits"},{"key":"mod","names":["mod"],"mappings":{"default":{"default":"módulo"}},"category":"Elementary"},{"key":"Pr","names":["Pr"],"mappings":{"default":{"default":"probabilidad"}},"category":"Probability"}]
,
"es/hyperbolic.js": 
[{"locale":"es"},{"key":"cosh","names":["cosh"],"mappings":{"default":{"default":"coseno hiperbólico"}},"category":"Hyperbolic"},{"key":"coth","names":["coth"],"mappings":{"default":{"default":"cotangente hiperbólica"}},"category":"Hyperbolic"},{"key":"csch","names":["csch"],"mappings":{"default":{"default":"cosecante hiperbólica"}},"category":"Hyperbolic"},{"key":"sech","names":["sech"],"mappings":{"default":{"default":"secante hiperbólica"}},"category":"Hyperbolic"},{"key":"sinh","names":["sinh"],"mappings":{"default":{"default":"seno hiperbólico"}},"category":"Hyperbolic"},{"key":"tanh","names":["tanh"],"mappings":{"default":{"default":"tangente hiperbólica"}},"category":"Hyperbolic"},{"key":"arcosh","names":["arcosh","arccosh"],"mappings":{"default":{"default":"area coseno hiperbólico"}},"category":"Area"},{"key":"arcoth","names":["arcoth","arccoth"],"mappings":{"default":{"default":"area cotangente hiperbólica"}},"category":"Area"},{"key":"arcsch","names":["arcsch","arccsch"],"mappings":{"default":{"default":"area cosecante hiperbólica"}},"category":"Area"},{"key":"arsech","names":["arsech","arcsech"],"mappings":{"default":{"default":"area secante hiperbólica"}},"category":"Area"},{"key":"arsinh","names":["arsinh","arcsinh"],"mappings":{"default":{"default":"area seno hiperbólico"}},"category":"Area"},{"key":"artanh","names":["artanh","arctanh"],"mappings":{"default":{"default":"area tangente hiperbólica"}},"category":"Area"}]
,
"es/trigonometry.js": 
[{"locale":"es"},{"key":"cos","names":["cos","cosine"],"mappings":{"default":{"default":"coseno"}},"category":"Trigonometric"},{"key":"cot","names":["cot"],"mappings":{"default":{"default":"cotangente"}},"category":"Trigonometric"},{"key":"csc","names":["csc"],"mappings":{"default":{"default":"cosecante"}},"category":"Trigonometric"},{"key":"sec","names":["sec"],"mappings":{"default":{"default":"secant"}},"category":"Trigonometric"},{"key":"sin","names":["sin","sine","sen"],"mappings":{"default":{"default":"seno"}},"category":"Trigonometric"},{"key":"tan","names":["tan"],"mappings":{"default":{"default":"tangente"}},"category":"Trigonometric"},{"key":"arccos","names":["arccos"],"mappings":{"default":{"default":"arco coseno"}},"category":"Cyclometric"},{"key":"arccot","names":["arccot"],"mappings":{"default":{"default":"arco cotangente"}},"category":"Cyclometric"},{"key":"arccsc","names":["arccsc"],"mappings":{"default":{"default":"arco cosecante"}},"category":"Cyclometric"},{"key":"arcsec","names":["arcsec"],"mappings":{"default":{"default":"arco secante"}},"category":"Cyclometric"},{"key":"arcsin","names":["arcsin"],"mappings":{"default":{"default":"arco seno"}},"category":"Cyclometric"},{"key":"arctan","names":["arctan"],"mappings":{"default":{"default":"arco tangente"}},"category":"Cyclometric"}]
,
"es/greek-capital.js": 
[{"locale":"es"},{"key":"0391","mappings":{"default":{"default":"mayúscula Alfa"}},"category":"Lu"},{"key":"0392","mappings":{"default":{"default":"mayúscula Beta"}},"category":"Lu"},{"key":"0393","mappings":{"default":{"default":"mayúscula Gamma"}},"category":"Lu"},{"key":"0394","mappings":{"default":{"default":"mayúscula Delta"}},"category":"Lu"},{"key":"0395","mappings":{"default":{"default":"mayúscula Épsilon"}},"category":"Lu"},{"key":"0396","mappings":{"default":{"default":"mayúscula Zeta"}},"category":"Lu"},{"key":"0397","mappings":{"default":{"default":"mayúscula Eta"}},"category":"Lu"},{"key":"0398","mappings":{"default":{"default":"mayúscula Theta"}},"category":"Lu"},{"key":"0399","mappings":{"default":{"default":"mayúscula Iota"}},"category":"Lu"},{"key":"039A","mappings":{"default":{"default":"mayúscula Kappa"}},"category":"Lu"},{"key":"039B","mappings":{"default":{"default":"mayúscula Lambda"}},"category":"Lu"},{"key":"039C","mappings":{"default":{"default":"mayúscula Mi"}},"category":"Lu"},{"key":"039D","mappings":{"default":{"default":"mayúscula Ni"}},"category":"Lu"},{"key":"039E","mappings":{"default":{"default":"mayúscula Xi"}},"category":"Lu"},{"key":"039F","mappings":{"default":{"default":"mayúscula Ómicron"}},"category":"Lu"},{"key":"03A0","mappings":{"default":{"default":"mayúscula Pi"}},"category":"Lu"},{"key":"03A1","mappings":{"default":{"default":"mayúscula Rho"}},"category":"Lu"},{"key":"03A3","mappings":{"default":{"default":"mayúscula Sigma"}},"category":"Lu"},{"key":"03A4","mappings":{"default":{"default":"mayúscula Tau"}},"category":"Lu"},{"key":"03A5","mappings":{"default":{"default":"mayúscula Ípsilon"}},"category":"Lu"},{"key":"03A6","mappings":{"default":{"default":"mayúscula Phi"}},"category":"Lu"},{"key":"03A7","mappings":{"default":{"default":"mayúscula Ji"}},"category":"Lu"},{"key":"03A8","mappings":{"default":{"default":"mayúscula Psi"}},"category":"Lu"},{"key":"03A9","mappings":{"default":{"default":"mayúscula Omega"}},"category":"Lu"}]
,
"es/greek-mathfonts-bold.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Alfa"}},"key":"1D6A8"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Beta"}},"key":"1D6A9"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Gamma"}},"key":"1D6AA"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Delta"}},"key":"1D6AB"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Épsilon"}},"key":"1D6AC"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Zeta"}},"key":"1D6AD"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Eta"}},"key":"1D6AE"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Theta"}},"key":"1D6AF"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Iota"}},"key":"1D6B0"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Kappa"}},"key":"1D6B1"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Lambda"}},"key":"1D6B2"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Mi"}},"key":"1D6B3"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Ni"}},"key":"1D6B4"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Xi"}},"key":"1D6B5"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Ómicron"}},"key":"1D6B6"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Pi"}},"key":"1D6B7"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Rho"}},"key":"1D6B8"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Sigma"}},"key":"1D6BA"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Tau"}},"key":"1D6BB"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Ípsilon"}},"key":"1D6BC"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Phi"}},"key":"1D6BD"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Ji"}},"key":"1D6BE"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Psi"}},"key":"1D6BF"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Omega"}},"key":"1D6C0"},{"category":"Ll","mappings":{"default":{"default":"negrita alfa"}},"key":"1D6C2"},{"category":"Ll","mappings":{"default":{"default":"negrita beta"}},"key":"1D6C3"},{"category":"Ll","mappings":{"default":{"default":"negrita gamma"}},"key":"1D6C4"},{"category":"Ll","mappings":{"default":{"default":"negrita delta"}},"key":"1D6C5"},{"category":"Ll","mappings":{"default":{"default":"negrita épsilon"}},"key":"1D6C6"},{"category":"Ll","mappings":{"default":{"default":"negrita zeta"}},"key":"1D6C7"},{"category":"Ll","mappings":{"default":{"default":"negrita eta"}},"key":"1D6C8"},{"category":"Ll","mappings":{"default":{"default":"negrita theta"}},"key":"1D6C9"},{"category":"Ll","mappings":{"default":{"default":"negrita iota"}},"key":"1D6CA"},{"category":"Ll","mappings":{"default":{"default":"negrita kappa"}},"key":"1D6CB"},{"category":"Ll","mappings":{"default":{"default":"negrita lambda"}},"key":"1D6CC"},{"category":"Ll","mappings":{"default":{"default":"negrita mi"}},"key":"1D6CD"},{"category":"Ll","mappings":{"default":{"default":"negrita ni"}},"key":"1D6CE"},{"category":"Ll","mappings":{"default":{"default":"negrita xi"}},"key":"1D6CF"},{"category":"Ll","mappings":{"default":{"default":"negrita ómicron"}},"key":"1D6D0"},{"category":"Ll","mappings":{"default":{"default":"negrita pi"}},"key":"1D6D1"},{"category":"Ll","mappings":{"default":{"default":"negrita rho"}},"key":"1D6D2"},{"category":"Ll","mappings":{"default":{"default":"negrita final sigma"}},"key":"1D6D3"},{"category":"Ll","mappings":{"default":{"default":"negrita sigma"}},"key":"1D6D4"},{"category":"Ll","mappings":{"default":{"default":"negrita tau"}},"key":"1D6D5"},{"category":"Ll","mappings":{"default":{"default":"negrita ípsilon"}},"key":"1D6D6"},{"category":"Ll","mappings":{"default":{"default":"negrita phi"}},"key":"1D6D7"},{"category":"Ll","mappings":{"default":{"default":"negrita ji"}},"key":"1D6D8"},{"category":"Ll","mappings":{"default":{"default":"negrita psi"}},"key":"1D6D9"},{"category":"Ll","mappings":{"default":{"default":"negrita omega"}},"key":"1D6DA"}]
,
"es/greek-mathfonts-italic.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Alfa"}},"key":"1D6E2"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Beta"}},"key":"1D6E3"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Gamma"}},"key":"1D6E4"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Delta"}},"key":"1D6E5"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Épsilon"}},"key":"1D6E6"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Zeta"}},"key":"1D6E7"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Eta"}},"key":"1D6E8"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Theta"}},"key":"1D6E9"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Iota"}},"key":"1D6EA"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Kappa"}},"key":"1D6EB"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Lambda"}},"key":"1D6EC"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Mi"}},"key":"1D6ED"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Ni"}},"key":"1D6EE"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Xi"}},"key":"1D6EF"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Ómicron"}},"key":"1D6F0"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Pi"}},"key":"1D6F1"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Rho"}},"key":"1D6F2"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Sigma"}},"key":"1D6F4"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Tau"}},"key":"1D6F5"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Ípsilon"}},"key":"1D6F6"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Phi"}},"key":"1D6F7"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Ji"}},"key":"1D6F8"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Psi"}},"key":"1D6F9"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Omega"}},"key":"1D6FA"},{"category":"Ll","mappings":{"default":{"default":"cursiva alfa"}},"key":"1D6FC"},{"category":"Ll","mappings":{"default":{"default":"cursiva beta"}},"key":"1D6FD"},{"category":"Ll","mappings":{"default":{"default":"cursiva gamma"}},"key":"1D6FE"},{"category":"Ll","mappings":{"default":{"default":"cursiva delta"}},"key":"1D6FF"},{"category":"Ll","mappings":{"default":{"default":"cursiva épsilon"}},"key":"1D700"},{"category":"Ll","mappings":{"default":{"default":"cursiva zeta"}},"key":"1D701"},{"category":"Ll","mappings":{"default":{"default":"cursiva eta"}},"key":"1D702"},{"category":"Ll","mappings":{"default":{"default":"cursiva theta"}},"key":"1D703"},{"category":"Ll","mappings":{"default":{"default":"cursiva iota"}},"key":"1D704"},{"category":"Ll","mappings":{"default":{"default":"cursiva kappa"}},"key":"1D705"},{"category":"Ll","mappings":{"default":{"default":"cursiva lambda"}},"key":"1D706"},{"category":"Ll","mappings":{"default":{"default":"cursiva mi"}},"key":"1D707"},{"category":"Ll","mappings":{"default":{"default":"cursiva ni"}},"key":"1D708"},{"category":"Ll","mappings":{"default":{"default":"cursiva xi"}},"key":"1D709"},{"category":"Ll","mappings":{"default":{"default":"cursiva ómicron"}},"key":"1D70A"},{"category":"Ll","mappings":{"default":{"default":"cursiva pi"}},"key":"1D70B"},{"category":"Ll","mappings":{"default":{"default":"cursiva rho"}},"key":"1D70C"},{"category":"Ll","mappings":{"default":{"default":"cursiva final sigma"}},"key":"1D70D"},{"category":"Ll","mappings":{"default":{"default":"cursiva sigma"}},"key":"1D70E"},{"category":"Ll","mappings":{"default":{"default":"cursiva tau"}},"key":"1D70F"},{"category":"Ll","mappings":{"default":{"default":"cursiva ípsilon"}},"key":"1D710"},{"category":"Ll","mappings":{"default":{"default":"cursiva phi"}},"key":"1D711"},{"category":"Ll","mappings":{"default":{"default":"cursiva ji"}},"key":"1D712"},{"category":"Ll","mappings":{"default":{"default":"cursiva psi"}},"key":"1D713"},{"category":"Ll","mappings":{"default":{"default":"cursiva omega"}},"key":"1D714"}]
,
"es/greek-mathfonts-sans-serif-bold.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Alfa"}},"key":"1D756"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Beta"}},"key":"1D757"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Gamma"}},"key":"1D758"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Delta"}},"key":"1D759"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Épsilon"}},"key":"1D75A"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Zeta"}},"key":"1D75B"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Eta"}},"key":"1D75C"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Theta"}},"key":"1D75D"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Iota"}},"key":"1D75E"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Kappa"}},"key":"1D75F"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Lambda"}},"key":"1D760"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Mi"}},"key":"1D761"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Ni"}},"key":"1D762"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Xi"}},"key":"1D763"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Ómicron"}},"key":"1D764"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Pi"}},"key":"1D765"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Rho"}},"key":"1D766"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Sigma"}},"key":"1D768"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Tau"}},"key":"1D769"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Ípsilon"}},"key":"1D76A"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Phi"}},"key":"1D76B"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Ji"}},"key":"1D76C"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Psi"}},"key":"1D76D"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Omega"}},"key":"1D76E"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita alfa"}},"key":"1D770"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita beta"}},"key":"1D771"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita gamma"}},"key":"1D772"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita delta"}},"key":"1D773"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita épsilon"}},"key":"1D774"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita zeta"}},"key":"1D775"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita eta"}},"key":"1D776"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita theta"}},"key":"1D777"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita iota"}},"key":"1D778"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita kappa"}},"key":"1D779"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita lambda"}},"key":"1D77A"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita mi"}},"key":"1D77B"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita ni"}},"key":"1D77C"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita xi"}},"key":"1D77D"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita ómicron"}},"key":"1D77E"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita pi"}},"key":"1D77F"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita rho"}},"key":"1D780"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita final sigma"}},"key":"1D781"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita sigma"}},"key":"1D782"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita tau"}},"key":"1D783"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita ípsilon"}},"key":"1D784"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita phi"}},"key":"1D785"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita ji"}},"key":"1D786"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita psi"}},"key":"1D787"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita omega"}},"key":"1D788"}]
,
"es/greek-scripts.js": 
[{"locale":"es"}]
,
"es/greek-small.js": 
[{"locale":"es"},{"key":"03B1","mappings":{"default":{"default":"alfa"}},"category":"Ll"},{"key":"03B2","mappings":{"default":{"default":"beta"}},"category":"Ll"},{"key":"03B3","mappings":{"default":{"default":"gamma"}},"category":"Ll"},{"key":"03B4","mappings":{"default":{"default":"delta"}},"category":"Ll"},{"key":"03B5","mappings":{"default":{"default":"épsilon"}},"category":"Ll"},{"key":"03B6","mappings":{"default":{"default":"zeta"}},"category":"Ll"},{"key":"03B7","mappings":{"default":{"default":"eta"}},"category":"Ll"},{"key":"03B8","mappings":{"default":{"default":"theta"}},"category":"Ll"},{"key":"03B9","mappings":{"default":{"default":"iota"}},"category":"Ll"},{"key":"03BA","mappings":{"default":{"default":"kappa"}},"category":"Ll"},{"key":"03BB","mappings":{"default":{"default":"lambda"}},"category":"Ll"},{"key":"03BC","mappings":{"default":{"default":"mi"}},"category":"Ll"},{"key":"03BD","mappings":{"default":{"default":"ni"}},"category":"Ll"},{"key":"03BE","mappings":{"default":{"default":"xi"}},"category":"Ll"},{"key":"03BF","mappings":{"default":{"default":"ómicron"}},"category":"Ll"},{"key":"03C0","mappings":{"default":{"default":"pi"}},"category":"Ll"},{"key":"03C1","mappings":{"default":{"default":"rho"}},"category":"Ll"},{"key":"03C2","mappings":{"default":{"default":"sigma final"}},"category":"Ll"},{"key":"03C3","mappings":{"default":{"default":"sigma"}},"category":"Ll"},{"key":"03C4","mappings":{"default":{"default":"tau"}},"category":"Ll"},{"key":"03C5","mappings":{"default":{"default":"ípsilon"}},"category":"Ll"},{"key":"03C6","mappings":{"default":{"default":"phi"}},"category":"Ll"},{"key":"03C7","mappings":{"default":{"default":"ji"}},"category":"Ll"},{"key":"03C8","mappings":{"default":{"default":"psi"}},"category":"Ll"},{"key":"03C9","mappings":{"default":{"default":"omega"}},"category":"Ll"}]
,
"es/greek-symbols.js": 
[{"locale":"es"},{"key":"03D0","mappings":{"default":{"default":"símbolo beta"}},"category":"Ll"},{"key":"03D1","mappings":{"default":{"default":"variante de theta"}},"category":"Ll"},{"key":"03D5","mappings":{"default":{"default":"phi recta"}},"category":"Ll"},{"key":"03D6","mappings":{"default":{"default":"pi","defaultMP":"variante de pi"}},"category":"Ll"},{"key":"03D7","mappings":{"default":{"default":"símbolo kai griego"}},"category":"Ll"},{"key":"03F0","mappings":{"default":{"default":"kappa","defaultMP":"variante de kappa"}},"category":"Ll"},{"key":"03F1","mappings":{"default":{"default":"rho","defaultMP":"variante de rho"}},"category":"Ll"},{"key":"03F5","mappings":{"default":{"default":"épsilon","defaultMP":"variante de épsilon"}},"category":"Ll"},{"key":"03F6","mappings":{"default":{"default":"épsilon invertido"}},"category":"Sm"},{"key":"03F4","mappings":{"default":{"default":"mayúscula variante de Theta"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula variante de Theta"}},"key":"1D6B9"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula variante de Theta"}},"key":"1D6F3"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula variante de Theta"}},"key":"1D767"}]
,
"es/hebrew_letters.js": 
[{"locale":"es"},{"key":"2135","mappings":{"default":{"default":"alef"}},"category":"Lo"},{"key":"2136","mappings":{"default":{"default":"bet"}},"category":"Lo"},{"key":"2137","mappings":{"default":{"default":"guímel"}},"category":"Lo"},{"key":"2138","mappings":{"default":{"default":"dálet"}},"category":"Lo"}]
,
"es/latin-lower-double-accent.js": 
[{"locale":"es"},{"key":"1E09","mappings":{"default":{"default":"c con cedilla y agudo"}},"category":"Ll"},{"key":"1E15","mappings":{"default":{"default":"e con macrón y grave"}},"category":"Ll"},{"key":"1E17","mappings":{"default":{"default":"e con macrón y agudo"}},"category":"Ll"},{"key":"1E1D","mappings":{"default":{"default":"e con cedilla y breve"}},"category":"Ll"},{"key":"1E2F","mappings":{"default":{"default":"i con diéresis y agudo"}},"category":"Ll"},{"key":"1E39","mappings":{"default":{"default":"l con punto debajo y macrón"}},"category":"Ll"},{"key":"1E4D","mappings":{"default":{"default":"o con tilde y acute"}},"category":"Ll"},{"key":"1E4F","mappings":{"default":{"default":"o con tilde y diéresis"}},"category":"Ll"},{"key":"1E51","mappings":{"default":{"default":"o con macrón y grave"}},"category":"Ll"},{"key":"1E53","mappings":{"default":{"default":"o con macrón y agudo"}},"category":"Ll"},{"key":"1E5D","mappings":{"default":{"default":"r con punto debajo y macrón"}},"category":"Ll"},{"key":"1E65","mappings":{"default":{"default":"s con agudo y punto arriba"}},"category":"Ll"},{"key":"1E67","mappings":{"default":{"default":"s con carón y punto arriba"}},"category":"Ll"},{"key":"1E69","mappings":{"default":{"default":"s con punto debajo y punto arriba"}},"category":"Ll"},{"key":"1E79","mappings":{"default":{"default":"u con tilde y agudo"}},"category":"Ll"},{"key":"1E7B","mappings":{"default":{"default":"u con macrón y diéresis"}},"category":"Ll"},{"key":"1EA5","mappings":{"default":{"default":"a con acento circunflejo y agudo"}},"category":"Ll"},{"key":"1EA7","mappings":{"default":{"default":"a con acento circunflejo y grave"}},"category":"Ll"},{"key":"1EA9","mappings":{"default":{"default":"a con acento circunflejo y gancho arriba"}},"category":"Ll"},{"key":"1EAB","mappings":{"default":{"default":"a con acento circunflejo y tilde"}},"category":"Ll"},{"key":"1EAD","mappings":{"default":{"default":"a con acento circunflejo y punto debajo"}},"category":"Ll"},{"key":"1EAF","mappings":{"default":{"default":"a con breve y agudo"}},"category":"Ll"},{"key":"1EB1","mappings":{"default":{"default":"a con breve y grave"}},"category":"Ll"},{"key":"1EB3","mappings":{"default":{"default":"a con breve y gancho arriba"}},"category":"Ll"},{"key":"1EB5","mappings":{"default":{"default":"a con breve y tilde"}},"category":"Ll"},{"key":"1EB7","mappings":{"default":{"default":"a con breve y punto debajo"}},"category":"Ll"},{"key":"1EBF","mappings":{"default":{"default":"e con acento circunflejo y agudo"}},"category":"Ll"},{"key":"1EC1","mappings":{"default":{"default":"e con acento circunflejo y grave"}},"category":"Ll"},{"key":"1EC3","mappings":{"default":{"default":"e con acento circunflejo y gancho arriba"}},"category":"Ll"},{"key":"1EC5","mappings":{"default":{"default":"e con acento circunflejo y tilde"}},"category":"Ll"},{"key":"1EC7","mappings":{"default":{"default":"e con acento circunflejo y punto debajo"}},"category":"Ll"},{"key":"1ED1","mappings":{"default":{"default":"o con acento circunflejo y agudo"}},"category":"Ll"},{"key":"1ED3","mappings":{"default":{"default":"o con acento circunflejo y grave"}},"category":"Ll"},{"key":"1ED5","mappings":{"default":{"default":"o con acento circunflejo y gancho arriba"}},"category":"Ll"},{"key":"1ED7","mappings":{"default":{"default":"o con acento circunflejo y tilde"}},"category":"Ll"},{"key":"1ED9","mappings":{"default":{"default":"o con acento circunflejo y punto debajo"}},"category":"Ll"},{"key":"1EDB","mappings":{"default":{"default":"o with horn and acute"}},"category":"Ll"},{"key":"1EDD","mappings":{"default":{"default":"o with horn and grave"}},"category":"Ll"},{"key":"1EDF","mappings":{"default":{"default":"o with horn and hook above"}},"category":"Ll"},{"key":"1EE1","mappings":{"default":{"default":"o with horn and tilde"}},"category":"Ll"},{"key":"1EE3","mappings":{"default":{"default":"o con cuerno y punto debajo"}},"category":"Ll"},{"key":"1EE9","mappings":{"default":{"default":"u con cuerno y agudo"}},"category":"Ll"},{"key":"1EEB","mappings":{"default":{"default":"u con cuerno y grave"}},"category":"Ll"},{"key":"1EED","mappings":{"default":{"default":"u con cuerno y gancho arriba"}},"category":"Ll"},{"key":"1EEF","mappings":{"default":{"default":"u con cuerno y tilde"}},"category":"Ll"},{"key":"1EF1","mappings":{"default":{"default":"u con cuerno y punto debajo"}},"category":"Ll"}]
,
"es/latin-lower-normal.js": 
[{"locale":"es"},{"key":"0061","mappings":{"default":{"default":"a"}},"category":"Ll"},{"key":"0062","mappings":{"default":{"default":"b"}},"category":"Ll"},{"key":"0063","mappings":{"default":{"default":"c"}},"category":"Ll"},{"key":"0064","mappings":{"default":{"default":"d"}},"category":"Ll"},{"key":"0065","mappings":{"default":{"default":"e"}},"category":"Ll"},{"key":"0066","mappings":{"default":{"default":"f"}},"category":"Ll"},{"key":"0067","mappings":{"default":{"default":"g"}},"category":"Ll"},{"key":"0068","mappings":{"default":{"default":"h"}},"category":"Ll"},{"key":"0069","mappings":{"default":{"default":"i"}},"category":"Ll"},{"key":"006A","mappings":{"default":{"default":"j"}},"category":"Ll"},{"key":"006B","mappings":{"default":{"default":"k"}},"category":"Ll"},{"key":"006C","mappings":{"default":{"default":"l"}},"category":"Ll"},{"key":"006D","mappings":{"default":{"default":"m"}},"category":"Ll"},{"key":"006E","mappings":{"default":{"default":"n"}},"category":"Ll"},{"key":"006F","mappings":{"default":{"default":"o"}},"category":"Ll"},{"key":"0070","mappings":{"default":{"default":"p"}},"category":"Ll"},{"key":"0071","mappings":{"default":{"default":"q"}},"category":"Ll"},{"key":"0072","mappings":{"default":{"default":"r"}},"category":"Ll"},{"key":"0073","mappings":{"default":{"default":"s"}},"category":"Ll"},{"key":"0074","mappings":{"default":{"default":"t"}},"category":"Ll"},{"key":"0075","mappings":{"default":{"default":"u"}},"category":"Ll"},{"key":"0076","mappings":{"default":{"default":"v"}},"category":"Ll"},{"key":"0077","mappings":{"default":{"default":"w"}},"category":"Ll"},{"key":"0078","mappings":{"default":{"default":"x"}},"category":"Ll"},{"key":"0079","mappings":{"default":{"default":"y","defaultMP":"ye"}},"category":"Ll"},{"key":"007A","mappings":{"default":{"default":"z"}},"category":"Ll"}]
,
"es/latin-lower-phonetic.js": 
[{"locale":"es"},{"key":"00F8","mappings":{"default":{"default":"o barrada"}},"category":"Ll"},{"key":"0111","mappings":{"default":{"default":"d con barra"}},"category":"Ll"},{"key":"0127","mappings":{"default":{"default":"h con guión"}},"category":"Ll"},{"key":"0142","mappings":{"default":{"default":"l con guión"}},"category":"Ll"},{"key":"0167","mappings":{"default":{"default":"t con guión"}},"category":"Ll"},{"key":"019B","mappings":{"default":{"default":"lambda tachada"}},"category":"Ll"},{"key":"1E9B","mappings":{"default":{"default":"s larga con punto arriba"}},"category":"Ll"},{"key":"0138","mappings":{"default":{"default":"kra"}},"category":"Ll"},{"key":"0192","mappings":{"default":{"default":"f con gancho"}},"category":"Ll"},{"key":"019A","mappings":{"default":{"default":"l con barra"}},"category":"Ll"},{"key":"025B","mappings":{"default":{"default":"e abierta"}},"category":"Ll"},{"key":"0149","mappings":{"default":{"default":"n precedida por apóstrofe"}},"category":"Ll"},{"key":"014B","mappings":{"default":{"default":"eng"}},"category":"Ll"}]
,
"es/latin-lower-single-accent.js": 
[{"locale":"es"},{"key":"00E0","mappings":{"default":{"default":"a grave"}},"category":"Ll"},{"key":"00E1","mappings":{"default":{"default":"a aguda"}},"category":"Ll"},{"key":"00E2","mappings":{"default":{"default":"a acento circunflejo"}},"category":"Ll"},{"key":"00E3","mappings":{"default":{"default":"a con tilde"}},"category":"Ll"},{"key":"00E4","mappings":{"default":{"default":"a diéresis"}},"category":"Ll"},{"key":"00E5","mappings":{"default":{"default":"a con anillo"}},"category":"Ll"},{"key":"00E7","mappings":{"default":{"default":"c cedilla"}},"category":"Ll"},{"key":"00E8","mappings":{"default":{"default":"e grave"}},"category":"Ll"},{"key":"00E9","mappings":{"default":{"default":"e aguda"}},"category":"Ll"},{"key":"00EA","mappings":{"default":{"default":"e acento circunflejo"}},"category":"Ll"},{"key":"00EB","mappings":{"default":{"default":"e diéresis"}},"category":"Ll"},{"key":"00EC","mappings":{"default":{"default":"i grave"}},"category":"Ll"},{"key":"00ED","mappings":{"default":{"default":"i aguda"}},"category":"Ll"},{"key":"00EE","mappings":{"default":{"default":"i acento circunflejo"}},"category":"Ll"},{"key":"00EF","mappings":{"default":{"default":"i diéresis"}},"category":"Ll"},{"key":"00F1","mappings":{"default":{"default":"eñe"}},"category":"Ll"},{"key":"00F2","mappings":{"default":{"default":"o grave"}},"category":"Ll"},{"key":"00F3","mappings":{"default":{"default":"o aguda"}},"category":"Ll"},{"key":"00F4","mappings":{"default":{"default":"o acento circunflejo"}},"category":"Ll"},{"key":"00F5","mappings":{"default":{"default":"o con tilde"}},"category":"Ll"},{"key":"00F6","mappings":{"default":{"default":"o diéresis"}},"category":"Ll"},{"key":"00F9","mappings":{"default":{"default":"u grave"}},"category":"Ll"},{"key":"00FA","mappings":{"default":{"default":"u aguda"}},"category":"Ll"},{"key":"00FB","mappings":{"default":{"default":"u acento circunflejo"}},"category":"Ll"},{"key":"00FC","mappings":{"default":{"default":"u diéresis"}},"category":"Ll"},{"key":"00FD","mappings":{"default":{"default":"Y aguda","defaultMP":"ye aguda"}},"category":"Ll"},{"key":"00FF","mappings":{"default":{"default":"y diéresis","defaultMP":"ye diéresis"}},"category":"Ll"},{"key":"0101","mappings":{"default":{"default":"a barra"}},"category":"Ll"},{"key":"0103","mappings":{"default":{"default":"a con breve"}},"category":"Ll"},{"key":"0105","mappings":{"default":{"default":"a con ogonek"}},"category":"Ll"},{"key":"0107","mappings":{"default":{"default":"c con agudo"}},"category":"Ll"},{"key":"0109","mappings":{"default":{"default":"c con acento circunflejo"}},"category":"Ll"},{"key":"010B","mappings":{"default":{"default":"c con punto arriba"}},"category":"Ll"},{"key":"010D","mappings":{"default":{"default":"c con carón"}},"category":"Ll"},{"key":"010F","mappings":{"default":{"default":"d con carón"}},"category":"Ll"},{"key":"0113","mappings":{"default":{"default":"e barra"}},"category":"Ll"},{"key":"0117","mappings":{"default":{"default":"e con punto arriba"}},"category":"Ll"},{"key":"0119","mappings":{"default":{"default":"e con ogonek"}},"category":"Ll"},{"key":"011B","mappings":{"default":{"default":"e con carón"}},"category":"Ll"},{"key":"011D","mappings":{"default":{"default":"g con acento circunflejo"}},"category":"Ll"},{"key":"011F","mappings":{"default":{"default":"g con breve"}},"category":"Ll"},{"key":"0121","mappings":{"default":{"default":"g con punto arriba"}},"category":"Ll"},{"key":"0125","mappings":{"default":{"default":"h con acento circunflejo"}},"category":"Ll"},{"key":"0129","mappings":{"default":{"default":"i con tilde"}},"category":"Ll"},{"key":"012B","mappings":{"default":{"default":"i barra"}},"category":"Ll"},{"key":"012F","mappings":{"default":{"default":"i con ogonek"}},"category":"Ll"},{"key":"0131","mappings":{"default":{"default":"i sin punto"}},"category":"Ll"},{"key":"0135","mappings":{"default":{"default":"j con acento circunflejo"}},"category":"Ll"},{"key":"0137","mappings":{"default":{"default":"k con cedilla"}},"category":"Ll"},{"key":"013A","mappings":{"default":{"default":"l con agudo"}},"category":"Ll"},{"key":"013C","mappings":{"default":{"default":"l con cedilla"}},"category":"Ll"},{"key":"013E","mappings":{"default":{"default":"l con carón"}},"category":"Ll"},{"key":"0140","mappings":{"default":{"default":"l con punto mediano"}},"category":"Ll"},{"key":"0144","mappings":{"default":{"default":"n con agudo"}},"category":"Ll"},{"key":"0146","mappings":{"default":{"default":"n con cedilla"}},"category":"Ll"},{"key":"0148","mappings":{"default":{"default":"n con carón"}},"category":"Ll"},{"key":"014D","mappings":{"default":{"default":"o barra"}},"category":"Ll"},{"key":"0151","mappings":{"default":{"default":"o con doble acento agudo"}},"category":"Ll"},{"key":"0155","mappings":{"default":{"default":"r con agudo"}},"category":"Ll"},{"key":"0157","mappings":{"default":{"default":"r con cedilla"}},"category":"Ll"},{"key":"0159","mappings":{"default":{"default":"r con carón"}},"category":"Ll"},{"key":"015B","mappings":{"default":{"default":"s con agudo"}},"category":"Ll"},{"key":"015D","mappings":{"default":{"default":"s con acento circunflejo"}},"category":"Ll"},{"key":"015F","mappings":{"default":{"default":"s con cedilla"}},"category":"Ll"},{"key":"0161","mappings":{"default":{"default":"s con carón"}},"category":"Ll"},{"key":"0163","mappings":{"default":{"default":"t con cedilla"}},"category":"Ll"},{"key":"0165","mappings":{"default":{"default":"t con carón"}},"category":"Ll"},{"key":"0169","mappings":{"default":{"default":"u con tilde"}},"category":"Ll"},{"key":"016B","mappings":{"default":{"default":"u barra"}},"category":"Ll"},{"key":"016D","mappings":{"default":{"default":"u con breve"}},"category":"Ll"},{"key":"016F","mappings":{"default":{"default":"u con anillo arriba"}},"category":"Ll"},{"key":"0171","mappings":{"default":{"default":"u con doble acento agudo"}},"category":"Ll"},{"key":"0173","mappings":{"default":{"default":"u con ogonek"}},"category":"Ll"},{"key":"0175","mappings":{"default":{"default":"w con circunflejo"}},"category":"Ll"},{"key":"0177","mappings":{"default":{"default":"y con circunflejo"}},"category":"Ll"},{"key":"017A","mappings":{"default":{"default":"z con agudo"}},"category":"Ll"},{"key":"017C","mappings":{"default":{"default":"z con punto"}},"category":"Ll"},{"key":"017E","mappings":{"default":{"default":"z con carón"}},"category":"Ll"},{"key":"01F5","mappings":{"default":{"default":"g con agudo"}},"category":"Ll"},{"key":"1E01","mappings":{"default":{"default":"a con anillo debajo"}},"category":"Ll"},{"key":"1E03","mappings":{"default":{"default":"b con punto arriba"}},"category":"Ll"},{"key":"1E05","mappings":{"default":{"default":"b con punto debajo"}},"category":"Ll"},{"key":"1E07","mappings":{"default":{"default":"b con línea debajo"}},"category":"Ll"},{"key":"1E0B","mappings":{"default":{"default":"d con punto arriba"}},"category":"Ll"},{"key":"1E0D","mappings":{"default":{"default":"d con punto debajo"}},"category":"Ll"},{"key":"1E0F","mappings":{"default":{"default":"d con línea debajo"}},"category":"Ll"},{"key":"1E11","mappings":{"default":{"default":"d con cedilla"}},"category":"Ll"},{"key":"1E13","mappings":{"default":{"default":"d con acento circunflejo debajo"}},"category":"Ll"},{"key":"1E19","mappings":{"default":{"default":"e con acento circunflejo debajo"}},"category":"Ll"},{"key":"1E1B","mappings":{"default":{"default":"e con tilde debajo"}},"category":"Ll"},{"key":"1E1F","mappings":{"default":{"default":"f con punto arriba"}},"category":"Ll"},{"key":"1E21","mappings":{"default":{"default":"g con macrón"}},"category":"Ll"},{"key":"1E23","mappings":{"default":{"default":"h con punto arriba"}},"category":"Ll"},{"key":"1E25","mappings":{"default":{"default":"h con punto debajo"}},"category":"Ll"},{"key":"1E27","mappings":{"default":{"default":"h con diéresis"}},"category":"Ll"},{"key":"1E29","mappings":{"default":{"default":"h con cedilla"}},"category":"Ll"},{"key":"1E2B","mappings":{"default":{"default":"h con breve debajo"}},"category":"Ll"},{"key":"1E2D","mappings":{"default":{"default":"i con tilde debajo"}},"category":"Ll"},{"key":"1E31","mappings":{"default":{"default":"k con agudo"}},"category":"Ll"},{"key":"1E33","mappings":{"default":{"default":"k con punto debajo"}},"category":"Ll"},{"key":"1E35","mappings":{"default":{"default":"k con línea debajo"}},"category":"Ll"},{"key":"1E37","mappings":{"default":{"default":"l con punto debajo"}},"category":"Ll"},{"key":"1E3B","mappings":{"default":{"default":"l con línea debajo"}},"category":"Ll"},{"key":"1E3D","mappings":{"default":{"default":"l con acento circunflejo debajo"}},"category":"Ll"},{"key":"1E3F","mappings":{"default":{"default":"m con agudo"}},"category":"Ll"},{"key":"1E41","mappings":{"default":{"default":"m con punto arriba"}},"category":"Ll"},{"key":"1E43","mappings":{"default":{"default":"m con punto debajo"}},"category":"Ll"},{"key":"1E45","mappings":{"default":{"default":"n con punto arriba"}},"category":"Ll"},{"key":"1E47","mappings":{"default":{"default":"n con punto debajo"}},"category":"Ll"},{"key":"1E49","mappings":{"default":{"default":"n con línea debajo"}},"category":"Ll"},{"key":"1E4B","mappings":{"default":{"default":"n con acento circunflejo debajo"}},"category":"Ll"},{"key":"1E55","mappings":{"default":{"default":"p con agudo"}},"category":"Ll"},{"key":"1E57","mappings":{"default":{"default":"p con punto arriba"}},"category":"Ll"},{"key":"1E59","mappings":{"default":{"default":"r con punto arriba"}},"category":"Ll"},{"key":"1E5B","mappings":{"default":{"default":"r con punto debajo"}},"category":"Ll"},{"key":"1E5F","mappings":{"default":{"default":"r con línea debajo"}},"category":"Ll"},{"key":"1E61","mappings":{"default":{"default":"s con punto arriba"}},"category":"Ll"},{"key":"1E63","mappings":{"default":{"default":"s con punto debajo"}},"category":"Ll"},{"key":"1E6B","mappings":{"default":{"default":"t con punto arriba"}},"category":"Ll"},{"key":"1E6D","mappings":{"default":{"default":"t con punto debajo"}},"category":"Ll"},{"key":"1E6F","mappings":{"default":{"default":"t con línea debajo"}},"category":"Ll"},{"key":"1E71","mappings":{"default":{"default":"t con acento circunflejo debajo"}},"category":"Ll"},{"key":"1E73","mappings":{"default":{"default":"u con diéresis debajo"}},"category":"Ll"},{"key":"1E75","mappings":{"default":{"default":"u con tilde debajo"}},"category":"Ll"},{"key":"1E77","mappings":{"default":{"default":"u con acento circunflejo debajo"}},"category":"Ll"},{"key":"1E7D","mappings":{"default":{"default":"v con tilde"}},"category":"Ll"},{"key":"1E7F","mappings":{"default":{"default":"v con punto debajo"}},"category":"Ll"},{"key":"1E81","mappings":{"default":{"default":"w con grave"}},"category":"Ll"},{"key":"1E83","mappings":{"default":{"default":"w con agudo"}},"category":"Ll"},{"key":"1E85","mappings":{"default":{"default":"w con diéresis"}},"category":"Ll"},{"key":"1E87","mappings":{"default":{"default":"w con punto arriba"}},"category":"Ll"},{"key":"1E89","mappings":{"default":{"default":"w con punto debajo"}},"category":"Ll"},{"key":"1E8B","mappings":{"default":{"default":"x con punto arriba"}},"category":"Ll"},{"key":"1E8D","mappings":{"default":{"default":"x con diéresis"}},"category":"Ll"},{"key":"1E8F","mappings":{"default":{"default":"y con punto arriba"}},"category":"Ll"},{"key":"1E91","mappings":{"default":{"default":"z con acento circunflejo"}},"category":"Ll"},{"key":"1E93","mappings":{"default":{"default":"z con punto debajo"}},"category":"Ll"},{"key":"1E95","mappings":{"default":{"default":"z con línea debajo"}},"category":"Ll"},{"key":"1E96","mappings":{"default":{"default":"h con línea debajo"}},"category":"Ll"},{"key":"1E97","mappings":{"default":{"default":"t con diéresis"}},"category":"Ll"},{"key":"1E98","mappings":{"default":{"default":"w con anillo arriba"}},"category":"Ll"},{"key":"1E99","mappings":{"default":{"default":"y con anillo arriba"}},"category":"Ll"},{"key":"1E9A","mappings":{"default":{"default":"a con medio derecho de anillo"}},"category":"Ll"},{"key":"1EA1","mappings":{"default":{"default":"a con punto debajo"}},"category":"Ll"},{"key":"1EA3","mappings":{"default":{"default":"a con gancho arriba"}},"category":"Ll"},{"key":"1EB9","mappings":{"default":{"default":"e con punto debajo"}},"category":"Ll"},{"key":"1EBB","mappings":{"default":{"default":"e con gancho arriba"}},"category":"Ll"},{"key":"1EBD","mappings":{"default":{"default":"e con tilde"}},"category":"Ll"},{"key":"1EC9","mappings":{"default":{"default":"i con gancho arriba"}},"category":"Ll"},{"key":"1ECB","mappings":{"default":{"default":"i con punto debajo"}},"category":"Ll"},{"key":"1ECD","mappings":{"default":{"default":"o con punto debajo"}},"category":"Ll"},{"key":"1ECF","mappings":{"default":{"default":"o con gancho arriba"}},"category":"Ll"},{"key":"1EE5","mappings":{"default":{"default":"u con punto debajo"}},"category":"Ll"},{"key":"1EE7","mappings":{"default":{"default":"u con gancho arriba"}},"category":"Ll"},{"key":"1EF3","mappings":{"default":{"default":"y con grave"}},"category":"Ll"},{"key":"1EF5","mappings":{"default":{"default":"y con punto debajo"}},"category":"Ll"},{"key":"1EF7","mappings":{"default":{"default":"y con gancho arriba"}},"category":"Ll"},{"key":"1EF9","mappings":{"default":{"default":"y con tilde"}},"category":"Ll"}]
,
"es/latin-mathfonts-bold-fraktur.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula A"}},"key":"1D56C"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula B"}},"key":"1D56D"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula C"}},"key":"1D56E"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula D"}},"key":"1D56F"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula E"}},"key":"1D570"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula F"}},"key":"1D571"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula G"}},"key":"1D572"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula H"}},"key":"1D573"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula I"}},"key":"1D574"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula J"}},"key":"1D575"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula K"}},"key":"1D576"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula L"}},"key":"1D577"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula M"}},"key":"1D578"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula N"}},"key":"1D579"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula O"}},"key":"1D57A"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula P"}},"key":"1D57B"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula Q"}},"key":"1D57C"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula R"}},"key":"1D57D"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula S"}},"key":"1D57E"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula T"}},"key":"1D57F"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula U"}},"key":"1D580"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula V"}},"key":"1D581"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula W"}},"key":"1D582"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula X"}},"key":"1D583"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula Y"}},"key":"1D584"},{"category":"Lu","mappings":{"default":{"default":"negrita Fraktur mayúscula Z"}},"key":"1D585"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur a"}},"key":"1D586"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur b"}},"key":"1D587"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur c"}},"key":"1D588"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur d"}},"key":"1D589"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur e"}},"key":"1D58A"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur f"}},"key":"1D58B"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur g"}},"key":"1D58C"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur h"}},"key":"1D58D"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur i"}},"key":"1D58E"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur j"}},"key":"1D58F"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur k"}},"key":"1D590"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur l"}},"key":"1D591"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur m"}},"key":"1D592"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur n"}},"key":"1D593"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur o"}},"key":"1D594"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur p"}},"key":"1D595"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur q"}},"key":"1D596"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur r"}},"key":"1D597"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur s"}},"key":"1D598"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur t"}},"key":"1D599"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur u"}},"key":"1D59A"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur v"}},"key":"1D59B"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur w"}},"key":"1D59C"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur x"}},"key":"1D59D"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur y"}},"key":"1D59E"},{"category":"Ll","mappings":{"default":{"default":"negrita Fraktur z"}},"key":"1D59F"}]
,
"es/latin-mathfonts-bold-script.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula A"}},"key":"1D4D0"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula B"}},"key":"1D4D1"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula C"}},"key":"1D4D2"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula D"}},"key":"1D4D3"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula E"}},"key":"1D4D4"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula F"}},"key":"1D4D5"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula G"}},"key":"1D4D6"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula H"}},"key":"1D4D7"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula I"}},"key":"1D4D8"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula J"}},"key":"1D4D9"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula K"}},"key":"1D4DA"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula L"}},"key":"1D4DB"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula M"}},"key":"1D4DC"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula N"}},"key":"1D4DD"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula O"}},"key":"1D4DE"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula P"}},"key":"1D4DF"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula Q"}},"key":"1D4E0"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula R"}},"key":"1D4E1"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula S"}},"key":"1D4E2"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula T"}},"key":"1D4E3"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula U"}},"key":"1D4E4"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula V"}},"key":"1D4E5"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula W"}},"key":"1D4E6"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula X"}},"key":"1D4E7"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula Y"}},"key":"1D4E8"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula Z"}},"key":"1D4E9"},{"category":"Ll","mappings":{"default":{"default":"negrita script a"}},"key":"1D4EA"},{"category":"Ll","mappings":{"default":{"default":"negrita script b"}},"key":"1D4EB"},{"category":"Ll","mappings":{"default":{"default":"negrita script c"}},"key":"1D4EC"},{"category":"Ll","mappings":{"default":{"default":"negrita script d"}},"key":"1D4ED"},{"category":"Ll","mappings":{"default":{"default":"negrita script e"}},"key":"1D4EE"},{"category":"Ll","mappings":{"default":{"default":"negrita script f"}},"key":"1D4EF"},{"category":"Ll","mappings":{"default":{"default":"negrita script g"}},"key":"1D4F0"},{"category":"Ll","mappings":{"default":{"default":"negrita script h"}},"key":"1D4F1"},{"category":"Ll","mappings":{"default":{"default":"negrita script i"}},"key":"1D4F2"},{"category":"Ll","mappings":{"default":{"default":"negrita script j"}},"key":"1D4F3"},{"category":"Ll","mappings":{"default":{"default":"negrita script k"}},"key":"1D4F4"},{"category":"Ll","mappings":{"default":{"default":"negrita script l"}},"key":"1D4F5"},{"category":"Ll","mappings":{"default":{"default":"negrita script m"}},"key":"1D4F6"},{"category":"Ll","mappings":{"default":{"default":"negrita script n"}},"key":"1D4F7"},{"category":"Ll","mappings":{"default":{"default":"negrita script o"}},"key":"1D4F8"},{"category":"Ll","mappings":{"default":{"default":"negrita script p"}},"key":"1D4F9"},{"category":"Ll","mappings":{"default":{"default":"negrita script q"}},"key":"1D4FA"},{"category":"Ll","mappings":{"default":{"default":"negrita script r"}},"key":"1D4FB"},{"category":"Ll","mappings":{"default":{"default":"negrita script s"}},"key":"1D4FC"},{"category":"Ll","mappings":{"default":{"default":"negrita script t"}},"key":"1D4FD"},{"category":"Ll","mappings":{"default":{"default":"negrita script u"}},"key":"1D4FE"},{"category":"Ll","mappings":{"default":{"default":"negrita script v"}},"key":"1D4FF"},{"category":"Ll","mappings":{"default":{"default":"negrita script w"}},"key":"1D500"},{"category":"Ll","mappings":{"default":{"default":"negrita script x"}},"key":"1D501"},{"category":"Ll","mappings":{"default":{"default":"negrita script y"}},"key":"1D502"},{"category":"Ll","mappings":{"default":{"default":"negrita script z"}},"key":"1D503"}]
,
"es/latin-mathfonts-bold.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula A"}},"key":"1D400"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula B"}},"key":"1D401"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula C"}},"key":"1D402"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula D"}},"key":"1D403"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula E"}},"key":"1D404"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula F"}},"key":"1D405"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula G"}},"key":"1D406"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula H"}},"key":"1D407"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula I"}},"key":"1D408"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula J"}},"key":"1D409"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula K"}},"key":"1D40A"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula L"}},"key":"1D40B"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula M"}},"key":"1D40C"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula N"}},"key":"1D40D"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula O"}},"key":"1D40E"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula P"}},"key":"1D40F"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Q"}},"key":"1D410"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula R"}},"key":"1D411"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula S"}},"key":"1D412"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula T"}},"key":"1D413"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula U"}},"key":"1D414"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula V"}},"key":"1D415"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula W"}},"key":"1D416"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula X"}},"key":"1D417"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Y"}},"key":"1D418"},{"category":"Lu","mappings":{"default":{"default":"negrita mayúscula Z"}},"key":"1D419"},{"category":"Ll","mappings":{"default":{"default":"negrita a"}},"key":"1D41A"},{"category":"Ll","mappings":{"default":{"default":"negrita b"}},"key":"1D41B"},{"category":"Ll","mappings":{"default":{"default":"negrita c"}},"key":"1D41C"},{"category":"Ll","mappings":{"default":{"default":"negrita d"}},"key":"1D41D"},{"category":"Ll","mappings":{"default":{"default":"negrita e"}},"key":"1D41E"},{"category":"Ll","mappings":{"default":{"default":"negrita f"}},"key":"1D41F"},{"category":"Ll","mappings":{"default":{"default":"negrita g"}},"key":"1D420"},{"category":"Ll","mappings":{"default":{"default":"negrita h"}},"key":"1D421"},{"category":"Ll","mappings":{"default":{"default":"negrita i"}},"key":"1D422"},{"category":"Ll","mappings":{"default":{"default":"negrita j"}},"key":"1D423"},{"category":"Ll","mappings":{"default":{"default":"negrita k"}},"key":"1D424"},{"category":"Ll","mappings":{"default":{"default":"negrita l"}},"key":"1D425"},{"category":"Ll","mappings":{"default":{"default":"negrita m"}},"key":"1D426"},{"category":"Ll","mappings":{"default":{"default":"negrita n"}},"key":"1D427"},{"category":"Ll","mappings":{"default":{"default":"negrita o"}},"key":"1D428"},{"category":"Ll","mappings":{"default":{"default":"negrita p"}},"key":"1D429"},{"category":"Ll","mappings":{"default":{"default":"negrita q"}},"key":"1D42A"},{"category":"Ll","mappings":{"default":{"default":"negrita r"}},"key":"1D42B"},{"category":"Ll","mappings":{"default":{"default":"negrita s"}},"key":"1D42C"},{"category":"Ll","mappings":{"default":{"default":"negrita t"}},"key":"1D42D"},{"category":"Ll","mappings":{"default":{"default":"negrita u"}},"key":"1D42E"},{"category":"Ll","mappings":{"default":{"default":"negrita v"}},"key":"1D42F"},{"category":"Ll","mappings":{"default":{"default":"negrita w"}},"key":"1D430"},{"category":"Ll","mappings":{"default":{"default":"negrita x"}},"key":"1D431"},{"category":"Ll","mappings":{"default":{"default":"negrita y"}},"key":"1D432"},{"category":"Ll","mappings":{"default":{"default":"negrita z"}},"key":"1D433"}]
,
"es/latin-mathfonts-double-struck.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula A"}},"key":"1D538"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula B"}},"key":"1D539"},{"key":"2102","mappings":{"default":{"default":"negrita de pizarra mayúscula C"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula D"}},"key":"1D53B"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula E"}},"key":"1D53C"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula F"}},"key":"1D53D"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula G"}},"key":"1D53E"},{"key":"210D","mappings":{"default":{"default":"negrita de pizarra mayúscula H"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula I"}},"key":"1D540"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula J"}},"key":"1D541"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula K"}},"key":"1D542"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula L"}},"key":"1D543"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula M"}},"key":"1D544"},{"key":"2115","mappings":{"default":{"default":"negrita de pizarra mayúscula N"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula O"}},"key":"1D546"},{"key":"2119","mappings":{"default":{"default":"negrita de pizarra mayúscula P"}},"category":"Lu"},{"key":"211A","mappings":{"default":{"default":"negrita de pizarra mayúscula Q"}},"category":"Lu"},{"key":"211D","mappings":{"default":{"default":"negrita de pizarra mayúscula R","defaultMP":"R mayúscula negrita"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula S"}},"key":"1D54A"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula T"}},"key":"1D54B"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula U"}},"key":"1D54C"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula V"}},"key":"1D54D"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula W"}},"key":"1D54E"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula X"}},"key":"1D54F"},{"category":"Lu","mappings":{"default":{"default":"negrita de pizarra mayúscula Y"}},"key":"1D550"},{"key":"2124","mappings":{"default":{"default":"negrita de pizarra mayúscula Z"}},"category":"Lu"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra a"}},"key":"1D552"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra b"}},"key":"1D553"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra c"}},"key":"1D554"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra d"}},"key":"1D555"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra e"}},"key":"1D556"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra f"}},"key":"1D557"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra g"}},"key":"1D558"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra h"}},"key":"1D559"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra i"}},"key":"1D55A"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra j"}},"key":"1D55B"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra k"}},"key":"1D55C"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra l"}},"key":"1D55D"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra m"}},"key":"1D55E"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra n"}},"key":"1D55F"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra o"}},"key":"1D560"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra p"}},"key":"1D561"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra q"}},"key":"1D562"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra r"}},"key":"1D563"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra s"}},"key":"1D564"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra t"}},"key":"1D565"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra u"}},"key":"1D566"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra v"}},"key":"1D567"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra w"}},"key":"1D568"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra x"}},"key":"1D569"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra y"}},"key":"1D56A"},{"category":"Ll","mappings":{"default":{"default":"negrita de pizarra z"}},"key":"1D56B"}]
,
"es/latin-mathfonts-fraktur.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula A"}},"key":"1D504"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula B"}},"key":"1D505"},{"key":"212D","mappings":{"default":{"default":"Fraktur mayúscula C"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula D"}},"key":"1D507"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula E"}},"key":"1D508"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula F"}},"key":"1D509"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula G"}},"key":"1D50A"},{"key":"210C","mappings":{"default":{"default":"Fraktur mayúscula H"}},"category":"Lu"},{"key":"2111","mappings":{"default":{"default":"Fraktur mayúscula I"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula J"}},"key":"1D50D"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula K"}},"key":"1D50E"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula L"}},"key":"1D50F"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula M"}},"key":"1D510"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula N"}},"key":"1D511"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula O"}},"key":"1D512"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula P"}},"key":"1D513"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula Q"}},"key":"1D514"},{"key":"211C","mappings":{"default":{"default":"Fraktur mayúscula R"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula S"}},"key":"1D516"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula T"}},"key":"1D517"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula U"}},"key":"1D518"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula V"}},"key":"1D519"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula W"}},"key":"1D51A"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula X"}},"key":"1D51B"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula Y"}},"key":"1D51C"},{"key":"2128","mappings":{"default":{"default":"Fraktur mayúscula Z"}},"category":"Lu"},{"category":"Ll","mappings":{"default":{"default":"Fraktur a"}},"key":"1D51E"},{"category":"Ll","mappings":{"default":{"default":"Fraktur b"}},"key":"1D51F"},{"category":"Ll","mappings":{"default":{"default":"Fraktur c"}},"key":"1D520"},{"category":"Ll","mappings":{"default":{"default":"Fraktur d"}},"key":"1D521"},{"category":"Ll","mappings":{"default":{"default":"Fraktur e"}},"key":"1D522"},{"category":"Ll","mappings":{"default":{"default":"Fraktur f"}},"key":"1D523"},{"category":"Ll","mappings":{"default":{"default":"Fraktur g"}},"key":"1D524"},{"category":"Ll","mappings":{"default":{"default":"Fraktur h"}},"key":"1D525"},{"category":"Ll","mappings":{"default":{"default":"Fraktur i"}},"key":"1D526"},{"category":"Ll","mappings":{"default":{"default":"Fraktur j"}},"key":"1D527"},{"category":"Ll","mappings":{"default":{"default":"Fraktur k"}},"key":"1D528"},{"category":"Ll","mappings":{"default":{"default":"Fraktur l"}},"key":"1D529"},{"category":"Ll","mappings":{"default":{"default":"Fraktur m"}},"key":"1D52A"},{"category":"Ll","mappings":{"default":{"default":"Fraktur n"}},"key":"1D52B"},{"category":"Ll","mappings":{"default":{"default":"Fraktur o"}},"key":"1D52C"},{"category":"Ll","mappings":{"default":{"default":"Fraktur p"}},"key":"1D52D"},{"category":"Ll","mappings":{"default":{"default":"Fraktur q"}},"key":"1D52E"},{"category":"Ll","mappings":{"default":{"default":"Fraktur r"}},"key":"1D52F"},{"category":"Ll","mappings":{"default":{"default":"Fraktur s"}},"key":"1D530"},{"category":"Ll","mappings":{"default":{"default":"Fraktur t"}},"key":"1D531"},{"category":"Ll","mappings":{"default":{"default":"Fraktur u"}},"key":"1D532"},{"category":"Ll","mappings":{"default":{"default":"Fraktur v"}},"key":"1D533"},{"category":"Ll","mappings":{"default":{"default":"Fraktur w"}},"key":"1D534"},{"category":"Ll","mappings":{"default":{"default":"Fraktur x"}},"key":"1D535"},{"category":"Ll","mappings":{"default":{"default":"Fraktur y"}},"key":"1D536"},{"category":"Ll","mappings":{"default":{"default":"Fraktur z"}},"key":"1D537"}]
,
"es/latin-mathfonts-italic.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula A"}},"key":"1D434"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula B"}},"key":"1D435"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula C"}},"key":"1D436"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula D"}},"key":"1D437"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula E"}},"key":"1D438"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula F"}},"key":"1D439"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula G"}},"key":"1D43A"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula H"}},"key":"1D43B"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula I"}},"key":"1D43C"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula J"}},"key":"1D43D"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula K"}},"key":"1D43E"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula L"}},"key":"1D43F"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula M"}},"key":"1D440"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula N"}},"key":"1D441"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula O"}},"key":"1D442"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula P"}},"key":"1D443"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Q"}},"key":"1D444"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula R"}},"key":"1D445"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula S"}},"key":"1D446"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula T"}},"key":"1D447"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula U"}},"key":"1D448"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula V"}},"key":"1D449"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula W"}},"key":"1D44A"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula X"}},"key":"1D44B"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Y"}},"key":"1D44C"},{"category":"Lu","mappings":{"default":{"default":"cursiva mayúscula Z"}},"key":"1D44D"},{"category":"Ll","mappings":{"default":{"default":"cursiva a"}},"key":"1D44E"},{"category":"Ll","mappings":{"default":{"default":"cursiva b"}},"key":"1D44F"},{"category":"Ll","mappings":{"default":{"default":"cursiva c"}},"key":"1D450"},{"category":"Ll","mappings":{"default":{"default":"cursiva d"}},"key":"1D451"},{"category":"Ll","mappings":{"default":{"default":"cursiva e"}},"key":"1D452"},{"category":"Ll","mappings":{"default":{"default":"cursiva f"}},"key":"1D453"},{"category":"Ll","mappings":{"default":{"default":"cursiva g"}},"key":"1D454"},{"key":"210E","mappings":{"default":{"default":"constante de Planck"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"cursiva i"}},"key":"1D456"},{"category":"Ll","mappings":{"default":{"default":"cursiva j"}},"key":"1D457"},{"category":"Ll","mappings":{"default":{"default":"cursiva k"}},"key":"1D458"},{"category":"Ll","mappings":{"default":{"default":"cursiva l"}},"key":"1D459"},{"category":"Ll","mappings":{"default":{"default":"cursiva m"}},"key":"1D45A"},{"category":"Ll","mappings":{"default":{"default":"cursiva n"}},"key":"1D45B"},{"category":"Ll","mappings":{"default":{"default":"cursiva o"}},"key":"1D45C"},{"category":"Ll","mappings":{"default":{"default":"cursiva p"}},"key":"1D45D"},{"category":"Ll","mappings":{"default":{"default":"cursiva q"}},"key":"1D45E"},{"category":"Ll","mappings":{"default":{"default":"cursiva r"}},"key":"1D45F"},{"category":"Ll","mappings":{"default":{"default":"cursiva s"}},"key":"1D460"},{"category":"Ll","mappings":{"default":{"default":"cursiva t"}},"key":"1D461"},{"category":"Ll","mappings":{"default":{"default":"cursiva u"}},"key":"1D462"},{"category":"Ll","mappings":{"default":{"default":"cursiva v"}},"key":"1D463"},{"category":"Ll","mappings":{"default":{"default":"cursiva w"}},"key":"1D464"},{"category":"Ll","mappings":{"default":{"default":"cursiva x"}},"key":"1D465"},{"category":"Ll","mappings":{"default":{"default":"cursiva y"}},"key":"1D466"},{"category":"Ll","mappings":{"default":{"default":"cursiva z"}},"key":"1D467"}]
,
"es/latin-mathfonts-monospace.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula A"}},"key":"1D670"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula B"}},"key":"1D671"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula C"}},"key":"1D672"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula D"}},"key":"1D673"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula E"}},"key":"1D674"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula F"}},"key":"1D675"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula G"}},"key":"1D676"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula H"}},"key":"1D677"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula I"}},"key":"1D678"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula J"}},"key":"1D679"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula K"}},"key":"1D67A"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula L"}},"key":"1D67B"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula M"}},"key":"1D67C"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula N"}},"key":"1D67D"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula O"}},"key":"1D67E"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula P"}},"key":"1D67F"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula Q"}},"key":"1D680"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula R"}},"key":"1D681"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula S"}},"key":"1D682"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula T"}},"key":"1D683"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula U"}},"key":"1D684"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula V"}},"key":"1D685"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula W"}},"key":"1D686"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula X"}},"key":"1D687"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula Y"}},"key":"1D688"},{"category":"Lu","mappings":{"default":{"default":"monoespacio mayúscula Z"}},"key":"1D689"},{"category":"Ll","mappings":{"default":{"default":"monoespacio a"}},"key":"1D68A"},{"category":"Ll","mappings":{"default":{"default":"monoespacio b"}},"key":"1D68B"},{"category":"Ll","mappings":{"default":{"default":"monoespacio c"}},"key":"1D68C"},{"category":"Ll","mappings":{"default":{"default":"monoespacio d"}},"key":"1D68D"},{"category":"Ll","mappings":{"default":{"default":"monoespacio e"}},"key":"1D68E"},{"category":"Ll","mappings":{"default":{"default":"monoespacio f"}},"key":"1D68F"},{"category":"Ll","mappings":{"default":{"default":"monoespacio g"}},"key":"1D690"},{"category":"Ll","mappings":{"default":{"default":"monoespacio h"}},"key":"1D691"},{"category":"Ll","mappings":{"default":{"default":"monoespacio i"}},"key":"1D692"},{"category":"Ll","mappings":{"default":{"default":"monoespacio j"}},"key":"1D693"},{"category":"Ll","mappings":{"default":{"default":"monoespacio k"}},"key":"1D694"},{"category":"Ll","mappings":{"default":{"default":"monoespacio l"}},"key":"1D695"},{"category":"Ll","mappings":{"default":{"default":"monoespacio m"}},"key":"1D696"},{"category":"Ll","mappings":{"default":{"default":"monoespacio n"}},"key":"1D697"},{"category":"Ll","mappings":{"default":{"default":"monoespacio o"}},"key":"1D698"},{"category":"Ll","mappings":{"default":{"default":"monoespacio p"}},"key":"1D699"},{"category":"Ll","mappings":{"default":{"default":"monoespacio q"}},"key":"1D69A"},{"category":"Ll","mappings":{"default":{"default":"monoespacio r"}},"key":"1D69B"},{"category":"Ll","mappings":{"default":{"default":"monoespacio s"}},"key":"1D69C"},{"category":"Ll","mappings":{"default":{"default":"monoespacio t"}},"key":"1D69D"},{"category":"Ll","mappings":{"default":{"default":"monoespacio u"}},"key":"1D69E"},{"category":"Ll","mappings":{"default":{"default":"monoespacio v"}},"key":"1D69F"},{"category":"Ll","mappings":{"default":{"default":"monoespacio w"}},"key":"1D6A0"},{"category":"Ll","mappings":{"default":{"default":"monoespacio x"}},"key":"1D6A1"},{"category":"Ll","mappings":{"default":{"default":"monoespacio y"}},"key":"1D6A2"},{"category":"Ll","mappings":{"default":{"default":"monoespacio z"}},"key":"1D6A3"}]
,
"es/latin-mathfonts-sans-serif-bold.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula A"}},"key":"1D5D4"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula B"}},"key":"1D5D5"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula C"}},"key":"1D5D6"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula D"}},"key":"1D5D7"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula E"}},"key":"1D5D8"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula F"}},"key":"1D5D9"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula G"}},"key":"1D5DA"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula H"}},"key":"1D5DB"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula I"}},"key":"1D5DC"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula J"}},"key":"1D5DD"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula K"}},"key":"1D5DE"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula L"}},"key":"1D5DF"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula M"}},"key":"1D5E0"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula N"}},"key":"1D5E1"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula O"}},"key":"1D5E2"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula P"}},"key":"1D5E3"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Q"}},"key":"1D5E4"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula R"}},"key":"1D5E5"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula S"}},"key":"1D5E6"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula T"}},"key":"1D5E7"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula U"}},"key":"1D5E8"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula V"}},"key":"1D5E9"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula W"}},"key":"1D5EA"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula X"}},"key":"1D5EB"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Y"}},"key":"1D5EC"},{"category":"Lu","mappings":{"default":{"default":"sans-serif negrita mayúscula Z"}},"key":"1D5ED"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita a"}},"key":"1D5EE"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita b"}},"key":"1D5EF"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita c"}},"key":"1D5F0"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita d"}},"key":"1D5F1"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita e"}},"key":"1D5F2"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita f"}},"key":"1D5F3"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita g"}},"key":"1D5F4"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita h"}},"key":"1D5F5"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita i"}},"key":"1D5F6"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita j"}},"key":"1D5F7"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita k"}},"key":"1D5F8"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita l"}},"key":"1D5F9"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita m"}},"key":"1D5FA"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita n"}},"key":"1D5FB"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita o"}},"key":"1D5FC"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita p"}},"key":"1D5FD"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita q"}},"key":"1D5FE"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita r"}},"key":"1D5FF"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita s"}},"key":"1D600"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita t"}},"key":"1D601"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita u"}},"key":"1D602"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita v"}},"key":"1D603"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita w"}},"key":"1D604"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita x"}},"key":"1D605"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita y"}},"key":"1D606"},{"category":"Ll","mappings":{"default":{"default":"sans-serif negrita z"}},"key":"1D607"}]
,
"es/latin-mathfonts-sans-serif-italic.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula A"}},"key":"1D608"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula B"}},"key":"1D609"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula C"}},"key":"1D60A"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula D"}},"key":"1D60B"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula E"}},"key":"1D60C"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula F"}},"key":"1D60D"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula G"}},"key":"1D60E"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula H"}},"key":"1D60F"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula I"}},"key":"1D610"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula J"}},"key":"1D611"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula K"}},"key":"1D612"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula L"}},"key":"1D613"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula M"}},"key":"1D614"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula N"}},"key":"1D615"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula O"}},"key":"1D616"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula P"}},"key":"1D617"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula Q"}},"key":"1D618"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula R"}},"key":"1D619"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula S"}},"key":"1D61A"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula T"}},"key":"1D61B"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula U"}},"key":"1D61C"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula V"}},"key":"1D61D"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula W"}},"key":"1D61E"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula X"}},"key":"1D61F"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula Y"}},"key":"1D620"},{"category":"Lu","mappings":{"default":{"default":"sans-serif cursiva mayúscula Z"}},"key":"1D621"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva a"}},"key":"1D622"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva b"}},"key":"1D623"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva c"}},"key":"1D624"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva d"}},"key":"1D625"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva e"}},"key":"1D626"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva f"}},"key":"1D627"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva g"}},"key":"1D628"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva h"}},"key":"1D629"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva i"}},"key":"1D62A"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva j"}},"key":"1D62B"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva k"}},"key":"1D62C"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva l"}},"key":"1D62D"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva m"}},"key":"1D62E"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva n"}},"key":"1D62F"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva o"}},"key":"1D630"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva p"}},"key":"1D631"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva q"}},"key":"1D632"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva r"}},"key":"1D633"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva s"}},"key":"1D634"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva t"}},"key":"1D635"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva u"}},"key":"1D636"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva v"}},"key":"1D637"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva w"}},"key":"1D638"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva x"}},"key":"1D639"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva y"}},"key":"1D63A"},{"category":"Ll","mappings":{"default":{"default":"sans-serif cursiva z"}},"key":"1D63B"}]
,
"es/latin-mathfonts-sans-serif.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula A"}},"key":"1D5A0"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula B"}},"key":"1D5A1"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula C"}},"key":"1D5A2"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula D"}},"key":"1D5A3"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula E"}},"key":"1D5A4"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula F"}},"key":"1D5A5"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula G"}},"key":"1D5A6"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula H"}},"key":"1D5A7"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula I"}},"key":"1D5A8"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula J"}},"key":"1D5A9"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula K"}},"key":"1D5AA"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula L"}},"key":"1D5AB"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula M"}},"key":"1D5AC"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula N"}},"key":"1D5AD"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula O"}},"key":"1D5AE"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula P"}},"key":"1D5AF"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula Q"}},"key":"1D5B0"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula R"}},"key":"1D5B1"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula S"}},"key":"1D5B2"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula T"}},"key":"1D5B3"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula U"}},"key":"1D5B4"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula V"}},"key":"1D5B5"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula W"}},"key":"1D5B6"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula X"}},"key":"1D5B7"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula Y"}},"key":"1D5B8"},{"category":"Lu","mappings":{"default":{"default":"sans-serif mayúscula Z"}},"key":"1D5B9"},{"category":"Ll","mappings":{"default":{"default":"sans-serif a"}},"key":"1D5BA"},{"category":"Ll","mappings":{"default":{"default":"sans-serif b"}},"key":"1D5BB"},{"category":"Ll","mappings":{"default":{"default":"sans-serif c"}},"key":"1D5BC"},{"category":"Ll","mappings":{"default":{"default":"sans-serif d"}},"key":"1D5BD"},{"category":"Ll","mappings":{"default":{"default":"sans-serif e"}},"key":"1D5BE"},{"category":"Ll","mappings":{"default":{"default":"sans-serif f"}},"key":"1D5BF"},{"category":"Ll","mappings":{"default":{"default":"sans-serif g"}},"key":"1D5C0"},{"category":"Ll","mappings":{"default":{"default":"sans-serif h"}},"key":"1D5C1"},{"category":"Ll","mappings":{"default":{"default":"sans-serif i"}},"key":"1D5C2"},{"category":"Ll","mappings":{"default":{"default":"sans-serif j"}},"key":"1D5C3"},{"category":"Ll","mappings":{"default":{"default":"sans-serif k"}},"key":"1D5C4"},{"category":"Ll","mappings":{"default":{"default":"sans-serif l"}},"key":"1D5C5"},{"category":"Ll","mappings":{"default":{"default":"sans-serif m"}},"key":"1D5C6"},{"category":"Ll","mappings":{"default":{"default":"sans-serif n"}},"key":"1D5C7"},{"category":"Ll","mappings":{"default":{"default":"sans-serif o"}},"key":"1D5C8"},{"category":"Ll","mappings":{"default":{"default":"sans-serif p"}},"key":"1D5C9"},{"category":"Ll","mappings":{"default":{"default":"sans-serif q"}},"key":"1D5CA"},{"category":"Ll","mappings":{"default":{"default":"sans-serif r"}},"key":"1D5CB"},{"category":"Ll","mappings":{"default":{"default":"sans-serif s"}},"key":"1D5CC"},{"category":"Ll","mappings":{"default":{"default":"sans-serif t"}},"key":"1D5CD"},{"category":"Ll","mappings":{"default":{"default":"sans-serif u"}},"key":"1D5CE"},{"category":"Ll","mappings":{"default":{"default":"sans-serif v"}},"key":"1D5CF"},{"category":"Ll","mappings":{"default":{"default":"sans-serif w"}},"key":"1D5D0"},{"category":"Ll","mappings":{"default":{"default":"sans-serif x"}},"key":"1D5D1"},{"category":"Ll","mappings":{"default":{"default":"sans-serif y"}},"key":"1D5D2"},{"category":"Ll","mappings":{"default":{"default":"sans-serif z"}},"key":"1D5D3"}]
,
"es/latin-mathfonts-script.js": 
[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula A"}},"key":"1D49C"},{"key":"212C","mappings":{"default":{"default":"script mayúscula B"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula C"}},"key":"1D49E"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula D"}},"key":"1D49F"},{"key":"2130","mappings":{"default":{"default":"script mayúscula E"}},"category":"Lu"},{"key":"2131","mappings":{"default":{"default":"script mayúscula F"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula G"}},"key":"1D4A2"},{"key":"210B","mappings":{"default":{"default":"script mayúscula H"}},"category":"Lu"},{"key":"2110","mappings":{"default":{"default":"script mayúscula I"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula J"}},"key":"1D4A5"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula K"}},"key":"1D4A6"},{"key":"2112","mappings":{"default":{"default":"script mayúscula L"}},"category":"Lu"},{"key":"2133","mappings":{"default":{"default":"script mayúscula M"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula N"}},"key":"1D4A9"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula O"}},"key":"1D4AA"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula P"}},"key":"1D4AB"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula Q"}},"key":"1D4AC"},{"key":"211B","mappings":{"default":{"default":"script mayúscula R"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula S"}},"key":"1D4AE"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula T"}},"key":"1D4AF"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula U"}},"key":"1D4B0"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula V"}},"key":"1D4B1"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula W"}},"key":"1D4B2"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula X"}},"key":"1D4B3"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula Y"}},"key":"1D4B4"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula Z"}},"key":"1D4B5"},{"category":"Ll","mappings":{"default":{"default":"script a"}},"key":"1D4B6"},{"category":"Ll","mappings":{"default":{"default":"script b"}},"key":"1D4B7"},{"category":"Ll","mappings":{"default":{"default":"script c"}},"key":"1D4B8"},{"category":"Ll","mappings":{"default":{"default":"script d"}},"key":"1D4B9"},{"key":"212F","mappings":{"default":{"default":"script e"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"script f"}},"key":"1D4BB"},{"key":"210A","mappings":{"default":{"default":"script g"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"script h"}},"key":"1D4BD"},{"category":"Ll","mappings":{"default":{"default":"script i"}},"key":"1D4BE"},{"category":"Ll","mappings":{"default":{"default":"script j"}},"key":"1D4BF"},{"category":"Ll","mappings":{"default":{"default":"script k"}},"key":"1D4C0"},{"category":"Ll","mappings":{"default":{"default":"script l"}},"key":"1D4C1"},{"category":"Ll","mappings":{"default":{"default":"script m"}},"key":"1D4C2"},{"category":"Ll","mappings":{"default":{"default":"script n"}},"key":"1D4C3"},{"key":"2134","mappings":{"default":{"default":"script o"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"script p"}},"key":"1D4C5"},{"category":"Ll","mappings":{"default":{"default":"script q"}},"key":"1D4C6"},{"category":"Ll","mappings":{"default":{"default":"script r"}},"key":"1D4C7"},{"category":"Ll","mappings":{"default":{"default":"script s"}},"key":"1D4C8"},{"category":"Ll","mappings":{"default":{"default":"script t"}},"key":"1D4C9"},{"category":"Ll","mappings":{"default":{"default":"script u"}},"key":"1D4CA"},{"category":"Ll","mappings":{"default":{"default":"script v"}},"key":"1D4CB"},{"category":"Ll","mappings":{"default":{"default":"script w"}},"key":"1D4CC"},{"category":"Ll","mappings":{"default":{"default":"script x"}},"key":"1D4CD"},{"category":"Ll","mappings":{"default":{"default":"script y"}},"key":"1D4CE"},{"category":"Ll","mappings":{"default":{"default":"script z"}},"key":"1D4CF"}]
,
"es/latin-rest.js": 
[{"locale":"es"},{"key":"24C8","mappings":{"default":{"default":"S en círculo"}},"category":"So"}]
,
"es/latin-upper-double-accent.js": 
[{"locale":"es"},{"key":"1E08","mappings":{"default":{"default":"mayúscula C con cedilla y agudo"}},"category":"Lu"},{"key":"1E14","mappings":{"default":{"default":"mayúscula E con macrón y grave"}},"category":"Lu"},{"key":"1E16","mappings":{"default":{"default":"mayúscula E con macrón y agudo"}},"category":"Lu"},{"key":"1E1C","mappings":{"default":{"default":"mayúscula E with cedilla and breve"}},"category":"Lu"},{"key":"1E2E","mappings":{"default":{"default":"mayúscula I con diéresis y agudo"}},"category":"Lu"},{"key":"1E38","mappings":{"default":{"default":"mayúscula L con punto debajo y macrón"}},"category":"Lu"},{"key":"1E4C","mappings":{"default":{"default":"mayúscula O con tilde y acute"}},"category":"Lu"},{"key":"1E4E","mappings":{"default":{"default":"mayúscula O con tilde y diéresis"}},"category":"Lu"},{"key":"1E50","mappings":{"default":{"default":"mayúscula O con macrón y grave"}},"category":"Lu"},{"key":"1E52","mappings":{"default":{"default":"mayúscula O con macrón y agudo"}},"category":"Lu"},{"key":"1E5C","mappings":{"default":{"default":"mayúscula R con punto debajo y macrón"}},"category":"Lu"},{"key":"1E64","mappings":{"default":{"default":"mayúscula S con agudo y punto arriba"}},"category":"Lu"},{"key":"1E66","mappings":{"default":{"default":"mayúscula S con carón y punto arriba"}},"category":"Lu"},{"key":"1E68","mappings":{"default":{"default":"mayúscula S con punto debajo y punto arriba"}},"category":"Lu"},{"key":"1E78","mappings":{"default":{"default":"mayúscula U con tilde y agudo"}},"category":"Lu"},{"key":"1E7A","mappings":{"default":{"default":"mayúscula U con macrón y diéresis"}},"category":"Lu"},{"key":"1EA4","mappings":{"default":{"default":"mayúscula A con acento circunflejo y agudo"}},"category":"Lu"},{"key":"1EA6","mappings":{"default":{"default":"mayúscula A con acento circunflejo y grave"}},"category":"Lu"},{"key":"1EA8","mappings":{"default":{"default":"mayúscula A con acento circunflejo y gancho arriba"}},"category":"Lu"},{"key":"1EAA","mappings":{"default":{"default":"mayúscula A con acento circunflejo y tilde"}},"category":"Lu"},{"key":"1EAC","mappings":{"default":{"default":"mayúscula A con acento circunflejo y punto debajo"}},"category":"Lu"},{"key":"1EAE","mappings":{"default":{"default":"mayúscula A con breve y agudo"}},"category":"Lu"},{"key":"1EB0","mappings":{"default":{"default":"mayúscula A con breve y grave"}},"category":"Lu"},{"key":"1EB2","mappings":{"default":{"default":"mayúscula A con breve y gancho arriba"}},"category":"Lu"},{"key":"1EB4","mappings":{"default":{"default":"mayúscula A con breve y tilde"}},"category":"Lu"},{"key":"1EB6","mappings":{"default":{"default":"mayúscula A con breve y punto debajo"}},"category":"Lu"},{"key":"1EBE","mappings":{"default":{"default":"mayúscula E con acento circunflejo y agudo"}},"category":"Lu"},{"key":"1EC0","mappings":{"default":{"default":"mayúscula E con acento circunflejo y grave"}},"category":"Lu"},{"key":"1EC2","mappings":{"default":{"default":"mayúscula E con acento circunflejo y gancho arriba"}},"category":"Lu"},{"key":"1EC4","mappings":{"default":{"default":"mayúscula E con acento circunflejo y tilde"}},"category":"Lu"},{"key":"1EC6","mappings":{"default":{"default":"mayúscula E con acento circunflejo y punto debajo"}},"category":"Lu"},{"key":"1ED0","mappings":{"default":{"default":"mayúscula O con acento circunflejo y agudo"}},"category":"Lu"},{"key":"1ED2","mappings":{"default":{"default":"mayúscula O con acento circunflejo y grave"}},"category":"Lu"},{"key":"1ED4","mappings":{"default":{"default":"mayúscula O con acento circunflejo y gancho arriba"}},"category":"Lu"},{"key":"1ED6","mappings":{"default":{"default":"mayúscula O con acento circunflejo y tilde"}},"category":"Lu"},{"key":"1ED8","mappings":{"default":{"default":"mayúscula O con acento circunflejo y punto debajo"}},"category":"Lu"},{"key":"1EDA","mappings":{"default":{"default":"mayúscula O with horn and acute"}},"category":"Lu"},{"key":"1EDC","mappings":{"default":{"default":"mayúscula O with horn and grave"}},"category":"Lu"},{"key":"1EDE","mappings":{"default":{"default":"mayúscula O with horn and hook above"}},"category":"Lu"},{"key":"1EE0","mappings":{"default":{"default":"mayúscula O with horn and tilde"}},"category":"Lu"},{"key":"1EE2","mappings":{"default":{"default":"mayúscula O con cuerno y punto debajo"}},"category":"Lu"},{"key":"1EE8","mappings":{"default":{"default":"mayúscula U con cuerno y agudo"}},"category":"Lu"},{"key":"1EEA","mappings":{"default":{"default":"mayúscula U con cuerno y grave"}},"category":"Lu"},{"key":"1EEC","mappings":{"default":{"default":"mayúscula U con cuerno y gancho arriba"}},"category":"Lu"},{"key":"1EEE","mappings":{"default":{"default":"mayúscula U con cuerno y tilde"}},"category":"Lu"},{"key":"1EF0","mappings":{"default":{"default":"mayúscula U con cuerno y punto debajo"}},"category":"Lu"}]
,
"es/latin-upper-normal.js": 
[{"locale":"es"},{"key":"0041","mappings":{"default":{"default":"mayúscula A"}},"category":"Lu"},{"key":"0042","mappings":{"default":{"default":"mayúscula B"}},"category":"Lu"},{"key":"0043","mappings":{"default":{"default":"mayúscula C"}},"category":"Lu"},{"key":"0044","mappings":{"default":{"default":"mayúscula D"}},"category":"Lu"},{"key":"0045","mappings":{"default":{"default":"mayúscula E"}},"category":"Lu"},{"key":"0046","mappings":{"default":{"default":"mayúscula F"}},"category":"Lu"},{"key":"0047","mappings":{"default":{"default":"mayúscula G"}},"category":"Lu"},{"key":"0048","mappings":{"default":{"default":"mayúscula H"}},"category":"Lu"},{"key":"0049","mappings":{"default":{"default":"mayúscula I"}},"category":"Lu"},{"key":"004A","mappings":{"default":{"default":"mayúscula J"}},"category":"Lu"},{"key":"004B","mappings":{"default":{"default":"mayúscula K"}},"category":"Lu"},{"key":"004C","mappings":{"default":{"default":"mayúscula L"}},"category":"Lu"},{"key":"004D","mappings":{"default":{"default":"mayúscula M"}},"category":"Lu"},{"key":"004E","mappings":{"default":{"default":"mayúscula N"}},"category":"Lu"},{"key":"004F","mappings":{"default":{"default":"mayúscula O"}},"category":"Lu"},{"key":"0050","mappings":{"default":{"default":"mayúscula P"}},"category":"Lu"},{"key":"0051","mappings":{"default":{"default":"mayúscula Q"}},"category":"Lu"},{"key":"0052","mappings":{"default":{"default":"mayúscula R"}},"category":"Lu"},{"key":"0053","mappings":{"default":{"default":"mayúscula S"}},"category":"Lu"},{"key":"0054","mappings":{"default":{"default":"mayúscula T"}},"category":"Lu"},{"key":"0055","mappings":{"default":{"default":"mayúscula U"}},"category":"Lu"},{"key":"0056","mappings":{"default":{"default":"mayúscula V"}},"category":"Lu"},{"key":"0057","mappings":{"default":{"default":"mayúscula W"}},"category":"Lu"},{"key":"0058","mappings":{"default":{"default":"mayúscula X"}},"category":"Lu"},{"key":"0059","mappings":{"default":{"default":"mayúscula Y","defaultMP":"Ye"}},"category":"Lu"},{"key":"005A","mappings":{"default":{"default":"mayúscula Z"}},"category":"Lu"}]
,
"es/latin-upper-single-accent.js": 
[{"locale":"es"},{"key":"00C0","mappings":{"default":{"default":"mayúscula A grave"}},"category":"Lu"},{"key":"00C1","mappings":{"default":{"default":"mayúscula A aguda"}},"category":"Lu"},{"key":"00C2","mappings":{"default":{"default":"mayúscula A acento circunflejo"}},"category":"Lu"},{"key":"00C3","mappings":{"default":{"default":"mayúscula A con tilde"}},"category":"Lu"},{"key":"00C4","mappings":{"default":{"default":"mayúscula A diéresis"}},"category":"Lu"},{"key":"00C5","mappings":{"default":{"default":"mayúscula A con anillo"}},"category":"Lu"},{"key":"00C7","mappings":{"default":{"default":"mayúscula C cedilla"}},"category":"Lu"},{"key":"00C8","mappings":{"default":{"default":"mayúscula E grave"}},"category":"Lu"},{"key":"00C9","mappings":{"default":{"default":"mayúscula E aguda"}},"category":"Lu"},{"key":"00CA","mappings":{"default":{"default":"mayúscula E acento circunflejo"}},"category":"Lu"},{"key":"00CB","mappings":{"default":{"default":"mayúscula E diéresis"}},"category":"Lu"},{"key":"00CC","mappings":{"default":{"default":"mayúscula I grave"}},"category":"Lu"},{"key":"00CD","mappings":{"default":{"default":"mayúscula I aguda"}},"category":"Lu"},{"key":"00CE","mappings":{"default":{"default":"mayúscula I acento circumflejo"}},"category":"Lu"},{"key":"00CF","mappings":{"default":{"default":"mayúscula I diéresis"}},"category":"Lu"},{"key":"00D1","mappings":{"default":{"default":"mayúscula Ñ"}},"category":"Lu"},{"key":"00D2","mappings":{"default":{"default":"mayúscula O grave"}},"category":"Lu"},{"key":"00D3","mappings":{"default":{"default":"mayúscula O aguda"}},"category":"Lu"},{"key":"00D4","mappings":{"default":{"default":"mayúscula O acento circunflejo"}},"category":"Lu"},{"key":"00D5","mappings":{"default":{"default":"mayúscula O con tilde"}},"category":"Lu"},{"key":"00D6","mappings":{"default":{"default":"mayúscula O diéresis"}},"category":"Lu"},{"key":"00D9","mappings":{"default":{"default":"mayúscula U grave"}},"category":"Lu"},{"key":"00DA","mappings":{"default":{"default":"mayúscula U aguda"}},"category":"Lu"},{"key":"00DB","mappings":{"default":{"default":"mayúscula U acento circunflejo"}},"category":"Lu"},{"key":"00DC","mappings":{"default":{"default":"mayúscula U diéresis"}},"category":"Lu"},{"key":"00DD","mappings":{"default":{"default":"mayúscula Y aguda"}},"category":"Lu"},{"key":"0100","mappings":{"default":{"default":"mayúscula A barra"}},"category":"Lu"},{"key":"0102","mappings":{"default":{"default":"mayúscula A con breve"}},"category":"Lu"},{"key":"0104","mappings":{"default":{"default":"mayúscula A con ogonek"}},"category":"Lu"},{"key":"0106","mappings":{"default":{"default":"mayúscula C con agudo"}},"category":"Lu"},{"key":"0108","mappings":{"default":{"default":"mayúscula C con acento circunflejo"}},"category":"Lu"},{"key":"010A","mappings":{"default":{"default":"mayúscula C con punto arriba"}},"category":"Lu"},{"key":"010C","mappings":{"default":{"default":"mayúscula C con carón"}},"category":"Lu"},{"key":"010E","mappings":{"default":{"default":"mayúscula D con carón"}},"category":"Lu"},{"key":"0112","mappings":{"default":{"default":"mayúscula E barra"}},"category":"Lu"},{"key":"0116","mappings":{"default":{"default":"mayúscula E con punto arriba"}},"category":"Lu"},{"key":"0118","mappings":{"default":{"default":"mayúscula E con ogonek"}},"category":"Lu"},{"key":"011A","mappings":{"default":{"default":"mayúscula E con carón"}},"category":"Lu"},{"key":"011C","mappings":{"default":{"default":"mayúscula G con acento circunflejo"}},"category":"Lu"},{"key":"011E","mappings":{"default":{"default":"mayúscula G con breve"}},"category":"Lu"},{"key":"0120","mappings":{"default":{"default":"mayúscula G con punto arriba"}},"category":"Lu"},{"key":"0122","mappings":{"default":{"default":"mayúscula G con cedilla"}},"category":"Lu"},{"key":"0124","mappings":{"default":{"default":"mayúscula H con acento circunflejo"}},"category":"Lu"},{"key":"0128","mappings":{"default":{"default":"mayúscula I con tilde"}},"category":"Lu"},{"key":"012A","mappings":{"default":{"default":"mayúscula I barra"}},"category":"Lu"},{"key":"012E","mappings":{"default":{"default":"mayúscula I con ogonek"}},"category":"Lu"},{"key":"0130","mappings":{"default":{"default":"mayúscula I con punto arriba"}},"category":"Lu"},{"key":"0134","mappings":{"default":{"default":"mayúscula J con acento circunflejo"}},"category":"Lu"},{"key":"0136","mappings":{"default":{"default":"mayúscula K con cedilla"}},"category":"Lu"},{"key":"0139","mappings":{"default":{"default":"mayúscula L con agudo"}},"category":"Lu"},{"key":"013B","mappings":{"default":{"default":"mayúscula L con cedilla"}},"category":"Lu"},{"key":"013D","mappings":{"default":{"default":"mayúscula L con carón"}},"category":"Lu"},{"key":"013F","mappings":{"default":{"default":"mayúscula L con punto mediano"}},"category":"Lu"},{"key":"0143","mappings":{"default":{"default":"mayúscula N con agudo"}},"category":"Lu"},{"key":"0145","mappings":{"default":{"default":"mayúscula N con cedilla"}},"category":"Lu"},{"key":"0147","mappings":{"default":{"default":"mayúscula n con carón"}},"category":"Lu"},{"key":"014C","mappings":{"default":{"default":"mayúscula O barra"}},"category":"Lu"},{"key":"0150","mappings":{"default":{"default":"mayúscula O con doble acento agudo "}},"category":"Lu"},{"key":"0154","mappings":{"default":{"default":"mayúscula R con agudo"}},"category":"Lu"},{"key":"0156","mappings":{"default":{"default":"mayúscula R con cedilla"}},"category":"Lu"},{"key":"0158","mappings":{"default":{"default":"mayúscula R con carón"}},"category":"Lu"},{"key":"015A","mappings":{"default":{"default":"mayúscula S con agudo"}},"category":"Lu"},{"key":"015C","mappings":{"default":{"default":"mayúscula S con acento circunflejo"}},"category":"Lu"},{"key":"015E","mappings":{"default":{"default":"mayúscula S con cedilla"}},"category":"Lu"},{"key":"0160","mappings":{"default":{"default":"mayúscula S con carón"}},"category":"Lu"},{"key":"0162","mappings":{"default":{"default":"mayúscula T con cedilla"}},"category":"Lu"},{"key":"0164","mappings":{"default":{"default":"mayúscula T con carón"}},"category":"Lu"},{"key":"0168","mappings":{"default":{"default":"mayúscula U con tilde"}},"category":"Lu"},{"key":"016A","mappings":{"default":{"default":"mayúscula U barra"}},"category":"Lu"},{"key":"016C","mappings":{"default":{"default":"mayúscula U con breve"}},"category":"Lu"},{"key":"016E","mappings":{"default":{"default":"mayúscula U con anillo arriba"}},"category":"Lu"},{"key":"0170","mappings":{"default":{"default":"mayúscula U con doble acento agudo"}},"category":"Lu"},{"key":"0172","mappings":{"default":{"default":"mayúscula U con ogonek"}},"category":"Lu"},{"key":"0174","mappings":{"default":{"default":"mayúscula W con acento circunflejo"}},"category":"Lu"},{"key":"0176","mappings":{"default":{"default":"mayúscula Y con circunflejo"}},"category":"Lu"},{"key":"0178","mappings":{"default":{"default":"mayúscula Y diéresis"}},"category":"Lu"},{"key":"0179","mappings":{"default":{"default":"mayúscula Z con agudo"}},"category":"Lu"},{"key":"017B","mappings":{"default":{"default":"mayúscula Z con punto"}},"category":"Lu"},{"key":"017D","mappings":{"default":{"default":"mayúscula Z con carón"}},"category":"Lu"},{"key":"1E00","mappings":{"default":{"default":"mayúscula A con anillo debajo"}},"category":"Lu"},{"key":"1E02","mappings":{"default":{"default":"mayúscula B con punto arriba"}},"category":"Lu"},{"key":"1E04","mappings":{"default":{"default":"mayúscula B con punto debajo"}},"category":"Lu"},{"key":"1E06","mappings":{"default":{"default":"mayúscula B con línea debajo"}},"category":"Lu"},{"key":"1E0A","mappings":{"default":{"default":"mayúscula D con punto arriba"}},"category":"Lu"},{"key":"1E0C","mappings":{"default":{"default":"mayúscula D con punto debajo"}},"category":"Lu"},{"key":"1E0E","mappings":{"default":{"default":"mayúscula D con línea debajo"}},"category":"Lu"},{"key":"1E10","mappings":{"default":{"default":"mayúscula D con cedilla"}},"category":"Lu"},{"key":"1E12","mappings":{"default":{"default":"mayúscula D con acento circunflejo debajo"}},"category":"Lu"},{"key":"1E18","mappings":{"default":{"default":"mayúscula E con acento circunflejo debajo"}},"category":"Lu"},{"key":"1E1A","mappings":{"default":{"default":"mayúscula E con tilde debajo"}},"category":"Lu"},{"key":"1E1E","mappings":{"default":{"default":"mayúscula F con punto arriba"}},"category":"Lu"},{"key":"1E20","mappings":{"default":{"default":"mayúscula G con macrón"}},"category":"Lu"},{"key":"1E22","mappings":{"default":{"default":"mayúscula H con punto arriba"}},"category":"Lu"},{"key":"1E24","mappings":{"default":{"default":"mayúscula H con punto debajo"}},"category":"Lu"},{"key":"1E26","mappings":{"default":{"default":"mayúscula H con diéresis"}},"category":"Lu"},{"key":"1E28","mappings":{"default":{"default":"mayúscula H con cedilla"}},"category":"Lu"},{"key":"1E2A","mappings":{"default":{"default":"mayúscula H con breve debajo"}},"category":"Lu"},{"key":"1E2C","mappings":{"default":{"default":"mayúscula I con tilde debajo"}},"category":"Lu"},{"key":"1E30","mappings":{"default":{"default":"mayúscula K con agudo"}},"category":"Lu"},{"key":"1E32","mappings":{"default":{"default":"mayúscula K con punto debajo"}},"category":"Lu"},{"key":"1E34","mappings":{"default":{"default":"mayúscula K con línea debajo"}},"category":"Lu"},{"key":"1E36","mappings":{"default":{"default":"mayúscula L con punto debajo"}},"category":"Lu"},{"key":"1E3A","mappings":{"default":{"default":"mayúscula L con línea debajo"}},"category":"Lu"},{"key":"1E3C","mappings":{"default":{"default":"mayúscula L con acento circunflejo debajo"}},"category":"Lu"},{"key":"1E3E","mappings":{"default":{"default":"mayúscula M con agudo"}},"category":"Lu"},{"key":"1E40","mappings":{"default":{"default":"mayúscula M con punto arriba"}},"category":"Lu"},{"key":"1E42","mappings":{"default":{"default":"mayúscula M con punto debajo"}},"category":"Lu"},{"key":"1E44","mappings":{"default":{"default":"mayúscula N con punto arriba"}},"category":"Lu"},{"key":"1E46","mappings":{"default":{"default":"mayúscula N con punto debajo"}},"category":"Lu"},{"key":"1E48","mappings":{"default":{"default":"mayúscula N con línea debajo"}},"category":"Lu"},{"key":"1E4A","mappings":{"default":{"default":"mayúscula N con acento circunflejo debajo"}},"category":"Lu"},{"key":"1E54","mappings":{"default":{"default":"mayúscula P con agudo"}},"category":"Lu"},{"key":"1E56","mappings":{"default":{"default":"mayúscula P con punto arriba"}},"category":"Lu"},{"key":"1E58","mappings":{"default":{"default":"mayúscula R con punto arriba"}},"category":"Lu"},{"key":"1E5A","mappings":{"default":{"default":"mayúscula R con punto debajo"}},"category":"Lu"},{"key":"1E5E","mappings":{"default":{"default":"mayúscula R con línea debajo"}},"category":"Lu"},{"key":"1E60","mappings":{"default":{"default":"mayúscula S con punto arriba"}},"category":"Lu"},{"key":"1E62","mappings":{"default":{"default":"mayúscula S con punto debajo"}},"category":"Lu"},{"key":"1E6A","mappings":{"default":{"default":"mayúscula T con punto arriba"}},"category":"Lu"},{"key":"1E6C","mappings":{"default":{"default":"mayúscula T con punto debajo"}},"category":"Lu"},{"key":"1E6E","mappings":{"default":{"default":"mayúscula T con línea debajo"}},"category":"Lu"},{"key":"1E70","mappings":{"default":{"default":"mayúscula T con acento circunflejo debajo"}},"category":"Lu"},{"key":"1E72","mappings":{"default":{"default":"mayúscula U con diéresis debajo"}},"category":"Lu"},{"key":"1E74","mappings":{"default":{"default":"mayúscula U con tilde debajo"}},"category":"Lu"},{"key":"1E76","mappings":{"default":{"default":"mayúscula U con acento circunflejo debajo"}},"category":"Lu"},{"key":"1E7C","mappings":{"default":{"default":"mayúscula V con tilde"}},"category":"Lu"},{"key":"1E7E","mappings":{"default":{"default":"mayúscula V con punto debajo"}},"category":"Lu"},{"key":"1E80","mappings":{"default":{"default":"mayúscula W con grave"}},"category":"Lu"},{"key":"1E82","mappings":{"default":{"default":"mayúscula W con agudo"}},"category":"Lu"},{"key":"1E84","mappings":{"default":{"default":"mayúscula W con diéresis"}},"category":"Lu"},{"key":"1E86","mappings":{"default":{"default":"mayúscula W con punto arriba"}},"category":"Lu"},{"key":"1E88","mappings":{"default":{"default":"mayúscula W con punto debajo"}},"category":"Lu"},{"key":"1E8A","mappings":{"default":{"default":"mayúscula X con punto arriba"}},"category":"Lu"},{"key":"1E8C","mappings":{"default":{"default":"mayúscula X con diéresis"}},"category":"Lu"},{"key":"1E8E","mappings":{"default":{"default":"mayúscula Y con punto arriba"}},"category":"Lu"},{"key":"1E90","mappings":{"default":{"default":"mayúscula Z con acento circunflejo"}},"category":"Lu"},{"key":"1E92","mappings":{"default":{"default":"mayúscula Z con punto debajo"}},"category":"Lu"},{"key":"1E94","mappings":{"default":{"default":"mayúscula Z with line below"}},"category":"Lu"},{"key":"1EA0","mappings":{"default":{"default":"mayúscula A con punto debajo"}},"category":"Lu"},{"key":"1EA2","mappings":{"default":{"default":"mayúscula A con gancho arriba"}},"category":"Lu"},{"key":"1EB8","mappings":{"default":{"default":"mayúscula E con punto debajo"}},"category":"Lu"},{"key":"1EBA","mappings":{"default":{"default":"mayúscula E con gancho arriba"}},"category":"Lu"},{"key":"1EBC","mappings":{"default":{"default":"mayúscula E con tilde"}},"category":"Lu"},{"key":"1EC8","mappings":{"default":{"default":"mayúscula I con gancho arriba"}},"category":"Lu"},{"key":"1ECA","mappings":{"default":{"default":"mayúscula I con punto debajo"}},"category":"Lu"},{"key":"1ECC","mappings":{"default":{"default":"mayúscula O con punto debajo"}},"category":"Lu"},{"key":"1ECE","mappings":{"default":{"default":"mayúscula O con gancho arriba"}},"category":"Lu"},{"key":"1EE4","mappings":{"default":{"default":"mayúscula U con punto debajo"}},"category":"Lu"},{"key":"1EE6","mappings":{"default":{"default":"mayúscula U con gancho arriba"}},"category":"Lu"},{"key":"1EF2","mappings":{"default":{"default":"mayúscula Y con grave"}},"category":"Lu"},{"key":"1EF4","mappings":{"default":{"default":"mayúscula Y con punto debajo"}},"category":"Lu"},{"key":"1EF6","mappings":{"default":{"default":"mayúscula Y con gancho arriba"}},"category":"Lu"},{"key":"1EF8","mappings":{"default":{"default":"mayúscula Y con tilde"}},"category":"Lu"}]
,
"es/math_angles.js": 
[{"locale":"es"},{"key":"22BE","mappings":{"default":{"default":"ángulo recto con arco"}},"category":"Sm"},{"key":"237C","mappings":{"default":{"default":"ángulo recto con flecha zigzag hacia abajo"}},"category":"Sm"},{"key":"27C0","mappings":{"default":{"default":"ángulo sólido"}},"category":"Sm"},{"key":"299D","mappings":{"default":{"default":"ángulo recto medido con punto"}},"category":"Sm"},{"key":"29A4","mappings":{"default":{"default":"ángulo con barra inferior"}},"category":"Sm"},{"key":"29A5","mappings":{"default":{"default":"ángulo inverso con barra inferior"}},"category":"Sm"},{"key":"29A6","mappings":{"default":{"default":"ángulo oblicuo hacia arriba"}},"category":"Sm"},{"key":"29A7","mappings":{"default":{"default":"ángulo oblicuo hacia abajo"}},"category":"Sm"},{"key":"29A8","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing up and to the right"}},"category":"Sm"},{"key":"29A9","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing up and to the left"}},"category":"Sm"},{"key":"29AA","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing down and to the right"}},"category":"Sm"},{"key":"29AB","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing down and to the left"}},"category":"Sm"},{"key":"29AC","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing right and up"}},"category":"Sm"},{"key":"29AD","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing left and up"}},"category":"Sm"},{"key":"29AE","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing right and down"}},"category":"Sm"},{"key":"29AF","mappings":{"default":{"default":"measured angle with open arm ending in arrow pointing left and down"}},"category":"Sm"}]
,
"es/math_arrows.js": 
[{"locale":"es"},{"key":"2190","mappings":{"default":{"default":"flecha izquierda"}},"category":"Sm"},{"key":"2191","mappings":{"default":{"default":"flecha arriba"}},"category":"Sm"},{"key":"2192","mappings":{"default":{"default":"flecha derecha","defaultMP":"flecha"}},"category":"Sm"},{"key":"2193","mappings":{"default":{"default":"flecha abajo"}},"category":"Sm"},{"key":"2194","mappings":{"default":{"default":"flecha izquierda y derecha"}},"category":"Sm"},{"key":"2195","mappings":{"default":{"default":"flecha arriba y abajo"}},"category":"So"},{"key":"2196","mappings":{"default":{"default":"flecha a noroeste"}},"category":"So"},{"key":"2197","mappings":{"default":{"default":"flecha a nordeste"}},"category":"So"},{"key":"2198","mappings":{"default":{"default":"flecha a sureste"}},"category":"So"},{"key":"2199","mappings":{"default":{"default":"flecha a suroeste"}},"category":"So"},{"key":"219A","mappings":{"default":{"default":"flecha izquierda tachada"}},"category":"Sm"},{"key":"219B","mappings":{"default":{"default":"flecha tachada"}},"category":"Sm"},{"key":"219C","mappings":{"default":{"default":"flecha ondulada izquierda"}},"category":"So"},{"key":"219D","mappings":{"default":{"default":"flecha ondulada"}},"category":"So"},{"key":"219E","mappings":{"default":{"default":"flecha izquierda con doble punta"}},"category":"So"},{"key":"219F","mappings":{"default":{"default":"flecha con doble punta hacia arriba"}},"category":"So"},{"key":"21A0","mappings":{"default":{"default":"flecha derechaa con doble punta"}},"category":"Sm"},{"key":"21A1","mappings":{"default":{"default":"flecha con doble punta hacia abajo"}},"category":"So"},{"key":"21A2","mappings":{"default":{"default":"flecha izquierda con cola"}},"category":"So"},{"key":"21A3","mappings":{"default":{"default":"flecha derecha con cola"}},"category":"Sm"},{"key":"21A4","mappings":{"default":{"default":"flecha izquierda de barra"}},"category":"So"},{"key":"21A5","mappings":{"default":{"default":"barra con flecha"}},"category":"So"},{"key":"21A6","mappings":{"default":{"default":"flecha derecha de barra"}},"category":"Sm"},{"key":"21A7","mappings":{"default":{"default":"flecha con barra"}},"category":"So"},{"key":"21A8","mappings":{"default":{"default":"flecha arriba y abajo con base"}},"category":"So"},{"key":"21A9","mappings":{"default":{"default":"flecha izquierda con gancho"}},"category":"So"},{"key":"21AA","mappings":{"default":{"default":"flecha con gancho"}},"category":"So"},{"key":"21AB","mappings":{"default":{"default":"flecha izquierda con lazo"}},"category":"So"},{"key":"21AC","mappings":{"default":{"default":"flecha con lazo"}},"category":"So"},{"key":"21AD","mappings":{"default":{"default":"flecha ondulada izquierda y derecha"}},"category":"So"},{"key":"21AE","mappings":{"default":{"default":"flecha izquierda y derecha tachada"}},"category":"Sm"},{"key":"21AF","mappings":{"default":{"default":"flecha zigzag abajo"}},"category":"So"},{"key":"21B0","mappings":{"default":{"default":"flecha arriba con punta izquierda"}},"category":"So"},{"key":"21B1","mappings":{"default":{"default":"flecha arriba con punta derecha"}},"category":"So"},{"key":"21B2","mappings":{"default":{"default":"flecha abajo con punta izquierda"}},"category":"So"},{"key":"21B3","mappings":{"default":{"default":"flecha abajo con punta derecha"}},"category":"So"},{"key":"21B4","mappings":{"default":{"default":"flecha derecha desde esquina inferior"}},"category":"So"},{"key":"21B5","mappings":{"default":{"default":"flecha hacia abajo desde esquina izquierda"}},"category":"So"},{"key":"21B6","mappings":{"default":{"default":"flecha semicircular superior en sentido antihorario"}},"category":"So"},{"key":"21B7","mappings":{"default":{"default":"flecha semicircular superior en sentido horario"}},"category":"So"},{"key":"21B8","mappings":{"default":{"default":"flecha noroeste a barra larga"}},"category":"So"},{"key":"21B9","mappings":{"default":{"default":"flecha izquierda a barra arriba de flecha derecha a barra"}},"category":"So"},{"key":"21BA","mappings":{"default":{"default":"flecha circular abierta en sentido antihorario"}},"category":"So"},{"key":"21BB","mappings":{"default":{"default":"flecha circular abierta en sentido horario"}},"category":"So"},{"key":"21C4","mappings":{"default":{"default":"flecha derecha arriba de flecha izquierda"}},"category":"So"},{"key":"21C5","mappings":{"default":{"default":"flecha arriba a la izquierda de flecha abajo"}},"category":"So"},{"key":"21C6","mappings":{"default":{"default":"flecha izquierda arriba de flecha derecha"}},"category":"So"},{"key":"21C7","mappings":{"default":{"default":"dos flechas hacia la izquierda"}},"category":"So"},{"key":"21C8","mappings":{"default":{"default":"dos flechas hacia arriba"}},"category":"So"},{"key":"21C9","mappings":{"default":{"default":"dos flechas"}},"category":"So"},{"key":"21CA","mappings":{"default":{"default":"dos flechas hacia abajo"}},"category":"So"},{"key":"21CD","mappings":{"default":{"default":"flecha doble izquierda tachada"}},"category":"So"},{"key":"21CE","mappings":{"default":{"default":"flecha doble izquierda y derecha tachada"}},"category":"Sm"},{"key":"21CF","mappings":{"default":{"default":"flecha doble tachada"}},"category":"Sm"},{"key":"21D0","mappings":{"default":{"default":"flecha doble hacia la izquierda"}},"category":"So"},{"key":"21D1","mappings":{"default":{"default":"flecha doble hacia arriba"}},"category":"So"},{"key":"21D2","mappings":{"default":{"default":"flecha doble"}},"category":"Sm"},{"key":"21D3","mappings":{"default":{"default":"flecha doble hacia abajo"}},"category":"So"},{"key":"21D4","mappings":{"default":{"default":"flecha doble izquierda-derecha"}},"category":"Sm"},{"key":"21D5","mappings":{"default":{"default":"flecha doble vertical"}},"category":"So"},{"key":"21D6","mappings":{"default":{"default":"flecha doble hacia noroeste"}},"category":"So"},{"key":"21D7","mappings":{"default":{"default":"flecha doble hacia nordeste"}},"category":"So"},{"key":"21D8","mappings":{"default":{"default":"flecha doble hacia sudeste"}},"category":"So"},{"key":"21D9","mappings":{"default":{"default":"flecha doble hacia sudoeste"}},"category":"So"},{"key":"21DA","mappings":{"default":{"default":"flecha triple izquierda"}},"category":"So"},{"key":"21DB","mappings":{"default":{"default":"flecha triple"}},"category":"So"},{"key":"21DC","mappings":{"default":{"default":"flecha ondulada izquierda"}},"category":"So"},{"key":"21DD","mappings":{"default":{"default":"flecha ondulada"}},"category":"So"},{"key":"21DE","mappings":{"default":{"default":"flecha hacia arriba con doble tachado"}},"category":"So"},{"key":"21DF","mappings":{"default":{"default":"flecha hacia abajo con doble tachado"}},"category":"So"},{"key":"21E0","mappings":{"default":{"default":"flecha de puntos hacia la izquierda"}},"category":"So"},{"key":"21E1","mappings":{"default":{"default":"flecha de puntos hacia arriba"}},"category":"So"},{"key":"21E2","mappings":{"default":{"default":"flecha de puntos"}},"category":"So"},{"key":"21E3","mappings":{"default":{"default":"flecha de puntos hacia abajo"}},"category":"So"},{"key":"21E4","mappings":{"default":{"default":"flecha izquierda a barra"}},"category":"So"},{"key":"21E5","mappings":{"default":{"default":"flecha derecha a barra"}},"category":"So"},{"key":"21E6","mappings":{"default":{"default":"flecha vacía hacia la izquierda"}},"category":"So"},{"key":"21E7","mappings":{"default":{"default":"flecha vacía hacia arriba"}},"category":"So"},{"key":"21E8","mappings":{"default":{"default":"flecha vacía"}},"category":"So"},{"key":"21E9","mappings":{"default":{"default":"flecha vacía hacia abajo"}},"category":"So"},{"key":"21EA","mappings":{"default":{"default":"flecha vacía hacia arriba desde barra"}},"category":"So"},{"key":"21F5","mappings":{"default":{"default":"upwards arrow to the right of downwards arrow"}},"category":"Sm"},{"key":"21FD","mappings":{"default":{"default":"flecha izquierda con punta vacía"}},"category":"Sm"},{"key":"21FE","mappings":{"default":{"default":"flecha izquierda con punta vacía"}},"category":"Sm"},{"key":"21FF","mappings":{"default":{"default":"flecha izquierda derecha con punta vacía"}},"category":"Sm"},{"key":"27F0","mappings":{"default":{"default":"flecha cuádruple hacia arriba"}},"category":"Sm"},{"key":"27F1","mappings":{"default":{"default":"flecha cuádruple hacia abajo"}},"category":"Sm"},{"key":"27F2","mappings":{"default":{"default":"flecha hacia la izquierda desde círculo"}},"category":"Sm"},{"key":"27F3","mappings":{"default":{"default":"flecha hacia la derecha desde círculo"}},"category":"Sm"},{"key":"27F4","mappings":{"default":{"default":"flecha con más en círculo"}},"category":"Sm"},{"key":"27F5","mappings":{"default":{"default":"flecha larga hacia la izquierda"}},"category":"Sm"},{"key":"27F6","mappings":{"default":{"default":"flecha larga"}},"category":"Sm"},{"key":"27F7","mappings":{"default":{"default":"flecha larga hacia izquierda y derecha"}},"category":"Sm"},{"key":"27F8","mappings":{"default":{"default":"doble flecha larga hacia la izquierda"}},"category":"Sm"},{"key":"27F9","mappings":{"default":{"default":"doble flecha larga"}},"category":"Sm"},{"key":"27FA","mappings":{"default":{"default":"doble flecha larga hacia izquierda y derecha"}},"category":"Sm"},{"key":"27FB","mappings":{"default":{"default":"flecha larga hacia la izquierda, desde barra"}},"category":"Sm"},{"key":"27FC","mappings":{"default":{"default":"flecha larga desde barra"}},"category":"Sm"},{"key":"27FD","mappings":{"default":{"default":"doble flecha larga hacia la izquierda desde barra"}},"category":"Sm"},{"key":"27FE","mappings":{"default":{"default":"doble flecha larga desde barra"}},"category":"Sm"},{"key":"27FF","mappings":{"default":{"default":"flecha larga en zigzag"}},"category":"Sm"},{"key":"2905","mappings":{"default":{"default":"rightwards two headed arrow from bar"}},"category":"Sm"},{"key":"290C","mappings":{"default":{"default":"leftwards double dash arrow"}},"category":"Sm"},{"key":"290D","mappings":{"default":{"default":"rightwards double dash arrow"}},"category":"Sm"},{"key":"290E","mappings":{"default":{"default":"leftwards triple dash arrow"}},"category":"Sm"},{"key":"290F","mappings":{"default":{"default":"rightwards triple dash arrow"}},"category":"Sm"},{"key":"2910","mappings":{"default":{"default":"rightwards two headed triple dash arrow"}},"category":"Sm"},{"key":"2911","mappings":{"default":{"default":"rightwards arrow with dotted stem"}},"category":"Sm"},{"key":"2912","mappings":{"default":{"default":"upwards arrow to bar"}},"category":"Sm"},{"key":"2913","mappings":{"default":{"default":"downwards arrow to bar"}},"category":"Sm"},{"key":"2916","mappings":{"default":{"default":"rightwards two headed arrow with tail"}},"category":"Sm"},{"key":"2919","mappings":{"default":{"default":"cola de flecha hacia la izquierda"}},"category":"Sm"},{"key":"291B","mappings":{"default":{"default":"cola de doble flecha hacia la izquierda"}},"category":"Sm"},{"key":"291C","mappings":{"default":{"default":"cola de doble flecha hacia la derecha"}},"category":"Sm"},{"key":"291D","mappings":{"default":{"default":"flecha hacia diamante relleno a la izquierda"}},"category":"Sm"},{"key":"291E","mappings":{"default":{"default":"flecha hacia diamante a la derecha"}},"category":"Sm"},{"key":"291F","mappings":{"default":{"default":"flecha desde barra hacia diamante a la izquierda"}},"category":"Sm"},{"key":"2920","mappings":{"default":{"default":"flecha desde barra hacia diamante a la derecha"}},"category":"Sm"},{"key":"2923","mappings":{"default":{"default":"flecha a noroeste con garfio"}},"category":"Sm"},{"key":"2924","mappings":{"default":{"default":"flecha a nordeste con garfio"}},"category":"Sm"},{"key":"2925","mappings":{"default":{"default":"flecha a sureste con garfio"}},"category":"Sm"},{"key":"2926","mappings":{"default":{"default":"flecha a suroeste con garfio"}},"category":"Sm"},{"key":"2927","mappings":{"default":{"default":"flechas a noroeste y nordeste"}},"category":"Sm"},{"key":"2928","mappings":{"default":{"default":"flechas a nordeste y sudeste"}},"category":"Sm"},{"key":"2929","mappings":{"default":{"default":"flechas a suddeste y sudoeste"}},"category":"Sm"},{"key":"292A","mappings":{"default":{"default":"flechas a sudoeste y noroeste"}},"category":"Sm"},{"key":"2933","mappings":{"default":{"default":"flecha ondulada"}},"category":"Sm"},{"key":"2935","mappings":{"default":{"default":"flecha hacia la derecha que gira hacia abajo"}},"category":"Sm"},{"key":"2936","mappings":{"default":{"default":"flecha hacia abajo que gira hacia la izquierda"}},"category":"Sm"},{"key":"2937","mappings":{"default":{"default":"flecha hacia abajo que gira hacia la derecha"}},"category":"Sm"},{"key":"2938","mappings":{"default":{"default":"flecha semicircular a la derecha en sentido horario"}},"category":"Sm"},{"key":"2939","mappings":{"default":{"default":"flecha semicircular a la izquierda en sentido antihorario"}},"category":"Sm"},{"key":"293C","mappings":{"default":{"default":"giro negativo"}},"category":"Sm"},{"key":"293D","mappings":{"default":{"default":"giro positivo"}},"category":"Sm"},{"key":"2945","mappings":{"default":{"default":"flecha con más suscrito"}},"category":"Sm"},{"key":"2948","mappings":{"default":{"default":"flecha hacia la izquierda a través de círculo"}},"category":"Sm"},{"key":"2949","mappings":{"default":{"default":"dos cabezas de flecha hacia arriba desde círculo"}},"category":"Sm"},{"key":"2970","mappings":{"default":{"default":"round implies"}},"category":"Sm"},{"key":"2971","mappings":{"default":{"default":"flecha con igual"}},"category":"Sm"},{"key":"2972","mappings":{"default":{"default":"flecha con tilde"}},"category":"Sm"},{"key":"2973","mappings":{"default":{"default":"tilde con flecha hacia la izquierda"}},"category":"Sm"},{"key":"2974","mappings":{"default":{"default":"tilde con flecha"}},"category":"Sm"},{"key":"2975","mappings":{"default":{"default":"flecha con casi igual a"}},"category":"Sm"},{"key":"2976","mappings":{"default":{"default":"flecha hacia la izquierda con menor que"}},"category":"Sm"},{"key":"2978","mappings":{"default":{"default":"flecha con mayor que"}},"category":"Sm"},{"key":"2979","mappings":{"default":{"default":"flecha hacia la izquierda con incluido"}},"category":"Sm"},{"key":"297B","mappings":{"default":{"default":"flecha hacia la izquierda con contiene"}},"category":"Sm"},{"key":"29B3","mappings":{"default":{"default":"conjunto vacío con flecha"}},"category":"Sm"},{"key":"29B4","mappings":{"default":{"default":"conjunto vacío con flecha inversa"}},"category":"Sm"},{"key":"2A17","mappings":{"default":{"default":"integral con flecha hacia la izquierda con garfio"}},"category":"Sm"}]
,
"es/math_characters.js": 
[{"locale":"es"},{"key":"2113","mappings":{"default":{"default":"script l"}},"category":"Ll"},{"key":"2118","mappings":{"default":{"default":"p de weierstrass"}},"category":"Sm"},{"key":"2145","mappings":{"default":{"default":"mayúscula D"}},"category":"Lu"},{"key":"2146","mappings":{"default":{"default":"d"}},"category":"Ll"},{"key":"2147","mappings":{"default":{"default":"e"}},"category":"Ll"},{"key":"2148","mappings":{"default":{"default":"i"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"cursiva dotless i"}},"key":"1D6A4"},{"category":"Ll","mappings":{"default":{"default":"cursiva dotless j"}},"key":"1D6A5"}]
,
"es/math_delimiters.js": 
[{"locale":"es"},{"key":"0028","mappings":{"default":{"default":"paréntesis izquierdo","defaultMP":"paréntesis"}},"category":"Ps"},{"key":"0029","mappings":{"default":{"default":"paréntesis derecho","defaultMP":"cierra paréntesis"}},"category":"Pe"},{"key":"005B","mappings":{"default":{"default":"corchete izquierdo","defaultMP":"abre corchetes"}},"category":"Ps"},{"key":"005D","mappings":{"default":{"default":"corchete derecho","defaultMP":"cierra corchetes"}},"category":"Pe"},{"key":"007B","mappings":{"default":{"default":"llave izquierda","defaultMP":"abre llaves"}},"category":"Ps"},{"key":"007D","mappings":{"default":{"default":"llaves derecha","defaultMP":"cierra llaves"}},"category":"Pe"},{"key":"2308","mappings":{"default":{"default":"esquina superior izquierda"}},"category":"Sm"},{"key":"2309","mappings":{"default":{"default":"esquina superior derecha"}},"category":"Sm"},{"key":"230A","mappings":{"default":{"default":"esquina inferior izquierda"}},"category":"Sm"},{"key":"230B","mappings":{"default":{"default":"esquina inferior derecha"}},"category":"Sm"},{"key":"230C","mappings":{"default":{"default":"corte inferior derecho"}},"category":"So"},{"key":"230D","mappings":{"default":{"default":"corte inferior izquierdo"}},"category":"So"},{"key":"230E","mappings":{"default":{"default":"corte superior derecho "}},"category":"So"},{"key":"230F","mappings":{"default":{"default":"corte superior izquierdo"}},"category":"So"},{"key":"231C","mappings":{"default":{"default":"ángulo superior izquierdo"}},"category":"So"},{"key":"231D","mappings":{"default":{"default":"ángulo superior derecho"}},"category":"So"},{"key":"231E","mappings":{"default":{"default":"ángulo inferior izquierdo"}},"category":"So"},{"key":"231F","mappings":{"default":{"default":"ángulo inferior derecho"}},"category":"So"},{"key":"2320","mappings":{"default":{"default":"mitad superior de integral"}},"category":"Sm"},{"key":"2321","mappings":{"default":{"default":"mitad inferior de integral"}},"category":"Sm"},{"key":"2329","mappings":{"default":{"default":"paréntesis angular izquierdo"}},"category":"Ps"},{"key":"232A","mappings":{"default":{"default":"paréntesis angular derecho"}},"category":"Pe"},{"key":"23B0","mappings":{"default":{"default":"izquierda arriba o derecho debajo sección llave"}},"category":"Sm"},{"key":"23B1","mappings":{"default":{"default":"derecha arriba o izquierdo debajo sección llave"}},"category":"Sm"},{"key":"23B4","mappings":{"default":{"default":"corchete superior"}},"category":"So"},{"key":"23B5","mappings":{"default":{"default":"corchete inferior"}},"category":"So"},{"key":"23DC","mappings":{"default":{"default":"paréntesis superior"}},"category":"Sm"},{"key":"23DD","mappings":{"default":{"default":"paréntesis inferior"}},"category":"Sm"},{"key":"23DE","mappings":{"default":{"default":"corchete rizado superior"}},"category":"Sm"},{"key":"23DF","mappings":{"default":{"default":"corchete rizado inferior"}},"category":"Sm"},{"key":"23E0","mappings":{"default":{"default":"corchete superior en tortuga"}},"category":"Sm"},{"key":"23E1","mappings":{"default":{"default":"corchete inferior en tortuga"}},"category":"Sm"},{"key":"27C5","mappings":{"default":{"default":"símbolo delimitador izquierdo de bolsa de s-formó"}},"category":"Ps"},{"key":"27C6","mappings":{"default":{"default":"símbolo delimitador derecho de bolsa de s-formó"}},"category":"Pe"},{"key":"27E6","mappings":{"default":{"default":"corchete vacío izquierdo"}},"category":"Ps"},{"key":"27E7","mappings":{"default":{"default":"corchete vacío derecho"}},"category":"Pe"},{"key":"27E8","mappings":{"default":{"default":"corchete agudo izquierdo"}},"category":"Ps"},{"key":"27E9","mappings":{"default":{"default":"corchete agudo derecho"}},"category":"Pe"},{"key":"27EA","mappings":{"default":{"default":"doble corchete agudo izquierdo"}},"category":"Ps"},{"key":"27EB","mappings":{"default":{"default":"doble corchete agudo derecho"}},"category":"Pe"},{"key":"27EC","mappings":{"default":{"default":"corchete de tortuga vacío izquierdo"}},"category":"Ps"},{"key":"27ED","mappings":{"default":{"default":"corchete de tortuga vacío derecho "}},"category":"Pe"},{"key":"27EE","mappings":{"default":{"default":"paréntesis plano izquierdo"}},"category":"Ps"},{"key":"27EF","mappings":{"default":{"default":"paréntesis plano derecho"}},"category":"Pe"},{"key":"2985","mappings":{"default":{"default":"left white paren"}},"category":"Ps"},{"key":"2986","mappings":{"default":{"default":"right white paren"}},"category":"Pe"},{"key":"2989","mappings":{"default":{"default":"z notation left binding bracket"}},"category":"Ps"},{"key":"298A","mappings":{"default":{"default":"z notation right binding bracket"}},"category":"Pe"},{"key":"298B","mappings":{"default":{"default":"left bracket with underbar"}},"category":"Ps"},{"key":"298C","mappings":{"default":{"default":"right bracket with underbar"}},"category":"Pe"},{"key":"298D","mappings":{"default":{"default":"left bracket with tick in top corner"}},"category":"Ps"},{"key":"298E","mappings":{"default":{"default":"right bracket with tick in bottom corner"}},"category":"Pe"},{"key":"298F","mappings":{"default":{"default":"left bracket with tick in bottom corner"}},"category":"Ps"},{"key":"2990","mappings":{"default":{"default":"right bracket with tick in top corner"}},"category":"Pe"},{"key":"2991","mappings":{"default":{"default":"left angle bracket with dot"}},"category":"Ps"},{"key":"2992","mappings":{"default":{"default":"right angle bracket with dot"}},"category":"Pe"},{"key":"2993","mappings":{"default":{"default":"left arc less than bracket"}},"category":"Ps"},{"key":"2994","mappings":{"default":{"default":"right arc greater than bracket"}},"category":"Pe"},{"key":"2995","mappings":{"default":{"default":"double left arc greater than bracket"}},"category":"Ps"},{"key":"2996","mappings":{"default":{"default":"double right arc less than bracket"}},"category":"Pe"},{"key":"29DA","mappings":{"default":{"default":"left double wiggly fence"}},"category":"Ps"},{"key":"29DB","mappings":{"default":{"default":"right double wiggly fence"}},"category":"Pe"},{"key":"300A","mappings":{"default":{"default":"paréntesis angular doble"}},"category":"Ps"},{"key":"300B","mappings":{"default":{"default":"paréntesis angular doble derecho","defaultMP":"cierra paréntesis angular doble"}},"category":"Pe"},{"key":"3014","mappings":{"default":{"default":"left tortoise shell bracket"}},"category":"Ps"},{"key":"3015","mappings":{"default":{"default":"right tortoise shell bracket"}},"category":"Pe"},{"key":"301A","mappings":{"default":{"default":"corchete vacío"}},"category":"Ps"},{"key":"301B","mappings":{"default":{"default":"corchete vacío derecho","defaultMP":"cierra corchete vacío"}},"category":"Pe"},{"key":"301E","mappings":{"default":{"default":"segunda"}},"category":"Pe"},{"key":"FE35","mappings":{"default":{"default":"paréntesis superior"}},"category":"Ps"},{"key":"FE36","mappings":{"default":{"default":"paréntesis inferior"}},"category":"Pe"},{"key":"FE37","mappings":{"default":{"default":"llave superior"}},"category":"Ps"},{"key":"FE38","mappings":{"default":{"default":"llave inferior"}},"category":"Pe"},{"key":"FE3F","mappings":{"default":{"default":"paréntesis angular superior"}},"category":"Ps"},{"key":"FE40","mappings":{"default":{"default":"paréntesis angular inferior"}},"category":"Pe"}]
,
"es/math_digits.js": 
[{"locale":"es"},{"key":"00B2","mappings":{"default":{"default":"super 2"}},"category":"No"},{"key":"00B3","mappings":{"default":{"default":"super 3"}},"category":"No"},{"key":"00B9","mappings":{"default":{"default":"super 1"}},"category":"No"},{"key":"00BC","mappings":{"default":{"default":"un cuarto"}},"category":"No"},{"key":"00BD","mappings":{"default":{"default":"un medio"}},"category":"No"},{"key":"00BE","mappings":{"default":{"default":"tres cuartos"}},"category":"No"},{"key":"2153","mappings":{"default":{"default":"un tercio"}},"category":"No"},{"key":"2154","mappings":{"default":{"default":"dos tercios"}},"category":"No"},{"key":"2155","mappings":{"default":{"default":"un quinto"}},"category":"No"},{"key":"2156","mappings":{"default":{"default":"dos quintos"}},"category":"No"},{"key":"2157","mappings":{"default":{"default":"tres quintos"}},"category":"No"},{"key":"2158","mappings":{"default":{"default":"cuatro quintos"}},"category":"No"},{"key":"2159","mappings":{"default":{"default":"un sexto"}},"category":"No"},{"key":"215A","mappings":{"default":{"default":"cinco sextos"}},"category":"No"},{"key":"215B","mappings":{"default":{"default":"un octavo"}},"category":"No"},{"key":"215C","mappings":{"default":{"default":"tres octavos"}},"category":"No"},{"key":"215D","mappings":{"default":{"default":"cinco octavos"}},"category":"No"},{"key":"215E","mappings":{"default":{"default":"siete octavos"}},"category":"No"},{"category":"Nd","mappings":{"default":{"default":"negrita 0"}},"key":"1D7CE"},{"category":"Nd","mappings":{"default":{"default":"negrita 1"}},"key":"1D7CF"},{"category":"Nd","mappings":{"default":{"default":"negrita 2"}},"key":"1D7D0"},{"category":"Nd","mappings":{"default":{"default":"negrita 3"}},"key":"1D7D1"},{"category":"Nd","mappings":{"default":{"default":"negrita 4"}},"key":"1D7D2"},{"category":"Nd","mappings":{"default":{"default":"negrita 5"}},"key":"1D7D3"},{"category":"Nd","mappings":{"default":{"default":"negrita 6"}},"key":"1D7D4"},{"category":"Nd","mappings":{"default":{"default":"negrita 7"}},"key":"1D7D5"},{"category":"Nd","mappings":{"default":{"default":"negrita 8"}},"key":"1D7D6"},{"category":"Nd","mappings":{"default":{"default":"negrita 9"}},"key":"1D7D7"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 0"}},"key":"1D7D8"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 1"}},"key":"1D7D9"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 2"}},"key":"1D7DA"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 3"}},"key":"1D7DB"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 4"}},"key":"1D7DC"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 5"}},"key":"1D7DD"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 6"}},"key":"1D7DE"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 7"}},"key":"1D7DF"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 8"}},"key":"1D7E0"},{"category":"Nd","mappings":{"default":{"default":"negrita de pizarra 9"}},"key":"1D7E1"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 0"}},"key":"1D7E2"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 1"}},"key":"1D7E3"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 2"}},"key":"1D7E4"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 3"}},"key":"1D7E5"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 4"}},"key":"1D7E6"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 5"}},"key":"1D7E7"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 6"}},"key":"1D7E8"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 7"}},"key":"1D7E9"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 8"}},"key":"1D7EA"},{"category":"Nd","mappings":{"default":{"default":"sans-serif 9"}},"key":"1D7EB"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 0"}},"key":"1D7EC"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 1"}},"key":"1D7ED"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 2"}},"key":"1D7EE"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 3"}},"key":"1D7EF"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 4"}},"key":"1D7F0"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 5"}},"key":"1D7F1"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 6"}},"key":"1D7F2"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 7"}},"key":"1D7F3"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 8"}},"key":"1D7F4"},{"category":"Nd","mappings":{"default":{"default":"sans-serif negrita 9"}},"key":"1D7F5"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 0"}},"key":"1D7F6"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 1"}},"key":"1D7F7"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 2"}},"key":"1D7F8"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 3"}},"key":"1D7F9"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 4"}},"key":"1D7FA"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 5"}},"key":"1D7FB"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 6"}},"key":"1D7FC"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 7"}},"key":"1D7FD"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 8"}},"key":"1D7FE"},{"category":"Nd","mappings":{"default":{"default":"monoespacio 9"}},"key":"1D7FF"},{"category":"No","mappings":{"default":{"default":"0 punto"}},"key":"1F100"},{"category":"No","mappings":{"default":{"default":"0 coma"}},"key":"1F101"},{"category":"No","mappings":{"default":{"default":"1 coma"}},"key":"1F102"},{"category":"No","mappings":{"default":{"default":"2 coma"}},"key":"1F103"},{"category":"No","mappings":{"default":{"default":"3 coma"}},"key":"1F104"},{"category":"No","mappings":{"default":{"default":"4 coma"}},"key":"1F105"},{"category":"No","mappings":{"default":{"default":"5 coma"}},"key":"1F106"},{"category":"No","mappings":{"default":{"default":"6 coma"}},"key":"1F107"},{"category":"No","mappings":{"default":{"default":"7 coma"}},"key":"1F108"},{"category":"No","mappings":{"default":{"default":"8 coma"}},"key":"1F109"},{"category":"No","mappings":{"default":{"default":"9 coma"}},"key":"1F10A"}]
,
"es/math_geometry.js": 
[{"locale":"es"},{"key":"2500","mappings":{"default":{"default":"delimitador horizontal"}},"category":"So"},{"key":"2502","mappings":{"default":{"default":"delimitador vertical"}},"category":"So"},{"key":"250C","mappings":{"default":{"default":"esquina inferior derecha"}},"category":"So"},{"key":"2510","mappings":{"default":{"default":"esquina inferior izquierda"}},"category":"So"},{"key":"2514","mappings":{"default":{"default":"esquina superior derecha"}},"category":"So"},{"key":"2518","mappings":{"default":{"default":"esquina superior izquierda"}},"category":"So"},{"key":"251C","mappings":{"default":{"default":"delimitador izquierdo y separador horizontal"}},"category":"So"},{"key":"2524","mappings":{"default":{"default":"delimitador derecho y separador horizontal"}},"category":"So"},{"key":"252C","mappings":{"default":{"default":"delimitador superior y separador vertical"}},"category":"So"},{"key":"2534","mappings":{"default":{"default":"delimitador inferior y separador vertical"}},"category":"So"},{"key":"253C","mappings":{"default":{"default":"cruce de separadores sencillos"}},"category":"So"},{"key":"2550","mappings":{"default":{"default":"delimitador horizontal doble"}},"category":"So"},{"key":"2551","mappings":{"default":{"default":"delimitador vertical doble"}},"category":"So"},{"key":"2552","mappings":{"default":{"default":"esquina inferior derecha, vertical doble"}},"category":"So"},{"key":"2553","mappings":{"default":{"default":"esquina inferior derecha, horizontal doble"}},"category":"So"},{"key":"2554","mappings":{"default":{"default":"esquina inferior derecha doble"}},"category":"So"},{"key":"2555","mappings":{"default":{"default":"esquina inferior izquierda, vertical doble"}},"category":"So"},{"key":"2556","mappings":{"default":{"default":"esquina inferior izquierda, horizontal doble"}},"category":"So"},{"key":"2557","mappings":{"default":{"default":"esquina inferior izquierda doble"}},"category":"So"},{"key":"2558","mappings":{"default":{"default":"esquina superior derecha, vertical doble"}},"category":"So"},{"key":"2559","mappings":{"default":{"default":"esquina superior derecha, horizontal doble"}},"category":"So"},{"key":"255A","mappings":{"default":{"default":"esquina superior derecha doble"}},"category":"So"},{"key":"255B","mappings":{"default":{"default":"esquina superior izquierda, vertical doble"}},"category":"So"},{"key":"255C","mappings":{"default":{"default":"esquina superior izquierda, horizontal doble"}},"category":"So"},{"key":"255D","mappings":{"default":{"default":"esquina superior izquierda doble"}},"category":"So"},{"key":"255E","mappings":{"default":{"default":"delimitador izquierdo con separador doble"}},"category":"So"},{"key":"255F","mappings":{"default":{"default":"delimitador izquierdo doble con separador horizontal"}},"category":"So"},{"key":"2560","mappings":{"default":{"default":"delimitador izquierdo y separador horizontal dobles"}},"category":"So"},{"key":"2561","mappings":{"default":{"default":"delimitador derecho con separador doble"}},"category":"So"},{"key":"2562","mappings":{"default":{"default":"delimitador derecho doble con separador horizontal"}},"category":"So"},{"key":"2563","mappings":{"default":{"default":"delimitador derecho y separador horizontal dobles"}},"category":"So"},{"key":"2564","mappings":{"default":{"default":"delimitador superior doble con separador vertical"}},"category":"So"},{"key":"2565","mappings":{"default":{"default":"delimitador superior con separador vertical doble"}},"category":"So"},{"key":"2566","mappings":{"default":{"default":"delimitador superior y separador vertical dobles"}},"category":"So"},{"key":"2567","mappings":{"default":{"default":"delimitador inferior doble con separador vertical"}},"category":"So"},{"key":"2568","mappings":{"default":{"default":"delimitador inferior con separador vertical doble"}},"category":"So"},{"key":"2569","mappings":{"default":{"default":"delimitador inferior y separador vertical dobles"}},"category":"So"},{"key":"256A","mappings":{"default":{"default":"cruce de separadores, vertical sencillo y horizontal doble"}},"category":"So"},{"key":"256B","mappings":{"default":{"default":"cruce de separadores, vertical doble y horizontal sencillo"}},"category":"So"},{"key":"256C","mappings":{"default":{"default":"cruce de separadores dobles"}},"category":"So"},{"key":"2580","mappings":{"default":{"default":"bloque mitad superior"}},"category":"So"},{"key":"2584","mappings":{"default":{"default":"bloque mitad inferior"}},"category":"So"},{"key":"2588","mappings":{"default":{"default":"bloque"}},"category":"So"},{"key":"2591","mappings":{"default":{"default":"sombra ligera"}},"category":"So"},{"key":"2592","mappings":{"default":{"default":"sombra media"}},"category":"So"},{"key":"2593","mappings":{"default":{"default":"sombra intensa"}},"category":"So"},{"key":"25A0","mappings":{"default":{"default":"cuadrado relleno"}},"category":"So"},{"key":"25A1","mappings":{"default":{"default":"cuadrado"}},"category":"So"},{"key":"25AA","mappings":{"default":{"default":"cuadrado relleno"}},"category":"So"},{"key":"25AB","mappings":{"default":{"default":"cuadrado"}},"category":"So"},{"key":"25AD","mappings":{"default":{"default":"rectángulo"}},"category":"So"},{"key":"25AE","mappings":{"default":{"default":"rectángulo relleno vertical"}},"category":"So"},{"key":"25AF","mappings":{"default":{"default":"rectángulo vertical"}},"category":"So"},{"key":"25B1","mappings":{"default":{"default":"paralelogramo"}},"category":"So"},{"key":"25B2","mappings":{"default":{"default":"triángulo relleno"}},"category":"So"},{"key":"25B3","mappings":{"default":{"default":"triángulo"}},"category":"So"},{"key":"25B4","mappings":{"default":{"default":"triángulo relleno"}},"category":"So"},{"key":"25B5","mappings":{"default":{"default":"triángulo"}},"category":"So"},{"key":"25B6","mappings":{"default":{"default":"triángulo relleno señala derecha"}},"category":"So"},{"key":"25B7","mappings":{"default":{"default":"triángulo señala derecha"}},"category":"Sm"},{"key":"25B8","mappings":{"default":{"default":"triángulo relleno señala derecha"}},"category":"So"},{"key":"25B9","mappings":{"default":{"default":"triángulo señala derecha"}},"category":"So"},{"key":"25BC","mappings":{"default":{"default":"triángulo relleno señala abajo"}},"category":"So"},{"key":"25BD","mappings":{"default":{"default":"triángulo señala abajo"}},"category":"So"},{"key":"25BE","mappings":{"default":{"default":"triángulo relleno señala abajo"}},"category":"So"},{"key":"25BF","mappings":{"default":{"default":"triángulo señala abajo"}},"category":"So"},{"key":"25C0","mappings":{"default":{"default":"triángulo relleno señala izquierda"}},"category":"So"},{"key":"25C1","mappings":{"default":{"default":"triángulo señala izquierda"}},"category":"Sm"},{"key":"25C2","mappings":{"default":{"default":"triángulo relleno señala izquierda"}},"category":"So"},{"key":"25C3","mappings":{"default":{"default":"triángulo señala izquierda"}},"category":"So"},{"key":"25C4","mappings":{"default":{"default":"puntero relleno señala izquierda"}},"category":"So"},{"key":"25C5","mappings":{"default":{"default":"puntero señala izquierda"}},"category":"So"},{"key":"25C6","mappings":{"default":{"default":"diamante relleno"}},"category":"So"},{"key":"25C7","mappings":{"default":{"default":"diamante"}},"category":"So"},{"key":"25C8","mappings":{"default":{"default":"diamante vacío contiene diamante relleno"}},"category":"So"},{"key":"25C9","mappings":{"default":{"default":"ojo de pez"}},"category":"So"},{"key":"25CA","mappings":{"default":{"default":"rombo"}},"category":"So"},{"key":"25CB","mappings":{"default":{"default":"círculo vacío"}},"category":"So"},{"key":"25CC","mappings":{"default":{"default":"círculo punteado"}},"category":"So"},{"key":"25CD","mappings":{"default":{"default":"círculo con relleno vertical"}},"category":"So"},{"key":"25CE","mappings":{"default":{"default":"blanco"}},"category":"So"},{"key":"25CF","mappings":{"default":{"default":"círculo relleno"}},"category":"So"},{"key":"25D0","mappings":{"default":{"default":"círculo con mitad izquierda rellena"}},"category":"So"},{"key":"25D1","mappings":{"default":{"default":"círculo con mitad derecha rellena"}},"category":"So"},{"key":"25D2","mappings":{"default":{"default":"círculo con mitad inferior rellena"}},"category":"So"},{"key":"25D3","mappings":{"default":{"default":"círculo con mitad superior rellena"}},"category":"So"},{"key":"25D4","mappings":{"default":{"default":"círculo con cuadrante superior derecho relleno"}},"category":"So"},{"key":"25D5","mappings":{"default":{"default":"círculo con cuadrante superior izquierdo relleno"}},"category":"So"},{"key":"25D6","mappings":{"default":{"default":"semicírculo izquierdo relleno"}},"category":"So"},{"key":"25D7","mappings":{"default":{"default":"semicírculo derecho relleno"}},"category":"So"},{"key":"25D8","mappings":{"default":{"default":"bullet inversa"}},"category":"So"},{"key":"25D9","mappings":{"default":{"default":"círculo vacío inverso"}},"category":"So"},{"key":"25DA","mappings":{"default":{"default":"semicírculo superior vacío inverso"}},"category":"So"},{"key":"25DB","mappings":{"default":{"default":"semicírculo superior vacío inverso"}},"category":"So"},{"key":"25DC","mappings":{"default":{"default":"arco superior izquierda"}},"category":"So"},{"key":"25DD","mappings":{"default":{"default":"arco superior derecha"}},"category":"So"},{"key":"25DE","mappings":{"default":{"default":"arco inferior derecha"}},"category":"So"},{"key":"25DF","mappings":{"default":{"default":"arco inferior izquierda"}},"category":"So"},{"key":"25E0","mappings":{"default":{"default":"semicírculo superior"}},"category":"So"},{"key":"25E1","mappings":{"default":{"default":"semicírculo inferior"}},"category":"So"},{"key":"25E2","mappings":{"default":{"default":"triángulo inferior derecha relleno"}},"category":"So"},{"key":"25E3","mappings":{"default":{"default":"triángulo inferior izquierda relleno"}},"category":"So"},{"key":"25E4","mappings":{"default":{"default":"triángulo superior izquierda relleno"}},"category":"So"},{"key":"25E5","mappings":{"default":{"default":"triángulo superior derecha relleno"}},"category":"So"},{"key":"25E6","mappings":{"default":{"default":"composición"}},"category":"So"},{"key":"25E7","mappings":{"default":{"default":"cuadrado con mitad izquierda rellena"}},"category":"So"},{"key":"25E8","mappings":{"default":{"default":"cuadrado con mitad derecha rellena"}},"category":"So"},{"key":"25E9","mappings":{"default":{"default":"cuadrado con mitad superior izquierda rellena"}},"category":"So"},{"key":"25EA","mappings":{"default":{"default":"cuadrado con mitad inferior derecha rellena"}},"category":"So"},{"key":"25EB","mappings":{"default":{"default":"cuadrado con bisectriz"}},"category":"So"},{"key":"25EC","mappings":{"default":{"default":"triángulo vacío con punto"}},"category":"So"},{"key":"25ED","mappings":{"default":{"default":"triángulo apuntando arriba con mitad izquierda rellena"}},"category":"So"},{"key":"25EE","mappings":{"default":{"default":"triángulo apuntando arriba con mitad derecha rellena"}},"category":"So"},{"key":"25EF","mappings":{"default":{"default":"círculo grande"}},"category":"So"},{"key":"25F8","mappings":{"default":{"default":"triángulo superior izquierda"}},"category":"Sm"},{"key":"25F9","mappings":{"default":{"default":"triángulo superior derecha"}},"category":"Sm"},{"key":"25FA","mappings":{"default":{"default":"triángulo inferior izquierda"}},"category":"Sm"},{"key":"25FB","mappings":{"default":{"default":"cuadrado mediano vacío"}},"category":"Sm"},{"key":"25FC","mappings":{"default":{"default":"cuadrado mediano relleno"}},"category":"Sm"},{"key":"25FD","mappings":{"default":{"default":"cuadrado mediano vacío"}},"category":"Sm"},{"key":"25FE","mappings":{"default":{"default":"cuadrado mediano relleno"}},"category":"Sm"},{"key":"25FF","mappings":{"default":{"default":"triángulo inferior derecha"}},"category":"Sm"},{"key":"2B50","mappings":{"default":{"default":"estrella media vacía"}},"category":"So"},{"key":"2B51","mappings":{"default":{"default":"estrella pequeña rellena"}},"category":"So"},{"key":"2B52","mappings":{"default":{"default":"estrella pequeña vacía"}},"category":"So"}]
,
"es/math_harpoons.js": 
[{"locale":"es"},{"key":"21BC","mappings":{"default":{"default":"flecha izquierda con arpón arriba"}},"category":"So"},{"key":"21BD","mappings":{"default":{"default":"flecha izquierda con arpón debajo"}},"category":"So"},{"key":"21BE","mappings":{"default":{"default":"flecha arriba con arpón derecho"}},"category":"So"},{"key":"21BF","mappings":{"default":{"default":"flecha arriba con arpón izquierdo"}},"category":"So"},{"key":"21C0","mappings":{"default":{"default":"flecha derecha con arpón arriba"}},"category":"So"},{"key":"21C1","mappings":{"default":{"default":"flecha derecha con arpón debajo"}},"category":"So"},{"key":"21C2","mappings":{"default":{"default":"flecha abajo con arpón derecho"}},"category":"So"},{"key":"21C3","mappings":{"default":{"default":"flecha abajo con arpón izquierdo"}},"category":"So"},{"key":"21CB","mappings":{"default":{"default":"arpón izquierdo arriba de arpón derecho"}},"category":"So"},{"key":"21CC","mappings":{"default":{"default":"arpón derecho arriba de arpón izquierdo"}},"category":"So"},{"key":"294A","mappings":{"default":{"default":"left barb up right barb down harpoon"}},"category":"Sm"},{"key":"294B","mappings":{"default":{"default":"left barb down right barb up harpoon"}},"category":"Sm"},{"key":"294E","mappings":{"default":{"default":"left barb up right barb up harpoon"}},"category":"Sm"},{"key":"294F","mappings":{"default":{"default":"arpón a la derecha hacia arriba y abajo"}},"category":"Sm"},{"key":"2950","mappings":{"default":{"default":"left barb down right barb down harpoon"}},"category":"Sm"},{"key":"2951","mappings":{"default":{"default":"arpón a la izquierda hacia arriba y abajo"}},"category":"Sm"},{"key":"2952","mappings":{"default":{"default":"leftwards harpoon to bar with barb upwards"}},"category":"Sm"},{"key":"2953","mappings":{"default":{"default":"rightwards harpoon to bar with barb upwards"}},"category":"Sm"},{"key":"2954","mappings":{"default":{"default":"upwards harpoon to bar with barb rightwards"}},"category":"Sm"},{"key":"2955","mappings":{"default":{"default":"downwards harpoon to bar with barb rightwards"}},"category":"Sm"},{"key":"2956","mappings":{"default":{"default":"leftwards harpoon to bar with barb downwards"}},"category":"Sm"},{"key":"2957","mappings":{"default":{"default":"rightwards harpoon to bar with barb downwards"}},"category":"Sm"},{"key":"2958","mappings":{"default":{"default":"upwards harpoon to bar with barb leftwards"}},"category":"Sm"},{"key":"2959","mappings":{"default":{"default":"downwards harpoon to bar with barb leftwards"}},"category":"Sm"},{"key":"295A","mappings":{"default":{"default":"leftwards harpoon from bar with barb upwards"}},"category":"Sm"},{"key":"295B","mappings":{"default":{"default":"rightwards harpoon from bar with barb upwards"}},"category":"Sm"},{"key":"295C","mappings":{"default":{"default":"upwards harpoon from bar with barb rightwards"}},"category":"Sm"},{"key":"295D","mappings":{"default":{"default":"downwards harpoon from bar with barb rightwards"}},"category":"Sm"},{"key":"295E","mappings":{"default":{"default":"leftwards harpoon from bar with barb downwards"}},"category":"Sm"},{"key":"295F","mappings":{"default":{"default":"rightwards harpoon from bar with barb downwards"}},"category":"Sm"},{"key":"2960","mappings":{"default":{"default":"upwards harpoon from bar with barb leftwards"}},"category":"Sm"},{"key":"2961","mappings":{"default":{"default":"downwards harpoon from bar with barb leftwards"}},"category":"Sm"},{"key":"2962","mappings":{"default":{"default":"leftwards harpoon with barb up above leftwards harpoon with barb down"}},"category":"Sm"},{"key":"2963","mappings":{"default":{"default":"upwards harpoon with barb left beside upwards harpoon with barb right"}},"category":"Sm"},{"key":"2964","mappings":{"default":{"default":"rightwards harpoon with barb up above rightwards harpoon with barb down"}},"category":"Sm"},{"key":"2965","mappings":{"default":{"default":"downwards harpoon with barb left beside downwards harpoon with barb right"}},"category":"Sm"},{"key":"2966","mappings":{"default":{"default":"leftwards harpoon with barb up above rightwards harpoon with barb up"}},"category":"Sm"},{"key":"2967","mappings":{"default":{"default":"leftwards harpoon with barb down above rightwards harpoon with barb down"}},"category":"Sm"},{"key":"2968","mappings":{"default":{"default":"rightwards harpoon with barb up above leftwards harpoon with barb up"}},"category":"Sm"},{"key":"2969","mappings":{"default":{"default":"rightwards harpoon with barb down above leftwards harpoon with barb down"}},"category":"Sm"},{"key":"296A","mappings":{"default":{"default":"barra con arpón hacia la izquierda"}},"category":"Sm"},{"key":"296B","mappings":{"default":{"default":"arpón hacia la izquierda con barra"}},"category":"Sm"},{"key":"296C","mappings":{"default":{"default":"barra con arpón hacia la derecha"}},"category":"Sm"},{"key":"296D","mappings":{"default":{"default":"arpón hacia la derecha con barra"}},"category":"Sm"},{"key":"296E","mappings":{"default":{"default":"upwards harpoon to the left of downwards harpoon"}},"category":"Sm"},{"key":"296F","mappings":{"default":{"default":"upwards harpoon to the right of downwards harpoon"}},"category":"Sm"},{"key":"297C","mappings":{"default":{"default":"left fish tail"}},"category":"Sm"},{"key":"297D","mappings":{"default":{"default":"right fish tail"}},"category":"Sm"},{"key":"297E","mappings":{"default":{"default":"barra con doble gancho"}},"category":"Sm"},{"key":"297F","mappings":{"default":{"default":"down fish tail"}},"category":"Sm"}]
,
"es/math_non_characters.js": 
[{"locale":"es"},{"key":"210F","mappings":{"default":{"default":"h barra"}},"category":"Ll"},{"key":"2116","mappings":{"default":{"default":"signo de número"}},"category":"So"},{"key":"2117","mappings":{"default":{"default":"derechos de autor de sonido"}},"category":"So"},{"key":"211E","mappings":{"default":{"default":"receta"}},"category":"So"},{"key":"2122","mappings":{"default":{"default":"registrado"}},"category":"So"},{"key":"2125","mappings":{"default":{"default":"onza"}},"category":"So"},{"key":"2126","mappings":{"default":{"default":"ohmio"}},"category":"Lu"},{"key":"2127","mappings":{"default":{"default":"ohmio invertido"}},"category":"So"},{"key":"212A","mappings":{"default":{"default":"grados kelvin"}},"category":"Lu"},{"key":"212B","mappings":{"default":{"default":"angstrom"}},"category":"Lu"},{"key":"2132","mappings":{"default":{"default":"mayúscula F invertida"}},"category":"Lu"}]
,
"es/math_symbols.js": 
[{"locale":"es"},{"key":"0021","mappings":{"default":{"default":"factorial"}},"category":"Po"},{"key":"0022","mappings":{"default":{"default":"comillas"}},"category":"Po"},{"key":"0023","mappings":{"default":{"default":"almuhadilla","defaultMP":"signo de número"}},"category":"Po"},{"key":"0024","mappings":{"default":{"default":"dólar"}},"category":"Sc"},{"key":"0025","mappings":{"default":{"default":"porciento"}},"category":"Po"},{"key":"0026","mappings":{"default":{"default":"ampersand"}},"category":"Po"},{"key":"0027","mappings":{"default":{"default":"prima","defaultMP":"apóstrofo"}},"category":"Po"},{"key":"002A","mappings":{"default":{"default":"por"}},"category":"Po"},{"key":"002B","mappings":{"default":{"default":"más"}},"category":"Sm"},{"key":"002C","mappings":{"default":{"default":"coma"}},"category":"Po"},{"key":"002D","mappings":{"default":{"default":"menos"}},"category":"Pd"},{"key":"002E","mappings":{"default":{"default":"punto"}},"category":"Po"},{"key":"002F","mappings":{"default":{"default":"barra oblicua"}},"category":"Po"},{"key":"003A","mappings":{"default":{"default":"dos puntos"}},"category":"Po"},{"key":"003B","mappings":{"default":{"default":"punto y coma"}},"category":"Po"},{"key":"003C","mappings":{"default":{"default":"menor que"}},"category":"Sm"},{"key":"003D","mappings":{"default":{"default":"igual"}},"category":"Sm"},{"key":"003E","mappings":{"default":{"default":"mayor que"}},"category":"Sm"},{"key":"003F","mappings":{"default":{"default":"interrogación derecho","defaultMP":"cierra interrogación"}},"category":"Po"},{"key":"0040","mappings":{"default":{"default":"arroba"}},"category":"Po"},{"key":"005C","mappings":{"default":{"default":"barra inversa"}},"category":"Po"},{"key":"005E","mappings":{"default":{"default":"circunflejo"}},"category":"Sk"},{"key":"005F","mappings":{"default":{"default":"subrayado"}},"category":"Pc"},{"key":"0060","mappings":{"default":{"default":"acento grave"}},"category":"Sk"},{"key":"007C","mappings":{"default":{"default":"barra vertical"}},"category":"Sm"},{"key":"007E","mappings":{"default":{"default":"tilde"}},"category":"Sm"},{"key":"00A1","mappings":{"default":{"default":"admiración izquierdo","defaultMP":"abre admiración"}},"category":"Po"},{"key":"00A2","mappings":{"default":{"default":"centavo"}},"category":"Sc"},{"key":"00A3","mappings":{"default":{"default":"libra esterlina"}},"category":"Sc"},{"key":"00A4","mappings":{"default":{"default":"moneda"}},"category":"Sc"},{"key":"00A5","mappings":{"default":{"default":"yen"}},"category":"Sc"},{"key":"00A6","mappings":{"default":{"default":"barra vertical partida"}},"category":"So"},{"key":"00A7","mappings":{"default":{"default":"sección"}},"category":"Po"},{"key":"00A8","mappings":{"default":{"default":"diéresis"}},"category":"Sk"},{"key":"00A9","mappings":{"default":{"default":"copyright"}},"category":"So"},{"key":"00AA","mappings":{"default":{"default":"ordinal femenino"}},"category":"Lo"},{"key":"00AB","mappings":{"default":{"default":"comillas angulares izquierda","defaultMP":"abre comillas angulares"}},"category":"Pi"},{"key":"00AC","mappings":{"default":{"default":"negación"}},"category":"Sm"},{"key":"00AE","mappings":{"default":{"default":"registrado"}},"category":"So"},{"key":"00AF","mappings":{"default":{"default":"barra"}},"category":"Sk"},{"key":"00B0","mappings":{"default":{"default":"grado"}},"category":"So"},{"key":"00B1","mappings":{"default":{"default":"más menos"}},"category":"Sm"},{"key":"00B4","mappings":{"default":{"default":"acento agudo"}},"category":"Sk"},{"key":"00B5","mappings":{"default":{"default":"micro"}},"category":"Ll"},{"key":"00B6","mappings":{"default":{"default":"párrafo"}},"category":"Po"},{"key":"00B7","mappings":{"default":{"default":"punto medio"}},"category":"Po"},{"key":"00B8","mappings":{"default":{"default":"cedilla"}},"category":"Sk"},{"key":"00BA","mappings":{"default":{"default":"ordinal masculino"}},"category":"Lo"},{"key":"00BB","mappings":{"default":{"default":"comillas angulares derecha","defaultMP":"cierra comillas angulares"}},"category":"Pf"},{"key":"00BF","mappings":{"default":{"default":"interrogación izquierdo","defaultMP":"abre interrogación"}},"category":"Po"},{"key":"00D7","mappings":{"default":{"default":"por"}},"category":"Sm"},{"key":"00F7","mappings":{"default":{"default":"dividido"}},"category":"Sm"},{"key":"02D8","mappings":{"default":{"default":"breve"}},"category":"Sk"},{"key":"02D9","mappings":{"default":{"default":"punto en superescrito"}},"category":"Sk"},{"key":"02DA","mappings":{"default":{"default":"anillo en superescrito"}},"category":"Sk"},{"key":"02DB","mappings":{"default":{"default":"ogonek"}},"category":"Sk"},{"key":"02DC","mappings":{"default":{"default":"tilde"}},"category":"Sk"},{"key":"02DD","mappings":{"default":{"default":"doble acento agudo"}},"category":"Sk"},{"key":"2010","mappings":{"default":{"default":"menos"}},"category":"Pd"},{"key":"2013","mappings":{"default":{"default":"en raya"}},"category":"Pd"},{"key":"2014","mappings":{"default":{"default":"em raya"}},"category":"Pd"},{"key":"2015","mappings":{"default":{"default":"barra horizontal"}},"category":"Pd"},{"key":"2016","mappings":{"default":{"default":"doble barra vertical"}},"category":"Po"},{"key":"2018","mappings":{"default":{"default":"comilla izquierda"}},"category":"Pi"},{"key":"2019","mappings":{"default":{"default":"comilla derecha"}},"category":"Pf"},{"key":"201A","mappings":{"default":{"default":"comilla bajo 9"}},"category":"Ps"},{"key":"201C","mappings":{"default":{"default":"doble comilla"}},"category":"Pi"},{"key":"201D","mappings":{"default":{"default":"doble comilla derecha"}},"category":"Pf"},{"key":"201E","mappings":{"default":{"default":"doble comilla bajo 9"}},"category":"Ps"},{"key":"2020","mappings":{"default":{"default":"daga"}},"category":"Po"},{"key":"2021","mappings":{"default":{"default":"doble daga"}},"category":"Po"},{"key":"2022","mappings":{"default":{"default":"bala"}},"category":"Po"},{"key":"2025","mappings":{"default":{"default":"dos puntos líder"}},"category":"Po"},{"key":"2026","mappings":{"default":{"default":"puntos suspensivos"}},"category":"Po"},{"key":"2030","mappings":{"default":{"default":"tanto por millar"}},"category":"Po"},{"key":"2031","mappings":{"default":{"default":"tanto por diez mil"}},"category":"Po"},{"key":"2032","mappings":{"default":{"default":"prima"}},"category":"Po"},{"key":"2033","mappings":{"default":{"default":"segunda"}},"category":"Po"},{"key":"2034","mappings":{"default":{"default":"tercera"}},"category":"Po"},{"key":"2035","mappings":{"default":{"default":"acento grave"}},"category":"Po"},{"key":"2036","mappings":{"default":{"default":"doble acento grave"}},"category":"Po"},{"key":"2039","mappings":{"default":{"default":"comillas izquierda","defaultMP":"abre comillas"}},"category":"Pi"},{"key":"203A","mappings":{"default":{"default":"comillas derecha","defaultMP":"cierra comillas"}},"category":"Pf"},{"key":"203E","mappings":{"default":{"default":"barra superior"}},"category":"Po"},{"key":"2040","mappings":{"default":{"default":"ligadura"}},"category":"Pc"},{"key":"2041","mappings":{"default":{"default":"punto de inserción"}},"category":"Po"},{"key":"2043","mappings":{"default":{"default":"guión bala"}},"category":"Po"},{"key":"2044","mappings":{"default":{"default":"barra de fracción"}},"category":"Sm"},{"key":"204F","mappings":{"default":{"default":"punto y coma invertido"}},"category":"Po"},{"key":"2050","mappings":{"default":{"default":"cierre superior"}},"category":"Po"},{"key":"2057","mappings":{"default":{"default":"cuarta"}},"category":"Po"},{"key":"2200","mappings":{"default":{"default":"para todo"}},"category":"Sm"},{"key":"2201","mappings":{"default":{"default":"complementario"}},"category":"Sm"},{"key":"2202","mappings":{"default":{"default":"derivada parcial"}},"category":"Sm"},{"key":"2203","mappings":{"default":{"default":"existe"}},"category":"Sm"},{"key":"2204","mappings":{"default":{"default":"no existe"}},"category":"Sm"},{"key":"2205","mappings":{"default":{"default":"conjunto vacío"}},"category":"Sm"},{"key":"2206","mappings":{"default":{"default":"incremento"}},"category":"Sm"},{"key":"2207","mappings":{"default":{"default":"gradiente"}},"category":"Sm"},{"key":"2208","mappings":{"default":{"default":"perteneciente a"}},"category":"Sm"},{"key":"2209","mappings":{"default":{"default":"no perteneciente a"}},"category":"Sm"},{"key":"220A","mappings":{"default":{"default":"perteneciente a"}},"category":"Sm"},{"key":"220B","mappings":{"default":{"default":"comprende a"}},"category":"Sm"},{"key":"220C","mappings":{"default":{"default":"no comprende a"}},"category":"Sm"},{"key":"220D","mappings":{"default":{"default":"comprende a"}},"category":"Sm"},{"key":"220E","mappings":{"default":{"default":"fin de demostración"}},"category":"Sm"},{"key":"220F","mappings":{"default":{"default":"producto"}},"category":"Sm"},{"key":"2210","mappings":{"default":{"default":"coproducto"}},"category":"Sm"},{"key":"2211","mappings":{"default":{"default":"sumatorio"}},"category":"Sm"},{"key":"2212","mappings":{"default":{"default":"menos"}},"category":"Sm"},{"key":"2213","mappings":{"default":{"default":"menos más"}},"category":"Sm"},{"key":"2214","mappings":{"default":{"default":"punto más"}},"category":"Sm"},{"key":"2215","mappings":{"default":{"default":"barra de división"}},"category":"Sm"},{"key":"2216","mappings":{"default":{"default":"menos"}},"category":"Sm"},{"key":"2217","mappings":{"default":{"default":"asterisco"}},"category":"Sm"},{"key":"2218","mappings":{"default":{"default":"composición"}},"category":"Sm"},{"key":"2219","mappings":{"default":{"default":"bala"}},"category":"Sm"},{"key":"221A","mappings":{"default":{"default":"raíz"}},"category":"Sm"},{"key":"221B","mappings":{"default":{"default":"raíz cúbica"}},"category":"Sm"},{"key":"221C","mappings":{"default":{"default":"raíz cuarta"}},"category":"Sm"},{"key":"221D","mappings":{"default":{"default":"proporcional a"}},"category":"Sm"},{"key":"221E","mappings":{"default":{"default":"infinito"}},"category":"Sm"},{"key":"221F","mappings":{"default":{"default":"ángulo recto"}},"category":"Sm"},{"key":"2220","mappings":{"default":{"default":"ángulo"}},"category":"Sm"},{"key":"2221","mappings":{"default":{"default":"ángulo medido"}},"category":"Sm"},{"key":"2222","mappings":{"default":{"default":"ángulo esférico"}},"category":"Sm"},{"key":"2223","mappings":{"default":{"default":"divide a"}},"category":"Sm"},{"key":"2224","mappings":{"default":{"default":"no divide a"}},"category":"Sm"},{"key":"2225","mappings":{"default":{"default":"paralela a"}},"category":"Sm"},{"key":"2226","mappings":{"default":{"default":"no paralela a"}},"category":"Sm"},{"key":"2227","mappings":{"default":{"default":"y"}},"category":"Sm"},{"key":"2228","mappings":{"default":{"default":"o"}},"category":"Sm"},{"key":"2229","mappings":{"default":{"default":"intersección"}},"category":"Sm"},{"key":"222A","mappings":{"default":{"default":"unión"}},"category":"Sm"},{"key":"222B","mappings":{"default":{"default":"integral"}},"category":"Sm"},{"key":"222C","mappings":{"default":{"default":"integral doble"}},"category":"Sm"},{"key":"222D","mappings":{"default":{"default":"integral triple"}},"category":"Sm"},{"key":"222E","mappings":{"default":{"default":"integral de contorno"}},"category":"Sm"},{"key":"222F","mappings":{"default":{"default":"integral de superficie"}},"category":"Sm"},{"key":"2230","mappings":{"default":{"default":"integral de volumen"}},"category":"Sm"},{"key":"2231","mappings":{"default":{"default":"integral de contorno en sentido horario"}},"category":"Sm"},{"key":"2232","mappings":{"default":{"default":"integral de contorno en sentido horario"}},"category":"Sm"},{"key":"2233","mappings":{"default":{"default":"integral de contorno en sentido antihorario"}},"category":"Sm"},{"key":"2234","mappings":{"default":{"default":"por lo tanto"}},"category":"Sm"},{"key":"2235","mappings":{"default":{"default":"porque"}},"category":"Sm"},{"key":"2236","mappings":{"default":{"default":"razón"}},"category":"Sm"},{"key":"2237","mappings":{"default":{"default":"proporción"}},"category":"Sm"},{"key":"2238","mappings":{"default":{"default":"punto menos"}},"category":"Sm"},{"key":"2239","mappings":{"default":{"default":"exceso"}},"category":"Sm"},{"key":"223A","mappings":{"default":{"default":"proporción geométrica"}},"category":"Sm"},{"key":"223B","mappings":{"default":{"default":"homotecia"}},"category":"Sm"},{"key":"223C","mappings":{"default":{"default":"tilde"}},"category":"Sm"},{"key":"223D","mappings":{"default":{"default":"tilde invertido"}},"category":"Sm"},{"key":"223E","mappings":{"default":{"default":"s horizontal invertida"}},"category":"Sm"},{"key":"223F","mappings":{"default":{"default":"sinusoide"}},"category":"Sm"},{"key":"2240","mappings":{"default":{"default":"producto de guirnalda"}},"category":"Sm"},{"key":"2241","mappings":{"default":{"default":"no tilde"}},"category":"Sm"},{"key":"2242","mappings":{"default":{"default":"menos tilde"}},"category":"Sm"},{"key":"2243","mappings":{"default":{"default":"asintóticamente igual a"}},"category":"Sm"},{"key":"2244","mappings":{"default":{"default":"no asintóticamente igual a"}},"category":"Sm"},{"key":"2245","mappings":{"default":{"default":"aproximadamente igual a"}},"category":"Sm"},{"key":"2246","mappings":{"default":{"default":"aproximado pero no igual a"}},"category":"Sm"},{"key":"2247","mappings":{"default":{"default":"no aproximado a"}},"category":"Sm"},{"key":"2248","mappings":{"default":{"default":"aproximado","defaultMP":"casi igual a"}},"category":"Sm"},{"key":"2249","mappings":{"default":{"default":"no es casi igual a"}},"category":"Sm"},{"key":"224A","mappings":{"default":{"default":"igual o casi igual a"}},"category":"Sm"},{"key":"224B","mappings":{"default":{"default":"triple tilde"}},"category":"Sm"},{"key":"224C","mappings":{"default":{"default":"todo igual a"}},"category":"Sm"},{"key":"224D","mappings":{"default":{"default":"equivalente a"}},"category":"Sm"},{"key":"224E","mappings":{"default":{"default":"geométricamente equivalente a"}},"category":"Sm"},{"key":"224F","mappings":{"default":{"default":"diferencia entre"}},"category":"Sm"},{"key":"2250","mappings":{"default":{"default":"se acerca al límite"}},"category":"Sm"},{"key":"2251","mappings":{"default":{"default":"geométricamente igual a"}},"category":"Sm"},{"key":"2252","mappings":{"default":{"default":"aproximadamente igual a o imagen de"}},"category":"Sm"},{"key":"2253","mappings":{"default":{"default":"imagen de o aproximadamente igual a"}},"category":"Sm"},{"key":"2254","mappings":{"default":{"default":"dos puntos igual"}},"category":"Sm"},{"key":"2255","mappings":{"default":{"default":"igual dos puntos"}},"category":"Sm"},{"key":"2256","mappings":{"default":{"default":"igual incluyendo anillo"}},"category":"Sm"},{"key":"2257","mappings":{"default":{"default":"igual anillo a"}},"category":"Sm"},{"key":"2258","mappings":{"default":{"default":"corresponde a"}},"category":"Sm"},{"key":"2259","mappings":{"default":{"default":"estima a"}},"category":"Sm"},{"key":"225A","mappings":{"default":{"default":"equiangular con"}},"category":"Sm"},{"key":"225B","mappings":{"default":{"default":"igual con estrella"}},"category":"Sm"},{"key":"225C","mappings":{"default":{"default":"igual con delta"}},"category":"Sm"},{"key":"225D","mappings":{"default":{"default":"igual por definición a"}},"category":"Sm"},{"key":"225E","mappings":{"default":{"default":"medido por"}},"category":"Sm"},{"key":"225F","mappings":{"default":{"default":"igual con interrogante"}},"category":"Sm"},{"key":"2260","mappings":{"default":{"default":"no es igual a","defaultMP":"distinto de"}},"category":"Sm"},{"key":"2261","mappings":{"default":{"default":"idéntico a"}},"category":"Sm"},{"key":"2262","mappings":{"default":{"default":"no es idéntico a"}},"category":"Sm"},{"key":"2263","mappings":{"default":{"default":"estrictamente equivalente a"}},"category":"Sm"},{"key":"2264","mappings":{"default":{"default":"menor o igual que"}},"category":"Sm"},{"key":"2265","mappings":{"default":{"default":"mayor o igual que"}},"category":"Sm"},{"key":"2266","mappings":{"default":{"default":"menor o igual que"}},"category":"Sm"},{"key":"2267","mappings":{"default":{"default":"mayor o igual que"}},"category":"Sm"},{"key":"2268","mappings":{"default":{"default":"estrictamente menor que"}},"category":"Sm"},{"key":"2269","mappings":{"default":{"default":"estrictamente mayor que"}},"category":"Sm"},{"key":"226A","mappings":{"default":{"default":"mucho menor que"}},"category":"Sm"},{"key":"226B","mappings":{"default":{"default":"mucho mayor que"}},"category":"Sm"},{"key":"226C","mappings":{"default":{"default":"entre"}},"category":"Sm"},{"key":"226D","mappings":{"default":{"default":"no equivalente a"}},"category":"Sm"},{"key":"226E","mappings":{"default":{"default":"no menor que"}},"category":"Sm"},{"key":"226F","mappings":{"default":{"default":"no mayor que"}},"category":"Sm"},{"key":"2270","mappings":{"default":{"default":"no menor ni igual a"}},"category":"Sm"},{"key":"2271","mappings":{"default":{"default":"no mayor ni igual a"}},"category":"Sm"},{"key":"2272","mappings":{"default":{"default":"menor o equivalente a"}},"category":"Sm"},{"key":"2273","mappings":{"default":{"default":"mayor o equivalente a"}},"category":"Sm"},{"key":"2274","mappings":{"default":{"default":"no menor ni equivalente a"}},"category":"Sm"},{"key":"2275","mappings":{"default":{"default":"no mayor ni equivalente a"}},"category":"Sm"},{"key":"2276","mappings":{"default":{"default":"menor o mayor que"}},"category":"Sm"},{"key":"2277","mappings":{"default":{"default":"mayor o menor que"}},"category":"Sm"},{"key":"2278","mappings":{"default":{"default":"no menor ni mayor que"}},"category":"Sm"},{"key":"2279","mappings":{"default":{"default":"no mayor ni menor que"}},"category":"Sm"},{"key":"227A","mappings":{"default":{"default":"precede a"}},"category":"Sm"},{"key":"227B","mappings":{"default":{"default":"sigue a"}},"category":"Sm"},{"key":"227C","mappings":{"default":{"default":"precede o es igual a"}},"category":"Sm"},{"key":"227D","mappings":{"default":{"default":"sigue o es igual a"}},"category":"Sm"},{"key":"227E","mappings":{"default":{"default":"precede o es equivalente a"}},"category":"Sm"},{"key":"227F","mappings":{"default":{"default":"sigue o es equivalente a"}},"category":"Sm"},{"key":"2280","mappings":{"default":{"default":"no precede a"}},"category":"Sm"},{"key":"2281","mappings":{"default":{"default":"no sigue a"}},"category":"Sm"},{"key":"2282","mappings":{"default":{"default":"incluido en"}},"category":"Sm"},{"key":"2283","mappings":{"default":{"default":"contiene a"}},"category":"Sm"},{"key":"2284","mappings":{"default":{"default":"no incluido en"}},"category":"Sm"},{"key":"2285","mappings":{"default":{"default":"no contiene a"}},"category":"Sm"},{"key":"2286","mappings":{"default":{"default":"incluido o igual a"}},"category":"Sm"},{"key":"2287","mappings":{"default":{"default":"contiene o es igual a"}},"category":"Sm"},{"key":"2288","mappings":{"default":{"default":"no incluido ni igual a"}},"category":"Sm"},{"key":"2289","mappings":{"default":{"default":"no contiene ni es igual a"}},"category":"Sm"},{"key":"228A","mappings":{"default":{"default":"incluido estrictamente en"}},"category":"Sm"},{"key":"228B","mappings":{"default":{"default":"contiene estrictamente a"}},"category":"Sm"},{"key":"228C","mappings":{"default":{"default":"familia de conjuntos"}},"category":"Sm"},{"key":"228D","mappings":{"default":{"default":"producto de familia de conjuntos"}},"category":"Sm"},{"key":"228E","mappings":{"default":{"default":"unión de familia de conjuntos"}},"category":"Sm"},{"key":"228F","mappings":{"default":{"default":"imagen cuadrada de"}},"category":"Sm"},{"key":"2290","mappings":{"default":{"default":"original cuadrado de"}},"category":"Sm"},{"key":"2291","mappings":{"default":{"default":"imagen cuadrada de o igual a"}},"category":"Sm"},{"key":"2292","mappings":{"default":{"default":"original cuadrado de o igual a"}},"category":"Sm"},{"key":"2293","mappings":{"default":{"default":"intersección cuadrada"}},"category":"Sm"},{"key":"2294","mappings":{"default":{"default":"unión cuadrada"}},"category":"Sm"},{"key":"2295","mappings":{"default":{"default":"más en círculo"}},"category":"Sm"},{"key":"2296","mappings":{"default":{"default":"menos en círculo"}},"category":"Sm"},{"key":"2297","mappings":{"default":{"default":"por en círculo"}},"category":"Sm"},{"key":"2298","mappings":{"default":{"default":"barra en círculo"}},"category":"Sm"},{"key":"2299","mappings":{"default":{"default":"punto en círculo"}},"category":"Sm"},{"key":"229A","mappings":{"default":{"default":"anillo en círculo"}},"category":"Sm"},{"key":"229B","mappings":{"default":{"default":"asterisco en círculo"}},"category":"Sm"},{"key":"229C","mappings":{"default":{"default":"igual en círculo"}},"category":"Sm"},{"key":"229D","mappings":{"default":{"default":"menos en círculo"}},"category":"Sm"},{"key":"229E","mappings":{"default":{"default":"más en cuadrado"}},"category":"Sm"},{"key":"229F","mappings":{"default":{"default":"menos en cuadrado"}},"category":"Sm"},{"key":"22A0","mappings":{"default":{"default":"veces en cuadrado"}},"category":"Sm"},{"key":"22A1","mappings":{"default":{"default":"punto en cuadrado"}},"category":"Sm"},{"key":"22A2","mappings":{"default":{"default":"t horizontal hacia la izquierda"}},"category":"Sm"},{"key":"22A3","mappings":{"default":{"default":"t horizontal hacia la derecha"}},"category":"Sm"},{"key":"22A4","mappings":{"default":{"default":"perpendicular"}},"category":"Sm"},{"key":"22A5","mappings":{"default":{"default":"perpendicular invertida"}},"category":"Sm"},{"key":"22A6","mappings":{"default":{"default":"afirmación"}},"category":"Sm"},{"key":"22A7","mappings":{"default":{"default":"modela"}},"category":"Sm"},{"key":"22A8","mappings":{"default":{"default":"verdadero"}},"category":"Sm"},{"key":"22A9","mappings":{"default":{"default":"obliga"}},"category":"Sm"},{"key":"22AA","mappings":{"default":{"default":"triple barra vertical torniquete derecho"}},"category":"Sm"},{"key":"22AB","mappings":{"default":{"default":"doble barra vertical doble torniquete derecho"}},"category":"Sm"},{"key":"22AC","mappings":{"default":{"default":"no prueba"}},"category":"Sm"},{"key":"22AD","mappings":{"default":{"default":"falso"}},"category":"Sm"},{"key":"22AE","mappings":{"default":{"default":"no obliga"}},"category":"Sm"},{"key":"22AF","mappings":{"default":{"default":"doble barra vertical doble torniquete derecho negada"}},"category":"Sm"},{"key":"22B0","mappings":{"default":{"default":"precede respecto de"}},"category":"Sm"},{"key":"22B1","mappings":{"default":{"default":"sigue respecto de"}},"category":"Sm"},{"key":"22B2","mappings":{"default":{"default":"subgrupo normal de"}},"category":"Sm"},{"key":"22B3","mappings":{"default":{"default":"contiene como subgrupo normal a"}},"category":"Sm"},{"key":"22B4","mappings":{"default":{"default":"subgrupo normal o es igual a"}},"category":"Sm"},{"key":"22B5","mappings":{"default":{"default":"contiene como subgrupo normal o es igual a"}},"category":"Sm"},{"key":"22B6","mappings":{"default":{"default":"original de"}},"category":"Sm"},{"key":"22B7","mappings":{"default":{"default":"imagen de"}},"category":"Sm"},{"key":"22B8","mappings":{"default":{"default":"multifunción"}},"category":"Sm"},{"key":"22B9","mappings":{"default":{"default":"matriz hermitiana conjugada"}},"category":"Sm"},{"key":"22BA","mappings":{"default":{"default":"interpola"}},"category":"Sm"},{"key":"22BB","mappings":{"default":{"default":"o excluyente"}},"category":"Sm"},{"key":"22BC","mappings":{"default":{"default":"no y"}},"category":"Sm"},{"key":"22BD","mappings":{"default":{"default":"no o"}},"category":"Sm"},{"key":"22BF","mappings":{"default":{"default":"triángulo rectángulo"}},"category":"Sm"},{"key":"22C0","mappings":{"default":{"default":"y"}},"category":"Sm"},{"key":"22C1","mappings":{"default":{"default":"o"}},"category":"Sm"},{"key":"22C2","mappings":{"default":{"default":"intersección"}},"category":"Sm"},{"key":"22C3","mappings":{"default":{"default":"unión"}},"category":"Sm"},{"key":"22C4","mappings":{"default":{"default":"operador diamante"}},"category":"Sm"},{"key":"22C5","mappings":{"default":{"default":"punto"}},"category":"Sm"},{"key":"22C6","mappings":{"default":{"default":"estrella"}},"category":"Sm"},{"key":"22C7","mappings":{"default":{"default":"dividido por"}},"category":"Sm"},{"key":"22C8","mappings":{"default":{"default":"moño"}},"category":"Sm"},{"key":"22C9","mappings":{"default":{"default":"factor normal izquierdo producto semidirecto"}},"category":"Sm"},{"key":"22CA","mappings":{"default":{"default":"factor normal derecho producto semidirecto"}},"category":"Sm"},{"key":"22CB","mappings":{"default":{"default":"producto semidirecto izquierdo"}},"category":"Sm"},{"key":"22CC","mappings":{"default":{"default":"producto semidirecto derecho"}},"category":"Sm"},{"key":"22CD","mappings":{"default":{"default":"tilde invertida igual a"}},"category":"Sm"},{"key":"22CE","mappings":{"default":{"default":"o rizada"}},"category":"Sm"},{"key":"22CF","mappings":{"default":{"default":"y rizada"}},"category":"Sm"},{"key":"22D0","mappings":{"default":{"default":"doble incluido"}},"category":"Sm"},{"key":"22D1","mappings":{"default":{"default":"doble contiene"}},"category":"Sm"},{"key":"22D2","mappings":{"default":{"default":"doble intersección"}},"category":"Sm"},{"key":"22D3","mappings":{"default":{"default":"doble unión"}},"category":"Sm"},{"key":"22D4","mappings":{"default":{"default":"bieldo"}},"category":"Sm"},{"key":"22D5","mappings":{"default":{"default":"paralela o igual a"}},"category":"Sm"},{"key":"22D6","mappings":{"default":{"default":"menor que con punto"}},"category":"Sm"},{"key":"22D7","mappings":{"default":{"default":"mayor que con punto"}},"category":"Sm"},{"key":"22D8","mappings":{"default":{"default":"mucho menor que"}},"category":"Sm"},{"key":"22D9","mappings":{"default":{"default":"mucho mayor que"}},"category":"Sm"},{"key":"22DA","mappings":{"default":{"default":"menor igual o mayor que"}},"category":"Sm"},{"key":"22DB","mappings":{"default":{"default":"mayor igual o menor que"}},"category":"Sm"},{"key":"22DC","mappings":{"default":{"default":"menor o igual que"}},"category":"Sm"},{"key":"22DD","mappings":{"default":{"default":"mayor o igual que"}},"category":"Sm"},{"key":"22DE","mappings":{"default":{"default":"precede o es igual a"}},"category":"Sm"},{"key":"22DF","mappings":{"default":{"default":"sigue o es igual a"}},"category":"Sm"},{"key":"22E0","mappings":{"default":{"default":"no precede ni es igual a"}},"category":"Sm"},{"key":"22E1","mappings":{"default":{"default":"no sigue ni es igual a"}},"category":"Sm"},{"key":"22E2","mappings":{"default":{"default":"no es imagen cuadrada ni igual a"}},"category":"Sm"},{"key":"22E3","mappings":{"default":{"default":"no es original cuadrada ni igual a"}},"category":"Sm"},{"key":"22E4","mappings":{"default":{"default":"imagen cuadrada estricta"}},"category":"Sm"},{"key":"22E5","mappings":{"default":{"default":"original cuadrada estricta"}},"category":"Sm"},{"key":"22E6","mappings":{"default":{"default":"menor que no equivalente a"}},"category":"Sm"},{"key":"22E7","mappings":{"default":{"default":"mayor que no equivalente a"}},"category":"Sm"},{"key":"22E8","mappings":{"default":{"default":"precede no equivalente a"}},"category":"Sm"},{"key":"22E9","mappings":{"default":{"default":"sigue no equivalente a"}},"category":"Sm"},{"key":"22EA","mappings":{"default":{"default":"no subgrupo normal de"}},"category":"Sm"},{"key":"22EB","mappings":{"default":{"default":"no contiene como subgrupo normal a"}},"category":"Sm"},{"key":"22EC","mappings":{"default":{"default":"no es subgrupo normal ni igual a"}},"category":"Sm"},{"key":"22ED","mappings":{"default":{"default":"no contiene como subgrupo normal ni es igual a"}},"category":"Sm"},{"key":"22EE","mappings":{"default":{"default":"puntos suspensivos verticales"}},"category":"Sm"},{"key":"22EF","mappings":{"default":{"default":"puntos suspensivos altos"}},"category":"Sm"},{"key":"22F0","mappings":{"default":{"default":"puntos suspensivos diagonales subiendo"}},"category":"Sm"},{"key":"22F1","mappings":{"default":{"default":"puntos suspensivos diagonales bajando"}},"category":"Sm"},{"key":"22F2","mappings":{"default":{"default":"pertenece con trazo horizontal"}},"category":"Sm"},{"key":"22F3","mappings":{"default":{"default":"pertenece con barra vertical al fin de raya horizontal"}},"category":"Sm"},{"key":"22F4","mappings":{"default":{"default":"pertenece en pequeño con trazo vertical"}},"category":"Sm"},{"key":"22F5","mappings":{"default":{"default":"pertenece con punto arriba"}},"category":"Sm"},{"key":"22F6","mappings":{"default":{"default":"pertenece con barra arriba"}},"category":"Sm"},{"key":"22F7","mappings":{"default":{"default":"perteneciente subrayado"}},"category":"Sm"},{"key":"22F8","mappings":{"default":{"default":"perteneciente subrayado"}},"category":"Sm"},{"key":"22F9","mappings":{"default":{"default":"pertenece con dos trazos horizontales"}},"category":"Sm"},{"key":"22FA","mappings":{"default":{"default":"contiene o es igual a"}},"category":"Sm"},{"key":"22FB","mappings":{"default":{"default":"contiene con marca"}},"category":"Sm"},{"key":"22FC","mappings":{"default":{"default":"contiene con marca"}},"category":"Sm"},{"key":"22FD","mappings":{"default":{"default":"contiene con barra"}},"category":"Sm"},{"key":"22FE","mappings":{"default":{"default":"perteneciente con barra"}},"category":"Sm"},{"key":"22FF","mappings":{"default":{"default":"z anotación asociación de bolsa"}},"category":"Sm"},{"key":"2300","mappings":{"default":{"default":"diámetro"}},"category":"So"},{"key":"2302","mappings":{"default":{"default":"casa"}},"category":"So"},{"key":"2305","mappings":{"default":{"default":"en proyectividad con"}},"category":"So"},{"key":"2306","mappings":{"default":{"default":"en perspectividad con"}},"category":"So"},{"key":"2310","mappings":{"default":{"default":"no invertido"}},"category":"So"},{"key":"2312","mappings":{"default":{"default":"arco"}},"category":"So"},{"key":"2313","mappings":{"default":{"default":"segmento"}},"category":"So"},{"key":"27C1","mappings":{"default":{"default":"triángulo encerrando triángulo"}},"category":"Sm"},{"key":"27C2","mappings":{"default":{"default":"perpendicular"}},"category":"Sm"},{"key":"27C3","mappings":{"default":{"default":"incluido en"}},"category":"Sm"},{"key":"27C4","mappings":{"default":{"default":"contiene a"}},"category":"Sm"},{"key":"27C7","mappings":{"default":{"default":"punto en círculo"}},"category":"Sm"},{"key":"27C8","mappings":{"default":{"default":"atrás tajo antes de subconjunto"}},"category":"Sm"},{"key":"27C9","mappings":{"default":{"default":"sobreconjunto antes de tajo"}},"category":"Sm"},{"key":"27CA","mappings":{"default":{"default":"barra vertical con golpe horizontal"}},"category":"Sm"},{"key":"27CC","mappings":{"default":{"default":"división larga"}},"category":"Sm"},{"key":"27D1","mappings":{"default":{"default":"y con punto interior"}},"category":"Sm"},{"key":"27D2","mappings":{"default":{"default":"elemento de apertura hacia arriba"}},"category":"Sm"},{"key":"27D3","mappings":{"default":{"default":"ángulo inferior derecho con punto"}},"category":"Sm"},{"key":"27D4","mappings":{"default":{"default":"ángulo inferior izquierdo con punto"}},"category":"Sm"},{"key":"27D5","mappings":{"default":{"default":"izquierdo exterior une"}},"category":"Sm"},{"key":"27D6","mappings":{"default":{"default":"derecho exterior une"}},"category":"Sm"},{"key":"27D7","mappings":{"default":{"default":"lleno exterior une"}},"category":"Sm"},{"key":"27D8","mappings":{"default":{"default":"perpendicular inversa"}},"category":"Sm"},{"key":"27D9","mappings":{"default":{"default":"perpendicular"}},"category":"Sm"},{"key":"27DA","mappings":{"default":{"default":"izquierdo y derecho doble torniquete"}},"category":"Sm"},{"key":"27DB","mappings":{"default":{"default":"doble T horizontal"}},"category":"Sm"},{"key":"27DC","mappings":{"default":{"default":"multifunción por la izquierda"}},"category":"Sm"},{"key":"27DD","mappings":{"default":{"default":"T horizontal derecha larga"}},"category":"Sm"},{"key":"27DE","mappings":{"default":{"default":"T horizontal izquierda larga"}},"category":"Sm"},{"key":"27DF","mappings":{"default":{"default":"perpendicular inversa con círculo arriba"}},"category":"Sm"},{"key":"27E0","mappings":{"default":{"default":"pastilla dividida por regla horizontal"}},"category":"Sm"},{"key":"27E1","mappings":{"default":{"default":"diamante cóncavo vacío"}},"category":"Sm"},{"key":"27E2","mappings":{"default":{"default":"diamante cóncavo con tictac hacia izquierda"}},"category":"Sm"},{"key":"27E3","mappings":{"default":{"default":"diamante cóncavo con tictac hacia derecha"}},"category":"Sm"},{"key":"27E4","mappings":{"default":{"default":"cuadrado con tictac hacia izquierda"}},"category":"Sm"},{"key":"27E5","mappings":{"default":{"default":"cuadrado con tictac hacia derecha"}},"category":"Sm"},{"key":"299A","mappings":{"default":{"default":"zigzag en vertical"}},"category":"Sm"},{"key":"29B0","mappings":{"default":{"default":"conjunto vacío invertido"}},"category":"Sm"},{"key":"29B1","mappings":{"default":{"default":"conjunto vacío con barra"}},"category":"Sm"},{"key":"29B2","mappings":{"default":{"default":"conjunto vacío con círculo"}},"category":"Sm"},{"key":"29B5","mappings":{"default":{"default":"círculo con barra"}},"category":"Sm"},{"key":"29B6","mappings":{"default":{"default":"barra en círculo"}},"category":"Sm"},{"key":"29B7","mappings":{"default":{"default":"paralelas en círculo"}},"category":"Sm"},{"key":"29B9","mappings":{"default":{"default":"perpendicular en círculo"}},"category":"Sm"},{"key":"29BB","mappings":{"default":{"default":"x superimpresa en círculo"}},"category":"Sm"},{"key":"29BC","mappings":{"default":{"default":"circled anticlockwise rotated division"}},"category":"Sm"},{"key":"29BE","mappings":{"default":{"default":"bullet vacía en círculo"}},"category":"Sm"},{"key":"29BF","mappings":{"default":{"default":"bullet en círculo"}},"category":"Sm"},{"key":"29C0","mappings":{"default":{"default":"menor que en círculo"}},"category":"Sm"},{"key":"29C1","mappings":{"default":{"default":"mayor que en círculo"}},"category":"Sm"},{"key":"29C2","mappings":{"default":{"default":"círculo con círculo a la derecha"}},"category":"Sm"},{"key":"29C3","mappings":{"default":{"default":"circle with two horizontal strokes to the right"}},"category":"Sm"},{"key":"29C4","mappings":{"default":{"default":"cuadrado con diagonal ascendente"}},"category":"Sm"},{"key":"29C5","mappings":{"default":{"default":"cuadrado con diagonal descendente"}},"category":"Sm"},{"key":"29C9","mappings":{"default":{"default":"dos cuadrados unidos"}},"category":"Sm"},{"key":"29CD","mappings":{"default":{"default":"triangle with serifs at bottom"}},"category":"Sm"},{"key":"29CE","mappings":{"default":{"default":"triángulo hacia la derecha sobre triángulo hacia la izquierda"}},"category":"Sm"},{"key":"29CF","mappings":{"default":{"default":"subgrupo normal o igual a"}},"category":"Sm"},{"key":"29D0","mappings":{"default":{"default":"contiene como subgrupo normal o es igual a"}},"category":"Sm"},{"key":"29DC","mappings":{"default":{"default":"infinito incompleto"}},"category":"Sm"},{"key":"29DE","mappings":{"default":{"default":"no infinito"}},"category":"Sm"},{"key":"29E3","mappings":{"default":{"default":"igual tachado doble "}},"category":"Sm"},{"key":"29E4","mappings":{"default":{"default":"igual con tilde, con doble tachado"}},"category":"Sm"},{"key":"29E5","mappings":{"default":{"default":"idéntico a con doble tachado"}},"category":"Sm"},{"key":"29EB","mappings":{"default":{"default":"rombo relleno"}},"category":"Sm"},{"key":"29F4","mappings":{"default":{"default":"rule delayed"}},"category":"Sm"},{"key":"29F6","mappings":{"default":{"default":"solidus with overbar"}},"category":"Sm"},{"key":"2A0C","mappings":{"default":{"default":"operador integral cuádruple"}},"category":"Sm"},{"key":"2A0D","mappings":{"default":{"default":"finite part integral"}},"category":"Sm"},{"key":"2A10","mappings":{"default":{"default":"circulation function"}},"category":"Sm"},{"key":"2A11","mappings":{"default":{"default":"integral en sentido antihorario"}},"category":"Sm"},{"key":"2A12","mappings":{"default":{"default":"integral lineal para rectángulo en polo"}},"category":"Sm"},{"key":"2A13","mappings":{"default":{"default":"integral lineal para semicírculo en polo"}},"category":"Sm"},{"key":"2A14","mappings":{"default":{"default":"integral lineal excluyendo el polo"}},"category":"Sm"},{"key":"2A15","mappings":{"default":{"default":"integral en torno de un punto operador"}},"category":"Sm"},{"key":"2A16","mappings":{"default":{"default":"operador integral para cuaterniones"}},"category":"Sm"},{"key":"2A22","mappings":{"default":{"default":"más con círculo"}},"category":"Sm"},{"key":"2A23","mappings":{"default":{"default":"más con ángulo"}},"category":"Sm"},{"key":"2A24","mappings":{"default":{"default":"tilde con más suscrito"}},"category":"Sm"},{"key":"2A25","mappings":{"default":{"default":"más con punto inferior"}},"category":"Sm"},{"key":"2A26","mappings":{"default":{"default":"tilde con más"}},"category":"Sm"},{"key":"2A27","mappings":{"default":{"default":"más con 2 suscrito"}},"category":"Sm"},{"key":"2A29","mappings":{"default":{"default":"menos con coma"}},"category":"Sm"},{"key":"2A2A","mappings":{"default":{"default":"menos con punto inferior"}},"category":"Sm"},{"key":"2A2D","mappings":{"default":{"default":"más en semicírculo izquierdo"}},"category":"Sm"},{"key":"2A2E","mappings":{"default":{"default":"más en semicírculo derecho"}},"category":"Sm"},{"key":"2A2F","mappings":{"default":{"default":"producto vectorial"}},"category":"Sm"},{"key":"2A30","mappings":{"default":{"default":"por con punto"}},"category":"Sm"},{"key":"2A31","mappings":{"default":{"default":"por con subrayado"}},"category":"Sm"},{"key":"2A33","mappings":{"default":{"default":"smash product"}},"category":"Sm"},{"key":"2A34","mappings":{"default":{"default":"por en semicírculo izquierdo"}},"category":"Sm"},{"key":"2A35","mappings":{"default":{"default":"por en semicírculo derecho"}},"category":"Sm"},{"key":"2A36","mappings":{"default":{"default":"por en círculo con ángulo"}},"category":"Sm"},{"key":"2A37","mappings":{"default":{"default":"por en anillo"}},"category":"Sm"},{"key":"2A38","mappings":{"default":{"default":"división en círculo"}},"category":"Sm"},{"key":"2A39","mappings":{"default":{"default":"más en triángulo"}},"category":"Sm"},{"key":"2A3A","mappings":{"default":{"default":"menos en triángulo"}},"category":"Sm"},{"key":"2A3B","mappings":{"default":{"default":"por en triángulo"}},"category":"Sm"},{"key":"2A3C","mappings":{"default":{"default":"producto interior"}},"category":"Sm"},{"key":"2A3F","mappings":{"default":{"default":"coproducto"}},"category":"Sm"},{"key":"2A40","mappings":{"default":{"default":"intersección con punto"}},"category":"Sm"},{"key":"2A42","mappings":{"default":{"default":"unión con barra"}},"category":"Sm"},{"key":"2A43","mappings":{"default":{"default":"intersección con barra"}},"category":"Sm"},{"key":"2A44","mappings":{"default":{"default":"intersección con and"}},"category":"Sm"},{"key":"2A45","mappings":{"default":{"default":"unión con or"}},"category":"Sm"},{"key":"2A46","mappings":{"default":{"default":"unión sobre intersección"}},"category":"Sm"},{"key":"2A47","mappings":{"default":{"default":"intersección sobre unión"}},"category":"Sm"},{"key":"2A48","mappings":{"default":{"default":"unión sobre barra, sobre intersección"}},"category":"Sm"},{"key":"2A49","mappings":{"default":{"default":"intersección sobre barra, sobre unión "}},"category":"Sm"},{"key":"2A4A","mappings":{"default":{"default":"unión y unión"}},"category":"Sm"},{"key":"2A4B","mappings":{"default":{"default":"intersección e intersección"}},"category":"Sm"},{"key":"2A4C","mappings":{"default":{"default":"unión cerrada"}},"category":"Sm"},{"key":"2A4D","mappings":{"default":{"default":"intersección cerrada"}},"category":"Sm"},{"key":"2A50","mappings":{"default":{"default":"unión cerrada con por"}},"category":"Sm"},{"key":"2A53","mappings":{"default":{"default":"y"}},"category":"Sm"},{"key":"2A54","mappings":{"default":{"default":"o"}},"category":"Sm"},{"key":"2A55","mappings":{"default":{"default":"two intersecting logical and"}},"category":"Sm"},{"key":"2A56","mappings":{"default":{"default":"two intersecting logical or"}},"category":"Sm"},{"key":"2A57","mappings":{"default":{"default":"sloping large or"}},"category":"Sm"},{"key":"2A58","mappings":{"default":{"default":"sloping large and"}},"category":"Sm"},{"key":"2A5A","mappings":{"default":{"default":"logical and with middle stem"}},"category":"Sm"},{"key":"2A5B","mappings":{"default":{"default":"logical or with middle stem"}},"category":"Sm"},{"key":"2A5C","mappings":{"default":{"default":"logical and with horizontal dash"}},"category":"Sm"},{"key":"2A5D","mappings":{"default":{"default":"logical or with horizontal dash"}},"category":"Sm"},{"key":"2A5F","mappings":{"default":{"default":"logical and with underbar"}},"category":"Sm"},{"key":"2A66","mappings":{"default":{"default":"igual con punto suscrito"}},"category":"Sm"},{"key":"2A6A","mappings":{"default":{"default":"tilde con punto"}},"category":"Sm"},{"key":"2A6D","mappings":{"default":{"default":"congruente con punto"}},"category":"Sm"},{"key":"2A6F","mappings":{"default":{"default":"casi igual con ángulo"}},"category":"Sm"},{"key":"2A71","mappings":{"default":{"default":"igual con más suscrito"}},"category":"Sm"},{"key":"2A72","mappings":{"default":{"default":"igual con más"}},"category":"Sm"},{"key":"2A73","mappings":{"default":{"default":"igual con operador tilde"}},"category":"Sm"},{"key":"2A74","mappings":{"default":{"default":"igual con dos puntos"}},"category":"Sm"},{"key":"2A75","mappings":{"default":{"default":"igual doble"}},"category":"Sm"},{"key":"2A77","mappings":{"default":{"default":"igual entre cuatro puntos"}},"category":"Sm"},{"key":"2A78","mappings":{"default":{"default":"equivalente con cuatro puntos"}},"category":"Sm"},{"key":"2A79","mappings":{"default":{"default":"menor que con círculo interior"}},"category":"Sm"},{"key":"2A7A","mappings":{"default":{"default":"mayor que con círculo interior"}},"category":"Sm"},{"key":"2A7B","mappings":{"default":{"default":"menor que con interrogante"}},"category":"Sm"},{"key":"2A7C","mappings":{"default":{"default":"mayor que con interrogante"}},"category":"Sm"},{"key":"2A7D","mappings":{"default":{"default":"estrictamente menor que"}},"category":"Sm"},{"key":"2A7E","mappings":{"default":{"default":"estrictamente mayor que"}},"category":"Sm"},{"key":"2A7F","mappings":{"default":{"default":"estrictamente menor que con punto interior"}},"category":"Sm"},{"key":"2A80","mappings":{"default":{"default":"estrictamente mayor que con punto interior"}},"category":"Sm"},{"key":"2A81","mappings":{"default":{"default":"estrictamente menor que con punto"}},"category":"Sm"},{"key":"2A82","mappings":{"default":{"default":"estrictamente mayor que con punto"}},"category":"Sm"},{"key":"2A83","mappings":{"default":{"default":"estrictamente menor que con punto"}},"category":"Sm"},{"key":"2A84","mappings":{"default":{"default":"estrictamente mayor que con punto"}},"category":"Sm"},{"key":"2A89","mappings":{"default":{"default":"menor que, pero no aproximado a"}},"category":"Sm"},{"key":"2A8A","mappings":{"default":{"default":"mayor que, pero no aproximado a"}},"category":"Sm"},{"key":"2A8D","mappings":{"default":{"default":"menor, similar o igual a"}},"category":"Sm"},{"key":"2A8E","mappings":{"default":{"default":"mayor, similar o igual a"}},"category":"Sm"},{"key":"2A8F","mappings":{"default":{"default":"menor, similar o mayor que"}},"category":"Sm"},{"key":"2A90","mappings":{"default":{"default":"mayor, similar o menor que"}},"category":"Sm"},{"key":"2A91","mappings":{"default":{"default":"menor, mayor o igual a"}},"category":"Sm"},{"key":"2A92","mappings":{"default":{"default":"mayor, menor o igual a"}},"category":"Sm"},{"key":"2A93","mappings":{"default":{"default":"estrictamente menor o mayor que"}},"category":"Sm"},{"key":"2A94","mappings":{"default":{"default":"estrictamente mayor o menor que"}},"category":"Sm"},{"key":"2A97","mappings":{"default":{"default":"estrictamente menor que con punto interior"}},"category":"Sm"},{"key":"2A98","mappings":{"default":{"default":"estrictamente mayor que con punto interior"}},"category":"Sm"},{"key":"2A99","mappings":{"default":{"default":"menor o igual a"}},"category":"Sm"},{"key":"2A9A","mappings":{"default":{"default":"mayor o igual a"}},"category":"Sm"},{"key":"2A9D","mappings":{"default":{"default":"equivalente o menor que"}},"category":"Sm"},{"key":"2A9E","mappings":{"default":{"default":"mayor o similar a"}},"category":"Sm"},{"key":"2A9F","mappings":{"default":{"default":"similar, menor o igual a"}},"category":"Sm"},{"key":"2AA0","mappings":{"default":{"default":"similar, mayor o igual a"}},"category":"Sm"},{"key":"2AA1","mappings":{"default":{"default":"mucho menor que"}},"category":"Sm"},{"key":"2AA2","mappings":{"default":{"default":"mucho mayor que"}},"category":"Sm"},{"key":"2AA4","mappings":{"default":{"default":"menor que, mayor que"}},"category":"Sm"},{"key":"2AA5","mappings":{"default":{"default":"mayor o menor que"}},"category":"Sm"},{"key":"2AA6","mappings":{"default":{"default":"menor que cerrado con curva"}},"category":"Sm"},{"key":"2AA7","mappings":{"default":{"default":"mayor que cerrado con curva"}},"category":"Sm"},{"key":"2AA8","mappings":{"default":{"default":"estrictamente menor que cerrado con curva"}},"category":"Sm"},{"key":"2AA9","mappings":{"default":{"default":"estrictamente mayor que cerrado con curva"}},"category":"Sm"},{"key":"2AAA","mappings":{"default":{"default":"más reducido que"}},"category":"Sm"},{"key":"2AAB","mappings":{"default":{"default":"más amplio que"}},"category":"Sm"},{"key":"2AAC","mappings":{"default":{"default":"más reducido o igual a"}},"category":"Sm"},{"key":"2AAD","mappings":{"default":{"default":"más amplio o igual a"}},"category":"Sm"},{"key":"2AAE","mappings":{"default":{"default":"diferencia entre"}},"category":"Sm"},{"key":"2AAF","mappings":{"default":{"default":"precede o es igual a"}},"category":"Sm"},{"key":"2AB5","mappings":{"default":{"default":"precede estrictamente a"}},"category":"Sm"},{"key":"2AB6","mappings":{"default":{"default":"sigue estrictamente a"}},"category":"Sm"},{"key":"2ABB","mappings":{"default":{"default":"precede mucho antes"}},"category":"Sm"},{"key":"2ABC","mappings":{"default":{"default":"sigue mucho después"}},"category":"Sm"},{"key":"2ABD","mappings":{"default":{"default":"subrelación de"}},"category":"Sm"},{"key":"2ABE","mappings":{"default":{"default":"contiene como subrelación a"}},"category":"Sm"},{"key":"2ABF","mappings":{"default":{"default":"incluido con más suscrito"}},"category":"Sm"},{"key":"2AC0","mappings":{"default":{"default":"contiene con más suscrito"}},"category":"Sm"},{"key":"2AC1","mappings":{"default":{"default":"incluido con por suscrito"}},"category":"Sm"},{"key":"2AC2","mappings":{"default":{"default":"contiene con por suscrito"}},"category":"Sm"},{"key":"2AC3","mappings":{"default":{"default":"incluido con punto o es igual a"}},"category":"Sm"},{"key":"2AC4","mappings":{"default":{"default":"contiene con punto o es igual a"}},"category":"Sm"},{"key":"2AC7","mappings":{"default":{"default":"incluido aproximadamente en"}},"category":"Sm"},{"key":"2AC8","mappings":{"default":{"default":"contiene aproximadamente a"}},"category":"Sm"},{"key":"2ACF","mappings":{"default":{"default":"incluido con cierre en"}},"category":"Sm"},{"key":"2AD0","mappings":{"default":{"default":"contiene al cierre del subconjunto"}},"category":"Sm"},{"key":"2AD1","mappings":{"default":{"default":"incluido el cierre o es igual a"}},"category":"Sm"},{"key":"2AD2","mappings":{"default":{"default":"contiene al cierre del subconjunto o es igual a"}},"category":"Sm"},{"key":"2AD3","mappings":{"default":{"default":"está incluido o contiene a"}},"category":"Sm"},{"key":"2AD4","mappings":{"default":{"default":"contiene o está incluido en"}},"category":"Sm"},{"key":"2AD5","mappings":{"default":{"default":"incluido doblemente en"}},"category":"Sm"},{"key":"2AD6","mappings":{"default":{"default":"contiene doblemente a"}},"category":"Sm"},{"key":"2AD7","mappings":{"default":{"default":"contiene o está incluido en"}},"category":"Sm"},{"key":"2AD8","mappings":{"default":{"default":"contiene o está incluido en"}},"category":"Sm"},{"key":"2AD9","mappings":{"default":{"default":"perteneciente dirigido hacia abajo"}},"category":"Sm"},{"key":"2ADA","mappings":{"default":{"default":"pitchfork with tee top"}},"category":"Sm"},{"key":"2ADB","mappings":{"default":{"default":"transversal intersection"}},"category":"Sm"},{"key":"2AE4","mappings":{"default":{"default":"double left turnstile vertical bar"}},"category":"Sm"},{"key":"2AE6","mappings":{"default":{"default":"long dash from left member of double vertical"}},"category":"Sm"},{"key":"2AE7","mappings":{"default":{"default":"short down tack with overbar"}},"category":"Sm"},{"key":"2AE8","mappings":{"default":{"default":"barra con perpendicular"}},"category":"Sm"},{"key":"2AE9","mappings":{"default":{"default":"short up tack above short down tack"}},"category":"Sm"},{"key":"2AEB","mappings":{"default":{"default":"double up tack"}},"category":"Sm"},{"key":"2AEC","mappings":{"default":{"default":"double stroke not sign"}},"category":"Sm"},{"key":"2AED","mappings":{"default":{"default":"reversed double stroke not sign"}},"category":"Sm"},{"key":"2AEE","mappings":{"default":{"default":"does not divide with reversed negation slash"}},"category":"Sm"},{"key":"2AEF","mappings":{"default":{"default":"barra vertical con círculo"}},"category":"Sm"},{"key":"2AF0","mappings":{"default":{"default":"barra con círculo inferior"}},"category":"Sm"},{"key":"2AF1","mappings":{"default":{"default":"down tack with circle below"}},"category":"Sm"},{"key":"2AF2","mappings":{"default":{"default":"paralela con marca"}},"category":"Sm"},{"key":"2AF3","mappings":{"default":{"default":"paralela con tilde"}},"category":"Sm"},{"key":"FE68","mappings":{"default":{"default":"división entera"}},"category":"Po"},{"key":"FF5C","mappings":{"default":{"default":"barra vertical"}},"category":"Sm"}]
,
"es/math_whitespace.js": 
[{"locale":"es"},{"key":"00A0","mappings":{"default":{"default":" "}},"category":"Zs"},{"key":"00AD","mappings":{"default":{"default":"guión corto"}},"category":"Cf"},{"key":"2002","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2003","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2004","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2005","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2007","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2008","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2009","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"200A","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"200B","mappings":{"default":{"default":""}},"category":"Cf"},{"key":"200C","mappings":{"default":{"default":"ancho de cero no ensamblador"}},"category":"Cf"},{"key":"200D","mappings":{"default":{"default":"ancho de cero ensamblador"}},"category":"Cf"},{"key":"200E","mappings":{"default":{"default":"marca de izquierda a derecha"}},"category":"Cf"},{"key":"200F","mappings":{"default":{"default":"marca de derecha a izquierda"}},"category":"Cf"},{"key":"205F","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2060","mappings":{"default":{"default":""}},"category":"Cf"},{"key":"2061","mappings":{"default":{"default":"de"}},"category":"Cf"},{"key":"2062","mappings":{"default":{"default":"por"}},"category":"Cf"},{"key":"2063","mappings":{"default":{"default":"coma"}},"category":"Cf"},{"key":"2064","mappings":{"default":{"default":"más"}},"category":"Cf"},{"key":"FEFF","mappings":{"default":{"default":""}},"category":"Cf"}]
,
"es/other_stars.js": 
[{"locale":"es"},{"key":"2605","mappings":{"default":{"default":"estrella rellena"}},"category":"So"},{"key":"2606","mappings":{"default":{"default":"estrella vacía"}},"category":"So"},{"key":"2713","mappings":{"default":{"default":"check mark"}},"category":"So"},{"key":"2717","mappings":{"default":{"default":"ballot x"}},"category":"So"},{"key":"2720","mappings":{"default":{"default":"cruz de Malta"}},"category":"So"},{"key":"2736","mappings":{"default":{"default":"estrella rellena de seis puntas"}},"category":"So"},{"key":"273D","mappings":{"default":{"default":"heavy teardrop spoked asterisk"}},"category":"So"}]
,
"es/energy.js": 
[{"locale":"es"},{"key":"W","names":["W","w"],"mappings":{"default":{"default":"watt"}},"category":"energy"},{"key":"kW","names":["kw","kW"],"mappings":{"default":{"default":"kilowatt"}},"category":"energy"},{"key":"mW","names":["mw","mW"],"mappings":{"default":{"default":"miliwatt"}},"category":"energy"},{"key":"kwh","names":["kwh","kWh"],"mappings":{"default":{"default":"kilowatt hora"}},"category":"energy"},{"key":"J","names":["J"],"mappings":{"default":{"default":"Joules"}},"category":"energy"},{"key":"N","names":["N"],"mappings":{"default":{"default":"Newton"}},"category":"energy"},{"key":"A","names":["A"],"mappings":{"default":{"default":"Ampere"}},"category":"energy"},{"key":"V","names":["V"],"mappings":{"default":{"default":"Voltio"}},"category":"energy"},{"key":"µΩ","names":["µΩ"],"mappings":{"default":{"default":"microohmio"}},"category":"energy"},{"key":"mΩ","names":["mΩ"],"mappings":{"default":{"default":"miliohmio"}},"category":"energy"},{"key":"Ω","names":["Ω","Ohm"],"mappings":{"default":{"default":"ohmio"}},"category":"energy"},{"key":"kΩ","names":["kΩ","KΩ"],"mappings":{"default":{"default":"kiloohmio"}},"category":"energy"},{"key":"MΩ","names":["MΩ"],"mappings":{"default":{"default":"megaohmio"}},"category":"energy"},{"key":"GΩ","names":["GΩ"],"mappings":{"default":{"default":"gigaohmio"}},"category":"energy"}]
,
"es/length.js": 
[{"locale":"es"},{"key":"mm","names":["mm"],"mappings":{"default":{"default":"milímetro"}},"category":"Length"},{"key":"cm","names":["cm"],"mappings":{"default":{"default":"centímetro"}},"category":"Length"},{"key":"m","names":["m"],"mappings":{"default":{"default":"metro"}},"category":"Length"},{"key":"km","names":["km"],"mappings":{"default":{"default":"kilómetro"}},"category":"Length"},{"key":"ft","names":["ft","ft."],"mappings":{"default":{"default":"pies"}},"category":"Length"},{"key":"in","names":["in","in."],"mappings":{"default":{"default":"pulgada"}},"category":"Length"},{"key":"mi","names":["mi","mi."],"mappings":{"default":{"default":"milla"}},"category":"Length"},{"key":"yd","names":["yd","yd."],"mappings":{"default":{"default":"yarda"}},"category":"Length"},{"key":"n.m.","names":["n.m."],"mappings":{"default":{"default":"millas náuticas"}}}]
,
"es/memory.js": 
[{"locale":"es"},{"key":"b","names":["b"],"mappings":{"default":{"default":"bit"}}},{"key":"B","names":["B"],"mappings":{"default":{"default":"byte"}}},{"key":"KB","names":["KB"],"mappings":{"default":{"default":"kilobyte"}}},{"key":"MB","names":["MB"],"mappings":{"default":{"default":"megabyte"}}},{"key":"GB","names":["GB"],"mappings":{"default":{"default":"gigabyte"}}},{"key":"TB","names":["TB"],"mappings":{"default":{"default":"terabyte"}}}]
,
"es/other.js": 
[{"locale":"es"},{"key":"doz","names":["doz","doz.","dz","dz."],"mappings":{"default":{"default":"docena"}}},{"key":"sq","names":["sq","sq."],"mappings":{"default":{"default":"al cuadrado"}}},{"key":"ha","names":["ha"],"mappings":{"default":{"default":"hectarea"}}}]
,
"es/speed.js": 
[{"locale":"es"},{"key":"kt","names":["kt","kt."],"mappings":{"default":{"default":"nudo"}}},{"key":"mph","names":["mph"],"mappings":{"default":{"default":"millas por hora"}}},{"key":"rpm","names":["rpm"],"mappings":{"default":{"default":"revoluciones por minuto"}}},{"key":"kmh","names":["kmh"],"mappings":{"default":{"default":"kilómetros por hora"}}}]
,
"es/temperature.js": 
[{"locale":"es"},{"key":"F","names":["F","F.","°F"],"mappings":{"default":{"default":"Fahrenheit"}}},{"key":"C","names":["C","°C"],"mappings":{"default":{"default":"centígrados"}}},{"key":"K","names":["K","°K"],"mappings":{"default":{"default":"Kelvin"}}}]
,
"es/time.js": 
[{"locale":"es"},{"key":"ns","names":["ns"],"mappings":{"default":{"default":"nanosegundos"}},"category":"time"},{"key":"µs","names":["µs"],"mappings":{"default":{"default":"microsegundos"}},"category":"time"},{"key":"ms","names":["ms"],"mappings":{"default":{"default":"milisegundos"}},"category":"time"},{"key":"s","names":["s"],"mappings":{"default":{"default":"segundos"}},"category":"time"},{"key":"min","names":["min"],"mappings":{"default":{"default":"minutos"}},"category":"time"},{"key":"h","names":["h","hr"],"mappings":{"default":{"default":"hora"}},"category":"time"}]
,
"es/volume.js": 
[{"locale":"es"},{"key":"bbl","names":["bbl.","bbl"],"mappings":{"default":{"default":"barrile"}},"category":"volume"},{"key":"cu","names":["cu","cu."],"mappings":{"default":{"default":"cúbico"}},"category":"volume"},{"key":"fl. oz.","names":["fl. oz."],"mappings":{"default":{"default":"onzas líquidas"}},"category":"volume"},{"key":"gal","names":["gal","gal."],"mappings":{"default":{"default":"galone"}},"category":"volume"},{"key":"pt","names":["pt","pt."],"mappings":{"default":{"default":"pinta"}},"category":"volume"},{"key":"qt","names":["qt","qt."],"mappings":{"default":{"default":"quart"}},"category":"volume"},{"key":"tbsp","names":["tbsp","tbsp."],"mappings":{"default":{"default":"cuchara"}},"category":"volume"},{"key":"tsp","names":["tsp","tsp."],"mappings":{"default":{"default":"cucharilla"}},"category":"volume"},{"key":"cc","names":["cc"],"mappings":{"default":{"default":"centímetros cúbicos"}},"category":"volume"},{"key":"kl","names":["kl"],"mappings":{"default":{"default":"kilolitro"}},"category":"volume"},{"key":"l","names":["l"],"mappings":{"default":{"default":"litro"}},"category":"volume"},{"key":"ml","names":["ml"],"mappings":{"default":{"default":"mililitro"}},"category":"volume"}]
,
"es/weight.js": 
[{"locale":"es"},{"key":"lb","names":["lb","lb."],"mappings":{"default":{"default":"libra"}}},{"key":"LT","names":["LT","L.T."],"mappings":{"default":{"default":"libras imperiales"}}},{"key":"oz","names":["oz","oz."],"mappings":{"default":{"default":"onza"}}},{"key":"µg","names":["µg","mcg"],"mappings":{"default":{"default":"microgramo"}}},{"key":"gr","names":["g","gr"],"mappings":{"default":{"default":"gramo"}}},{"key":"kg","names":["kg"],"mappings":{"default":{"default":"kilogramo"}}},{"key":"mg","names":["mg"],"mappings":{"default":{"default":"miligramo"}}},{"key":"t","names":["t","T"],"mappings":{"default":{"default":"tonelada"}}}]
}

